
/* vsdoc for goog.Disposable */

(function (window) {
    window.goog = window.goog || {};

    window.goog.Disposable = function(){
        /// <summary></summary>
        /// <field name="MonitoringMode" type=""></field>
        /// <field name="MONITORING_MODE" type=""></field>
        /// <field name="getDisposed" type="boolean"></field>
        /// <returns type="goog.Disposable"/>
    };

    var $x = window.goog.Disposable;
    $x.prototype = {
                
        getUndisposedObjects: function() {
            /// <summary></summary>
            /// <returns type="!Array.!goog.Disposable">All {@code goog.Disposable} objects that
            ///     haven&apos;t been disposed of.</returns>
        }, 
        
        clearUndisposedObjects: function() {
            /// <summary>Clears the registry of undisposed objects but doesn&apos;t dispose of them.</summary>
        }, 
        
        isDisposed: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the object has been disposed of.</returns>
        }, 
        
        dispose: function() {
            /// <summary>Disposes of the object. If the object hasn&apos;t already been disposed of, calls
            /// {@link #disposeInternal}. Classes that extend {@code goog.Disposable} should
            /// override {@link #disposeInternal} in order to delete references to COM
            /// objects, DOM nodes, and other disposable objects. Reentrant.</summary>
            /// <returns type="void">Nothing.</returns>
        }, 
        
        registerDisposable: function(disposable) {
            /// <summary>Associates a disposable object with this object so that they will be disposed
            /// together.</summary>
            /// <param name="disposable" type="goog.disposable.IDisposable">that will be disposed when
            ///     this object is disposed.</param>
        }, 
        
        addOnDisposeCallback: function(callback, opt_scope) {
            /// <summary>Invokes a callback function when this object is disposed. Callbacks are
            /// invoked in the order in which they were added.</summary>
            /// <param name="callback" type="!Function">The callback function.</param>
            /// <param name="opt_scope" type="Object=">An optional scope to call the callback in.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary>Deletes or nulls out any references to COM objects, DOM nodes, or other
            /// disposable objects. Classes that extend {@code goog.Disposable} should
            /// override this method.
            /// Not reentrant. To avoid calling it twice, it must only be called from the
            /// subclass&apos; {@code disposeInternal} method. Everywhere else the public
            /// {@code dispose} method must be used.
            /// For example:
            /// &lt;pre&gt;
            ///   mypackage.MyClass = function() {
            ///     goog.base(this);
            ///     // Constructor logic specific to MyClass.
            ///     ...
            ///   };
            ///   goog.inherits(mypackage.MyClass, goog.Disposable);
            /// 
            ///   mypackage.MyClass.prototype.disposeInternal = function() {
            ///     // Dispose logic specific to MyClass.
            ///     ...
            ///     // Call superclass&apos;s disposeInternal at the end of the subclass&apos;s, like
            ///     // in C++, to avoid hard-to-catch issues.
            ///     goog.base(this, &apos;disposeInternal&apos;);
            ///   };
            /// &lt;/pre&gt;</summary>
        }, 
        
        isDisposed: function(obj) {
            /// <summary>Returns True if we can verify the object is disposed.
            /// Calls {@code isDisposed} on the argument if it supports it.  If obj
            /// is not an object with an isDisposed() method, return false.</summary>
            /// <param name="obj" type="*">The object to investigate.</param>
            /// <returns type="boolean">True if we can verify the object is disposed.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.Disposable";
})(this);
