
/* vsdoc for goog.History */

(function (window) {
    window.goog = window.goog || {};

    window.goog.History = function(opt_invisible, opt_blankPageUrl, opt_input, opt_iframe){
        /// <summary></summary>
        /// <param name="opt_invisible" type="boolean=">True to use hidden history states instead of
        ///     the user-visible location hash.</param>
        /// <param name="opt_blankPageUrl" type="string=">A URL to a blank page on the same server.
        ///     Required if opt_invisible is true.  This URL is also used as the src
        ///     for the iframe used to track history state in IE (if not specified the
        ///     iframe is not given a src attribute).  Access is Denied error may
        ///     occur in IE7 if the window&apos;s URL&apos;s scheme is https, and this URL is
        ///     not specified.</param>
        /// <param name="opt_input" type="HTMLInputElement=">The hidden input element to be used to
        ///     store the history token.  If not provided, a hidden input element will
        ///     be created using document.write.</param>
        /// <param name="opt_iframe" type="HTMLIFrameElement=">The hidden iframe that will be used by
        ///     IE for pushing history state changes, or by all browsers if opt_invisible
        ///     is true. If not provided, a hidden iframe element will be created using
        ///     document.write.</param>
        /// <field name="documentLoaded" type="boolean">IE-only variable for determining if the document has loaded.</field>
        /// <field name="HAS_ONHASHCHANGE" type="boolean">Whether the browser supports HTML5 history management.
        /// {@link http://www.w3.org/TR/html5/history.html}.</field>
        /// <field name="LEGACY_IE" type="boolean">Whether the current browser is Internet Explorer prior to version 8. Many IE
        /// specific workarounds developed before version 8 are unnecessary in more
        /// current versions.</field>
        /// <field name="HASH_ALWAYS_REQUIRED" type="boolean">Whether the browser always requires the hash to be present. Internet Explorer
        /// before version 8 will reload the HTML page if the hash is omitted.</field>
        /// <field name="PollingType" type="">Types of polling. The values are in ms of the polling interval.</field>
        /// <field name="EventType" type="">Constant for the history change event type.</field>
        /// <returns type="goog.History"/>
    };

    var $x = window.goog.History;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Starts or stops the History polling loop. When enabled, the History object
            /// will immediately fire an event for the current location. The caller can set
            /// up event listeners between the call to the constructor and the call to
            /// setEnabled.
            /// 
            /// On IE, actual startup may be delayed until the iframe and hidden input
            /// element have been loaded and can be polled. This behavior is transparent to
            /// the caller.</summary>
            /// <param name="enable" type="boolean">Whether to enable the history polling loop.</param>
        }, 
        
        onDocumentLoaded: function() {
            /// <summary>Callback for the window onload event in IE. This is necessary to read the
            /// value of the hidden input after restoring a history session. The value of
            /// input elements is not viewable until after window onload for some reason (the
            /// iframe state is similarly unavailable during the loading phase.)  If
            /// setEnabled is called before the iframe has completed loading, the history
            /// object will actually be enabled at this point.</summary>
        }, 
        
        getToken: function() {
            /// <summary></summary>
            /// <returns type="string">The current token.</returns>
        }, 
        
        setToken: function(token, opt_title) {
            /// <summary>Sets the history state. When user visible states are used, the URL fragment
            /// will be set to the provided token.  Sometimes it is necessary to set the
            /// history token before the document title has changed, in this case IE&apos;s
            /// history drop down can be out of sync with the token.  To get around this
            /// problem, the app can pass in a title to use with the hidden iframe.</summary>
            /// <param name="token" type="string">The history state identifier.</param>
            /// <param name="opt_title" type="string=">Optional title used when setting the hidden iframe
            ///     title in IE.</param>
        }, 
        
        replaceToken: function(token, opt_title) {
            /// <summary>Replaces the current history state without affecting the rest of the history
            /// stack.</summary>
            /// <param name="token" type="string">The history state identifier.</param>
            /// <param name="opt_title" type="string=">Optional title used when setting the hidden iframe
            ///     title in IE.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.History";
})(this);
