
/* vsdoc for goog.Timer */

(function (window) {
    window.goog = window.goog || {};

    window.goog.Timer = function(opt_interval, opt_timerObject){
        /// <summary></summary>
        /// <param name="opt_interval" type="number=">Number of ms between ticks (Default: 1ms).</param>
        /// <param name="opt_timerObject" type="Object=">An object that has setTimeout, setInterval,
        ///     clearTimeout and clearInterval (eg Window).</param>
        /// <field name="enabled" type="boolean">Whether this timer is enabled</field>
        /// <field name="defaultTimerObject" type="Object">An object that implements setTimout, setInterval, clearTimeout and
        /// clearInterval. We default to the window object. Changing this on
        /// goog.Timer.prototype changes the object for all timer instances which can be
        /// useful if your environment has some other implementation of timers than the
        /// window object.</field>
        /// <field name="intervalScale" type="number">A variable that controls the timer error correction. If the
        /// timer is called before the requested interval times
        /// intervalScale, which often happens on mozilla, the timer is
        /// rescheduled. See also this.last_</field>
        /// <field name="TICK" type="string">Constant for the timer&apos;s event type</field>
        /// <returns type="goog.Timer"/>
    };

    var $x = window.goog.Timer;
    $x.prototype = {
                
        getInterval: function() {
            /// <summary>Gets the interval of the timer.</summary>
            /// <returns type="number">interval Number of ms between ticks.</returns>
        }, 
        
        setInterval: function(interval) {
            /// <summary>Sets the interval of the timer.</summary>
            /// <param name="interval" type="number">Number of ms between ticks.</param>
        }, 
        
        dispatchTick: function() {
            /// <summary>Dispatches the TICK event. This is its own method so subclasses can override.</summary>
        }, 
        
        start: function() {
            /// <summary>Starts the timer.</summary>
        }, 
        
        stop: function() {
            /// <summary>Stops the timer.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        callOnce: function(listener, opt_delay, opt_handler) {
            /// <summary>Calls the given function once, after the optional pause.
            /// 
            /// The function is always called asynchronously, even if the delay is 0. This
            /// is a common trick to schedule a function to run after a batch of browser
            /// event processing.</summary>
            /// <param name="listener" type="Function">Function or object that has a handleEvent method.</param>
            /// <param name="opt_delay" type="number=">Milliseconds to wait; default is 0.</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
            /// <returns type="number">A handle to the timer ID.</returns>
        }, 
        
        clear: function(timerId) {
            /// <summary>Clears a timeout initiated by callOnce</summary>
            /// <param name="timerId" type="?number">a timer ID.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.Timer";
})(this);
