
/* vsdoc for goog.Uri */

(function (window) {
    window.goog = window.goog || {};

    window.goog.Uri = function(opt_uri, opt_ignoreCase){
        /// <summary></summary>
        /// <param name="opt_uri" type="*=">Optional string URI to parse
        ///        (use goog.Uri.create() to create a URI from parts), or if
        ///        a goog.Uri is passed, a clone is created.</param>
        /// <param name="opt_ignoreCase" type="boolean=">If true, #getParameterValue will ignore
        /// the case of the parameter name.</param>
        /// <field name="preserveParameterTypesCompatibilityFlag" type="boolean">If true, we preserve the type of query parameters set programmatically.
        /// 
        /// This means that if you set a parameter to a boolean, and then call
        /// getParameterValue, you will get a boolean back.
        /// 
        /// If false, we will coerce parameters to strings, just as they would
        /// appear in real URIs.
        /// 
        /// TODO(nicksantos): Remove this once people have time to fix all tests.</field>
        /// <field name="RANDOM_PARAM" type="string">Parameter name added to stop caching.</field>
        /// <returns type="goog.Uri"/>
    };

    var $x = window.goog.Uri;
    $x.prototype = {
                
        toString: function() {
            /// <summary></summary>
            /// <returns type="string">The string form of the url.</returns>
        }, 
        
        resolve: function(relativeUri) {
            /// <summary>Resolves a relative url string to a this base uri.
            /// 
            /// There are several kinds of relative urls:<br>
            /// 1. foo - replaces the last part of the path, the whole query and fragment<br>
            /// 2. /foo - replaces the the path, the query and fragment<br>
            /// 3. //foo - replaces everything from the domain on.  foo is a domain name<br>
            /// 4. ?foo - replace the query and fragment<br>
            /// 5. #foo - replace the fragment only
            /// 
            /// Additionally, if relative url has a non-empty path, all &quot;..&quot; and &quot;.&quot;
            /// segments will be resolved, as described in RFC 3986.</summary>
            /// <param name="relativeUri" type="goog.Uri">The relative url to resolve.</param>
            /// <returns type="!goog.Uri">The resolved URI.</returns>
        }, 
        
        clone: function() {
            /// <summary>Clones the URI instance.</summary>
            /// <returns type="!goog.Uri">New instance of the URI objcet.</returns>
        }, 
        
        getScheme: function() {
            /// <summary></summary>
            /// <returns type="string">The encoded scheme/protocol for the URI.</returns>
        }, 
        
        setScheme: function(newScheme, opt_decode) {
            /// <summary>Sets the scheme/protocol.</summary>
            /// <param name="newScheme" type="string">New scheme value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasScheme: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the scheme has been set.</returns>
        }, 
        
        getUserInfo: function() {
            /// <summary></summary>
            /// <returns type="string">The decoded user info.</returns>
        }, 
        
        setUserInfo: function(newUserInfo, opt_decode) {
            /// <summary>Sets the userInfo.</summary>
            /// <param name="newUserInfo" type="string">New userInfo value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasUserInfo: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the user info has been set.</returns>
        }, 
        
        getDomain: function() {
            /// <summary></summary>
            /// <returns type="string">The decoded domain.</returns>
        }, 
        
        setDomain: function(newDomain, opt_decode) {
            /// <summary>Sets the domain.</summary>
            /// <param name="newDomain" type="string">New domain value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasDomain: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the domain has been set.</returns>
        }, 
        
        getPort: function() {
            /// <summary></summary>
            /// <returns type="?number">The port number.</returns>
        }, 
        
        setPort: function(newPort) {
            /// <summary>Sets the port number.</summary>
            /// <param name="newPort" type="*">Port number. Will be explicitly casted to a number.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasPort: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the port has been set.</returns>
        }, 
        
        getPath: function() {
            /// <summary></summary>
            /// <returns type="string">The decoded path.</returns>
        }, 
        
        setPath: function(newPath, opt_decode) {
            /// <summary>Sets the path.</summary>
            /// <param name="newPath" type="string">New path value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasPath: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the path has been set.</returns>
        }, 
        
        hasQuery: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the query string has been set.</returns>
        }, 
        
        setQueryData: function(queryData, opt_decode) {
            /// <summary>Sets the query data.</summary>
            /// <param name="queryData" type="goog.Uri.QueryData|string|undefined">QueryData object.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.
            ///     Applies only if queryData is a string.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        setQuery: function(newQuery, opt_decode) {
            /// <summary>Sets the URI query.</summary>
            /// <param name="newQuery" type="string">New query value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        getEncodedQuery: function() {
            /// <summary></summary>
            /// <returns type="string">The encoded URI query, not including the ?.</returns>
        }, 
        
        getDecodedQuery: function() {
            /// <summary></summary>
            /// <returns type="string">The decoded URI query, not including the ?.</returns>
        }, 
        
        getQueryData: function() {
            /// <summary>Returns the query data.</summary>
            /// <returns type="goog.Uri.QueryData">QueryData object.</returns>
        }, 
        
        getQuery: function() {
            /// <summary></summary>
            /// <returns type="string">The encoded URI query, not including the ?.
            /// 
            /// Warning: This method, unlike other getter methods, returns encoded
            /// value, instead of decoded one.</returns>
        }, 
        
        setParameterValue: function(key, value) {
            /// <summary>Sets the value of the named query parameters, clearing previous values for
            /// that key.</summary>
            /// <param name="key" type="string">The parameter to set.</param>
            /// <param name="value" type="*">The new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        setParameterValues: function(key, values) {
            /// <summary>Sets the values of the named query parameters, clearing previous values for
            /// that key.  Not new values will currently be moved to the end of the query
            /// string.
            /// 
            /// So, &lt;code&gt;goog.Uri.parse(&apos;foo?a=b&amp;c=d&amp;e=f&apos;).setParameterValues(&apos;c&apos;, [&apos;new&apos;])
            /// &lt;/code&gt; yields &lt;tt&gt;foo?a=b&amp;e=f&amp;c=new&lt;/tt&gt;.&lt;/p&gt;</summary>
            /// <param name="key" type="string">The parameter to set.</param>
            /// <param name="values" type="*">The new values. If values is a single
            ///     string then it will be treated as the sole value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        getParameterValues: function(name) {
            /// <summary>Returns the value<b>s</b> for a given cgi parameter as a list of decoded
            /// query parameter values.</summary>
            /// <param name="name" type="string">The parameter to get values for.</param>
            /// <returns type="Array">The values for a given cgi parameter as a list of
            ///     decoded query parameter values.</returns>
        }, 
        
        getParameterValue: function(paramName) {
            /// <summary>Returns the first value for a given cgi parameter or undefined if the given
            /// parameter name does not appear in the query string.</summary>
            /// <param name="paramName" type="string">Unescaped parameter name.</param>
            /// <returns type="string|undefined">The first value for a given cgi parameter or
            ///     undefined if the given parameter name does not appear in the query
            ///     string.</returns>
        }, 
        
        getFragment: function() {
            /// <summary></summary>
            /// <returns type="string">The URI fragment, not including the #.</returns>
        }, 
        
        setFragment: function(newFragment, opt_decode) {
            /// <summary>Sets the URI fragment.</summary>
            /// <param name="newFragment" type="string">New fragment value.</param>
            /// <param name="opt_decode" type="boolean=">Optional param for whether to decode new value.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        hasFragment: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the URI has a fragment set.</returns>
        }, 
        
        hasSameDomainAs: function(uri2) {
            /// <summary>Returns true if this has the same domain as that of uri2.</summary>
            /// <param name="uri2" type="goog.Uri">The URI object to compare to.</param>
            /// <returns type="boolean">true if same domain; false otherwise.</returns>
        }, 
        
        makeUnique: function() {
            /// <summary>Adds a random parameter to the Uri.</summary>
            /// <returns type="!goog.Uri">Reference to this Uri object.</returns>
        }, 
        
        removeParameter: function(key) {
            /// <summary>Removes the named query parameter.</summary>
            /// <param name="key" type="string">The parameter to remove.</param>
            /// <returns type="!goog.Uri">Reference to this URI object.</returns>
        }, 
        
        setReadOnly: function(isReadOnly) {
            /// <summary>Sets whether Uri is read only. If this goog.Uri is read-only,
            /// enforceReadOnly_ will be called at the start of any function that may modify
            /// this Uri.</summary>
            /// <param name="isReadOnly" type="boolean">whether this goog.Uri should be read only.</param>
            /// <returns type="!goog.Uri">Reference to this Uri object.</returns>
        }, 
        
        isReadOnly: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the URI is read only.</returns>
        }, 
        
        enforceReadOnly: function() {
            /// <summary>Checks if this Uri has been marked as read only, and if so, throws an error.
            /// This should be called whenever any modifying function is called.</summary>
        }, 
        
        setIgnoreCase: function(ignoreCase) {
            /// <summary>Sets whether to ignore case.
            /// NOTE: If there are already key/value pairs in the QueryData, and
            /// ignoreCase_ is set to false, the keys will all be lower-cased.</summary>
            /// <param name="ignoreCase" type="boolean">whether this goog.Uri should ignore case.</param>
            /// <returns type="!goog.Uri">Reference to this Uri object.</returns>
        }, 
        
        getIgnoreCase: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether to ignore case.</returns>
        }, 
        
        parse: function(uri, opt_ignoreCase) {
            /// <summary>Creates a uri from the string form.  Basically an alias of new goog.Uri().
            /// If a Uri object is passed to parse then it will return a clone of the object.</summary>
            /// <param name="uri" type="*">Raw URI string or instance of Uri
            ///     object.</param>
            /// <param name="opt_ignoreCase" type="boolean=">Whether to ignore the case of parameter
            /// names in #getParameterValue.</param>
            /// <returns type="!goog.Uri">The new URI object.</returns>
        }, 
        
        create: function(opt_scheme, opt_userInfo, opt_domain, opt_port, opt_path, opt_query, opt_fragment, opt_ignoreCase) {
            /// <summary>Creates a new goog.Uri object from unencoded parts.</summary>
            /// <param name="opt_scheme" type="?string=">Scheme/protocol or full URI to parse.</param>
            /// <param name="opt_userInfo" type="?string=">username:password.</param>
            /// <param name="opt_domain" type="?string=">www.google.com.</param>
            /// <param name="opt_port" type="?number=">9830.</param>
            /// <param name="opt_path" type="?string=">/some/path/to/a/file.html.</param>
            /// <param name="opt_query" type="string|goog.Uri.QueryData=">a=1&amp;b=2.</param>
            /// <param name="opt_fragment" type="?string=">The fragment without the #.</param>
            /// <param name="opt_ignoreCase" type="boolean=">Whether to ignore parameter name case in
            ///     #getParameterValue.</param>
            /// <returns type="!goog.Uri">The new URI object.</returns>
        }, 
        
        resolve: function(base, rel) {
            /// <summary>Resolves a relative Uri against a base Uri, accepting both strings and
            /// Uri objects.</summary>
            /// <param name="base" type="*">Base Uri.</param>
            /// <param name="rel" type="*">Relative Uri.</param>
            /// <returns type="!goog.Uri">Resolved uri.</returns>
        }, 
        
        removeDotSegments: function(path) {
            /// <summary>Removes dot segments in given path component, as described in
            /// RFC 3986, section 5.2.4.</summary>
            /// <param name="path" type="string">A non-empty path component.</param>
            /// <returns type="string">Path component with removed dot segments.</returns>
        }, 
        
        haveSameDomain: function(uri1String, uri2String) {
            /// <summary>Checks whether two URIs have the same domain.</summary>
            /// <param name="uri1String" type="string">First URI string.</param>
            /// <param name="uri2String" type="string">Second URI string.</param>
            /// <returns type="boolean">true if the two URIs have the same domain; false otherwise.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.Uri";
})(this);
