
/* vsdoc for goog.Uri.QueryData */

(function (window) {
    window.goog.Uri = window.goog.Uri || {};

    window.goog.Uri.QueryData = function(opt_query, opt_uri, opt_ignoreCase){
        /// <summary></summary>
        /// <param name="opt_query" type="?string=">Optional encoded query string to parse into
        ///     the object.</param>
        /// <param name="opt_uri" type="goog.Uri=">Optional uri object that should have its
        ///     cache invalidated when this object updates. Deprecated -- this
        ///     is no longer required.</param>
        /// <param name="opt_ignoreCase" type="boolean=">If true, ignore the case of the parameter
        ///     name in #get.</param>
        /// <returns type="goog.Uri.QueryData"/>
    };

    var $x = window.goog.Uri.QueryData;
    $x.prototype = {
                
        createFromMap: function(map, opt_uri, opt_ignoreCase) {
            /// <summary>Creates a new query data instance from a map of names and values.</summary>
            /// <param name="map" type="!goog.structs.Map|!Object">Map of string parameter
            ///     names to parameter value. If parameter value is an array, it is
            ///     treated as if the key maps to each individual value in the
            ///     array.</param>
            /// <param name="opt_uri" type="goog.Uri=">URI object that should have its cache
            ///     invalidated when this object updates.</param>
            /// <param name="opt_ignoreCase" type="boolean=">If true, ignore the case of the parameter
            ///     name in #get.</param>
            /// <returns type="!goog.Uri.QueryData">The populated query data instance.</returns>
        }, 
        
        createFromKeysValues: function(keys, values, opt_uri, opt_ignoreCase) {
            /// <summary>Creates a new query data instance from parallel arrays of parameter names
            /// and values. Allows for duplicate parameter names. Throws an error if the
            /// lengths of the arrays differ.</summary>
            /// <param name="keys" type="Array.string">Parameter names.</param>
            /// <param name="values" type="Array">Parameter values.</param>
            /// <param name="opt_uri" type="goog.Uri=">URI object that should have its cache
            ///     invalidated when this object updates.</param>
            /// <param name="opt_ignoreCase" type="boolean=">If true, ignore the case of the parameter
            ///     name in #get.</param>
            /// <returns type="!goog.Uri.QueryData">The populated query data instance.</returns>
        }, 
        
        getCount: function() {
            /// <summary></summary>
            /// <returns type="?number">The number of parameters.</returns>
        }, 
        
        add: function(key, value) {
            /// <summary>Adds a key value pair.</summary>
            /// <param name="key" type="string">Name.</param>
            /// <param name="value" type="*">Value.</param>
            /// <returns type="!goog.Uri.QueryData">Instance of this object.</returns>
        }, 
        
        remove: function(key) {
            /// <summary>Removes all the params with the given key.</summary>
            /// <param name="key" type="string">Name.</param>
            /// <returns type="boolean">Whether any parameter was removed.</returns>
        }, 
        
        clear: function() {
            /// <summary>Clears the parameters.</summary>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether we have any parameters.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary>Whether there is a parameter with the given name</summary>
            /// <param name="key" type="string">The parameter name to check for.</param>
            /// <returns type="boolean">Whether there is a parameter with the given name.</returns>
        }, 
        
        containsValue: function(value) {
            /// <summary>Whether there is a parameter with the given value.</summary>
            /// <param name="value" type="*">The value to check for.</param>
            /// <returns type="boolean">Whether there is a parameter with the given value.</returns>
        }, 
        
        getKeys: function() {
            /// <summary>Returns all the keys of the parameters. If a key is used multiple times
            /// it will be included multiple times in the returned array</summary>
            /// <returns type="!Array">All the keys of the parameters.</returns>
        }, 
        
        getValues: function(opt_key) {
            /// <summary>Returns all the values of the parameters with the given name. If the query
            /// data has no such key this will return an empty array. If no key is given
            /// all values wil be returned.</summary>
            /// <param name="opt_key" type="string=">The name of the parameter to get the values for.</param>
            /// <returns type="!Array">All the values of the parameters with the given name.</returns>
        }, 
        
        set: function(key, value) {
            /// <summary>Sets a key value pair and removes all other keys with the same value.</summary>
            /// <param name="key" type="string">Name.</param>
            /// <param name="value" type="*">Value.</param>
            /// <returns type="!goog.Uri.QueryData">Instance of this object.</returns>
        }, 
        
        get: function(key, opt_default) {
            /// <summary>Returns the first value associated with the key. If the query data has no
            /// such key this will return undefined or the optional default.</summary>
            /// <param name="key" type="string">The name of the parameter to get the value for.</param>
            /// <param name="opt_default" type="*=">The default value to return if the query data
            ///     has no such key.</param>
            /// <returns type="*">The first string value associated with the key, or opt_default
            ///     if there&apos;s no value.</returns>
        }, 
        
        setValues: function(key, values) {
            /// <summary>Sets the values for a key. If the key already exists, this will
            /// override all of the existing values that correspond to the key.</summary>
            /// <param name="key" type="string">The key to set values for.</param>
            /// <param name="values" type="Array">The values to set.</param>
        }, 
        
        toString: function() {
            /// <summary></summary>
            /// <returns type="string">Encoded query string.</returns>
        }, 
        
        toDecodedString: function() {
            /// <summary></summary>
            /// <returns type="string">Decoded query string.</returns>
        }, 
        
        filterKeys: function(keys) {
            /// <summary>Removes all keys that are not in the provided list. (Modifies this object.)</summary>
            /// <param name="keys" type="Array.string">The desired keys.</param>
            /// <returns type="!goog.Uri.QueryData">a reference to this object.</returns>
        }, 
        
        clone: function() {
            /// <summary>Clone the query data instance.</summary>
            /// <returns type="!goog.Uri.QueryData">New instance of the QueryData object.</returns>
        }, 
        
        setIgnoreCase: function(ignoreCase) {
            /// <summary>Ignore case in parameter names.
            /// NOTE: If there are already key/value pairs in the QueryData, and
            /// ignoreCase_ is set to false, the keys will all be lower-cased.</summary>
            /// <param name="ignoreCase" type="boolean">whether this goog.Uri should ignore case.</param>
        }, 
        
        extend: function(var_args) {
            /// <summary>Extends a query data object with another query data or map like object. This
            /// operates &apos;in-place&apos;, it does not create a new QueryData object.</summary>
            /// <param name="var_args" type="...(goog.Uri.QueryData|goog.structs.Map|Object)">The object
            ///     from which key value pairs will be copied.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.Uri.QueryData";
})(this);
