
/* vsdoc for goog.array */

(function (window) {
    window.goog = window.goog || {};

    window.goog.array = {
        /// <summary></summary>
        /// <field name="ArrayLike" type=""></field>
        /// <field name="indexOf" type="number">Returns the index of the first element of an array with a specified
        /// value, or -1 if the element is not present in the array.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-indexof}</field>
        /// <field name="lastIndexOf" type="number">Returns the index of the last element of an array with a specified value, or
        /// -1 if the element is not present in the array.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-lastindexof}</field>
        /// <field name="forEach" type="">Calls a function for each element in an array.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-foreach}</field>
        /// <field name="filter" type="!Array">Calls a function for each element in an array, and if the function returns
        /// true adds the element to a new array.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-filter}</field>
        /// <field name="map" type="!Array">Calls a function for each element in an array and inserts the result into a
        /// new array.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-map}</field>
        /// <field name="some" type="boolean">Calls f for each element of an array. If any call returns true, some()
        /// returns true (without checking the remaining elements). If all calls
        /// return false, some() returns false.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-some}</field>
        /// <field name="every" type="boolean">Call f for each element of an array. If all calls return true, every()
        /// returns true. If any call returns false, every() returns false and
        /// does not continue to check the remaining elements.
        /// 
        /// See {@link http://tinyurl.com/developer-mozilla-org-array-every}</field>
        /// <field name="clone" type="!Array">Does a shallow copy of an array.</field>
        /// <returns type="goog.array"/>
                
        peek: function(array) {
            /// <summary>Returns the last element in an array without removing it.</summary>
            /// <param name="array" type="goog.array.ArrayLike">The array.</param>
            /// <returns type="*">Last item in array.</returns>
        }, 
        
        forEachRight: function(arr, f, opt_obj) {
            /// <summary>Calls a function for each element in an array, starting from the last
            /// element rather than the first.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this: S|T|number|?): ?">The function to call for every
            ///     element. This function
            ///     takes 3 arguments (the element, the index and the array). The return
            ///     value is ignored.</param>
            /// <param name="opt_obj" type="S=">The object to be used as the value of &apos;this&apos;
            ///     within f.</param>
        }, 
        
        reduce: function(arr, f, val, opt_obj) {
            /// <summary>Passes every element of an array into a function and accumulates the result.
            /// 
            /// See {@link http://tinyurl.com/developer-mozilla-org-array-reduce}
            /// 
            /// For example:
            /// var a = [1, 2, 3, 4];
            /// goog.array.reduce(a, function(r, v, i, arr) {return r + v;}, 0);
            /// returns 10</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|R|T|number|?) : R">The function to call for
            ///     every element. This function
            ///     takes 4 arguments (the function&apos;s previous result or the initial value,
            ///     the value of the current array element, the current array index, and the
            ///     array itself)
            ///     function(previousValue, currentValue, index, array).</param>
            /// <param name="val" type="?">The initial value to pass into the function on the first call.</param>
            /// <param name="opt_obj" type="S=">The object to be used as the value of &apos;this&apos;
            ///     within f.</param>
            /// <returns type="R">Result of evaluating f repeatedly across the values of the array.</returns>
        }, 
        
        reduceRight: function(arr, f, val, opt_obj) {
            /// <summary>Passes every element of an array into a function and accumulates the result,
            /// starting from the last element and working towards the first.
            /// 
            /// See {@link http://tinyurl.com/developer-mozilla-org-array-reduceright}
            /// 
            /// For example:
            /// var a = [&apos;a&apos;, &apos;b&apos;, &apos;c&apos;];
            /// goog.array.reduceRight(a, function(r, v, i, arr) {return r + v;}, &apos;&apos;);
            /// returns &apos;cba&apos;</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|R|T|number|?) : R">The function to call for
            ///     every element. This function
            ///     takes 4 arguments (the function&apos;s previous result or the initial value,
            ///     the value of the current array element, the current array index, and the
            ///     array itself)
            ///     function(previousValue, currentValue, index, array).</param>
            /// <param name="val" type="?">The initial value to pass into the function on the first call.</param>
            /// <param name="opt_obj" type="S=">The object to be used as the value of &apos;this&apos;
            ///     within f.</param>
            /// <returns type="R">Object returned as a result of evaluating f repeatedly across the
            ///     values of the array.</returns>
        }, 
        
        find: function(arr, f, opt_obj) {
            /// <summary>Search an array for the first element that satisfies a given condition and
            /// return that element.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|T|number|?) : boolean">The function to call
            ///     for every element. This function takes 3 arguments (the element, the
            ///     index and the array) and should return a boolean.</param>
            /// <param name="opt_obj" type="S=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="T">The first array element that passes the test, or null if no
            ///     element is found.</returns>
        }, 
        
        findIndex: function(arr, f, opt_obj) {
            /// <summary>Search an array for the first element that satisfies a given condition and
            /// return its index.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|T|number|?) : boolean">The function to call for
            ///     every element. This function
            ///     takes 3 arguments (the element, the index and the array) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="S=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="number">The index of the first array element that passes the test,
            ///     or -1 if no element is found.</returns>
        }, 
        
        findRight: function(arr, f, opt_obj) {
            /// <summary>Search an array (in reverse order) for the last element that satisfies a
            /// given condition and return that element.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|T|number|?) : boolean">The function to call
            ///     for every element. This function
            ///     takes 3 arguments (the element, the index and the array) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="S=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="T">The last array element that passes the test, or null if no
            ///     element is found.</returns>
        }, 
        
        findIndexRight: function(arr, f, opt_obj) {
            /// <summary>Search an array (in reverse order) for the last element that satisfies a
            /// given condition and return its index.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|T|number|?) : boolean">The function to call
            ///     for every element. This function
            ///     takes 3 arguments (the element, the index and the array) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="number">The index of the last array element that passes the test,
            ///     or -1 if no element is found.</returns>
        }, 
        
        contains: function(arr, obj) {
            /// <summary>Whether the array contains the given object.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to test for the presence of the
            ///     element.</param>
            /// <param name="obj" type="*">The object for which to test.</param>
            /// <returns type="boolean">true if obj is present.</returns>
        }, 
        
        isEmpty: function(arr) {
            /// <summary>Whether the array is empty.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to test.</param>
            /// <returns type="boolean">true if empty.</returns>
        }, 
        
        clear: function(arr) {
            /// <summary>Clears the array.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">Array or array like object to clear.</param>
        }, 
        
        insert: function(arr, obj) {
            /// <summary>Pushes an item into an array, if it&apos;s not already in the array.</summary>
            /// <param name="arr" type="Array.T">Array into which to insert the item.</param>
            /// <param name="obj" type="T">Value to add.</param>
        }, 
        
        insertAt: function(arr, obj, opt_i) {
            /// <summary>Inserts an object at the given index of the array.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to modify.</param>
            /// <param name="obj" type="*">The object to insert.</param>
            /// <param name="opt_i" type="number=">The index at which to insert the object. If omitted,
            ///      treated as 0. A negative index is counted from the end of the array.</param>
        }, 
        
        insertArrayAt: function(arr, elementsToAdd, opt_i) {
            /// <summary>Inserts at the given index of the array, all elements of another array.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to modify.</param>
            /// <param name="elementsToAdd" type="goog.array.ArrayLike">The array of elements to add.</param>
            /// <param name="opt_i" type="number=">The index at which to insert the object. If omitted,
            ///      treated as 0. A negative index is counted from the end of the array.</param>
        }, 
        
        insertBefore: function(arr, obj, opt_obj2) {
            /// <summary>Inserts an object into an array before a specified object.</summary>
            /// <param name="arr" type="Array.T">The array to modify.</param>
            /// <param name="obj" type="T">The object to insert.</param>
            /// <param name="opt_obj2" type="T=">The object before which obj should be inserted. If obj2
            ///     is omitted or not found, obj is inserted at the end of the array.</param>
        }, 
        
        remove: function(arr, obj) {
            /// <summary>Removes the first occurrence of a particular value from an array.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">Array from which to remove value.</param>
            /// <param name="obj" type="*">Object to remove.</param>
            /// <returns type="boolean">True if an element was removed.</returns>
        }, 
        
        removeAt: function(arr, i) {
            /// <summary>Removes from an array the element at index i</summary>
            /// <param name="arr" type="goog.array.ArrayLike">Array or array like object from which to
            ///     remove value.</param>
            /// <param name="i" type="number">The index to remove.</param>
            /// <returns type="boolean">True if an element was removed.</returns>
        }, 
        
        removeIf: function(arr, f, opt_obj) {
            /// <summary>Removes the first value that satisfies the given condition.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array
            ///     like object over which to iterate.</param>
            /// <param name="f" type="?function(this:S|T|number|?) : boolean">The function to call
            ///     for every element. This function
            ///     takes 3 arguments (the element, the index and the array) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="S=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="boolean">True if an element was removed.</returns>
        }, 
        
        concat: function(var_args) {
            /// <summary>Returns a new array that is the result of joining the arguments.  If arrays
            /// are passed then their items are added, however, if non-arrays are passed they
            /// will be added to the return array as is.
            /// 
            /// Note that ArrayLike objects will be added as is, rather than having their
            /// items added.
            /// 
            /// goog.array.concat([1, 2], [3, 4]) -> [1, 2, 3, 4]
            /// goog.array.concat(0, [1, 2]) -> [0, 1, 2]
            /// goog.array.concat([1, 2], null) -> [1, 2, null]
            /// 
            /// There is bug in all current versions of IE (6, 7 and 8) where arrays created
            /// in an iframe become corrupted soon (not immediately) after the iframe is
            /// destroyed. This is common if loading data via goog.net.IframeIo, for example.
            /// This corruption only affects the concat method which will start throwing
            /// Catastrophic Errors (#-2147418113).
            /// 
            /// See http://endoflow.com/scratch/corrupted-arrays.html for a test case.
            /// 
            /// Internally goog.array should use this, so that all methods will continue to
            /// work on these broken array objects.</summary>
            /// <param name="var_args" type="...*">Items to concatenate.  Arrays will have each item
            ///     added, while primitives and objects will be added as is.</param>
            /// <returns type="!Array">The new resultant array.</returns>
        }, 
        
        toArray: function(object) {
            /// <summary>Converts an object to an array.</summary>
            /// <param name="object" type="goog.array.ArrayLike">The object to convert to an array.</param>
            /// <returns type="!Array">The object converted into an array. If object has a
            ///     length property, every property indexed with a non-negative number
            ///     less than length will be included in the result. If object does not
            ///     have a length property, an empty array will be returned.</returns>
        }, 
        
        extend: function(arr1, var_args) {
            /// <summary>Extends an array with another array, element, or &quot;array like&quot; object.
            /// This function operates &apos;in-place&apos;, it does not create a new Array.
            /// 
            /// Example:
            /// var a = [];
            /// goog.array.extend(a, [0, 1]);
            /// a; // [0, 1]
            /// goog.array.extend(a, 2);
            /// a; // [0, 1, 2]</summary>
            /// <param name="arr1" type="Array">The array to modify.</param>
            /// <param name="var_args" type="...*">The elements or arrays of elements to add to arr1.</param>
        }, 
        
        splice: function(arr, index, howMany, var_args) {
            /// <summary>Adds or removes elements from an array. This is a generic version of Array
            /// splice. This means that it might work on other objects similar to arrays,
            /// such as the arguments object.</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to modify.</param>
            /// <param name="index" type="number|undefined">The index at which to start changing the
            ///     array. If not defined, treated as 0.</param>
            /// <param name="howMany" type="number">How many elements to remove (0 means no removal. A
            ///     value below 0 is treated as zero and so is any other non number. Numbers
            ///     are floored).</param>
            /// <param name="var_args" type="...*">Optional, additional elements to insert into the
            ///     array.</param>
            /// <returns type="!Array">the removed elements.</returns>
        }, 
        
        slice: function(arr, start, opt_end) {
            /// <summary>Returns a new array from a segment of an array. This is a generic version of
            /// Array slice. This means that it might work on other objects similar to
            /// arrays, such as the arguments object.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">The array from
            /// which to copy a segment.</param>
            /// <param name="start" type="number">The index of the first element to copy.</param>
            /// <param name="opt_end" type="number=">The index after the last element to copy.</param>
            /// <returns type="!Array.T">A new array containing the specified segment of the
            ///     original array.</returns>
        }, 
        
        removeDuplicates: function(arr, opt_rv) {
            /// <summary>Removes all duplicates from an array (retaining only the first
            /// occurrence of each array element).  This function modifies the
            /// array in place and doesn&apos;t change the order of the non-duplicate items.
            /// 
            /// For objects, duplicates are identified as having the same unique ID as
            /// defined by {@link goog.getUid}.
            /// 
            /// Runtime: N,
            /// Worstcase space: 2N (no dupes)</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array from which to remove duplicates.</param>
            /// <param name="opt_rv" type="Array=">An optional array in which to return the results,
            ///     instead of performing the removal inplace.  If specified, the original
            ///     array will remain unchanged.</param>
        }, 
        
        binarySearch: function(arr, target, opt_compareFn) {
            /// <summary>Searches the specified array for the specified target using the binary
            /// search algorithm.  If no opt_compareFn is specified, elements are compared
            /// using &lt;code&gt;goog.array.defaultCompare&lt;/code&gt;, which compares the elements
            /// using the built in &lt; and &gt; operators.  This will produce the expected
            /// behavior for homogeneous arrays of String(s) and Number(s). The array
            /// specified <b>must</b> be sorted in ascending order (as defined by the
            /// comparison function).  If the array is not sorted, results are undefined.
            /// If the array contains multiple instances of the specified target value, any
            /// of these instances may be found.
            /// 
            /// Runtime: O(log n)</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to be searched.</param>
            /// <param name="target" type="*">The sought value.</param>
            /// <param name="opt_compareFn" type="Function=">Optional comparison function by which the
            ///     array is ordered. Should take 2 arguments to compare, and return a
            ///     negative number, zero, or a positive number depending on whether the
            ///     first argument is less than, equal to, or greater than the second.</param>
            /// <returns type="number">Lowest index of the target value if found, otherwise
            ///     (-(insertion point) - 1). The insertion point is where the value should
            ///     be inserted into arr to preserve the sorted property.  Return value >= 0
            ///     iff target is found.</returns>
        }, 
        
        binarySelect: function(arr, evaluator, opt_obj) {
            /// <summary>Selects an index in the specified array using the binary search algorithm.
            /// The evaluator receives an element and determines whether the desired index
            /// is before, at, or after it.  The evaluator must be consistent (formally,
            /// goog.array.map(goog.array.map(arr, evaluator, opt_obj), goog.math.sign)
            /// must be monotonically non-increasing).
            /// 
            /// Runtime: O(log n)</summary>
            /// <param name="arr" type="goog.array.ArrayLike">The array to be searched.</param>
            /// <param name="evaluator" type="Function">Evaluator function that receives 3 arguments
            ///     (the element, the index and the array). Should return a negative number,
            ///     zero, or a positive number depending on whether the desired index is
            ///     before, at, or after the element passed to it.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within evaluator.</param>
            /// <returns type="number">Index of the leftmost element matched by the evaluator, if
            ///     such exists; otherwise (-(insertion point) - 1). The insertion point is
            ///     the index of the first element for which the evaluator returns negative,
            ///     or arr.length if no such element exists. The return value is non-negative
            ///     iff a match is found.</returns>
        }, 
        
        sort: function(arr, opt_compareFn) {
            /// <summary>Sorts the specified array into ascending order.  If no opt_compareFn is
            /// specified, elements are compared using
            /// &lt;code&gt;goog.array.defaultCompare&lt;/code&gt;, which compares the elements using
            /// the built in &lt; and &gt; operators.  This will produce the expected behavior
            /// for homogeneous arrays of String(s) and Number(s), unlike the native sort,
            /// but will give unpredictable results for heterogenous lists of strings and
            /// numbers with different numbers of digits.
            /// 
            /// This sort is not guaranteed to be stable.
            /// 
            /// Runtime: Same as &lt;code&gt;Array.prototype.sort&lt;/code&gt;</summary>
            /// <param name="arr" type="Array.T">The array to be sorted.</param>
            /// <param name="opt_compareFn" type="?function(T|T):number=">Optional comparison
            ///     function by which the
            ///     array is to be ordered. Should take 2 arguments to compare, and return a
            ///     negative number, zero, or a positive number depending on whether the
            ///     first argument is less than, equal to, or greater than the second.</param>
        }, 
        
        stableSort: function(arr, opt_compareFn) {
            /// <summary>Sorts the specified array into ascending order in a stable way.  If no
            /// opt_compareFn is specified, elements are compared using
            /// &lt;code&gt;goog.array.defaultCompare&lt;/code&gt;, which compares the elements using
            /// the built in &lt; and &gt; operators.  This will produce the expected behavior
            /// for homogeneous arrays of String(s) and Number(s).
            /// 
            /// Runtime: Same as &lt;code&gt;Array.prototype.sort&lt;/code&gt;, plus an additional
            /// O(n) overhead of copying the array twice.</summary>
            /// <param name="arr" type="Array.T">The array to be sorted.</param>
            /// <param name="opt_compareFn" type="?function(T|T): number=">Optional comparison function
            ///     by which the array is to be ordered. Should take 2 arguments to compare,
            ///     and return a negative number, zero, or a positive number depending on
            ///     whether the first argument is less than, equal to, or greater than the
            ///     second.</param>
        }, 
        
        sortObjectsByKey: function(arr, key, opt_compareFn) {
            /// <summary>Sorts an array of objects by the specified object key and compare
            /// function. If no compare function is provided, the key values are
            /// compared in ascending order using &lt;code&gt;goog.array.defaultCompare&lt;/code&gt;.
            /// This won&apos;t work for keys that get renamed by the compiler. So use
            /// {&apos;foo&apos;: 1, &apos;bar&apos;: 2} rather than {foo: 1, bar: 2}.</summary>
            /// <param name="arr" type="Array.Object">An array of objects to sort.</param>
            /// <param name="key" type="string">The object key to sort by.</param>
            /// <param name="opt_compareFn" type="Function=">The function to use to compare key
            ///     values.</param>
        }, 
        
        isSorted: function(arr, opt_compareFn, opt_strict) {
            /// <summary>Tells if the array is sorted.</summary>
            /// <param name="arr" type="!Array.T">The array.</param>
            /// <param name="opt_compareFn" type="?function(T|T):number=">Function to compare the
            ///     array elements.
            ///     Should take 2 arguments to compare, and return a negative number, zero,
            ///     or a positive number depending on whether the first argument is less
            ///     than, equal to, or greater than the second.</param>
            /// <param name="opt_strict" type="boolean=">If true no equal elements are allowed.</param>
            /// <returns type="boolean">Whether the array is sorted.</returns>
        }, 
        
        equals: function(arr1, arr2, opt_equalsFn) {
            /// <summary>Compares two arrays for equality. Two arrays are considered equal if they
            /// have the same length and their corresponding elements are equal according to
            /// the comparison function.</summary>
            /// <param name="arr1" type="goog.array.ArrayLike">The first array to compare.</param>
            /// <param name="arr2" type="goog.array.ArrayLike">The second array to compare.</param>
            /// <param name="opt_equalsFn" type="Function=">Optional comparison function.
            ///     Should take 2 arguments to compare, and return true if the arguments
            ///     are equal. Defaults to {@link goog.array.defaultCompareEquality} which
            ///     compares the elements using the built-in &apos;===&apos; operator.</param>
            /// <returns type="boolean">Whether the two arrays are equal.</returns>
        }, 
        
        compare: function(arr1, arr2, opt_equalsFn) {
            /// <summary></summary>
            /// <param name="arr1" type="goog.array.ArrayLike">See {@link goog.array.equals}.</param>
            /// <param name="arr2" type="goog.array.ArrayLike">See {@link goog.array.equals}.</param>
            /// <param name="opt_equalsFn" type="Function=">See {@link goog.array.equals}.</param>
            /// <returns type="boolean">See {@link goog.array.equals}.</returns>
        }, 
        
        compare3: function(arr1, arr2, opt_compareFn) {
            /// <summary>3-way array compare function.</summary>
            /// <param name="arr1" type="!goog.array.ArrayLike">The first array to compare.</param>
            /// <param name="arr2" type="!goog.array.ArrayLike">The second array to compare.</param>
            /// <param name="opt_compareFn" type="?function(?|?): number=">Optional comparison function
            ///     by which the array is to be ordered. Should take 2 arguments to compare,
            ///     and return a negative number, zero, or a positive number depending on
            ///     whether the first argument is less than, equal to, or greater than the
            ///     second.</param>
            /// <returns type="number">Negative number, zero, or a positive number depending on
            ///     whether the first argument is less than, equal to, or greater than the
            ///     second.</returns>
        }, 
        
        defaultCompare: function(a, b) {
            /// <summary>Compares its two arguments for order, using the built in &lt; and &gt;
            /// operators.</summary>
            /// <param name="a" type="*">The first object to be compared.</param>
            /// <param name="b" type="*">The second object to be compared.</param>
            /// <returns type="number">A negative number, zero, or a positive number as the first
            ///     argument is less than, equal to, or greater than the second.</returns>
        }, 
        
        defaultCompareEquality: function(a, b) {
            /// <summary>Compares its two arguments for equality, using the built in === operator.</summary>
            /// <param name="a" type="*">The first object to compare.</param>
            /// <param name="b" type="*">The second object to compare.</param>
            /// <returns type="boolean">True if the two arguments are equal, false otherwise.</returns>
        }, 
        
        binaryInsert: function(array, value, opt_compareFn) {
            /// <summary>Inserts a value into a sorted array. The array is not modified if the
            /// value is already present.</summary>
            /// <param name="array" type="Array.T">The array to modify.</param>
            /// <param name="value" type="T">The object to insert.</param>
            /// <param name="opt_compareFn" type="?function(T|T):number=">Optional comparison function by
            ///     which the
            ///     array is ordered. Should take 2 arguments to compare, and return a
            ///     negative number, zero, or a positive number depending on whether the
            ///     first argument is less than, equal to, or greater than the second.</param>
            /// <returns type="boolean">True if an element was inserted.</returns>
        }, 
        
        binaryRemove: function(array, value, opt_compareFn) {
            /// <summary>Removes a value from a sorted array.</summary>
            /// <param name="array" type="Array">The array to modify.</param>
            /// <param name="value" type="*">The object to remove.</param>
            /// <param name="opt_compareFn" type="Function=">Optional comparison function by which the
            ///     array is ordered. Should take 2 arguments to compare, and return a
            ///     negative number, zero, or a positive number depending on whether the
            ///     first argument is less than, equal to, or greater than the second.</param>
            /// <returns type="boolean">True if an element was removed.</returns>
        }, 
        
        bucket: function(array, sorter) {
            /// <summary>Splits an array into disjoint buckets according to a splitting function.</summary>
            /// <param name="array" type="Array.T">The array.</param>
            /// <param name="sorter" type="function(T|number|Array.T):?">Function to call for every
            ///     element.  This
            ///     takes 3 arguments (the element, the index and the array) and must
            ///     return a valid object key (a string, number, etc), or undefined, if
            ///     that object should not be placed in a bucket.</param>
            /// <returns type="!Object">An object, with keys being all of the unique return values
            ///     of sorter, and values being arrays containing the items for
            ///     which the splitter returned that key.</returns>
        }, 
        
        toObject: function(arr, keyFunc, opt_obj) {
            /// <summary>Creates a new object built from the provided array and the key-generation
            /// function.</summary>
            /// <param name="arr" type="Array.T|goog.array.ArrayLike">Array or array like object over
            ///     which to iterate whose elements will be the values in the new object.</param>
            /// <param name="keyFunc" type="?function(this:S|T|number|?) : string">The function to
            ///     call for every element. This function takes 3 arguments (the element, the
            ///     index and the array) and should return a string that will be used as the
            ///     key for the element in the new object. If the function returns the same
            ///     key for more than one element, the value for that key is
            ///     implementation-defined.</param>
            /// <param name="opt_obj" type="S=">The object to be used as the value of &apos;this&apos;
            ///     within keyFunc.</param>
            /// <returns type="!Object.T">The new object.</returns>
        }, 
        
        repeat: function(value, n) {
            /// <summary>Returns an array consisting of the given value repeated N times.</summary>
            /// <param name="value" type="*">The value to repeat.</param>
            /// <param name="n" type="number">The repeat count.</param>
            /// <returns type="!Array">An array with the repeated value.</returns>
        }, 
        
        flatten: function(var_args) {
            /// <summary>Returns an array consisting of every argument with all arrays
            /// expanded in-place recursively.</summary>
            /// <param name="var_args" type="...*">The values to flatten.</param>
            /// <returns type="!Array">An array containing the flattened values.</returns>
        }, 
        
        rotate: function(array, n) {
            /// <summary>Rotates an array in-place. After calling this method, the element at
            /// index i will be the element previously at index (i - n) %
            /// array.length, for all values of i between 0 and array.length - 1,
            /// inclusive.
            /// 
            /// For example, suppose list comprises [t, a, n, k, s]. After invoking
            /// rotate(array, 1) (or rotate(array, -4)), array will comprise [s, t, a, n, k].</summary>
            /// <param name="array" type="!Array.T">The array to rotate.</param>
            /// <param name="n" type="number">The amount to rotate.</param>
            /// <returns type="!Array.T">The array.</returns>
        }, 
        
        zip: function(var_args) {
            /// <summary>Creates a new array for which the element at position i is an array of the
            /// ith element of the provided arrays.  The returned array will only be as long
            /// as the shortest array provided; additional values are ignored.  For example,
            /// the result of zipping [1, 2] and [3, 4, 5] is [[1,3], [2, 4]].
            /// 
            /// This is similar to the zip() function in Python.  See {@link
            /// http://docs.python.org/library/functions.html#zip}</summary>
            /// <param name="var_args" type="...!goog.array.ArrayLike">Arrays to be combined.</param>
            /// <returns type="!Array.!Array">A new array of arrays created from provided arrays.</returns>
        }, 
        
        shuffle: function(arr, opt_randFn) {
            /// <summary>Shuffles the values in the specified array using the Fisher-Yates in-place
            /// shuffle (also known as the Knuth Shuffle). By default, calls Math.random()
            /// and so resets the state of that random number generator. Similarly, may reset
            /// the state of the any other specified random number generator.
            /// 
            /// Runtime: O(n)</summary>
            /// <param name="arr" type="!Array">The array to be shuffled.</param>
            /// <param name="opt_randFn" type="function():number=">Optional random function to use for
            ///     shuffling.
            ///     Takes no arguments, and returns a random number on the interval [0, 1).
            ///     Defaults to Math.random() using JavaScript&apos;s built-in Math library.</param>
        }
        
    };

    var $x = window.goog.array;
    $x.__namespace = "true";
    $x.__typeName = "goog.array";
})(this);
