
/* vsdoc for goog.asserts */

(function (window) {
    window.goog = window.goog || {};

    window.goog.asserts = {
        /// <summary></summary>
        /// <field name="ENABLE_ASSERTS" type=""></field>
        /// <returns type="goog.asserts"/>
                
        assert: function(condition, opt_message, var_args) {
            /// <summary>Checks if the condition evaluates to true if goog.asserts.ENABLE_ASSERTS is
            /// true.</summary>
            /// <param name="condition" type="*">The condition to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="*">The value of the condition.</returns>
        }, 
        
        fail: function(opt_message, var_args) {
            /// <summary>Fails if goog.asserts.ENABLE_ASSERTS is true. This function is useful in case
            /// when we want to add a check in the unreachable area like switch-case
            /// statement:
            /// 
            /// &lt;pre&gt;
            ///  switch(type) {
            ///    case FOO: doSomething(); break;
            ///    case BAR: doSomethingElse(); break;
            ///    default: goog.assert.fail(&apos;Unrecognized type: &apos; + type);
            ///      // We have only 2 types - &quot;default:&quot; section is unreachable code.
            ///  }
            /// &lt;/pre&gt;</summary>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
        }, 
        
        assertNumber: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is a number if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="number">The value, guaranteed to be a number when asserts enabled.</returns>
        }, 
        
        assertString: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is a string if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="string">The value, guaranteed to be a string when asserts enabled.</returns>
        }, 
        
        assertFunction: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is a function if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="!Function">The value, guaranteed to be a function when asserts
            ///     enabled.</returns>
        }, 
        
        assertObject: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is an Object if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="!Object">The value, guaranteed to be a non-null object.</returns>
        }, 
        
        assertArray: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is an Array if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="!Array">The value, guaranteed to be a non-null array.</returns>
        }, 
        
        assertBoolean: function(value, opt_message, var_args) {
            /// <summary>Checks if the value is a boolean if goog.asserts.ENABLE_ASSERTS is true.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="boolean">The value, guaranteed to be a boolean when asserts are
            ///     enabled.</returns>
        }, 
        
        assertInstanceof: function(value, type, opt_message, var_args) {
            /// <summary>Checks if the value is an instance of the user-defined type if
            /// goog.asserts.ENABLE_ASSERTS is true.
            /// 
            /// The compiler may tighten the type returned by this function.</summary>
            /// <param name="value" type="*">The value to check.</param>
            /// <param name="type" type="!Function">A user-defined constructor.</param>
            /// <param name="opt_message" type="string=">Error message in case of failure.</param>
            /// <param name="var_args" type="...*">The items to substitute into the failure message.</param>
            /// <returns type="!Object"></returns>
        }
        
    };

    var $x = window.goog.asserts;
    $x.__namespace = "true";
    $x.__typeName = "goog.asserts";
})(this);
