
/* vsdoc for goog.async.ConditionalDelay */

(function (window) {
    window.goog.async = window.goog.async || {};

    window.goog.async.ConditionalDelay = function(listener, opt_handler){
        /// <summary></summary>
        /// <param name="listener" type="function():boolean">Function to call when the delay
        ///     completes. Should return a value that type-converts to {@code true} if
        ///     the call succeeded and this delay should be stopped.</param>
        /// <param name="opt_handler" type="Object=">The object scope to invoke the function in.</param>
        /// <returns type="goog.async.ConditionalDelay"/>
    };

    var $x = window.goog.async.ConditionalDelay;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        start: function(opt_interval, opt_timeout) {
            /// <summary>Starts the delay timer. The provided listener function will be called
            /// repeatedly after the specified interval until the function returns
            /// {@code true} or the timeout is exceeded. Calling start on an active timer
            /// will stop the timer first.</summary>
            /// <param name="opt_interval" type="number=">The time interval between the function
            ///     invocations (in milliseconds). Default is 0.</param>
            /// <param name="opt_timeout" type="number=">The timeout interval (in milliseconds). Takes
            ///     precedence over the {@code opt_interval}, i.e. if the timeout is less
            ///     than the invocation interval, the function will be called when the
            ///     timeout is exceeded. A negative value means no timeout. Default is 0.</param>
        }, 
        
        stop: function() {
            /// <summary>Stops the delay timer if it is active. No action is taken if the timer is not
            /// in use.</summary>
        }, 
        
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the delay is currently active, false otherwise.</returns>
        }, 
        
        isDone: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the listener has been executed and returned
            ///     {@code true} since the last call to {@see #start}.</returns>
        }, 
        
        onSuccess: function() {
            /// <summary>Called when the listener has been successfully executed and returned
            /// {@code true}. The {@see #isDone} method should return {@code true} by now.
            /// Designed for inheritance, should be overridden by subclasses or on the
            /// instances if they care.</summary>
        }, 
        
        onFailure: function() {
            /// <summary>Called when this delayed call is cancelled because the timeout has been
            /// exceeded, and the listener has never returned {@code true}.
            /// Designed for inheritance, should be overridden by subclasses or on the
            /// instances if they care.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.async.ConditionalDelay";
})(this);
