
/* vsdoc for goog.async.Throttle */

(function (window) {
    window.goog.async = window.goog.async || {};

    window.goog.async.Throttle = function(listener, interval, opt_handler){
        /// <summary></summary>
        /// <param name="listener" type="Function">Function to callback when the action is triggered.</param>
        /// <param name="interval" type="number">Interval over which to throttle. The handler can
        ///     only be called once per interval.</param>
        /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
        /// <returns type="goog.async.Throttle"/>
    };

    var $x = window.goog.async.Throttle;
    $x.prototype = {
                
        fire: function() {
            /// <summary>Notifies the throttle that the action has happened. It will throttle the call
            /// so that the callback is not called too often according to the interval
            /// parameter passed to the constructor.</summary>
        }, 
        
        stop: function() {
            /// <summary>Cancels any pending action callback. The throttle can be restarted by
            /// calling {@link #fire}.</summary>
        }, 
        
        pause: function() {
            /// <summary>Pauses the throttle.  All pending and future action callbacks will be
            /// delayed until the throttle is resumed.  Pauses can be nested.</summary>
        }, 
        
        resume: function() {
            /// <summary>Resumes the throttle.  If doing so drops the pausing count to zero, pending
            /// action callbacks will be executed as soon as possible, but still no sooner
            /// than an interval&apos;s delay after the previous call.  Future action callbacks
            /// will be executed as normal.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.async.Throttle";
})(this);
