
/* vsdoc for goog.color */

(function (window) {
    window.goog = window.goog || {};

    window.goog.color = {
        /// <summary></summary>
        /// <field name="alpha" type=""></field>
        /// <field name="names" type="">A map that contains a lot of colors that are recognised by various browsers.
        /// This list is way larger than the minimal one dictated by W3C.
        /// The keys of this map are the lowercase &quot;readable&quot; names of the colors, while
        /// the values are the &quot;hex&quot; values.</field>
        /// <returns type="goog.color"/>
                
        parse: function(str) {
            /// <summary>Parses a color out of a string.</summary>
            /// <param name="str" type="string">Color in some format.</param>
            /// <returns type="Object">Contains two properties: &apos;hex&apos;, which is a string containing
            ///     a hex representation of the color, as well as &apos;type&apos;, which is a string
            ///     containing the type of color format passed in (&apos;hex&apos;, &apos;rgb&apos;, &apos;named&apos;).</returns>
        }, 
        
        isValidColor: function(str) {
            /// <summary>Determines if the given string can be parsed as a color.
            ///     {@see goog.color.parse}.</summary>
            /// <param name="str" type="string">Potential color string.</param>
            /// <returns type="boolean">True if str is in a format that can be parsed to a color.</returns>
        }, 
        
        parseRgb: function(str) {
            /// <summary>Parses red, green, blue components out of a valid rgb color string.
            /// Throws Error if the color string is invalid.</summary>
            /// <param name="str" type="string">RGB representation of a color.
            ///    {@see goog.color.isValidRgbColor_}.</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        hexToRgbStyle: function(hexColor) {
            /// <summary>Converts a hex representation of a color to RGB.</summary>
            /// <param name="hexColor" type="string">Color to convert.</param>
            /// <returns type="string">string of the form &apos;rgb(R,G,B)&apos; which can be used in
            ///    styles.</returns>
        }, 
        
        normalizeHex: function(hexColor) {
            /// <summary>Normalize an hex representation of a color</summary>
            /// <param name="hexColor" type="string">an hex color string.</param>
            /// <returns type="string">hex color in the format &apos;#rrggbb&apos; with all lowercase
            ///     literals.</returns>
        }, 
        
        hexToRgb: function(hexColor) {
            /// <summary>Converts a hex representation of a color to RGB.</summary>
            /// <param name="hexColor" type="string">Color to convert.</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        rgbToHex: function(r, g, b) {
            /// <summary>Converts a color from RGB to hex representation.</summary>
            /// <param name="r" type="number">Amount of red, int between 0 and 255.</param>
            /// <param name="g" type="number">Amount of green, int between 0 and 255.</param>
            /// <param name="b" type="number">Amount of blue, int between 0 and 255.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        rgbArrayToHex: function(rgb) {
            /// <summary>Converts a color from RGB to hex representation.</summary>
            /// <param name="rgb" type="goog.color.Rgb">rgb representation of the color.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        rgbToHsl: function(r, g, b) {
            /// <summary>Converts a color from RGB color space to HSL color space.
            /// Modified from {@link http://en.wikipedia.org/wiki/HLS_color_space}.</summary>
            /// <param name="r" type="number">Value of red, in [0, 255].</param>
            /// <param name="g" type="number">Value of green, in [0, 255].</param>
            /// <param name="b" type="number">Value of blue, in [0, 255].</param>
            /// <returns type="!goog.color.Hsl">hsl representation of the color.</returns>
        }, 
        
        rgbArrayToHsl: function(rgb) {
            /// <summary>Converts a color from RGB color space to HSL color space.</summary>
            /// <param name="rgb" type="goog.color.Rgb">rgb representation of the color.</param>
            /// <returns type="!goog.color.Hsl">hsl representation of the color.</returns>
        }, 
        
        hslToRgb: function(h, s, l) {
            /// <summary>Converts a color from HSL color space to RGB color space.
            /// Modified from {@link http://www.easyrgb.com/math.html}</summary>
            /// <param name="h" type="number">Hue, in [0, 360].</param>
            /// <param name="s" type="number">Saturation, in [0, 1].</param>
            /// <param name="l" type="number">Luminosity, in [0, 1].</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        hslArrayToRgb: function(hsl) {
            /// <summary>Converts a color from HSL color space to RGB color space.</summary>
            /// <param name="hsl" type="goog.color.Hsl">hsl representation of the color.</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        prependZeroIfNecessaryHelper: function(hex) {
            /// <summary>Takes a hex value and prepends a zero if it&apos;s a single digit.
            /// Small helper method for use by goog.color and friends.</summary>
            /// <param name="hex" type="string">Hex value to prepend if single digit.</param>
            /// <returns type="string">hex value prepended with zero if it was single digit,
            ///     otherwise the same value that was passed in.</returns>
        }, 
        
        prependHashIfNecessaryHelper: function(str) {
            /// <summary>Takes a string a prepends a &apos;#&apos; sign if one doesn&apos;t exist.
            /// Small helper method for use by goog.color and friends.</summary>
            /// <param name="str" type="string">String to check.</param>
            /// <returns type="string">The value passed in, prepended with a &apos;#&apos; if it didn&apos;t
            ///     already have one.</returns>
        }, 
        
        hsvToRgb: function(h, s, brightness) {
            /// <summary>Converts an HSV triplet to an RGB array.  V is brightness because b is
            ///   reserved for blue in RGB.</summary>
            /// <param name="h" type="number">Hue value in [0, 360].</param>
            /// <param name="s" type="number">Saturation value in [0, 1].</param>
            /// <param name="brightness" type="number">brightness in [0, 255].</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        rgbToHsv: function(red, green, blue) {
            /// <summary>Converts from RGB values to an array of HSV values.</summary>
            /// <param name="red" type="number">Red value in [0, 255].</param>
            /// <param name="green" type="number">Green value in [0, 255].</param>
            /// <param name="blue" type="number">Blue value in [0, 255].</param>
            /// <returns type="!goog.color.Hsv">hsv representation of the color.</returns>
        }, 
        
        rgbArrayToHsv: function(rgb) {
            /// <summary>Converts from an array of RGB values to an array of HSV values.</summary>
            /// <param name="rgb" type="goog.color.Rgb">rgb representation of the color.</param>
            /// <returns type="!goog.color.Hsv">hsv representation of the color.</returns>
        }, 
        
        hsvArrayToRgb: function(hsv) {
            /// <summary>Converts an HSV triplet to an RGB array.</summary>
            /// <param name="hsv" type="goog.color.Hsv">hsv representation of the color.</param>
            /// <returns type="!goog.color.Rgb">rgb representation of the color.</returns>
        }, 
        
        hexToHsl: function(hex) {
            /// <summary>Converts a hex representation of a color to HSL.</summary>
            /// <param name="hex" type="string">Color to convert.</param>
            /// <returns type="!goog.color.Hsv">hsv representation of the color.</returns>
        }, 
        
        hslToHex: function(h, s, l) {
            /// <summary>Converts from h,s,l values to a hex string</summary>
            /// <param name="h" type="number">Hue, in [0, 360].</param>
            /// <param name="s" type="number">Saturation, in [0, 1].</param>
            /// <param name="l" type="number">Luminosity, in [0, 1].</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hslArrayToHex: function(hsl) {
            /// <summary>Converts from an hsl array to a hex string</summary>
            /// <param name="hsl" type="goog.color.Hsl">hsl representation of the color.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hexToHsv: function(hex) {
            /// <summary>Converts a hex representation of a color to HSV</summary>
            /// <param name="hex" type="string">Color to convert.</param>
            /// <returns type="!goog.color.Hsv">hsv representation of the color.</returns>
        }, 
        
        hsvToHex: function(h, s, v) {
            /// <summary>Converts from h,s,v values to a hex string</summary>
            /// <param name="h" type="number">Hue, in [0, 360].</param>
            /// <param name="s" type="number">Saturation, in [0, 1].</param>
            /// <param name="v" type="number">Value, in [0, 255].</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hsvArrayToHex: function(hsv) {
            /// <summary>Converts from an HSV array to a hex string</summary>
            /// <param name="hsv" type="goog.color.Hsv">hsv representation of the color.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hslDistance: function(hsl1, hsl2) {
            /// <summary>Calculates the Euclidean distance between two color vectors on an HSL sphere.
            /// A demo of the sphere can be found at:
            /// http://en.wikipedia.org/wiki/HSL_color_space
            /// In short, a vector for color (H, S, L) in this system can be expressed as
            /// (S*L&apos;*cos(2*PI*H), S*L&apos;*sin(2*PI*H), L), where L&apos; = abs(L - 0.5), and we
            /// simply calculate the 1-2 distance using these coordinates</summary>
            /// <param name="hsl1" type="goog.color.Hsl">First color in hsl representation.</param>
            /// <param name="hsl2" type="goog.color.Hsl">Second color in hsl representation.</param>
            /// <returns type="number">Distance between the two colors, in the range [0, 1].</returns>
        }, 
        
        blend: function(rgb1, rgb2, factor) {
            /// <summary>Blend two colors together, using the specified factor to indicate the weight
            /// given to the first color</summary>
            /// <param name="rgb1" type="goog.color.Rgb">First color represented in rgb.</param>
            /// <param name="rgb2" type="goog.color.Rgb">Second color represented in rgb.</param>
            /// <param name="factor" type="number">The weight to be given to rgb1 over rgb2. Values
            ///     should be in the range [0, 1]. If less than 0, factor will be set to 0.
            ///     If greater than 1, factor will be set to 1.</param>
            /// <returns type="!goog.color.Rgb">Combined color represented in rgb.</returns>
        }, 
        
        darken: function(rgb, factor) {
            /// <summary>Adds black to the specified color, darkening it</summary>
            /// <param name="rgb" type="goog.color.Rgb">rgb representation of the color.</param>
            /// <param name="factor" type="number">Number in the range [0, 1]. 0 will do nothing, while
            ///     1 will return black. If less than 0, factor will be set to 0. If greater
            ///     than 1, factor will be set to 1.</param>
            /// <returns type="!goog.color.Rgb">Combined rgb color.</returns>
        }, 
        
        lighten: function(rgb, factor) {
            /// <summary>Adds white to the specified color, lightening it</summary>
            /// <param name="rgb" type="goog.color.Rgb">rgb representation of the color.</param>
            /// <param name="factor" type="number">Number in the range [0, 1].  0 will do nothing, while
            ///     1 will return white. If less than 0, factor will be set to 0. If greater
            ///     than 1, factor will be set to 1.</param>
            /// <returns type="!goog.color.Rgb">Combined rgb color.</returns>
        }, 
        
        highContrast: function(prime, suggestions) {
            /// <summary>Find the &quot;best&quot; (highest-contrast) of the suggested colors for the prime
            /// color. Uses W3C formula for judging readability and visual accessibility:
            /// http://www.w3.org/TR/AERT#color-contrast</summary>
            /// <param name="prime" type="goog.color.Rgb">Color represented as a rgb array.</param>
            /// <param name="suggestions" type="Array.goog.color.Rgb">Array of colors,
            ///     each representing a rgb array.</param>
            /// <returns type="!goog.color.Rgb">Highest-contrast color represented by an array..</returns>
        }
        
    };

    var $x = window.goog.color;
    $x.__namespace = "true";
    $x.__typeName = "goog.color";
})(this);
