
/* vsdoc for goog.color.alpha */

(function (window) {
    window.goog.color = window.goog.color || {};

    window.goog.color.alpha = {
        /// <summary></summary>
        /// <returns type="goog.color.alpha"/>
                
        parse: function(str) {
            /// <summary>Parses an alpha color out of a string.</summary>
            /// <param name="str" type="string">Color in some format.</param>
            /// <returns type="Object">Contains two properties: &apos;hex&apos;, which is a string containing
            ///     a hex representation of the color, as well as &apos;type&apos;, which is a string
            ///     containing the type of color format passed in (&apos;hex&apos;, &apos;rgb&apos;, &apos;named&apos;).</returns>
        }, 
        
        hexToRgbaStyle: function(hexColor) {
            /// <summary>Converts a hex representation of a color to RGBA.</summary>
            /// <param name="hexColor" type="string">Color to convert.</param>
            /// <returns type="string">string of the form &apos;rgba(R,G,B,A)&apos; which can be used in
            ///    styles.</returns>
        }, 
        
        extractHexColor: function(colorWithAlpha) {
            /// <summary>Gets the hex color part of an alpha hex color. For example, from &apos;#abcdef55&apos;
            /// return &apos;#abcdef&apos;.</summary>
            /// <param name="colorWithAlpha" type="string">The alpha hex color to get the hex color from.</param>
            /// <returns type="string">The hex color where the alpha part has been stripped off.</returns>
        }, 
        
        extractAlpha: function(colorWithAlpha) {
            /// <summary>Gets the alpha color part of an alpha hex color. For example, from
            /// &apos;#abcdef55&apos; return &apos;55&apos;. The result is guaranteed to be two characters long.</summary>
            /// <param name="colorWithAlpha" type="string">The alpha hex color to get the hex color from.</param>
            /// <returns type="string">The hex color where the alpha part has been stripped off.</returns>
        }, 
        
        hexToRgba: function(hexColor) {
            /// <summary>Converts an 8-hex representation of a color to RGBA.</summary>
            /// <param name="hexColor" type="string">Color to convert.</param>
            /// <returns type="Array">array containing [r, g, b] as ints in [0, 255].</returns>
        }, 
        
        rgbaToHex: function(r, g, b, a) {
            /// <summary>Converts a color from RGBA to hex representation.</summary>
            /// <param name="r" type="number">Amount of red, int between 0 and 255.</param>
            /// <param name="g" type="number">Amount of green, int between 0 and 255.</param>
            /// <param name="b" type="number">Amount of blue, int between 0 and 255.</param>
            /// <param name="a" type="number">Amount of alpha, float between 0 and 1.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hslaToHex: function(h, s, l, a) {
            /// <summary>Converts a color from HSLA to hex representation.</summary>
            /// <param name="h" type="number">Amount of hue, int between 0 and 360.</param>
            /// <param name="s" type="number">Amount of saturation, int between 0 and 100.</param>
            /// <param name="l" type="number">Amount of lightness, int between 0 and 100.</param>
            /// <param name="a" type="number">Amount of alpha, float between 0 and 1.</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        rgbaArrayToHex: function(rgba) {
            /// <summary>Converts a color from RGBA to hex representation.</summary>
            /// <param name="rgba" type="Array.number">Array of [r, g, b, a], with r, g, b in [0, 255]
            ///     and a in [0, 1].</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        rgbaToRgbaStyle: function(r, g, b, a) {
            /// <summary>Converts a color from RGBA to an RGBA style string.</summary>
            /// <param name="r" type="number">Value of red, in [0, 255].</param>
            /// <param name="g" type="number">Value of green, in [0, 255].</param>
            /// <param name="b" type="number">Value of blue, in [0, 255].</param>
            /// <param name="a" type="number">Value of alpha, in [0, 1].</param>
            /// <returns type="string">An &apos;rgba(r,g,b,a)&apos; string ready for use in a CSS rule.</returns>
        }, 
        
        rgbaArrayToRgbaStyle: function(rgba) {
            /// <summary>Converts a color from RGBA to an RGBA style string.</summary>
            /// <param name="rgba" type="(Array.number|Float32Array)">Array of [r, g, b, a],
            ///     with r, g, b in [0, 255] and a in [0, 1].</param>
            /// <returns type="string">An &apos;rgba(r,g,b,a)&apos; string ready for use in a CSS rule.</returns>
        }, 
        
        hslaArrayToHex: function(hsla) {
            /// <summary>Converts a color from HSLA to hex representation.</summary>
            /// <param name="hsla" type="Array.number">Array of [h, s, l, a], where h is an integer in
            ///     [0, 360], s and l are integers in [0, 100], and a is in [0, 1].</param>
            /// <returns type="string">hex representation of the color, such as &apos;#af457eff&apos;.</returns>
        }, 
        
        hslaArrayToRgbaStyle: function(hsla) {
            /// <summary>Converts a color from HSLA to an RGBA style string.</summary>
            /// <param name="hsla" type="Array.number">Array of [h, s, l, a], where h is and integer in
            ///     [0, 360], s and l are integers in [0, 100], and a is in [0, 1].</param>
            /// <returns type="string">An &apos;rgba(r,g,b,a)&apos; string ready for use in a CSS rule.</returns>
        }, 
        
        hslaToRgbaStyle: function(h, s, l, a) {
            /// <summary>Converts a color from HSLA to an RGBA style string.</summary>
            /// <param name="h" type="number">Amount of hue, int between 0 and 360.</param>
            /// <param name="s" type="number">Amount of saturation, int between 0 and 100.</param>
            /// <param name="l" type="number">Amount of lightness, int between 0 and 100.</param>
            /// <param name="a" type="number">Amount of alpha, float between 0 and 1.</param>
            /// <returns type="string">An &apos;rgba(r,g,b,a)&apos; string ready for use in a CSS rule.
            ///     styles.</returns>
        }, 
        
        hslaToRgba: function(h, s, l, a) {
            /// <summary>Converts a color from HSLA color space to RGBA color space.</summary>
            /// <param name="h" type="number">Amount of hue, int between 0 and 360.</param>
            /// <param name="s" type="number">Amount of saturation, int between 0 and 100.</param>
            /// <param name="l" type="number">Amount of lightness, int between 0 and 100.</param>
            /// <param name="a" type="number">Amount of alpha, float between 0 and 1.</param>
            /// <returns type="Array.number">[r, g, b, a] values for the color, where r, g, b
            ///     are integers in [0, 255] and a is a float in [0, 1].</returns>
        }, 
        
        rgbaToHsla: function(r, g, b, a) {
            /// <summary>Converts a color from RGBA color space to HSLA color space.
            /// Modified from {@link http://en.wikipedia.org/wiki/HLS_color_space}.</summary>
            /// <param name="r" type="number">Value of red, in [0, 255].</param>
            /// <param name="g" type="number">Value of green, in [0, 255].</param>
            /// <param name="b" type="number">Value of blue, in [0, 255].</param>
            /// <param name="a" type="number">Value of alpha, in [0, 255].</param>
            /// <returns type="Array.number">[h, s, l, a] values for the color, with h an int in
            ///     [0, 360] and s, l and a in [0, 1].</returns>
        }, 
        
        rgbaArrayToHsla: function(rgba) {
            /// <summary>Converts a color from RGBA color space to HSLA color space.</summary>
            /// <param name="rgba" type="Array.number">[r, g, b, a] values for the color, each in
            ///     [0, 255].</param>
            /// <returns type="Array.number">[h, s, l, a] values for the color, with h in
            ///     [0, 360] and s, l and a in [0, 1].</returns>
        }, 
        
        hsvaToHex: function(h, s, v, a) {
            /// <summary>Converts from h,s,v,a values to a hex string</summary>
            /// <param name="h" type="number">Hue, in [0, 1].</param>
            /// <param name="s" type="number">Saturation, in [0, 1].</param>
            /// <param name="v" type="number">Value, in [0, 255].</param>
            /// <param name="a" type="number">Alpha, in [0, 1].</param>
            /// <returns type="string">hex representation of the color.</returns>
        }, 
        
        hsvaArrayToHex: function(hsva) {
            /// <summary>Converts from an HSVA array to a hex string</summary>
            /// <param name="hsva" type="Array">Array of [h, s, v, a] in
            ///     [[0, 1], [0, 1], [0, 255], [0, 1]].</param>
            /// <returns type="string">hex representation of the color.</returns>
        }
        
    };

    var $x = window.goog.color.alpha;
    $x.__namespace = "true";
    $x.__typeName = "goog.color.alpha";
})(this);
