
/* vsdoc for goog.cssom */

(function (window) {
    window.goog = window.goog || {};

    window.goog.cssom = {
        /// <summary></summary>
        /// <field name="CssRuleType" type="">Enumeration of {@code CSSRule} types.</field>
        /// <returns type="goog.cssom"/>
                
        getAllCssText: function(opt_styleSheet) {
            /// <summary>Recursively gets all CSS as text, optionally starting from a given
            /// CSSStyleSheet.</summary>
            /// <param name="opt_styleSheet" type="CSSStyleSheet=">The CSSStyleSheet.</param>
            /// <returns type="string">css text.</returns>
        }, 
        
        getAllCssStyleRules: function(opt_styleSheet) {
            /// <summary>Recursively gets all CSSStyleRules, optionally starting from a given
            /// CSSStyleSheet.
            /// Note that this excludes any CSSImportRules, CSSMediaRules, etc..</summary>
            /// <param name="opt_styleSheet" type="CSSStyleSheet=">The CSSStyleSheet.</param>
            /// <returns type="Array.CSSStyleRule">A list of CSSStyleRules.</returns>
        }, 
        
        getCssRulesFromStyleSheet: function(styleSheet) {
            /// <summary>Returns the CSSRules from a styleSheet.
            /// Worth noting here is that IE and FF differ in terms of what they will return.
            /// Firefox will return styleSheet.cssRules, which includes ImportRules and
            /// anything which implements the CSSRules interface. IE returns simply a list of
            /// CSSRules.</summary>
            /// <param name="styleSheet" type="CSSStyleSheet">The CSSStyleSheet.</param>
            /// <returns type="CSSRuleList">An array of CSSRules or null.</returns>
        }, 
        
        getAllCssStyleSheets: function(opt_styleSheet, opt_includeDisabled) {
            /// <summary>Gets all CSSStyleSheet objects starting from some CSSStyleSheet. Note that we
            /// want to return the sheets in the order of the cascade, therefore if we
            /// encounter an import, we will splice that CSSStyleSheet object in front of
            /// the CSSStyleSheet that contains it in the returned array of CSSStyleSheets.</summary>
            /// <param name="opt_styleSheet" type="CSSStyleSheet=">A CSSStyleSheet.</param>
            /// <param name="opt_includeDisabled" type="boolean=">If true, includes disabled stylesheets,
            ///    defaults to false.</param>
            /// <returns type="Array.CSSStyleSheet">A list of CSSStyleSheet objects.</returns>
        }, 
        
        getCssTextFromCssRule: function(cssRule) {
            /// <summary>Gets the cssText from a CSSRule object cross-browserly.</summary>
            /// <param name="cssRule" type="CSSRule">A CSSRule.</param>
            /// <returns type="string">cssText The text for the rule, including the selector.</returns>
        }, 
        
        getCssRuleIndexInParentStyleSheet: function(cssRule, opt_parentStyleSheet) {
            /// <summary>Get the index of the CSSRule in it&apos;s CSSStyleSheet.</summary>
            /// <param name="cssRule" type="CSSRule">A CSSRule.</param>
            /// <param name="opt_parentStyleSheet" type="CSSStyleSheet=">A reference to the stylesheet
            ///     object this cssRule belongs to.</param>
            /// <returns type="number">The index of the CSSRule, or -1.</returns>
        }, 
        
        getParentStyleSheet: function(cssRule) {
            /// <summary>We do some trickery in getAllCssStyleRules that hacks this in for IE.
            /// If the cssRule object isn&apos;t coming from a result of that function call, this
            /// method will return undefined in IE.</summary>
            /// <param name="cssRule" type="CSSRule">The CSSRule.</param>
            /// <returns type="CSSStyleSheet">A styleSheet object.</returns>
        }, 
        
        replaceCssRule: function(cssRule, cssText, opt_parentStyleSheet, opt_index) {
            /// <summary>Replace a cssRule with some cssText for a new rule.
            /// If the cssRule object is not one of objects returned by
            /// getAllCssStyleRules, then you&apos;ll need to provide both the styleSheet and
            /// possibly the index, since we can&apos;t infer them from the standard cssRule
            /// object in IE. We do some trickery in getAllCssStyleRules to hack this in.</summary>
            /// <param name="cssRule" type="CSSRule">A CSSRule.</param>
            /// <param name="cssText" type="string">The text for the new CSSRule.</param>
            /// <param name="opt_parentStyleSheet" type="CSSStyleSheet=">A reference to the stylesheet
            ///     object this cssRule belongs to.</param>
            /// <param name="opt_index" type="number=">The index of the cssRule in its parentStylesheet.</param>
        }, 
        
        addCssRule: function(cssStyleSheet, cssText, opt_index) {
            /// <summary>Cross browser function to add a CSSRule into a CSSStyleSheet, optionally
            /// at a given index.</summary>
            /// <param name="cssStyleSheet" type="CSSStyleSheet">The CSSRule&apos;s parentStyleSheet.</param>
            /// <param name="cssText" type="string">The text for the new CSSRule.</param>
            /// <param name="opt_index" type="number=">The index of the cssRule in its parentStylesheet.</param>
        }, 
        
        removeCssRule: function(cssStyleSheet, index) {
            /// <summary>Cross browser function to remove a CSSRule in a CSSStyleSheet at an index.</summary>
            /// <param name="cssStyleSheet" type="CSSStyleSheet">The CSSRule&apos;s parentStyleSheet.</param>
            /// <param name="index" type="number">The CSSRule&apos;s index in the parentStyleSheet.</param>
        }, 
        
        addCssText: function(cssText, opt_domHelper) {
            /// <summary>Appends a DOM node to HEAD containing the css text that&apos;s passed in.</summary>
            /// <param name="cssText" type="string">CSS to add to the end of the document.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper user for
            ///     document interactions.</param>
            /// <returns type="Element">The newly created STYLE element.</returns>
        }, 
        
        getFileNameFromStyleSheet: function(styleSheet) {
            /// <summary>Cross browser method to get the filename from the StyleSheet&apos;s href.
            /// Explorer only returns the filename in the href, while other agents return
            /// the full path.</summary>
            /// <param name="styleSheet" type="!StyleSheet">Any valid StyleSheet object with an href.</param>
            /// <returns type="?string">filename The filename, or null if not an external
            ///    styleSheet.</returns>
        }
        
    };

    var $x = window.goog.cssom;
    $x.__namespace = "true";
    $x.__typeName = "goog.cssom";
})(this);
