
/* vsdoc for goog.date */

(function (window) {
    window.goog = window.goog || {};

    window.goog.date = {
        /// <summary></summary>
        /// <field name="weekDay" type="">Constants for weekdays.</field>
        /// <field name="month" type="">Constants for months.</field>
        /// <field name="DateLike" type=""></field>
        /// <field name="relative" type=""></field>
        /// <returns type="goog.date"/>
                
        formatMonthAndYear: function(monthName, yearNum) {
            /// <summary>Formats a month/year string.
            /// Example: &quot;January 2008&quot;</summary>
            /// <param name="monthName" type="string">The month name to use in the result.</param>
            /// <param name="yearNum" type="number">The numeric year to use in the result.</param>
            /// <returns type="string">A formatted month/year string.</returns>
        }, 
        
        isLeapYear: function(year) {
            /// <summary>Returns whether the given year is a leap year.</summary>
            /// <param name="year" type="number">Year part of date.</param>
            /// <returns type="boolean">Whether the given year is a leap year.</returns>
        }, 
        
        isLongIsoYear: function(year) {
            /// <summary>Returns whether the given year is a long ISO year.
            /// See {@link http://www.phys.uu.nl/~vgent/calendar/isocalendar_text3.htm}.</summary>
            /// <param name="year" type="number">Full year part of date.</param>
            /// <returns type="boolean">Whether the given year is a long ISO year.</returns>
        }, 
        
        getNumberOfDaysInMonth: function(year, month) {
            /// <summary>Returns the number of days for a given month.</summary>
            /// <param name="year" type="number">Year part of date.</param>
            /// <param name="month" type="number">Month part of date.</param>
            /// <returns type="number">The number of days for the given month.</returns>
        }, 
        
        isSameDay: function(date, opt_now) {
            /// <summary>Returns true if the 2 dates are in the same day.</summary>
            /// <param name="date" type="goog.date.DateLike">The time to check.</param>
            /// <param name="opt_now" type="goog.date.DateLike=">The current time.</param>
            /// <returns type="boolean">Whether the dates are on the same day.</returns>
        }, 
        
        isSameMonth: function(date, opt_now) {
            /// <summary>Returns true if the 2 dates are in the same month.</summary>
            /// <param name="date" type="goog.date.DateLike">The time to check.</param>
            /// <param name="opt_now" type="goog.date.DateLike=">The current time.</param>
            /// <returns type="boolean">Whether the dates are in the same calendar month.</returns>
        }, 
        
        isSameYear: function(date, opt_now) {
            /// <summary>Returns true if the 2 dates are in the same year.</summary>
            /// <param name="date" type="goog.date.DateLike">The time to check.</param>
            /// <param name="opt_now" type="goog.date.DateLike=">The current time.</param>
            /// <returns type="boolean">Whether the dates are in the same calendar year.</returns>
        }, 
        
        getWeekNumber: function(year, month, date, opt_weekDay, opt_firstDayOfWeek) {
            /// <summary>Static function for week number calculation. ISO 8601 implementation.</summary>
            /// <param name="year" type="number">Year part of date.</param>
            /// <param name="month" type="number">Month part of date (0-11).</param>
            /// <param name="date" type="number">Day part of date (1-31).</param>
            /// <param name="opt_weekDay" type="number=">Cut off weekday, defaults to Thursday.</param>
            /// <param name="opt_firstDayOfWeek" type="number=">First day of the week, defaults to
            ///     Monday.
            ///     Monday=0, Sunday=6.</param>
            /// <returns type="number">The week number (1-53).</returns>
        }, 
        
        fromIsoString: function(formatted) {
            /// <summary>Creates a DateTime from a datetime string expressed in ISO 8601 format.</summary>
            /// <param name="formatted" type="string">A date or datetime expressed in ISO 8601 format.</param>
            /// <returns type="goog.date.DateTime">Parsed date or null if parse fails.</returns>
        }, 
        
        setIso8601DateTime: function(dateTime, formatted) {
            /// <summary>Parses a datetime string expressed in ISO 8601 format. Overwrites the date
            /// and optionally the time part of the given object with the parsed values.</summary>
            /// <param name="dateTime" type="!goog.date.DateTime">Object whose fields will be set.</param>
            /// <param name="formatted" type="string">A date or datetime expressed in ISO 8601 format.</param>
            /// <returns type="boolean">Whether the parsing succeeded.</returns>
        }
        
    };

    var $x = window.goog.date;
    $x.__namespace = "true";
    $x.__typeName = "goog.date";
})(this);
