
/* vsdoc for goog.date.Date */

(function (window) {
    window.goog.date = window.goog.date || {};

    window.goog.date.Date = function(opt_year, opt_month, opt_date){
        /// <summary></summary>
        /// <param name="opt_year" type="number|Object=">Four digit year or a date-like object. If
        ///     not set, the created object will contain the date determined by
        ///     goog.now().</param>
        /// <param name="opt_month" type="number=">Month, 0 = Jan, 11 = Dec.</param>
        /// <param name="opt_date" type="number=">Date of month, 1 - 31.</param>
        /// <returns type="goog.date.Date"/>
    };

    var $x = window.goog.date.Date;
    $x.prototype = {
                
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.date.Date">A clone of the date object.</returns>
        }, 
        
        getFullYear: function() {
            /// <summary></summary>
            /// <returns type="number">The four digit year of date.</returns>
        }, 
        
        getYear: function() {
            /// <summary>Alias for getFullYear.</summary>
            /// <returns type="number">The four digit year of date.</returns>
        }, 
        
        getMonth: function() {
            /// <summary></summary>
            /// <returns type="goog.date.month">The month of date, 0 = Jan, 11 = Dec.</returns>
        }, 
        
        getDate: function() {
            /// <summary></summary>
            /// <returns type="number">The date of month.</returns>
        }, 
        
        getTime: function() {
            /// <summary>Returns the number of milliseconds since 1 January 1970 00:00:00.</summary>
            /// <returns type="number">The number of milliseconds since 1 January 1970 00:00:00.</returns>
        }, 
        
        getDay: function() {
            /// <summary></summary>
            /// <returns type="goog.date.weekDay">The day of week, US style. 0 = Sun, 6 = Sat.</returns>
        }, 
        
        getIsoWeekday: function() {
            /// <summary></summary>
            /// <returns type="number">The day of week, ISO style. 0 = Mon, 6 = Sun.</returns>
        }, 
        
        getWeekday: function() {
            /// <summary></summary>
            /// <returns type="number">The day of week according to firstDayOfWeek setting.</returns>
        }, 
        
        getUTCFullYear: function() {
            /// <summary></summary>
            /// <returns type="number">The four digit year of date according to universal time.</returns>
        }, 
        
        getUTCMonth: function() {
            /// <summary></summary>
            /// <returns type="goog.date.month">The month of date according to universal time,
            ///     0 = Jan, 11 = Dec.</returns>
        }, 
        
        getUTCDate: function() {
            /// <summary></summary>
            /// <returns type="number">The date of month according to universal time.</returns>
        }, 
        
        getUTCDay: function() {
            /// <summary></summary>
            /// <returns type="goog.date.weekDay">The day of week according to universal time,
            ///     US style. 0 = Sun, 1 = Mon, 6 = Sat.</returns>
        }, 
        
        getUTCHours: function() {
            /// <summary></summary>
            /// <returns type="number">The hours value according to universal time.</returns>
        }, 
        
        getUTCMinutes: function() {
            /// <summary></summary>
            /// <returns type="number">The hours value according to universal time.</returns>
        }, 
        
        getUTCIsoWeekday: function() {
            /// <summary></summary>
            /// <returns type="number">The day of week according to universal time, ISO style.
            ///     0 = Mon, 6 = Sun.</returns>
        }, 
        
        getUTCWeekday: function() {
            /// <summary></summary>
            /// <returns type="number">The day of week according to universal time and
            ///     firstDayOfWeek setting.</returns>
        }, 
        
        getFirstDayOfWeek: function() {
            /// <summary></summary>
            /// <returns type="number">The first day of the week. 0 = Mon, 6 = Sun.</returns>
        }, 
        
        getFirstWeekCutOffDay: function() {
            /// <summary></summary>
            /// <returns type="number">The cut off weekday used for week number calculations.
            ///     0 = Mon, 6 = Sun.</returns>
        }, 
        
        getNumberOfDaysInMonth: function() {
            /// <summary></summary>
            /// <returns type="number">The number of days for the selected month.</returns>
        }, 
        
        getWeekNumber: function() {
            /// <summary></summary>
            /// <returns type="number">The week number.</returns>
        }, 
        
        getDayOfYear: function() {
            /// <summary></summary>
            /// <returns type="number">The day of year.</returns>
        }, 
        
        getTimezoneOffset: function() {
            /// <summary>Returns timezone offset. The timezone offset is the delta in minutes between
            /// UTC and your local time. E.g., UTC+10 returns -600. Daylight savings time
            /// prevents this value from being constant.</summary>
            /// <returns type="number">The timezone offset.</returns>
        }, 
        
        getTimezoneOffsetString: function() {
            /// <summary>Returns timezone offset as a string. Returns offset in [+-]HH:mm format or Z
            /// for UTC.</summary>
            /// <returns type="string">The timezone offset as a string.</returns>
        }, 
        
        set: function(date) {
            /// <summary>Sets the date.</summary>
            /// <param name="date" type="goog.date.Date">Date object to set date from.</param>
        }, 
        
        setFullYear: function(year) {
            /// <summary>Sets the year part of the date.</summary>
            /// <param name="year" type="number">Four digit year.</param>
        }, 
        
        setYear: function(year) {
            /// <summary>Alias for setFullYear.</summary>
            /// <param name="year" type="number">Four digit year.</param>
        }, 
        
        setMonth: function(month) {
            /// <summary>Sets the month part of the date.
            /// 
            /// TODO(nnaze): Update type to goog.date.month.</summary>
            /// <param name="month" type="number">The month, where 0 = Jan, 11 = Dec.</param>
        }, 
        
        setDate: function(date) {
            /// <summary>Sets the day part of the date.</summary>
            /// <param name="date" type="number">The day part.</param>
        }, 
        
        setTime: function(ms) {
            /// <summary>Sets the value of the date object as expressed in the number of milliseconds
            /// since 1 January 1970 00:00:00.</summary>
            /// <param name="ms" type="number">Number of milliseconds since 1 Jan 1970.</param>
        }, 
        
        setUTCFullYear: function(year) {
            /// <summary>Sets the year part of the date according to universal time.</summary>
            /// <param name="year" type="number">Four digit year.</param>
        }, 
        
        setUTCMonth: function(month) {
            /// <summary>Sets the month part of the date according to universal time.</summary>
            /// <param name="month" type="number">The month, where 0 = Jan, 11 = Dec.</param>
        }, 
        
        setUTCDate: function(date) {
            /// <summary>Sets the day part of the date according to universal time.</summary>
            /// <param name="date" type="number">The UTC date.</param>
        }, 
        
        setFirstDayOfWeek: function(day) {
            /// <summary>Sets the first day of week.</summary>
            /// <param name="day" type="number">0 = Mon, 6 = Sun.</param>
        }, 
        
        setFirstWeekCutOffDay: function(day) {
            /// <summary>Sets cut off weekday used for week number calculations. 0 = Mon, 6 = Sun.</summary>
            /// <param name="day" type="number">The cut off weekday.</param>
        }, 
        
        add: function(interval) {
            /// <summary>Performs date calculation by adding the supplied interval to the date.</summary>
            /// <param name="interval" type="goog.date.Interval">Date interval to add.</param>
        }, 
        
        toIsoString: function(opt_verbose, opt_tz) {
            /// <summary>Returns ISO 8601 string representation of date.</summary>
            /// <param name="opt_verbose" type="boolean=">Whether the verbose format should be used
            ///     instead of the default compact one.</param>
            /// <param name="opt_tz" type="boolean=">Whether the timezone offset should be included
            ///     in the string.</param>
            /// <returns type="string">ISO 8601 string representation of date.</returns>
        }, 
        
        toUTCIsoString: function(opt_verbose, opt_tz) {
            /// <summary>Returns ISO 8601 string representation of date according to universal time.</summary>
            /// <param name="opt_verbose" type="boolean=">Whether the verbose format should be used
            ///     instead of the default compact one.</param>
            /// <param name="opt_tz" type="boolean=">Whether the timezone offset should be included in
            ///     the string.</param>
            /// <returns type="string">ISO 8601 string representation of date according to
            ///     universal time.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Tests whether given date is equal to this Date.
            /// Note: This ignores units more precise than days (hours and below)
            /// and also ignores timezone considerations.</summary>
            /// <param name="other" type="goog.date.Date">The date to compare.</param>
            /// <returns type="boolean">Whether the given date is equal to this one.</returns>
        }, 
        
        toString: function() {
            /// <summary>Overloaded toString method for object.</summary>
            /// <returns type="string">ISO 8601 string representation of date.</returns>
        }, 
        
        valueOf: function() {
            /// <summary></summary>
            /// <returns type="number">Value of wrapped date.</returns>
        }, 
        
        compare: function(date1, date2) {
            /// <summary>Compares two dates.  May be used as a sorting function.</summary>
            /// <param name="date1" type="!goog.date.DateLike">Date to compare.</param>
            /// <param name="date2" type="!goog.date.DateLike">Date to compare.</param>
            /// <returns type="number">Comparison result. 0 if dates are the same, less than 0 if
            ///     date1 is earlier than date2, greater than 0 if date1 is later than date2.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.date.Date";
})(this);
