
/* vsdoc for goog.date.DateRange */

(function (window) {
    window.goog.date = window.goog.date || {};

    window.goog.date.DateRange = function(startDate, endDate){
        /// <summary></summary>
        /// <param name="startDate" type="goog.date.Date">The first date in the range.</param>
        /// <param name="endDate" type="goog.date.Date">The last date in the range.</param>
        /// <field name="MINIMUM_DATE" type="goog.date.Date">The first possible day, as far as this class is concerned.</field>
        /// <field name="MAXIMUM_DATE" type="goog.date.Date">The last possible day, as far as this class is concerned.</field>
        /// <field name="StandardDateRangeKeys" type="">Standard date range keys. Equivalent to the enum IDs in
        /// DateRange.java http://go/datarange.java</field>
        /// <returns type="goog.date.DateRange"/>
    };

    var $x = window.goog.date.DateRange;
    $x.prototype = {
                
        getStartDate: function() {
            /// <summary></summary>
            /// <returns type="goog.date.Date">The first date in the range.</returns>
        }, 
        
        getEndDate: function() {
            /// <summary></summary>
            /// <returns type="goog.date.Date">The last date in the range.</returns>
        }, 
        
        iterator: function() {
            /// <summary></summary>
            /// <returns type="goog.iter.Iterator">An iterator over the date range.</returns>
        }, 
        
        equals: function(a, b) {
            /// <summary>Tests two {@link goog.date.DateRange} objects for equality.</summary>
            /// <param name="a" type="goog.date.DateRange">A date range.</param>
            /// <param name="b" type="goog.date.DateRange">A date range.</param>
            /// <returns type="boolean">Whether |a| is the same range as |b|.</returns>
        }, 
        
        yesterday: function(opt_today) {
            /// <summary>Returns the range from yesterday to yesterday.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that includes only yesterday.</returns>
        }, 
        
        today: function(opt_today) {
            /// <summary>Returns the range from today to today.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that includes only today.</returns>
        }, 
        
        last7Days: function(opt_today) {
            /// <summary>Returns the range that includes the seven days that end yesterday.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that includes the seven days that
            ///     end yesterday.</returns>
        }, 
        
        thisMonth: function(opt_today) {
            /// <summary>Returns the range that starts the first of this month and ends the last day
            /// of this month.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that starts the first of this month
            ///     and ends the last day of this month.</returns>
        }, 
        
        lastMonth: function(opt_today) {
            /// <summary>Returns the range that starts the first of last month and ends the last day
            /// of last month.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that starts the first of last month
            ///     and ends the last day of last month.</returns>
        }, 
        
        thisWeek: function(opt_today) {
            /// <summary>Returns the seven-day range that starts on the first day of the week
            /// (see {@link goog.i18n.DateTimeSymbols.FIRSTDAYOFWEEK}) on or before today.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that starts the Monday on or before
            ///     today and ends the Sunday on or after today.</returns>
        }, 
        
        lastWeek: function(opt_today) {
            /// <summary>Returns the seven-day range that ends the day before the first day of
            /// the week (see {@link goog.i18n.DateTimeSymbols.FIRSTDAYOFWEEK}) that
            /// contains today.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that starts seven days before the
            ///     Monday on or before today and ends the Sunday on or before yesterday.</returns>
        }, 
        
        lastBusinessWeek: function(opt_today) {
            /// <summary>Returns the range that starts seven days before the Monday on or before
            /// today and ends the Friday before today.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that starts seven days before the
            ///     Monday on or before today and ends the Friday before today.</returns>
        }, 
        
        allTime: function(opt_today) {
            /// <summary>Returns the range that includes all days between January 1, 1900 and
            /// December 31, 9999.</summary>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The range that includes all days between
            ///     January 1, 1900 and December 31, 9999.</returns>
        }, 
        
        standardDateRange: function(dateRangeKey, opt_today) {
            /// <summary></summary>
            /// <param name="dateRangeKey" type="string">A standard date range key.</param>
            /// <param name="opt_today" type="goog.date.Date=">The date to consider today.
            ///     Defaults to today.</param>
            /// <returns type="goog.date.DateRange">The date range that corresponds to that key.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.date.DateRange";
})(this);
