
/* vsdoc for goog.date.DateTime */

(function (window) {
    window.goog.date = window.goog.date || {};

    window.goog.date.DateTime = function(opt_year, opt_month, opt_date, opt_hours, opt_minutes, opt_seconds, opt_milliseconds){
        /// <summary></summary>
        /// <param name="opt_year" type="number|Object=">Four digit year or a date-like object. If
        ///     not set, the created object will contain the date determined by
        ///     goog.now().</param>
        /// <param name="opt_month" type="number=">Month, 0 = Jan, 11 = Dec.</param>
        /// <param name="opt_date" type="number=">Date of month, 1 - 31.</param>
        /// <param name="opt_hours" type="number=">Hours, 0 - 24.</param>
        /// <param name="opt_minutes" type="number=">Minutes, 0 - 59.</param>
        /// <param name="opt_seconds" type="number=">Seconds, 0 - 61.</param>
        /// <param name="opt_milliseconds" type="number=">Milliseconds, 0 - 999.</param>
        /// <returns type="goog.date.DateTime"/>
    };

    var $x = window.goog.date.DateTime;
    $x.prototype = {
                
        fromRfc822String: function(formatted) {
            /// <summary>Creates a DateTime from a datetime string expressed in RFC 822 format.</summary>
            /// <param name="formatted" type="string">A date or datetime expressed in RFC 822 format.</param>
            /// <returns type="goog.date.DateTime">Parsed date or null if parse fails.</returns>
        }, 
        
        getHours: function() {
            /// <summary>Returns the hours part of the datetime.</summary>
            /// <returns type="number">An integer between 0 and 23, representing the hour.</returns>
        }, 
        
        getMinutes: function() {
            /// <summary>Returns the minutes part of the datetime.</summary>
            /// <returns type="number">An integer between 0 and 59, representing the minutes.</returns>
        }, 
        
        getSeconds: function() {
            /// <summary>Returns the seconds part of the datetime.</summary>
            /// <returns type="number">An integer between 0 and 59, representing the seconds.</returns>
        }, 
        
        getMilliseconds: function() {
            /// <summary>Returns the milliseconds part of the datetime.</summary>
            /// <returns type="number">An integer between 0 and 999, representing the milliseconds.</returns>
        }, 
        
        getUTCDay: function() {
            /// <summary>Returns the day of week according to universal time, US style.</summary>
            /// <returns type="goog.date.weekDay">Day of week, 0 = Sun, 1 = Mon, 6 = Sat.</returns>
        }, 
        
        getUTCHours: function() {
            /// <summary>Returns the hours part of the datetime according to universal time.</summary>
            /// <returns type="number">An integer between 0 and 23, representing the hour.</returns>
        }, 
        
        getUTCMinutes: function() {
            /// <summary>Returns the minutes part of the datetime according to universal time.</summary>
            /// <returns type="number">An integer between 0 and 59, representing the minutes.</returns>
        }, 
        
        getUTCSeconds: function() {
            /// <summary>Returns the seconds part of the datetime according to universal time.</summary>
            /// <returns type="number">An integer between 0 and 59, representing the seconds.</returns>
        }, 
        
        getUTCMilliseconds: function() {
            /// <summary>Returns the milliseconds part of the datetime according to universal time.</summary>
            /// <returns type="number">An integer between 0 and 999, representing the milliseconds.</returns>
        }, 
        
        setHours: function(hours) {
            /// <summary>Sets the hours part of the datetime.</summary>
            /// <param name="hours" type="number">An integer between 0 and 23, representing the hour.</param>
        }, 
        
        setMinutes: function(minutes) {
            /// <summary>Sets the minutes part of the datetime.</summary>
            /// <param name="minutes" type="number">Integer between 0 and 59, representing the minutes.</param>
        }, 
        
        setSeconds: function(seconds) {
            /// <summary>Sets the seconds part of the datetime.</summary>
            /// <param name="seconds" type="number">Integer between 0 and 59, representing the seconds.</param>
        }, 
        
        setMilliseconds: function(ms) {
            /// <summary>Sets the seconds part of the datetime.</summary>
            /// <param name="ms" type="number">Integer between 0 and 999, representing the milliseconds.</param>
        }, 
        
        setUTCHours: function(hours) {
            /// <summary>Sets the hours part of the datetime according to universal time.</summary>
            /// <param name="hours" type="number">An integer between 0 and 23, representing the hour.</param>
        }, 
        
        setUTCMinutes: function(minutes) {
            /// <summary>Sets the minutes part of the datetime according to universal time.</summary>
            /// <param name="minutes" type="number">Integer between 0 and 59, representing the minutes.</param>
        }, 
        
        setUTCSeconds: function(seconds) {
            /// <summary>Sets the seconds part of the datetime according to universal time.</summary>
            /// <param name="seconds" type="number">Integer between 0 and 59, representing the seconds.</param>
        }, 
        
        setUTCMilliseconds: function(ms) {
            /// <summary>Sets the seconds part of the datetime according to universal time.</summary>
            /// <param name="ms" type="number">Integer between 0 and 999, representing the milliseconds.</param>
        }, 
        
        add: function(interval) {
            /// <summary>Performs date calculation by adding the supplied interval to the date.</summary>
            /// <param name="interval" type="goog.date.Interval">Date interval to add.</param>
        }, 
        
        toIsoString: function(opt_verbose, opt_tz) {
            /// <summary>Returns ISO 8601 string representation of date/time.</summary>
            /// <param name="opt_verbose" type="boolean=">Whether the verbose format should be used
            ///     instead of the default compact one.</param>
            /// <param name="opt_tz" type="boolean=">Whether the timezone offset should be included
            ///     in the string.</param>
            /// <returns type="string">ISO 8601 string representation of date/time.</returns>
        }, 
        
        toXmlDateTime: function(opt_timezone) {
            /// <summary>Returns XML Schema 2 string representation of date/time.
            /// The return value is also ISO 8601 compliant.</summary>
            /// <param name="opt_timezone" type="boolean=">Should the timezone offset be included in the
            ///     string?.</param>
            /// <returns type="string">XML Schema 2 string representation of date/time.</returns>
        }, 
        
        toUTCIsoString: function(opt_verbose, opt_tz) {
            /// <summary>Returns ISO 8601 string representation of date/time according to universal
            /// time.</summary>
            /// <param name="opt_verbose" type="boolean=">Whether the opt_verbose format should be
            ///     returned instead of the default compact one.</param>
            /// <param name="opt_tz" type="boolean=">Whether the the timezone offset should be included
            ///     in the string.</param>
            /// <returns type="string">ISO 8601 string representation of date/time according to
            ///     universal time.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Tests whether given datetime is exactly equal to this DateTime.</summary>
            /// <param name="other" type="goog.date.Date">The datetime to compare.</param>
            /// <returns type="boolean">Whether the given datetime is exactly equal to this one.</returns>
        }, 
        
        toString: function() {
            /// <summary>Overloaded toString method for object.</summary>
            /// <returns type="string">ISO 8601 string representation of date/time.</returns>
        }, 
        
        toUsTimeString: function(opt_padHours, opt_showAmPm, opt_omitZeroMinutes) {
            /// <summary>Generates time label for the datetime, e.g., &apos;5:30am&apos;.
            /// By default this does not pad hours (e.g., to &apos;05:30&apos;) and it does add
            /// an am/pm suffix.
            /// TODO(user): i18n -- hardcoding time format like this is bad.  E.g., in CJK
            ///               locales, need Chinese characters for hour and minute units.</summary>
            /// <param name="opt_padHours" type="boolean=">Whether to pad hours, e.g., &apos;05:30&apos; vs &apos;5:30&apos;.</param>
            /// <param name="opt_showAmPm" type="boolean=">Whether to show the &apos;am&apos; and &apos;pm&apos; suffix.</param>
            /// <param name="opt_omitZeroMinutes" type="boolean=">E.g., &apos;5:00pm&apos; becomes &apos;5pm&apos;,
            ///                                      but &apos;5:01pm&apos; remains &apos;5:01pm&apos;.</param>
            /// <returns type="string">The time label.</returns>
        }, 
        
        toIsoTimeString: function(opt_showSeconds) {
            /// <summary>Generates time label for the datetime in standard ISO 24-hour time format.
            /// E.g., &apos;06:00:00&apos; or &apos;23:30:15&apos;.</summary>
            /// <param name="opt_showSeconds" type="boolean=">Whether to shows seconds. Defaults to TRUE.</param>
            /// <returns type="string">The time label.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.date.DateTime">A clone of the datetime object.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.date.DateTime";
})(this);
