
/* vsdoc for goog.date.Interval */

(function (window) {
    window.goog.date = window.goog.date || {};

    window.goog.date.Interval = function(opt_years, opt_months, opt_days, opt_hours, opt_minutes, opt_seconds){
        /// <summary></summary>
        /// <param name="opt_years" type="number|string=">Years or string representing date part.</param>
        /// <param name="opt_months" type="number=">Months or number of whatever date part specified
        ///     by first parameter.</param>
        /// <param name="opt_days" type="number=">Days.</param>
        /// <param name="opt_hours" type="number=">Hours.</param>
        /// <param name="opt_minutes" type="number=">Minutes.</param>
        /// <param name="opt_seconds" type="number=">Seconds.</param>
        /// <field name="YEARS" type="string">Years constant for the date parts.</field>
        /// <field name="MONTHS" type="string">Months constant for the date parts.</field>
        /// <field name="DAYS" type="string">Days constant for the date parts.</field>
        /// <field name="HOURS" type="string">Hours constant for the date parts.</field>
        /// <field name="MINUTES" type="string">Minutes constant for the date parts.</field>
        /// <field name="SECONDS" type="string">Seconds constant for the date parts.</field>
        /// <returns type="goog.date.Interval"/>
    };

    var $x = window.goog.date.Interval;
    $x.prototype = {
                
        fromIsoString: function(duration) {
            /// <summary>Parses an XML Schema duration (ISO 8601 extended).</summary>
            /// <param name="duration" type="string">An XML schema duration in textual format.
            ///     Recurring durations and weeks are not supported.</param>
            /// <returns type="goog.date.Interval">The duration as a goog.date.Interval or null
            ///     if the parse fails.</returns>
        }, 
        
        toIsoString: function(opt_verbose) {
            /// <summary>Serializes goog.date.Interval into XML Schema duration (ISO 8601 extended).</summary>
            /// <param name="opt_verbose" type="boolean=">Include zero fields in the duration string.</param>
            /// <returns type="?string">An XML schema duration in ISO 8601 extended format,
            ///     or null if the interval contains both positive and negative fields.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Tests whether the given interval is equal to this interval.
            /// Note, this is a simple field-by-field comparison, it doesn&apos;t
            /// account for comparisons like &quot;12 months == 1 year&quot;.</summary>
            /// <param name="other" type="goog.date.Interval">The interval to test.</param>
            /// <returns type="boolean">Whether the intervals are equal.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.date.Interval">A clone of the interval object.</returns>
        }, 
        
        isZero: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether all fields of the interval are zero.</returns>
        }, 
        
        getInverse: function() {
            /// <summary></summary>
            /// <returns type="!goog.date.Interval">Negative of this interval.</returns>
        }, 
        
        times: function(n) {
            /// <summary>Calculates n * (this interval) by memberwise multiplication.</summary>
            /// <param name="n" type="number">An integer.</param>
            /// <returns type="!goog.date.Interval">n * this.</returns>
        }, 
        
        getTotalSeconds: function() {
            /// <summary>Gets the total number of seconds in the time interval. Assumes that months
            /// and years are empty.</summary>
            /// <returns type="number">Total number of seconds in the interval.</returns>
        }, 
        
        add: function(interval) {
            /// <summary>Adds the Interval in the argument to this Interval field by field.</summary>
            /// <param name="interval" type="goog.date.Interval">The Interval to add.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.date.Interval";
})(this);
