
/* vsdoc for goog.date.relative */

(function (window) {
    window.goog.date = window.goog.date || {};

    window.goog.date.relative = {
        /// <summary></summary>
        /// <returns type="goog.date.relative"/>
                
        format: function(dateMs) {
            /// <summary>Accepts a timestamp in milliseconds and outputs a relative time in the form
            /// of &quot;1 hour ago&quot;, &quot;1 day ago&quot;, &quot;in 1 hour&quot;, &quot;in 2 days&quot; etc.  If the date
            /// delta is over 2 weeks, then the output string will be empty.</summary>
            /// <param name="dateMs" type="number">Date in milliseconds.</param>
            /// <returns type="string">The formatted date.</returns>
        }, 
        
        formatPast: function(dateMs) {
            /// <summary>Accepts a timestamp in milliseconds and outputs a relative time in the form
            /// of &quot;1 hour ago&quot;, &quot;1 day ago&quot;.  All future times will be returned as 0 minutes
            /// ago.
            /// 
            /// This is provided for compatibility with users of the previous incarnation of
            /// the above {@see #format} method who relied on it protecting against
            /// future dates.</summary>
            /// <param name="dateMs" type="number">Date in milliseconds.</param>
            /// <returns type="string">The formatted date.</returns>
        }, 
        
        formatDay: function(dateMs, opt_formatter) {
            /// <summary>Accepts a timestamp in milliseconds and outputs a relative day. i.e. &quot;Today&quot;,
            /// &quot;Yesterday&quot; or &quot;Sept 15&quot;.</summary>
            /// <param name="dateMs" type="number">Date in milliseconds.</param>
            /// <param name="opt_formatter" type="!function(!Date):string=">Formatter for the date.
            ///     Defaults to form &apos;MMM dd&apos;.</param>
            /// <returns type="string">The formatted date.</returns>
        }, 
        
        getDateString: function(date, opt_shortTimeMsg, opt_fullDateMsg) {
            /// <summary>Formats a date, adding the relative date in parenthesis.  If the date is less
            /// than 24 hours then the time will be printed, otherwise the full-date will be
            /// used.  Examples:
            ///   2:20 PM (1 minute ago)
            ///   Monday, February 27, 2009 (4 days ago)
            ///   Tuesday, March 20, 2005    // Too long ago for a relative date.</summary>
            /// <param name="date" type="Date|goog.date.DateTime">A date object.</param>
            /// <param name="opt_shortTimeMsg" type="string=">An optional short time message can be
            ///     provided if available, so that it&apos;s not recalculated in this function.</param>
            /// <param name="opt_fullDateMsg" type="string=">An optional date message can be
            ///     provided if available, so that it&apos;s not recalculated in this function.</param>
            /// <returns type="string">The date string in the above form.</returns>
        }, 
        
        getPastDateString: function(date, opt_shortTimeMsg, opt_fullDateMsg) {
            /// <summary>Formats a date, adding the relative date in parenthesis.   Functions the same
            /// as #getDateString but ensures that the date is always seen to be in the past.
            /// If the date is in the future, it will be shown as 0 minutes ago.
            /// 
            /// This is provided for compatibility with users of the previous incarnation of
            /// the above {@see #getDateString} method who relied on it protecting against
            /// future dates.</summary>
            /// <param name="date" type="Date|goog.date.DateTime">A date object.</param>
            /// <param name="opt_shortTimeMsg" type="string=">An optional short time message can be
            ///     provided if available, so that it&apos;s not recalculated in this function.</param>
            /// <param name="opt_fullDateMsg" type="string=">An optional date message can be
            ///     provided if available, so that it&apos;s not recalculated in this function.</param>
            /// <returns type="string">The date string in the above form.</returns>
        }
        
    };

    var $x = window.goog.date.relative;
    $x.__namespace = "true";
    $x.__typeName = "goog.date.relative";
})(this);
