
/* vsdoc for goog.db.Cursor */

(function (window) {
    window.goog.db = window.goog.db || {};

    window.goog.db.Cursor = function(){
        /// <summary></summary>
        /// <field name="Direction" type="">Possible cursor directions.</field>
        /// <field name="EventType" type="">Event types that the cursor can dispatch. COMPLETE events are dispatched when
        /// a cursor is depleted of values, a NEW_DATA event if there is new data
        /// availible, and ERROR if an error occurred.</field>
        /// <returns type="goog.db.Cursor"/>
    };

    var $x = window.goog.db.Cursor;
    $x.prototype = {
                
        next: function(opt_key) {
            /// <summary>Advances the cursor to the next position along its direction. When new data
            /// is availible, the NEW_DATA event will be fired. If the cursor has reached the
            /// end of the range it will fire the COMPLETE event. If opt_key is specified it
            /// will advance to the key it matches in its direction.
            /// 
            /// This wraps the native #continue method on the underlying object.</summary>
            /// <param name="opt_key" type="!Object=">The optional key to advance to.</param>
        }, 
        
        update: function(value) {
            /// <summary>Updates the value at the current position of the cursor in the object store.
            /// If the cursor points to a value that has just been deleted, a new value is
            /// created.</summary>
            /// <param name="value" type="!Object">The value to be stored.</param>
            /// <returns type="!goog.async.Deferred">The resulting deferred request.</returns>
        }, 
        
        remove: function() {
            /// <summary>Deletes the value at the cursor&apos;s position, without changing the cursor&apos;s
            /// position. Once the value is deleted, the cursor&apos;s value is set to null.</summary>
            /// <returns type="!goog.async.Deferred">The resulting deferred request.</returns>
        }, 
        
        getValue: function() {
            /// <summary></summary>
            /// <returns type="Object">The value for the value at the cursor&apos;s position. Undefined
            ///     if no current value, or null if value has just been deleted.</returns>
        }, 
        
        getKey: function() {
            /// <summary></summary>
            /// <returns type="*">The key for the value at the cursor&apos;s position. If the
            ///     cursor is outside its range, this is undefined.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.db.Cursor";
})(this);
