
/* vsdoc for goog.db.IndexedDb */

(function (window) {
    window.goog.db = window.goog.db || {};

    window.goog.db.IndexedDb = function(db){
        /// <summary></summary>
        /// <param name="db" type="!IDBDatabase">Underlying IndexedDB database object.</param>
        /// <returns type="goog.db.IndexedDb"/>
    };

    var $x = window.goog.db.IndexedDb;
    $x.prototype = {
                
        close: function() {
            /// <summary>Closes the database connection. Metadata queries can still be made after this
            /// method is called, but otherwise this wrapper should not be used further.</summary>
        }, 
        
        isOpen: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether a connection is open and the database can be used.</returns>
        }, 
        
        getName: function() {
            /// <summary></summary>
            /// <returns type="string">The name of this database.</returns>
        }, 
        
        getVersion: function() {
            /// <summary></summary>
            /// <returns type="string">The current database version.</returns>
        }, 
        
        getObjectStoreNames: function() {
            /// <summary></summary>
            /// <returns type="DOMStringList">List of object stores in this database.</returns>
        }, 
        
        createObjectStore: function(name, opt_params) {
            /// <summary>Creates an object store in this database. Can only be called inside the
            /// callback for the Deferred returned from #setVersion.</summary>
            /// <param name="name" type="string">Name for the new object store.</param>
            /// <param name="opt_params" type="Object=">Options object. The available options are:
            ///     keyPath, which is a string and determines what object attribute
            ///     to use as the key when storing objects in this object store; and
            ///     autoIncrement, which is a boolean, which defaults to false and determines
            ///     whether the object store should automatically generate keys for stored
            ///     objects. If keyPath is not provided and autoIncrement is false, then all
            ///     insert operations must provide a key as a parameter.</param>
            /// <returns type="goog.db.ObjectStore">The newly created object store.</returns>
        }, 
        
        "delete": function(name) {
            /// <summary>Deletes an object store. Can only be called inside the callback for the
            /// Deferred returned from #setVersion.</summary>
            /// <param name="name" type="string">Name of the object store to delete.</param>
        }, 
        
        setVersion: function(version) {
            /// <summary>Updates the version of the database and returns a Deferred transaction.
            /// The database&apos;s structure can be changed inside this Deferred&apos;s callback, but
            /// nowhere else. This means adding or deleting object stores, and adding or
            /// deleting indexes. The version change will not succeed unless there are no
            /// other connections active for this database anywhere. A new database
            /// connection should be opened after the version change is finished to pick
            /// up changes.</summary>
            /// <param name="version" type="string">The new version of the database.</param>
            /// <returns type="!goog.async.Deferred">The deferred transaction for changing the
            ///     version.</returns>
        }, 
        
        createTransaction: function(storeNames, opt_mode) {
            /// <summary>Creates a new transaction.</summary>
            /// <param name="storeNames" type="!Array.string">A list of strings that contains the
            ///     transaction&apos;s scope, the object stores that this transaction can operate
            ///     on.</param>
            /// <param name="opt_mode" type="goog.db.Transaction.TransactionMode=">The mode of the
            ///     transaction. If not present, the default is READ_ONLY. For VERSION_CHANGE
            ///     transactions call {@link goog.db.IndexedDB#setVersion} instead.</param>
            /// <returns type="!goog.db.Transaction">The wrapper for the newly created transaction.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.db.IndexedDb";
})(this);
