
/* vsdoc for goog.db.ObjectStore */

(function (window) {
    window.goog.db = window.goog.db || {};

    window.goog.db.ObjectStore = function(store){
        /// <summary></summary>
        /// <param name="store" type="!IDBObjectStore">The backing IndexedDb object.</param>
        /// <returns type="goog.db.ObjectStore"/>
    };

    var $x = window.goog.db.ObjectStore;
    $x.prototype = {
                
        getName: function() {
            /// <summary></summary>
            /// <returns type="string">The name of the object store.</returns>
        }, 
        
        put: function(value, opt_key) {
            /// <summary>Adds an object to the object store. Replaces existing objects with the
            /// same key.</summary>
            /// <param name="value" type="!Object">The value to put.</param>
            /// <param name="opt_key" type="!Object=">The key to use. Cannot be used if the keyPath was
            ///     specified for the object store. If the keyPath was not specified but
            ///     autoIncrement was not enabled, it must be used.</param>
            /// <returns type="!goog.async.Deferred">The deferred put request.</returns>
        }, 
        
        add: function(value, opt_key) {
            /// <summary>Adds an object to the object store. Requires that there is no object with
            /// the same key already present.</summary>
            /// <param name="value" type="!Object">The value to add.</param>
            /// <param name="opt_key" type="!Object=">The key to use. Cannot be used if the keyPath was
            ///     specified for the object store. If the keyPath was not specified but
            ///     autoIncrement was not enabled, it must be used.</param>
            /// <returns type="!goog.async.Deferred">The deferred add request.</returns>
        }, 
        
        remove: function(key) {
            /// <summary>Removes an object from the store. No-op if there is no object present with
            /// the given key.</summary>
            /// <param name="key" type="!Object">The key to remove objects under.</param>
            /// <returns type="!goog.async.Deferred">The deferred remove request.</returns>
        }, 
        
        get: function(key) {
            /// <summary>Gets an object from the store. If no object is present with that key
            /// the result is {@code undefined}.</summary>
            /// <param name="key" type="!Object">The key to look up.</param>
            /// <returns type="!goog.async.Deferred">The deferred get request.</returns>
        }, 
        
        getAll: function(opt_range, opt_direction) {
            /// <summary>Gets all objects from the store and returns them as an array.</summary>
            /// <param name="opt_range" type="!goog.db.KeyRange=">The key range. If undefined iterates
            ///     over the whole object store.</param>
            /// <param name="opt_direction" type="!goog.db.Cursor.Direction=">The direction. If undefined
            ///     moves in a forward direction with duplicates.</param>
            /// <returns type="!goog.async.Deferred">The deferred getAll request.</returns>
        }, 
        
        openCursor: function(opt_range, opt_direction) {
            /// <summary>Opens a cursor over the specified key range. Returns a cursor object which is
            /// able to iterate over the given range.
            /// 
            /// Example usage:
            /// 
            /// &lt;code&gt;
            ///  var cursor = objectStore.openCursor(goog.db.Range.bound(&apos;a&apos;, &apos;c&apos;));
            /// 
            ///  var key = goog.events.listen(
            ///      cursor, goog.db.Cursor.EventType.NEW_DATA, function() {
            ///    // Do something with data.
            ///    cursor.next();
            ///  });
            /// 
            ///  goog.events.listenOnce(
            ///      cursor, goog.db.Cursor.EventType.COMPLETE, function() {
            ///    // Clean up listener, and perform a finishing operation on the data.
            ///    goog.events.unlistenByKey(key);
            ///  });
            /// &lt;/code&gt;</summary>
            /// <param name="opt_range" type="!goog.db.KeyRange=">The key range. If undefined iterates
            ///     over the whole object store.</param>
            /// <param name="opt_direction" type="!goog.db.Cursor.Direction=">The direction. If undefined
            ///     moves in a forward direction with duplicates.</param>
            /// <returns type="!goog.db.Cursor">The cursor.</returns>
        }, 
        
        clear: function() {
            /// <summary>Deletes all objects from the store.</summary>
            /// <returns type="!goog.async.Deferred">The deferred clear request.</returns>
        }, 
        
        createIndex: function(name, keyPath, opt_parameters) {
            /// <summary>Creates an index in this object store. Can only be called inside the callback
            /// for the Deferred returned from goog.db.IndexedDb#setVersion.</summary>
            /// <param name="name" type="string">Name of the index to create.</param>
            /// <param name="keyPath" type="string">Attribute to index on.</param>
            /// <param name="opt_parameters" type="!Object=">Optional parameters object. The only
            ///     available option is unique, which defaults to false. If unique is true,
            ///     the index will enforce that there is only ever one object in the object
            ///     store for each unique value it indexes on.</param>
            /// <returns type="goog.db.Index">The newly created, wrapped index.</returns>
        }, 
        
        getIndex: function(name) {
            /// <summary>Gets an index.</summary>
            /// <param name="name" type="string">Name of the index to fetch.</param>
            /// <returns type="goog.db.Index">The requested wrapped index.</returns>
        }, 
        
        "delete": function(name) {
            /// <summary>Deletes an index from the object store. Can only be called inside the
            /// callback for the Deferred returned from goog.db.IndexedDb#setVersion.</summary>
            /// <param name="name" type="string">Name of the index to delete.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.db.ObjectStore";
})(this);
