
/* vsdoc for goog.debug */

(function (window) {
    window.goog = window.goog || {};

    window.goog.debug = {
        /// <summary></summary>
        /// <field name="MAX_STACK_DEPTH" type="number">Max length of stack to try and output</field>
        /// <field name="devCssRunner" type=""></field>
        /// <field name="entryPointRegistry" type=""></field>
        /// <field name="errorHandlerWeakDep" type="Object">Dummy object to work around undefined properties compiler warning.</field>
        /// <field name="GcDiagnostics" type="goog.debug.GcDiagnostics_">Singleton GcDiagnostics object</field>
        /// <field name="LogManager" type="">There is a single global LogManager object that is used to maintain a set of
        /// shared state about Loggers and log services. This is loosely based on the
        /// java class java.util.logging.LogManager.</field>
        /// <field name="logRecordSerializer" type=""></field>
        /// <field name="reflect" type=""></field>
        /// <field name="Trace" type="goog.debug.Trace_">Singleton trace object</field>
        /// <returns type="goog.debug"/>
                
        catchErrors: function(logFunc, opt_cancel, opt_target) {
            /// <summary>Catches onerror events fired by windows and similar objects.</summary>
            /// <param name="logFunc" type="function(Object)">The function to call with the error
            ///    information.</param>
            /// <param name="opt_cancel" type="boolean=">Whether to stop the error from reaching the
            ///    browser.</param>
            /// <param name="opt_target" type="Object=">Object that fires onerror events.</param>
        }, 
        
        expose: function(obj, opt_showFn) {
            /// <summary>Creates a string representing an object and all its properties.</summary>
            /// <param name="obj" type="Object|null|undefined">Object to expose.</param>
            /// <param name="opt_showFn" type="boolean=">Show the functions as well as the properties,
            ///     default is false.</param>
            /// <returns type="string">The string representation of {@code obj}.</returns>
        }, 
        
        deepExpose: function(obj, opt_showFn) {
            /// <summary>Creates a string representing a given primitive or object, and for an
            /// object, all its properties and nested objects.  WARNING: If an object is
            /// given, it and all its nested objects will be modified.  To detect reference
            /// cycles, this method identifies objects using goog.getUid() which mutates the
            /// object.</summary>
            /// <param name="obj" type="*">Object to expose.</param>
            /// <param name="opt_showFn" type="boolean=">Also show properties that are functions (by
            ///     default, functions are omitted).</param>
            /// <returns type="string">A string representation of {@code obj}.</returns>
        }, 
        
        exposeArray: function(arr) {
            /// <summary>Recursively outputs a nested array as a string.</summary>
            /// <param name="arr" type="Array">The array.</param>
            /// <returns type="string">String representing nested array.</returns>
        }, 
        
        exposeException: function(err, opt_fn) {
            /// <summary>Exposes an exception that has been caught by a try...catch and outputs the
            /// error with a stack trace.</summary>
            /// <param name="err" type="Object">Error object or string.</param>
            /// <param name="opt_fn" type="Function=">Optional function to start stack trace from.</param>
            /// <returns type="string">Details of exception.</returns>
        }, 
        
        normalizeErrorObject: function(err) {
            /// <summary>Normalizes the error/exception object between browsers.</summary>
            /// <param name="err" type="Object">Raw error object.</param>
            /// <returns type="Object">Normalized error object.</returns>
        }, 
        
        enhanceError: function(err, opt_message) {
            /// <summary>Converts an object to an Error if it&apos;s a String,
            /// adds a stacktrace if there isn&apos;t one,
            /// and optionally adds an extra message.</summary>
            /// <param name="err" type="Error|string">the original thrown object or string.</param>
            /// <param name="opt_message" type="string=">optional additional message to add to the
            ///     error.</param>
            /// <returns type="Error">If err is a string, it is used to create a new Error,
            ///     which is enhanced and returned.  Otherwise err itself is enhanced
            ///     and returned.</returns>
        }, 
        
        getStacktraceSimple: function(opt_depth) {
            /// <summary>Gets the current stack trace. Simple and iterative - doesn&apos;t worry about
            /// catching circular references or getting the args.</summary>
            /// <param name="opt_depth" type="number=">Optional maximum depth to trace back to.</param>
            /// <returns type="string">A string with the function names of all functions in the
            ///     stack, separated by \n.</returns>
        }, 
        
        getStacktrace: function(opt_fn) {
            /// <summary>Gets the current stack trace, either starting from the caller or starting
            /// from a specified function that&apos;s currently on the call stack.</summary>
            /// <param name="opt_fn" type="Function=">Optional function to start getting the trace from.
            ///     If not provided, defaults to the function that called this.</param>
            /// <returns type="string">Stack trace.</returns>
        }, 
        
        setFunctionResolver: function(resolver) {
            /// <summary>Set a custom function name resolver.</summary>
            /// <param name="resolver" type="function(Function): string">Resolves functions to their
            ///     names.</param>
        }, 
        
        getFunctionName: function(fn) {
            /// <summary>Gets a function name</summary>
            /// <param name="fn" type="Function">Function to get name of.</param>
            /// <returns type="string">Function&apos;s name.</returns>
        }, 
        
        makeWhitespaceVisible: function(string) {
            /// <summary>Makes whitespace visible by replacing it with printable characters.
            /// This is useful in finding diffrences between the expected and the actual
            /// output strings of a testcase.</summary>
            /// <param name="string" type="string">whose whitespace needs to be made visible.</param>
            /// <returns type="string">string whose whitespace is made visible.</returns>
        }, 
        
        EntryPointMonitor: function() {
            /// <summary></summary>
        }
        
    };

    var $x = window.goog.debug;
    $x.__namespace = "true";
    $x.__typeName = "goog.debug";
})(this);
