
/* vsdoc for goog.debug.DebugWindow */

(function (window) {
    window.goog.debug = window.goog.debug || {};

    window.goog.debug.DebugWindow = function(opt_identifier, opt_prefix){
        /// <summary></summary>
        /// <param name="opt_identifier" type="string=">Identifier for this logging class.</param>
        /// <param name="opt_prefix" type="string=">Prefix prepended to messages.</param>
        /// <field name="identifier_" type="string">Identifier for this logging class</field>
        /// <field name="outputBuffer_" type="Array">Array used to buffer log output</field>
        /// <field name="MAX_SAVED" type="number">Max number of messages to be saved</field>
        /// <field name="COOKIE_TIME" type="number">How long to keep the cookies for in milliseconds</field>
        /// <field name="welcomeMessage" type="string">HTML string printed when the debug window opens</field>
        /// <field name="win_" type="Window">Reference to debug window</field>
        /// <field name="lastCall_" type="number">Timestamp for the last time the log was written to.</field>
        /// <returns type="goog.debug.DebugWindow"/>
    };

    var $x = window.goog.debug.DebugWindow;
    $x.prototype = {
                
        setWelcomeMessage: function(msg) {
            /// <summary>Sets the welcome message shown when the window is first opened or reset.</summary>
            /// <param name="msg" type="string">An HTML string.</param>
        }, 
        
        init: function() {
            /// <summary>Initializes the debug window.</summary>
        }, 
        
        isEnabled: function() {
            /// <summary>Whether the DebugWindow is enabled. When the DebugWindow is enabled, it
            /// tries to keep its window open and logs all messages to the window.  When the
            /// DebugWindow is disabled, it stops logging messages to its window.</summary>
            /// <returns type="boolean">Whether the DebugWindow is enabled.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Sets whether the DebugWindow is enabled. When the DebugWindow is enabled, it
            /// tries to keep its window open and log all messages to the window. When the
            /// DebugWindow is disabled, it stops logging messages to its window. The
            /// DebugWindow also saves this state to a cookie so that it&apos;s persisted across
            /// application refreshes.</summary>
            /// <param name="enable" type="boolean">Whether the DebugWindow is enabled.</param>
        }, 
        
        setForceEnableOnSevere: function(enableOnSevere) {
            /// <summary>Sets whether the debug window should be force enabled when a severe log is
            /// encountered.</summary>
            /// <param name="enableOnSevere" type="boolean">Whether to enable on severe logs..</param>
        }, 
        
        isCapturing: function() {
            /// <summary>Whether we are currently capturing logger output.</summary>
            /// <returns type="boolean">whether we are currently capturing logger output.</returns>
        }, 
        
        setCapturing: function(capturing) {
            /// <summary>Sets whether we are currently capturing logger output.</summary>
            /// <param name="capturing" type="boolean">Whether to capture logger output.</param>
        }, 
        
        getFormatter: function() {
            /// <summary>Gets the formatter for outputting to the debug window. The default formatter
            /// is an instance of goog.debug.HtmlFormatter</summary>
            /// <returns type="goog.debug.Formatter">The formatter in use.</returns>
        }, 
        
        setFormatter: function(formatter) {
            /// <summary>Sets the formatter for outputting to the debug window.</summary>
            /// <param name="formatter" type="goog.debug.Formatter">The formatter to use.</param>
        }, 
        
        addSeparator: function() {
            /// <summary>Adds a separator to the debug window.</summary>
        }, 
        
        hasActiveWindow: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether there is an active window.</returns>
        }, 
        
        clear_: function() {
            /// <summary>Clears the contents of the debug window</summary>
        }, 
        
        addLogRecord: function(logRecord) {
            /// <summary>Adds a log record.</summary>
            /// <param name="logRecord" type="goog.debug.LogRecord">the LogRecord.</param>
        }, 
        
        writeBufferToLog: function() {
            /// <summary>Write to the log and maybe scroll into view.</summary>
        }, 
        
        writeSavedMessages_: function() {
            /// <summary>Writes all saved messages to the DebugWindow.</summary>
        }, 
        
        getStyleRules: function() {
            /// <summary></summary>
            /// <returns type="string">The style rule text, for inclusion in the initial HTML.</returns>
        }, 
        
        writeInitialDocument: function() {
            /// <summary>Writes the initial HTML of the debug window.</summary>
        }, 
        
        isEnabled: function(identifier) {
            /// <summary></summary>
            /// <param name="identifier" type="string">Identifier for logging class.</param>
            /// <returns type="boolean">Whether the DebugWindow is enabled.</returns>
        }, 
        
        addFilter: function(loggerName) {
            /// <summary>Adds a logger name to be filtered.</summary>
            /// <param name="loggerName" type="string">the logger name to add.</param>
        }, 
        
        removeFilter: function(loggerName) {
            /// <summary>Removes a logger name to be filtered.</summary>
            /// <param name="loggerName" type="string">the logger name to remove.</param>
        }, 
        
        resetBufferWithNewSize: function(size) {
            /// <summary>Modify the size of the circular buffer. Allows the log to retain more
            /// information while the window is closed.</summary>
            /// <param name="size" type="number">New size of the circular buffer.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.debug.DebugWindow";
})(this);
