
/* vsdoc for goog.debug.ErrorReporter */

(function (window) {
    window.goog.debug = window.goog.debug || {};

    window.goog.debug.ErrorReporter = function(handlerUrl, opt_contextProvider, opt_noAutoProtect){
        /// <summary></summary>
        /// <param name="handlerUrl" type="string">The URL to which all errors will be reported.</param>
        /// <param name="opt_contextProvider" type="function(!Error|!Object.string|string)=">When a report is to be sent to the server,
        ///     this method will be called, and given an opportunity to modify the
        ///     context object before submission to the server.</param>
        /// <param name="opt_noAutoProtect" type="boolean=">Whether to automatically add handlers for
        ///     onerror and to protect entry points.  If apps have other error reporting
        ///     facilities, it may make sense for them to set these up themselves and use
        ///     the ErrorReporter just for transmission of reports.</param>
        /// <returns type="goog.debug.ErrorReporter"/>
    };

    var $x = window.goog.debug.ErrorReporter;
    $x.prototype = {
                
        install: function(loggingUrl, opt_contextProvider, opt_noAutoProtect) {
            /// <summary>Installs an error reporter to catch all JavaScript errors raised.</summary>
            /// <param name="loggingUrl" type="string">The URL to which the errors caught will be
            ///     reported.</param>
            /// <param name="opt_contextProvider" type="function(!Error|!Object.string|string)=">When a report is to be sent to the server,
            ///     this method will be called, and given an opportunity to modify the
            ///     context object before submission to the server.</param>
            /// <param name="opt_noAutoProtect" type="boolean=">Whether to automatically add handlers for
            ///     onerror and to protect entry points.  If apps have other error reporting
            ///     facilities, it may make sense for them to set these up themselves and use
            ///     the ErrorReporter just for transmission of reports.</param>
            /// <returns type="goog.debug.ErrorReporter">The error reporter.</returns>
        }, 
        
        defaultXhrSender: function(uri, method, content, opt_headers) {
            /// <summary>Default implemntation of XHR sender interface.</summary>
            /// <param name="uri" type="string">URI to make request to.</param>
            /// <param name="method" type="string">Send method.</param>
            /// <param name="content" type="string">Post data.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
        }, 
        
        protectAdditionalEntryPoint: function(fn) {
            /// <summary>Installs exception protection for an entry point function in addition
            /// to those that are protected by default.
            /// Has no effect in IE because window.onerror is used for reporting
            /// exceptions in that case.</summary>
            /// <param name="fn" type="Function">An entry point function to be protected.</param>
            /// <returns type="Function">A protected wrapper function that calls the entry point
            ///     function or null if the entry point could not be protected.</returns>
        }, 
        
        setLoggingHeaders: function(loggingHeaders) {
            /// <summary>Add headers to the logging url.</summary>
            /// <param name="loggingHeaders" type="Object|goog.structs.Map">Extra headers to send
            ///     to the logging URL.</param>
        }, 
        
        setXhrSender: function(xhrSender) {
            /// <summary>Set the function used to send error reports to the server.</summary>
            /// <param name="xhrSender" type="function(string|string|string|(Object|goog.structs.Map)=)">If provided, this will be used to send a report to the
            ///     server instead of the default method. The function will be given the URI,
            ///     HTTP method request content, and (optionally) request headers to be
            ///     added.</param>
        }, 
        
        handleException: function(e, opt_context) {
            /// <summary>Handler for caught exceptions. Sends report to the LoggingServlet and
            /// notifies any listeners.</summary>
            /// <param name="e" type="Object">The exception.</param>
            /// <param name="opt_context" type="!Object.string|string=">Context values to optionally
            ///     include in the error report.</param>
        }, 
        
        sendErrorReport: function(message, fileName, line, opt_trace, opt_context) {
            /// <summary>Sends an error report to the logging URL.  This will not consult the context
            /// provider, the report will be sent exactly as specified.</summary>
            /// <param name="message" type="string">Error description.</param>
            /// <param name="fileName" type="string">URL of the JavaScript file with the error.</param>
            /// <param name="line" type="number">Line number of the error.</param>
            /// <param name="opt_trace" type="string=">Call stack trace of the error.</param>
            /// <param name="opt_context" type="!Object.string|string=">Context information to include
            ///     in the request.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.debug.ErrorReporter";
})(this);
