
/* vsdoc for goog.debug.LogRecord */

(function (window) {
    window.goog.debug = window.goog.debug || {};

    window.goog.debug.LogRecord = function(level, msg, loggerName, opt_time, opt_sequenceNumber){
        /// <summary></summary>
        /// <param name="level" type="goog.debug.Logger.Level">One of the level identifiers.</param>
        /// <param name="msg" type="string">The string message.</param>
        /// <param name="loggerName" type="string">The name of the source logger.</param>
        /// <param name="opt_time" type="number=">Time this log record was created if other than now.
        ///     If 0, we use #goog.now.</param>
        /// <param name="opt_sequenceNumber" type="number=">Sequence number of this log record. This
        ///     should only be passed in when restoring a log record from persistence.</param>
        /// <field name="ENABLE_SEQUENCE_NUMBERS" type=""></field>
        /// <returns type="goog.debug.LogRecord"/>
    };

    var $x = window.goog.debug.LogRecord;
    $x.prototype = {
                
        reset: function(level, msg, loggerName, opt_time, opt_sequenceNumber) {
            /// <summary>Sets all fields of the log record.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">One of the level identifiers.</param>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="loggerName" type="string">The name of the source logger.</param>
            /// <param name="opt_time" type="number=">Time this log record was created if other than now.
            ///     If 0, we use #goog.now.</param>
            /// <param name="opt_sequenceNumber" type="number=">Sequence number of this log record. This
            ///     should only be passed in when restoring a log record from persistence.</param>
        }, 
        
        getLoggerName: function() {
            /// <summary>Get the source Logger&apos;s name.</summary>
            /// <returns type="string">source logger name (may be null).</returns>
        }, 
        
        getException: function() {
            /// <summary>Get the exception that is part of the log record.</summary>
            /// <returns type="Object">the exception.</returns>
        }, 
        
        setException: function(exception) {
            /// <summary>Set the exception that is part of the log record.</summary>
            /// <param name="exception" type="Object">the exception.</param>
        }, 
        
        getExceptionText: function() {
            /// <summary>Get the exception text that is part of the log record.</summary>
            /// <returns type="?string">Exception text.</returns>
        }, 
        
        setExceptionText: function(text) {
            /// <summary>Set the exception text that is part of the log record.</summary>
            /// <param name="text" type="string">The exception text.</param>
        }, 
        
        setLoggerName: function(loggerName) {
            /// <summary>Get the source Logger&apos;s name.</summary>
            /// <param name="loggerName" type="string">source logger name (may be null).</param>
        }, 
        
        getLevel: function() {
            /// <summary>Get the logging message level, for example Level.SEVERE.</summary>
            /// <returns type="goog.debug.Logger.Level">the logging message level.</returns>
        }, 
        
        setLevel: function(level) {
            /// <summary>Set the logging message level, for example Level.SEVERE.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">the logging message level.</param>
        }, 
        
        getMessage: function() {
            /// <summary>Get the &quot;raw&quot; log message, before localization or formatting.</summary>
            /// <returns type="string">the raw message string.</returns>
        }, 
        
        setMessage: function(msg) {
            /// <summary>Set the &quot;raw&quot; log message, before localization or formatting.</summary>
            /// <param name="msg" type="string">the raw message string.</param>
        }, 
        
        getMillis: function() {
            /// <summary>Get event time in milliseconds since 1970.</summary>
            /// <returns type="number">event time in millis since 1970.</returns>
        }, 
        
        setMillis: function(time) {
            /// <summary>Set event time in milliseconds since 1970.</summary>
            /// <param name="time" type="number">event time in millis since 1970.</param>
        }, 
        
        getSequenceNumber: function() {
            /// <summary>Get the sequence number.
            /// &lt;p&gt;
            /// Sequence numbers are normally assigned in the LogRecord
            /// constructor, which assigns unique sequence numbers to
            /// each new LogRecord in increasing order.</summary>
            /// <returns type="number">the sequence number.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.debug.LogRecord";
})(this);
