
/* vsdoc for goog.debug.Logger */

(function (window) {
    window.goog.debug = window.goog.debug || {};

    window.goog.debug.Logger = function(name){
        /// <summary></summary>
        /// <param name="name" type="string">The name of the Logger.</param>
        /// <field name="ENABLE_HIERARCHY" type=""></field>
        /// <returns type="goog.debug.Logger"/>
    };

    var $x = window.goog.debug.Logger;
    $x.prototype = {
                
        getLogger: function(name) {
            /// <summary>Find or create a logger for a named subsystem. If a logger has already been
            /// created with the given name it is returned. Otherwise a new logger is
            /// created. If a new logger is created its log level will be configured based
            /// on the LogManager configuration and it will configured to also send logging
            /// output to its parent&apos;s handlers. It will be registered in the LogManager
            /// global namespace.</summary>
            /// <param name="name" type="string">A name for the logger. This should be a dot-separated
            /// name and should normally be based on the package name or class name of the
            /// subsystem, such as goog.net.BrowserChannel.</param>
            /// <returns type="!goog.debug.Logger">The named logger.</returns>
        }, 
        
        logToProfilers: function(msg) {
            /// <summary>Logs a message to profiling tools, if available.
            /// {@see http://code.google.com/webtoolkit/speedtracer/logging-api.html}
            /// {@see http://msdn.microsoft.com/en-us/library/dd433074(VS.85).aspx}</summary>
            /// <param name="msg" type="string">The message to log.</param>
        }, 
        
        getName: function() {
            /// <summary>Gets the name of this logger.</summary>
            /// <returns type="string">The name of this logger.</returns>
        }, 
        
        addHandler: function(handler) {
            /// <summary>Adds a handler to the logger. This doesn&apos;t use the event system because
            /// we want to be able to add logging to the event system.</summary>
            /// <param name="handler" type="Function">Handler function to add.</param>
        }, 
        
        removeHandler: function(handler) {
            /// <summary>Removes a handler from the logger. This doesn&apos;t use the event system because
            /// we want to be able to add logging to the event system.</summary>
            /// <param name="handler" type="Function">Handler function to remove.</param>
            /// <returns type="boolean">Whether the handler was removed.</returns>
        }, 
        
        getParent: function() {
            /// <summary>Returns the parent of this logger.</summary>
            /// <returns type="goog.debug.Logger">The parent logger or null if this is the root.</returns>
        }, 
        
        getChildren: function() {
            /// <summary>Returns the children of this logger as a map of the child name to the logger.</summary>
            /// <returns type="!Object">The map where the keys are the child leaf names and the
            ///     values are the Logger objects.</returns>
        }, 
        
        setLevel: function(level) {
            /// <summary>Set the log level specifying which message levels will be logged by this
            /// logger. Message levels lower than this value will be discarded.
            /// The level value Level.OFF can be used to turn off logging. If the new level
            /// is null, it means that this node should inherit its level from its nearest
            /// ancestor with a specific (non-null) level value.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">The new level.</param>
        }, 
        
        getLevel: function() {
            /// <summary>Gets the log level specifying which message levels will be logged by this
            /// logger. Message levels lower than this value will be discarded.
            /// The level value Level.OFF can be used to turn off logging. If the level
            /// is null, it means that this node should inherit its level from its nearest
            /// ancestor with a specific (non-null) level value.</summary>
            /// <returns type="goog.debug.Logger.Level">The level.</returns>
        }, 
        
        getEffectiveLevel: function() {
            /// <summary>Returns the effective level of the logger based on its ancestors&apos; levels.</summary>
            /// <returns type="goog.debug.Logger.Level">The level.</returns>
        }, 
        
        isLoggable: function(level) {
            /// <summary>Check if a message of the given level would actually be logged by this
            /// logger. This check is based on the Loggers effective level, which may be
            /// inherited from its parent.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">The level to check.</param>
            /// <returns type="boolean">Whether the message would be logged.</returns>
        }, 
        
        log: function(level, msg, opt_exception) {
            /// <summary>Log a message. If the logger is currently enabled for the
            /// given message level then the given message is forwarded to all the
            /// registered output Handler objects.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">One of the level identifiers.</param>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error|Object=">An exception associated with the
            ///     message.</param>
        }, 
        
        getLogRecord: function(level, msg, opt_exception) {
            /// <summary>Creates a new log record and adds the exception (if present) to it.</summary>
            /// <param name="level" type="goog.debug.Logger.Level">One of the level identifiers.</param>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error|Object=">An exception associated with the
            ///     message.</param>
            /// <returns type="!goog.debug.LogRecord">A log record.</returns>
        }, 
        
        shout: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.SHOUT level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        severe: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.SEVERE level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        warning: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.WARNING level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        info: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.INFO level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        config: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.CONFIG level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        fine: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.FINE level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        finer: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.FINER level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        finest: function(msg, opt_exception) {
            /// <summary>Log a message at the Logger.Level.FINEST level.
            /// If the logger is currently enabled for the given message level then the
            /// given message is forwarded to all the registered output Handler objects.</summary>
            /// <param name="msg" type="string">The string message.</param>
            /// <param name="opt_exception" type="Error=">An exception associated with the message.</param>
        }, 
        
        logRecord: function(logRecord) {
            /// <summary>Log a LogRecord. If the logger is currently enabled for the
            /// given message level then the given message is forwarded to all the
            /// registered output Handler objects.</summary>
            /// <param name="logRecord" type="goog.debug.LogRecord">A log record to log.</param>
        }, 
        
        doLogRecord_: function(logRecord) {
            /// <summary></summary>
            /// <param name="logRecord" type=""></param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.debug.Logger";
})(this);
