
/* vsdoc for goog.debug.entryPointRegistry */

(function (window) {
    window.goog.debug = window.goog.debug || {};

    window.goog.debug.entryPointRegistry = {
        /// <summary></summary>
        /// <returns type="goog.debug.entryPointRegistry"/>
                
        register: function(callback) {
            /// <summary>Register an entry point with this module.
            /// 
            /// The entry point will be instrumented when a monitor is passed to
            /// goog.debug.entryPointRegistry.monitorAll. If this has already occurred, the
            /// entry point is instrumented immediately.</summary>
            /// <param name="callback" type="function(!Function)">A callback function which is called
            ///     with a transforming function to instrument the entry point. The callback
            ///     is responsible for wrapping the relevant entry point with the
            ///     transforming function.</param>
        }, 
        
        monitorAll: function(monitor) {
            /// <summary>Configures a monitor to wrap all entry points.
            /// 
            /// Entry points that have already been registered are immediately wrapped by
            /// the monitor. When an entry point is registered in the future, it will also
            /// be wrapped by the monitor when it is registered.</summary>
            /// <param name="monitor" type="!goog.debug.EntryPointMonitor">An entry point monitor.</param>
        }, 
        
        unmonitorAllIfPossible: function(monitor) {
            /// <summary>Try to unmonitor all the entry points that have already been registered. If
            /// an entry point is registered in the future, it will not be wrapped by the
            /// monitor when it is registered. Note that this may fail if the entry points
            /// have additional wrapping.</summary>
            /// <param name="monitor" type="!goog.debug.EntryPointMonitor">The last monitor to wrap
            ///     the entry points.</param>
        }
        
    };

    var $x = window.goog.debug.entryPointRegistry;
    $x.__namespace = "true";
    $x.__typeName = "goog.debug.entryPointRegistry";
})(this);
