
/* vsdoc for goog.dom */

(function (window) {
    window.goog = window.goog || {};

    window.goog.dom = {
        /// <summary></summary>
        /// <field name="a11y" type=""></field>
        /// <field name="RangeType" type="">Types of ranges.</field>
        /// <field name="annotate" type=""></field>
        /// <field name="BrowserFeature" type="">Enum of browser capabilities.</field>
        /// <field name="browserrange" type=""></field>
        /// <field name="BufferedViewportSizeMonitorTest" type=""></field>
        /// <field name="classes" type=""></field>
        /// <field name="classes_test" type=""></field>
        /// <field name="dataset" type=""></field>
        /// <field name="ASSUME_QUIRKS_MODE" type=""></field>
        /// <field name="ASSUME_STANDARDS_MODE" type=""></field>
        /// <field name="NodeType" type="">Enumeration for DOM node types (for reference)</field>
        /// <field name="$" type="Element">Alias for getElement.</field>
        /// <field name="$$" type="{length: number}">Alias for {@code getElementsByTagNameAndClass}.</field>
        /// <field name="$dom" type="!Element">Alias for {@code createDom}.</field>
        /// <field name="dom_test" type=""></field>
        /// <field name="forms" type=""></field>
        /// <field name="$F" type="Function">Alias for goog.dom.form.element.getValue</field>
        /// <field name="fullscreen" type=""></field>
        /// <field name="iframe" type=""></field>
        /// <field name="pattern" type=""></field>
        /// <field name="Range" type=""></field>
        /// <field name="RangeEndpoint" type="">Constants for selection endpoints.</field>
        /// <field name="selection" type=""></field>
        /// <field name="TagWalkType" type="">There are three types of token:
        ///  &lt;ol&gt;
        ///    &lt;li&gt;{@code START_TAG} - The beginning of a tag.
        ///    &lt;li&gt;{@code OTHER} - Any non-element node position.
        ///    &lt;li&gt;{@code END_TAG} - The end of a tag.
        ///  &lt;/ol&gt;
        /// Users of this enumeration can rely on {@code START_TAG + END_TAG = 0} and
        /// that {@code OTHER = 0}.</field>
        /// <field name="TagName" type="">Enum of all html tag names specified by the W3C HTML4.01 and HTML5
        /// specifications.</field>
        /// <field name="xml" type=""></field>
        /// <returns type="goog.dom"/>
                
        getDomHelper: function(opt_element) {
            /// <summary>Gets the DomHelper object for the document where the element resides.</summary>
            /// <param name="opt_element" type="(Node|Window)=">If present, gets the DomHelper for this
            ///     element.</param>
            /// <returns type="!goog.dom.DomHelper">The DomHelper.</returns>
        }, 
        
        getDocument: function() {
            /// <summary>Gets the document object being used by the dom library.</summary>
            /// <returns type="!Document">Document object.</returns>
        }, 
        
        getElement: function(element) {
            /// <summary>Alias for getElementById. If a DOM node is passed in then we just return
            /// that.</summary>
            /// <param name="element" type="string|Element">Element ID or a DOM node.</param>
            /// <returns type="Element">The element with the given ID, or the node passed in.</returns>
        }, 
        
        getElementsByTagNameAndClass: function(opt_tag, opt_class, opt_el) {
            /// <summary>Looks up elements by both tag and class name, using browser native functions
            /// ({@code querySelectorAll}, {@code getElementsByTagName | @code getElementsByClassName}) where possible. This function
            /// is a useful, if limited, way of collecting a list of DOM elements
            /// with certain characteristics.  {@code goog.dom.query} offers a
            /// more powerful and general solution which allows matching on CSS3
            /// selector expressions, but at increased cost in code size. If all you
            /// need is particular tags belonging to a single class, this function
            /// is fast and sleek.</summary>
            /// <param name="opt_tag" type="?string=">Element tag name.</param>
            /// <param name="opt_class" type="?string=">Optional class name.</param>
            /// <param name="opt_el" type="(Document|Element)=">Optional element to look in.</param>
            /// <returns type="{length: number}">Array-like list of elements (only a length
            ///     property and numerical indices are guaranteed to exist).</returns>
        }, 
        
        getElementsByClass: function(className, opt_el) {
            /// <summary>Returns an array of all the elements with the provided className.</summary>
            /// <param name="className" type="string">the name of the class to look for.</param>
            /// <param name="opt_el" type="(Document|Element)=">Optional element to look in.</param>
            /// <returns type="{length: number}">The items found with the class name provided.</returns>
        }, 
        
        getElementByClass: function(className, opt_el) {
            /// <summary>Returns the first element with the provided className.</summary>
            /// <param name="className" type="string">the name of the class to look for.</param>
            /// <param name="opt_el" type="Element|Document=">Optional element to look in.</param>
            /// <returns type="Element">The first item with the class name provided.</returns>
        }, 
        
        setProperties: function(element, properties) {
            /// <summary>Sets multiple properties on a node.</summary>
            /// <param name="element" type="Element">DOM node to set properties on.</param>
            /// <param name="properties" type="Object">Hash of property:value pairs.</param>
        }, 
        
        getViewportSize: function(opt_window) {
            /// <summary>Gets the dimensions of the viewport.
            /// 
            /// Gecko Standards mode:
            /// docEl.clientWidth  Width of viewport excluding scrollbar.
            /// win.innerWidth     Width of viewport including scrollbar.
            /// body.clientWidth   Width of body element.
            /// 
            /// docEl.clientHeight Height of viewport excluding scrollbar.
            /// win.innerHeight    Height of viewport including scrollbar.
            /// body.clientHeight  Height of document.
            /// 
            /// Gecko Backwards compatible mode:
            /// docEl.clientWidth  Width of viewport excluding scrollbar.
            /// win.innerWidth     Width of viewport including scrollbar.
            /// body.clientWidth   Width of viewport excluding scrollbar.
            /// 
            /// docEl.clientHeight Height of document.
            /// win.innerHeight    Height of viewport including scrollbar.
            /// body.clientHeight  Height of viewport excluding scrollbar.
            /// 
            /// IE6/7 Standards mode:
            /// docEl.clientWidth  Width of viewport excluding scrollbar.
            /// win.innerWidth     Undefined.
            /// body.clientWidth   Width of body element.
            /// 
            /// docEl.clientHeight Height of viewport excluding scrollbar.
            /// win.innerHeight    Undefined.
            /// body.clientHeight  Height of document element.
            /// 
            /// IE5 + IE6/7 Backwards compatible mode:
            /// docEl.clientWidth  0.
            /// win.innerWidth     Undefined.
            /// body.clientWidth   Width of viewport excluding scrollbar.
            /// 
            /// docEl.clientHeight 0.
            /// win.innerHeight    Undefined.
            /// body.clientHeight  Height of viewport excluding scrollbar.
            /// 
            /// Opera 9 Standards and backwards compatible mode:
            /// docEl.clientWidth  Width of viewport excluding scrollbar.
            /// win.innerWidth     Width of viewport including scrollbar.
            /// body.clientWidth   Width of viewport excluding scrollbar.
            /// 
            /// docEl.clientHeight Height of document.
            /// win.innerHeight    Height of viewport including scrollbar.
            /// body.clientHeight  Height of viewport excluding scrollbar.
            /// 
            /// WebKit:
            /// Safari 2
            /// docEl.clientHeight Same as scrollHeight.
            /// docEl.clientWidth  Same as innerWidth.
            /// win.innerWidth     Width of viewport excluding scrollbar.
            /// win.innerHeight    Height of the viewport including scrollbar.
            /// frame.innerHeight  Height of the viewport exluding scrollbar.
            /// 
            /// Safari 3 (tested in 522)
            /// 
            /// docEl.clientWidth  Width of viewport excluding scrollbar.
            /// docEl.clientHeight Height of viewport excluding scrollbar in strict mode.
            /// body.clientHeight  Height of viewport excluding scrollbar in quirks mode.</summary>
            /// <param name="opt_window" type="Window=">Optional window element to test.</param>
            /// <returns type="!goog.math.Size">Object with values &apos;width&apos; and &apos;height&apos;.</returns>
        }, 
        
        getDocumentHeight: function() {
            /// <summary>Calculates the height of the document.</summary>
            /// <returns type="number">The height of the current document.</returns>
        }, 
        
        getPageScroll: function(opt_window) {
            /// <summary>Gets the page scroll distance as a coordinate object.</summary>
            /// <param name="opt_window" type="Window=">Optional window element to test.</param>
            /// <returns type="!goog.math.Coordinate">Object with values &apos;x&apos; and &apos;y&apos;.</returns>
        }, 
        
        getDocumentScroll: function() {
            /// <summary>Gets the document scroll distance as a coordinate object.</summary>
            /// <returns type="!goog.math.Coordinate">Object with values &apos;x&apos; and &apos;y&apos;.</returns>
        }, 
        
        getDocumentScrollElement: function() {
            /// <summary>Gets the document scroll element.</summary>
            /// <returns type="Element">Scrolling element.</returns>
        }, 
        
        getWindow: function(opt_doc) {
            /// <summary>Gets the window object associated with the given document.</summary>
            /// <param name="opt_doc" type="Document=">Document object to get window for.</param>
            /// <returns type="!Window">The window associated with the given document.</returns>
        }, 
        
        createDom: function(tagName, opt_attributes, var_args) {
            /// <summary>Returns a dom node with a set of attributes.  This function accepts varargs
            /// for subsequent nodes to be added.  Subsequent nodes will be added to the
            /// first node as childNodes.
            /// 
            /// So:
            /// &lt;code&gt;createDom(&apos;div&apos;, null, createDom(&apos;p&apos;), createDom(&apos;p&apos;));&lt;/code&gt;
            /// would return a div with two child paragraphs</summary>
            /// <param name="tagName" type="string">Tag to create.</param>
            /// <param name="opt_attributes" type="(Object|Array.string|string)=">If object, then a map
            ///     of name-value pairs for attributes. If a string, then this is the
            ///     className of the new element. If an array, the elements will be joined
            ///     together as the className of the new element.</param>
            /// <param name="var_args" type="...(Object|string|Array|NodeList)">Further DOM nodes or
            ///     strings for text nodes. If one of the var_args is an array or NodeList,i
            ///     its elements will be added as childNodes instead.</param>
            /// <returns type="!Element">Reference to a DOM node.</returns>
        }, 
        
        createElement: function(name) {
            /// <summary>Creates a new element.</summary>
            /// <param name="name" type="string">Tag name.</param>
            /// <returns type="!Element">The new element.</returns>
        }, 
        
        createTextNode: function(content) {
            /// <summary>Creates a new text node.</summary>
            /// <param name="content" type="string">Content.</param>
            /// <returns type="!Text">The new text node.</returns>
        }, 
        
        createTable: function(rows, columns, opt_fillWithNbsp) {
            /// <summary>Create a table.</summary>
            /// <param name="rows" type="number">The number of rows in the table.  Must be >= 1.</param>
            /// <param name="columns" type="number">The number of columns in the table.  Must be >= 1.</param>
            /// <param name="opt_fillWithNbsp" type="boolean=">If true, fills table entries with nsbps.</param>
            /// <returns type="!Element">The created table.</returns>
        }, 
        
        htmlToDocumentFragment: function(htmlString) {
            /// <summary>Converts an HTML string into a document fragment. The string must be
            /// sanitized in order to avoid cross-site scripting. For example
            /// {@code goog.dom.htmlToDocumentFragment(&apos;&amp;lt;img src=x onerror=alert(0)&amp;gt;&apos;)}
            /// triggers an alert in all browsers, even if the returned document fragment
            /// is thrown away immediately.</summary>
            /// <param name="htmlString" type="string">The HTML string to convert.</param>
            /// <returns type="!Node">The resulting document fragment.</returns>
        }, 
        
        getCompatMode: function() {
            /// <summary>Returns the compatMode of the document.</summary>
            /// <returns type="string">The result is either CSS1Compat or BackCompat.</returns>
        }, 
        
        isCss1CompatMode: function() {
            /// <summary>Returns true if the browser is in &quot;CSS1-compatible&quot; (standards-compliant)
            /// mode, false otherwise.</summary>
            /// <returns type="boolean">True if in CSS1-compatible mode.</returns>
        }, 
        
        canHaveChildren: function(node) {
            /// <summary>Determines if the given node can contain children, intended to be used for
            /// HTML generation.
            /// 
            /// IE natively supports node.canHaveChildren but has inconsistent behavior.
            /// Prior to IE8 the base tag allows children and in IE9 all nodes return true
            /// for canHaveChildren.
            /// 
            /// In practice all non-IE browsers allow you to add children to any node, but
            /// the behavior is inconsistent:
            /// 
            /// &lt;pre&gt;
            ///   var a = document.createElement(&apos;br&apos;);
            ///   a.appendChild(document.createTextNode(&apos;foo&apos;));
            ///   a.appendChild(document.createTextNode(&apos;bar&apos;));
            ///   console.log(a.childNodes.length);  // 2
            ///   console.log(a.innerHTML);  // Chrome: &quot;&quot;, IE9: &quot;foobar&quot;, FF3.5: &quot;foobar&quot;
            /// &lt;/pre&gt;
            /// 
            /// TODO(user): Rename shouldAllowChildren() ?</summary>
            /// <param name="node" type="Node">The node to check.</param>
            /// <returns type="boolean">Whether the node can contain children.</returns>
        }, 
        
        appendChild: function(parent, child) {
            /// <summary>Appends a child to a node.</summary>
            /// <param name="parent" type="Node">Parent.</param>
            /// <param name="child" type="Node">Child.</param>
        }, 
        
        append: function(parent, var_args) {
            /// <summary>Appends a node with text or other nodes.</summary>
            /// <param name="parent" type="!Node">The node to append nodes to.</param>
            /// <param name="var_args" type="...goog.dom.Appendable">The things to append to the node.
            ///     If this is a Node it is appended as is.
            ///     If this is a string then a text node is appended.
            ///     If this is an array like object then fields 0 to length - 1 are appended.</param>
        }, 
        
        removeChildren: function(node) {
            /// <summary>Removes all the child nodes on a DOM node.</summary>
            /// <param name="node" type="Node">Node to remove children from.</param>
        }, 
        
        insertSiblingBefore: function(newNode, refNode) {
            /// <summary>Inserts a new node before an existing reference node (i.e. as the previous
            /// sibling). If the reference node has no parent, then does nothing.</summary>
            /// <param name="newNode" type="Node">Node to insert.</param>
            /// <param name="refNode" type="Node">Reference node to insert before.</param>
        }, 
        
        insertSiblingAfter: function(newNode, refNode) {
            /// <summary>Inserts a new node after an existing reference node (i.e. as the next
            /// sibling). If the reference node has no parent, then does nothing.</summary>
            /// <param name="newNode" type="Node">Node to insert.</param>
            /// <param name="refNode" type="Node">Reference node to insert after.</param>
        }, 
        
        insertChildAt: function(parent, child, index) {
            /// <summary>Insert a child at a given index. If index is larger than the number of child
            /// nodes that the parent currently has, the node is inserted as the last child
            /// node.</summary>
            /// <param name="parent" type="Element">The element into which to insert the child.</param>
            /// <param name="child" type="Node">The element to insert.</param>
            /// <param name="index" type="number">The index at which to insert the new child node. Must
            ///     not be negative.</param>
        }, 
        
        removeNode: function(node) {
            /// <summary>Removes a node from its parent.</summary>
            /// <param name="node" type="Node">The node to remove.</param>
            /// <returns type="Node">The node removed if removed; else, null.</returns>
        }, 
        
        replaceNode: function(newNode, oldNode) {
            /// <summary>Replaces a node in the DOM tree. Will do nothing if {@code oldNode} has no
            /// parent.</summary>
            /// <param name="newNode" type="Node">Node to insert.</param>
            /// <param name="oldNode" type="Node">Node to replace.</param>
        }, 
        
        flattenElement: function(element) {
            /// <summary>Flattens an element. That is, removes it and replace it with its children.
            /// Does nothing if the element is not in the document.</summary>
            /// <param name="element" type="Element">The element to flatten.</param>
            /// <returns type="Element|undefined">The original element, detached from the document
            ///     tree, sans children; or undefined, if the element was not in the document
            ///     to begin with.</returns>
        }, 
        
        getChildren: function(element) {
            /// <summary>Returns an array containing just the element children of the given element.</summary>
            /// <param name="element" type="Element">The element whose element children we want.</param>
            /// <returns type="!(Array|NodeList)">An array or array-like list of just the element
            ///     children of the given element.</returns>
        }, 
        
        getFirstElementChild: function(node) {
            /// <summary>Returns the first child node that is an element.</summary>
            /// <param name="node" type="Node">The node to get the first child element of.</param>
            /// <returns type="Element">The first child node of {@code node} that is an element.</returns>
        }, 
        
        getLastElementChild: function(node) {
            /// <summary>Returns the last child node that is an element.</summary>
            /// <param name="node" type="Node">The node to get the last child element of.</param>
            /// <returns type="Element">The last child node of {@code node} that is an element.</returns>
        }, 
        
        getNextElementSibling: function(node) {
            /// <summary>Returns the first next sibling that is an element.</summary>
            /// <param name="node" type="Node">The node to get the next sibling element of.</param>
            /// <returns type="Element">The next sibling of {@code node} that is an element.</returns>
        }, 
        
        getPreviousElementSibling: function(node) {
            /// <summary>Returns the first previous sibling that is an element.</summary>
            /// <param name="node" type="Node">The node to get the previous sibling element of.</param>
            /// <returns type="Element">The first previous sibling of {@code node} that is
            ///     an element.</returns>
        }, 
        
        getNextNode: function(node) {
            /// <summary>Returns the next node in source order from the given node.</summary>
            /// <param name="node" type="Node">The node.</param>
            /// <returns type="Node">The next node in the DOM tree, or null if this was the last
            ///     node.</returns>
        }, 
        
        getPreviousNode: function(node) {
            /// <summary>Returns the previous node in source order from the given node.</summary>
            /// <param name="node" type="Node">The node.</param>
            /// <returns type="Node">The previous node in the DOM tree, or null if this was the
            ///     first node.</returns>
        }, 
        
        isNodeLike: function(obj) {
            /// <summary>Whether the object looks like a DOM node.</summary>
            /// <param name="obj" type="*">The object being tested for node likeness.</param>
            /// <returns type="boolean">Whether the object looks like a DOM node.</returns>
        }, 
        
        isElement: function(obj) {
            /// <summary>Whether the object looks like an Element.</summary>
            /// <param name="obj" type="*">The object being tested for Element likeness.</param>
            /// <returns type="boolean">Whether the object looks like an Element.</returns>
        }, 
        
        isWindow: function(obj) {
            /// <summary>Returns true if the specified value is a Window object. This includes the
            /// global window for HTML pages, and iframe windows.</summary>
            /// <param name="obj" type="*">Variable to test.</param>
            /// <returns type="boolean">Whether the variable is a window.</returns>
        }, 
        
        getParentElement: function(element) {
            /// <summary>Returns an element&apos;s parent, if it&apos;s an Element.</summary>
            /// <param name="element" type="Element">The DOM element.</param>
            /// <returns type="Element">The parent, or null if not an Element.</returns>
        }, 
        
        contains: function(parent, descendant) {
            /// <summary>Whether a node contains another node.</summary>
            /// <param name="parent" type="Node">The node that should contain the other node.</param>
            /// <param name="descendant" type="Node">The node to test presence of.</param>
            /// <returns type="boolean">Whether the parent node contains the descendent node.</returns>
        }, 
        
        compareNodeOrder: function(node1, node2) {
            /// <summary>Compares the document order of two nodes, returning 0 if they are the same
            /// node, a negative number if node1 is before node2, and a positive number if
            /// node2 is before node1.  Note that we compare the order the tags appear in the
            /// document so in the tree <b><i>text</i></b> the B node is considered to be
            /// before the I node.</summary>
            /// <param name="node1" type="Node">The first node to compare.</param>
            /// <param name="node2" type="Node">The second node to compare.</param>
            /// <returns type="number">0 if the nodes are the same node, a negative number if node1
            ///     is before node2, and a positive number if node2 is before node1.</returns>
        }, 
        
        findCommonAncestor: function(var_args) {
            /// <summary>Find the deepest common ancestor of the given nodes.</summary>
            /// <param name="var_args" type="...Node">The nodes to find a common ancestor of.</param>
            /// <returns type="Node">The common ancestor of the nodes, or null if there is none.
            ///     null will only be returned if two or more of the nodes are from different
            ///     documents.</returns>
        }, 
        
        getOwnerDocument: function(node) {
            /// <summary>Returns the owner document for a node.</summary>
            /// <param name="node" type="Node|Window">The node to get the document for.</param>
            /// <returns type="!Document">The document owning the node.</returns>
        }, 
        
        getFrameContentDocument: function(frame) {
            /// <summary>Cross-browser function for getting the document element of a frame or iframe.</summary>
            /// <param name="frame" type="Element">Frame element.</param>
            /// <returns type="!Document">The frame content document.</returns>
        }, 
        
        getFrameContentWindow: function(frame) {
            /// <summary>Cross-browser function for getting the window of a frame or iframe.</summary>
            /// <param name="frame" type="Element">Frame element.</param>
            /// <returns type="Window">The window associated with the given frame.</returns>
        }, 
        
        setTextContent: function(element, text) {
            /// <summary>Cross-browser function for setting the text content of an element.</summary>
            /// <param name="element" type="Element">The element to change the text content of.</param>
            /// <param name="text" type="string">The string that should replace the current element
            ///     content.</param>
        }, 
        
        getOuterHtml: function(element) {
            /// <summary>Gets the outerHTML of a node, which islike innerHTML, except that it
            /// actually contains the HTML of the node itself.</summary>
            /// <param name="element" type="Element">The element to get the HTML of.</param>
            /// <returns type="string">The outerHTML of the given element.</returns>
        }, 
        
        findNode: function(root, p) {
            /// <summary>Finds the first descendant node that matches the filter function, using
            /// a depth first search. This function offers the most general purpose way
            /// of finding a matching element. You may also wish to consider
            /// {@code goog.dom.query} which can express many matching criteria using
            /// CSS selector expressions. These expressions often result in a more
            /// compact representation of the desired result.</summary>
            /// <param name="root" type="Node">The root of the tree to search.</param>
            /// <param name="p" type="function(Node) : boolean">The filter function.</param>
            /// <returns type="Node|undefined">The found node or undefined if none is found.</returns>
        }, 
        
        findNodes: function(root, p) {
            /// <summary>Finds all the descendant nodes that match the filter function, using a
            /// a depth first search. This function offers the most general-purpose way
            /// of finding a set of matching elements. You may also wish to consider
            /// {@code goog.dom.query} which can express many matching criteria using
            /// CSS selector expressions. These expressions often result in a more
            /// compact representation of the desired result.</summary>
            /// <param name="root" type="Node">The root of the tree to search.</param>
            /// <param name="p" type="function(Node) : boolean">The filter function.</param>
            /// <returns type="!Array.!Node">The found nodes or an empty array if none are found.</returns>
        }, 
        
        isFocusableTabIndex: function(element) {
            /// <summary>Returns true if the element has a tab index that allows it to receive
            /// keyboard focus (tabIndex >= 0), false otherwise.  Note that form elements
            /// natively support keyboard focus, even if they have no tab index.</summary>
            /// <param name="element" type="Element">Element to check.</param>
            /// <returns type="boolean">Whether the element has a tab index that allows keyboard
            ///     focus.</returns>
        }, 
        
        setFocusableTabIndex: function(element, enable) {
            /// <summary>Enables or disables keyboard focus support on the element via its tab index.
            /// Only elements for which {@link goog.dom.isFocusableTabIndex} returns true
            /// (or elements that natively support keyboard focus, like form elements) can
            /// receive keyboard focus.  See http://go/tabindex for more info.</summary>
            /// <param name="element" type="Element">Element whose tab index is to be changed.</param>
            /// <param name="enable" type="boolean">Whether to set or remove a tab index on the element
            ///     that supports keyboard focus.</param>
        }, 
        
        getTextContent: function(node) {
            /// <summary>Returns the text content of the current node, without markup and invisible
            /// symbols. New lines are stripped and whitespace is collapsed,
            /// such that each character would be visible.
            /// 
            /// In browsers that support it, innerText is used.  Other browsers attempt to
            /// simulate it via node traversal.  Line breaks are canonicalized in IE.</summary>
            /// <param name="node" type="Node">The node from which we are getting content.</param>
            /// <returns type="string">The text content.</returns>
        }, 
        
        getRawTextContent: function(node) {
            /// <summary>Returns the text content of the current node, without markup.
            /// 
            /// Unlike {@code getTextContent} this method does not collapse whitespaces
            /// or normalize lines breaks.</summary>
            /// <param name="node" type="Node">The node from which we are getting content.</param>
            /// <returns type="string">The raw text content.</returns>
        }, 
        
        getNodeTextLength: function(node) {
            /// <summary>Returns the text length of the text contained in a node, without markup. This
            /// is equivalent to the selection length if the node was selected, or the number
            /// of cursor movements to traverse the node. Images &amp; BRs take one space.  New
            /// lines are ignored.</summary>
            /// <param name="node" type="Node">The node whose text content length is being calculated.</param>
            /// <returns type="number">The length of {@code node}&apos;s text content.</returns>
        }, 
        
        getNodeTextOffset: function(node, opt_offsetParent) {
            /// <summary>Returns the text offset of a node relative to one of its ancestors. The text
            /// length is the same as the length calculated by goog.dom.getNodeTextLength.</summary>
            /// <param name="node" type="Node">The node whose offset is being calculated.</param>
            /// <param name="opt_offsetParent" type="Node=">The node relative to which the offset will
            ///     be calculated. Defaults to the node&apos;s owner document&apos;s body.</param>
            /// <returns type="number">The text offset.</returns>
        }, 
        
        getNodeAtOffset: function(parent, offset, opt_result) {
            /// <summary>Returns the node at a given offset in a parent node.  If an object is
            /// provided for the optional third parameter, the node and the remainder of the
            /// offset will stored as properties of this object.</summary>
            /// <param name="parent" type="Node">The parent node.</param>
            /// <param name="offset" type="number">The offset into the parent node.</param>
            /// <param name="opt_result" type="Object=">Object to be used to store the return value. The
            ///     return value will be stored in the form {node: Node, remainder: number}
            ///     if this object is provided.</param>
            /// <returns type="Node">The node at the given offset.</returns>
        }, 
        
        isNodeList: function(val) {
            /// <summary>Returns true if the object is a {@code NodeList}.  To qualify as a NodeList,
            /// the object must have a numeric length property and an item function (which
            /// has type &apos;string&apos; on IE for some reason).</summary>
            /// <param name="val" type="Object">Object to test.</param>
            /// <returns type="boolean">Whether the object is a NodeList.</returns>
        }, 
        
        getAncestorByTagNameAndClass: function(element, opt_tag, opt_class) {
            /// <summary>Walks up the DOM hierarchy returning the first ancestor that has the passed
            /// tag name and/or class name. If the passed element matches the specified
            /// criteria, the element itself is returned.</summary>
            /// <param name="element" type="Node">The DOM node to start with.</param>
            /// <param name="opt_tag" type="?(goog.dom.TagName|string)=">The tag name to match (or
            ///     null/undefined to match only based on class name).</param>
            /// <param name="opt_class" type="?string=">The class name to match (or null/undefined to
            ///     match only based on tag name).</param>
            /// <returns type="Element">The first ancestor that matches the passed criteria, or
            ///     null if no match is found.</returns>
        }, 
        
        getAncestorByClass: function(element, className) {
            /// <summary>Walks up the DOM hierarchy returning the first ancestor that has the passed
            /// class name. If the passed element matches the specified criteria, the
            /// element itself is returned.</summary>
            /// <param name="element" type="Node">The DOM node to start with.</param>
            /// <param name="className" type="string">The class name to match.</param>
            /// <returns type="Element">The first ancestor that matches the passed criteria, or
            ///     null if none match.</returns>
        }, 
        
        getAncestor: function(element, matcher, opt_includeNode, opt_maxSearchSteps) {
            /// <summary>Walks up the DOM hierarchy returning the first ancestor that passes the
            /// matcher function.</summary>
            /// <param name="element" type="Node">The DOM node to start with.</param>
            /// <param name="matcher" type="function(Node) : boolean">A function that returns true if the
            ///     passed node matches the desired criteria.</param>
            /// <param name="opt_includeNode" type="boolean=">If true, the node itself is included in
            ///     the search (the first call to the matcher will pass startElement as
            ///     the node to test).</param>
            /// <param name="opt_maxSearchSteps" type="number=">Maximum number of levels to search up the
            ///     dom.</param>
            /// <returns type="Node">DOM node that matched the matcher, or null if there was
            ///     no match.</returns>
        }, 
        
        getActiveElement: function(doc) {
            /// <summary>Determines the active element in the given document.</summary>
            /// <param name="doc" type="Document">The document to look in.</param>
            /// <returns type="Element">The active element.</returns>
        }
        
    };

    var $x = window.goog.dom;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom";
})(this);
