
/* vsdoc for goog.dom.AbstractRange */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.AbstractRange = function(){
        /// <summary></summary>
        /// <field name="clone" type="goog.dom.AbstractRange"></field>
        /// <field name="getType" type="goog.dom.RangeType"></field>
        /// <field name="getBrowserRangeObject" type="Range|TextRange"></field>
        /// <field name="getTextRangeCount" type="number"></field>
        /// <field name="getTextRange" type="goog.dom.TextRange">Get the i-th text range in this range.  The behavior is undefined if
        /// i >= getTextRangeCount or i < 0.</field>
        /// <field name="getContainer" type="Node"></field>
        /// <field name="getStartNode" type="Node"></field>
        /// <field name="getStartOffset" type="number"></field>
        /// <field name="getEndNode" type="Node"></field>
        /// <field name="getEndOffset" type="number"></field>
        /// <field name="containsRange" type="boolean">Tests if this range contains the given range.</field>
        /// <field name="isRangeInDocument" type="boolean">Tests whether this range is valid (i.e. whether its endpoints are still in
        /// the document).  A range becomes invalid when, after this object was created,
        /// either one or both of its endpoints are removed from the document.  Use of
        /// an invalid range can lead to runtime errors, particularly in IE.</field>
        /// <field name="isCollapsed" type="boolean"></field>
        /// <field name="getText" type="string"></field>
        /// <field name="getHtmlFragment" type="string">Returns the HTML fragment this range selects.  This is slow on all browsers.
        /// The HTML fragment may not be valid HTML, for instance if the user selects
        /// from a to b inclusively in the following html:
        /// 
        /// &amp;gt;div&amp;lt;a&amp;gt;/div&amp;lt;b
        /// 
        /// This method will return
        /// 
        /// a&amp;lt;/div&amp;gt;b
        /// 
        /// If you need valid HTML, use {@link #getValidHtml} instead.</field>
        /// <field name="getValidHtml" type="string">Returns valid HTML for this range.  This is fast on IE, and semi-fast on
        /// other browsers.</field>
        /// <field name="getPastableHtml" type="string">Returns pastable HTML for this range.  This guarantees that any child items
        /// that must have specific ancestors will have them, for instance all TDs will
        /// be contained in a TR in a TBODY in a TABLE and all LIs will be contained in
        /// a UL or OL as appropriate.  This is semi-fast on all browsers.</field>
        /// <field name="select" type="">Sets this range as the selection in its window.</field>
        /// <field name="removeContents" type="">Removes the contents of the range from the document.</field>
        /// <field name="insertNode" type="Node">Inserts a node before (or after) the range.  The range may be disrupted
        /// beyond recovery because of the way this splits nodes.</field>
        /// <field name="surroundWithNodes" type="">Surrounds this range with the two given nodes.  The range may be disrupted
        /// beyond recovery because of the way this splits nodes.</field>
        /// <field name="saveUsingDom" type="goog.dom.SavedRange">Saves the range so that if the start and end nodes are left alone, it can
        /// be restored.</field>
        /// <field name="collapse" type="">Collapses the range to one of its boundary points.</field>
        /// <returns type="goog.dom.AbstractRange"/>
    };

    var $x = window.goog.dom.AbstractRange;
    $x.prototype = {
                
        getBrowserSelectionForWindow: function(win) {
            /// <summary>Gets the browser native selection object from the given window.</summary>
            /// <param name="win" type="Window">The window to get the selection object from.</param>
            /// <returns type="Object">The browser native selection object, or null if it could
            ///     not be retrieved.</returns>
        }, 
        
        isNativeControlRange: function(range) {
            /// <summary>Tests if the given Object is a controlRange.</summary>
            /// <param name="range" type="Object">The range object to test.</param>
            /// <returns type="boolean">Whether the given Object is a controlRange.</returns>
        }, 
        
        setBrowserRangeObject: function(nativeRange) {
            /// <summary>Sets the native browser range object, overwriting any state this range was
            /// storing.</summary>
            /// <param name="nativeRange" type="Range|TextRange">The native browser range object.</param>
            /// <returns type="boolean">Whether the given range was accepted.  If not, the caller
            ///     will need to call goog.dom.Range.createFromBrowserRange to create a new
            ///     range object.</returns>
        }, 
        
        getTextRanges: function() {
            /// <summary>Gets an array of all text ranges this range is comprised of.  For non-multi
            /// ranges, returns a single element array containing this.</summary>
            /// <returns type="Array.goog.dom.TextRange">Array of text ranges.</returns>
        }, 
        
        getContainerElement: function() {
            /// <summary>Returns the deepest element in the tree that contains the entire range.</summary>
            /// <returns type="Element">The deepest element that contains the entire range.</returns>
        }, 
        
        getAnchorNode: function() {
            /// <summary></summary>
            /// <returns type="Node">The element or text node the range is anchored at.</returns>
        }, 
        
        getAnchorOffset: function() {
            /// <summary></summary>
            /// <returns type="number">The offset into the node the range is anchored at.  For
            ///     text nodes, this is an offset into the node value.  For elements, this
            ///     is an offset into the childNodes array.</returns>
        }, 
        
        getFocusNode: function() {
            /// <summary></summary>
            /// <returns type="Node">The element or text node the range is focused at - i.e. where
            ///     the cursor is.</returns>
        }, 
        
        getFocusOffset: function() {
            /// <summary></summary>
            /// <returns type="number">The offset into the node the range is focused at - i.e.
            ///     where the cursor is.  For text nodes, this is an offset into the node
            ///     value.  For elements, this is an offset into the childNodes array.</returns>
        }, 
        
        isReversed: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the selection is reversed.</returns>
        }, 
        
        getDocument: function() {
            /// <summary></summary>
            /// <returns type="Document">The document this selection is a part of.</returns>
        }, 
        
        getWindow: function() {
            /// <summary></summary>
            /// <returns type="Window">The window this selection is a part of.</returns>
        }, 
        
        containsNode: function(node, opt_allowPartial) {
            /// <summary>Tests if this range contains the given node.</summary>
            /// <param name="node" type="Node">The node to test for.</param>
            /// <param name="opt_allowPartial" type="boolean=">If not set or false, the node must be
            ///     entirely contained in the selection for this function to return true.</param>
            /// <returns type="boolean">Whether this range contains the given node.</returns>
        }, 
        
        replaceContentsWithNode: function(node) {
            /// <summary>Replaces the range contents with (possibly a copy of) the given node.  The
            /// range may be disrupted beyond recovery because of the way this splits nodes.</summary>
            /// <param name="node" type="Node">The node to insert.</param>
            /// <returns type="Node">The node added to the document.  This may be different
            ///     than the node parameter because on IE we have to clone it.</returns>
        }, 
        
        saveUsingCarets: function() {
            /// <summary>Saves the range using HTML carets. As long as the carets remained in the
            /// HTML, the range can be restored...even when the HTML is copied across
            /// documents.</summary>
            /// <returns type="goog.dom.SavedCaretRange?">A range representation that can be
            ///     restored as long as carets are not removed. Returns null if carets
            ///     could not be created.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.dom.AbstractRange";
})(this);
