
/* vsdoc for goog.dom.DomHelper */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.DomHelper = function(opt_document){
        /// <summary></summary>
        /// <param name="opt_document" type="Document=">Document object to associate with this
        ///     DOM helper.</param>
        /// <field name="getDomHelper" type="!goog.dom.DomHelper">Gets the dom helper object for the document where the element resides.</field>
        /// <field name="$" type="Element">Alias for {@code getElement}.</field>
        /// <field name="$$" type="{length: number}">Alias for {@code getElementsByTagNameAndClass}.</field>
        /// <field name="setProperties" type="">Sets a number of properties on a node.</field>
        /// <field name="$dom" type="!Element">Alias for {@code createDom}.</field>
        /// <field name="appendChild" type="">Appends a child to a node.</field>
        /// <field name="append" type="">Appends a node with text or other nodes.</field>
        /// <field name="canHaveChildren" type="boolean">Determines if the given node can contain children, intended to be used for
        /// HTML generation.</field>
        /// <field name="removeChildren" type="">Removes all the child nodes on a DOM node.</field>
        /// <field name="insertSiblingBefore" type="">Inserts a new node before an existing reference node (i.e., as the previous
        /// sibling). If the reference node has no parent, then does nothing.</field>
        /// <field name="insertSiblingAfter" type="">Inserts a new node after an existing reference node (i.e., as the next
        /// sibling). If the reference node has no parent, then does nothing.</field>
        /// <field name="insertChildAt" type="">Insert a child at a given index. If index is larger than the number of child
        /// nodes that the parent currently has, the node is inserted as the last child
        /// node.</field>
        /// <field name="removeNode" type="Node">Removes a node from its parent.</field>
        /// <field name="replaceNode" type="">Replaces a node in the DOM tree. Will do nothing if {@code oldNode} has no
        /// parent.</field>
        /// <field name="flattenElement" type="Element|undefined">Flattens an element. That is, removes it and replace it with its children.</field>
        /// <field name="getChildren" type="!(Array|NodeList)">Returns an array containing just the element children of the given element.</field>
        /// <field name="getFirstElementChild" type="Element">Returns the first child node that is an element.</field>
        /// <field name="getLastElementChild" type="Element">Returns the last child node that is an element.</field>
        /// <field name="getNextElementSibling" type="Element">Returns the first next sibling that is an element.</field>
        /// <field name="getPreviousElementSibling" type="Element">Returns the first previous sibling that is an element.</field>
        /// <field name="getNextNode" type="Node">Returns the next node in source order from the given node.</field>
        /// <field name="getPreviousNode" type="Node">Returns the previous node in source order from the given node.</field>
        /// <field name="isNodeLike" type="boolean">Whether the object looks like a DOM node.</field>
        /// <field name="isElement" type="boolean">Whether the object looks like an Element.</field>
        /// <field name="isWindow" type="boolean">Returns true if the specified value is a Window object. This includes the
        /// global window for HTML pages, and iframe windows.</field>
        /// <field name="getParentElement" type="Element">Returns an element&apos;s parent, if it&apos;s an Element.</field>
        /// <field name="contains" type="boolean">Whether a node contains another node.</field>
        /// <field name="compareNodeOrder" type="number">Compares the document order of two nodes, returning 0 if they are the same
        /// node, a negative number if node1 is before node2, and a positive number if
        /// node2 is before node1.  Note that we compare the order the tags appear in the
        /// document so in the tree <b><i>text</i></b> the B node is considered to be
        /// before the I node.</field>
        /// <field name="findCommonAncestor" type="Node">Find the deepest common ancestor of the given nodes.</field>
        /// <field name="getOwnerDocument" type="!Document">Returns the owner document for a node.</field>
        /// <field name="getFrameContentDocument" type="!Document">Cross browser function for getting the document element of an iframe.</field>
        /// <field name="getFrameContentWindow" type="Window">Cross browser function for getting the window of a frame or iframe.</field>
        /// <field name="setTextContent" type="">Cross browser function for setting the text content of an element.</field>
        /// <field name="getOuterHtml" type="string">Gets the outerHTML of a node, which islike innerHTML, except that it
        /// actually contains the HTML of the node itself.</field>
        /// <field name="findNode" type="Node|undefined">Finds the first descendant node that matches the filter function. This does
        /// a depth first search.</field>
        /// <field name="findNodes" type="Array.Node">Finds all the descendant nodes that matches the filter function. This does a
        /// depth first search.</field>
        /// <field name="isFocusableTabIndex" type="boolean">Returns true if the element has a tab index that allows it to receive
        /// keyboard focus (tabIndex >= 0), false otherwise.  Note that form elements
        /// natively support keyboard focus, even if they have no tab index.</field>
        /// <field name="setFocusableTabIndex" type="">Enables or disables keyboard focus support on the element via its tab index.
        /// Only elements for which {@link goog.dom.isFocusableTabIndex} returns true
        /// (or elements that natively support keyboard focus, like form elements) can
        /// receive keyboard focus.  See http://go/tabindex for more info.</field>
        /// <field name="getTextContent" type="string">Returns the text contents of the current node, without markup. New lines are
        /// stripped and whitespace is collapsed, such that each character would be
        /// visible.
        /// 
        /// In browsers that support it, innerText is used.  Other browsers attempt to
        /// simulate it via node traversal.  Line breaks are canonicalized in IE.</field>
        /// <field name="getNodeTextLength" type="number">Returns the text length of the text contained in a node, without markup. This
        /// is equivalent to the selection length if the node was selected, or the number
        /// of cursor movements to traverse the node. Images &amp; BRs take one space.  New
        /// lines are ignored.</field>
        /// <field name="getNodeTextOffset" type="number">Returns the text offset of a node relative to one of its ancestors. The text
        /// length is the same as the length calculated by
        /// {@code goog.dom.getNodeTextLength}.</field>
        /// <field name="getNodeAtOffset" type="Node">Returns the node at a given offset in a parent node.  If an object is
        /// provided for the optional third parameter, the node and the remainder of the
        /// offset will stored as properties of this object.</field>
        /// <field name="isNodeList" type="boolean">Returns true if the object is a {@code NodeList}.  To qualify as a NodeList,
        /// the object must have a numeric length property and an item function (which
        /// has type &apos;string&apos; on IE for some reason).</field>
        /// <field name="getAncestorByTagNameAndClass" type="Element">Walks up the DOM hierarchy returning the first ancestor that has the passed
        /// tag name and/or class name. If the passed element matches the specified
        /// criteria, the element itself is returned.</field>
        /// <field name="getAncestorByClass" type="Element">Walks up the DOM hierarchy returning the first ancestor that has the passed
        /// class name. If the passed element matches the specified criteria, the
        /// element itself is returned.</field>
        /// <field name="getAncestor" type="Node">Walks up the DOM hierarchy returning the first ancestor that passes the
        /// matcher function.</field>
        /// <returns type="goog.dom.DomHelper"/>
    };

    var $x = window.goog.dom.DomHelper;
    $x.prototype = {
                
        setDocument: function(document) {
            /// <summary>Sets the document object.</summary>
            /// <param name="document" type="!Document">Document object.</param>
        }, 
        
        getDocument: function() {
            /// <summary>Gets the document object being used by the dom library.</summary>
            /// <returns type="!Document">Document object.</returns>
        }, 
        
        getElement: function(element) {
            /// <summary>Alias for {@code getElementById}. If a DOM node is passed in then we just
            /// return that.</summary>
            /// <param name="element" type="string|Element">Element ID or a DOM node.</param>
            /// <returns type="Element">The element with the given ID, or the node passed in.</returns>
        }, 
        
        getElementsByTagNameAndClass: function(opt_tag, opt_class, opt_el) {
            /// <summary>Looks up elements by both tag and class name, using browser native functions
            /// ({@code querySelectorAll}, {@code getElementsByTagName | @code getElementsByClassName}) where possible. The returned array is a live
            /// NodeList or a static list depending on the code path taken.</summary>
            /// <param name="opt_tag" type="?string=">Element tag name or * for all tags.</param>
            /// <param name="opt_class" type="?string=">Optional class name.</param>
            /// <param name="opt_el" type="(Document|Element)=">Optional element to look in.</param>
            /// <returns type="{length: number}">Array-like list of elements (only a length
            ///     property and numerical indices are guaranteed to exist).</returns>
        }, 
        
        getElementsByClass: function(className, opt_el) {
            /// <summary>Returns an array of all the elements with the provided className.</summary>
            /// <param name="className" type="string">the name of the class to look for.</param>
            /// <param name="opt_el" type="Element|Document=">Optional element to look in.</param>
            /// <returns type="{length: number}">The items found with the class name provided.</returns>
        }, 
        
        getElementByClass: function(className, opt_el) {
            /// <summary>Returns the first element we find matching the provided class name.</summary>
            /// <param name="className" type="string">the name of the class to look for.</param>
            /// <param name="opt_el" type="(Element|Document)=">Optional element to look in.</param>
            /// <returns type="Element">The first item found with the class name provided.</returns>
        }, 
        
        getViewportSize: function(opt_window) {
            /// <summary>Gets the dimensions of the viewport.</summary>
            /// <param name="opt_window" type="Window=">Optional window element to test. Defaults to
            ///     the window of the Dom Helper.</param>
            /// <returns type="!goog.math.Size">Object with values &apos;width&apos; and &apos;height&apos;.</returns>
        }, 
        
        getDocumentHeight: function() {
            /// <summary>Calculates the height of the document.</summary>
            /// <returns type="number">The height of the document.</returns>
        }, 
        
        createDom: function(tagName, opt_attributes, var_args) {
            /// <summary>Returns a dom node with a set of attributes.  This function accepts varargs
            /// for subsequent nodes to be added.  Subsequent nodes will be added to the
            /// first node as childNodes.
            /// 
            /// So:
            /// &lt;code&gt;createDom(&apos;div&apos;, null, createDom(&apos;p&apos;), createDom(&apos;p&apos;));&lt;/code&gt;
            /// would return a div with two child paragraphs
            /// 
            /// An easy way to move all child nodes of an existing element to a new parent
            /// element is:
            /// &lt;code&gt;createDom(&apos;div&apos;, null, oldElement.childNodes);&lt;/code&gt;
            /// which will remove all child nodes from the old element and add them as
            /// child nodes of the new DIV.</summary>
            /// <param name="tagName" type="string">Tag to create.</param>
            /// <param name="opt_attributes" type="Object|string=">If object, then a map of name-value
            ///     pairs for attributes. If a string, then this is the className of the new
            ///     element.</param>
            /// <param name="var_args" type="...goog.dom.Appendable">Further DOM nodes or
            ///     strings for text nodes. If one of the var_args is an array or
            ///     NodeList, its elements will be added as childNodes instead.</param>
            /// <returns type="!Element">Reference to a DOM node.</returns>
        }, 
        
        createElement: function(name) {
            /// <summary>Creates a new element.</summary>
            /// <param name="name" type="string">Tag name.</param>
            /// <returns type="!Element">The new element.</returns>
        }, 
        
        createTextNode: function(content) {
            /// <summary>Creates a new text node.</summary>
            /// <param name="content" type="string">Content.</param>
            /// <returns type="!Text">The new text node.</returns>
        }, 
        
        createTable: function(rows, columns, opt_fillWithNbsp) {
            /// <summary>Create a table.</summary>
            /// <param name="rows" type="number">The number of rows in the table.  Must be >= 1.</param>
            /// <param name="columns" type="number">The number of columns in the table.  Must be >= 1.</param>
            /// <param name="opt_fillWithNbsp" type="boolean=">If true, fills table entries with nsbps.</param>
            /// <returns type="!Element">The created table.</returns>
        }, 
        
        htmlToDocumentFragment: function(htmlString) {
            /// <summary>Converts an HTML string into a node or a document fragment.  A single Node
            /// is used if the {@code htmlString} only generates a single node.  If the
            /// {@code htmlString} generates multiple nodes then these are put inside a
            /// {@code DocumentFragment}.</summary>
            /// <param name="htmlString" type="string">The HTML string to convert.</param>
            /// <returns type="!Node">The resulting node.</returns>
        }, 
        
        getCompatMode: function() {
            /// <summary>Returns the compatMode of the document.</summary>
            /// <returns type="string">The result is either CSS1Compat or BackCompat.</returns>
        }, 
        
        isCss1CompatMode: function() {
            /// <summary>Returns true if the browser is in &quot;CSS1-compatible&quot; (standards-compliant)
            /// mode, false otherwise.</summary>
            /// <returns type="boolean">True if in CSS1-compatible mode.</returns>
        }, 
        
        getWindow: function() {
            /// <summary>Gets the window object associated with the document.</summary>
            /// <returns type="!Window">The window associated with the given document.</returns>
        }, 
        
        getDocumentScrollElement: function() {
            /// <summary>Gets the document scroll element.</summary>
            /// <returns type="Element">Scrolling element.</returns>
        }, 
        
        getDocumentScroll: function() {
            /// <summary>Gets the document scroll distance as a coordinate object.</summary>
            /// <returns type="!goog.math.Coordinate">Object with properties &apos;x&apos; and &apos;y&apos;.</returns>
        }, 
        
        getActiveElement: function(opt_doc) {
            /// <summary>Determines the active element in the given document.</summary>
            /// <param name="opt_doc" type="Document=">The document to look in.</param>
            /// <returns type="Element">The active element.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.dom.DomHelper";
})(this);
