
/* vsdoc for goog.dom.Range */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.Range = {
        /// <summary></summary>
        /// <returns type="goog.dom.Range"/>
                
        createFromWindow: function(opt_win) {
            /// <summary>Create a new selection from the given browser window&apos;s current selection.
            /// Note that this object does not auto-update if the user changes their
            /// selection and should be used as a snapshot.</summary>
            /// <param name="opt_win" type="Window=">The window to get the selection of.  Defaults to the
            ///     window this class was defined in.</param>
            /// <returns type="goog.dom.AbstractRange?">A range wrapper object, or null if there
            ///     was an error.</returns>
        }, 
        
        createFromBrowserSelection: function(selection) {
            /// <summary>Create a new range wrapper from the given browser selection object.  Note
            /// that this object does not auto-update if the user changes their selection and
            /// should be used as a snapshot.</summary>
            /// <param name="selection" type="!Object">The browser selection object.</param>
            /// <returns type="goog.dom.AbstractRange?">A range wrapper object or null if there
            ///    was an error.</returns>
        }, 
        
        createFromBrowserRange: function(range, opt_isReversed) {
            /// <summary>Create a new range wrapper from the given browser range object.</summary>
            /// <param name="range" type="Range|TextRange">The browser range object.</param>
            /// <param name="opt_isReversed" type="boolean=">Whether the focus node is before the anchor
            ///     node.</param>
            /// <returns type="goog.dom.AbstractRange">A range wrapper object.</returns>
        }, 
        
        createFromNodeContents: function(node, opt_isReversed) {
            /// <summary>Create a new range wrapper that selects the given node&apos;s text.</summary>
            /// <param name="node" type="Node">The node to select.</param>
            /// <param name="opt_isReversed" type="boolean=">Whether the focus node is before the anchor
            ///     node.</param>
            /// <returns type="goog.dom.AbstractRange">A range wrapper object.</returns>
        }, 
        
        createCaret: function(node, offset) {
            /// <summary>Create a new range wrapper that represents a caret at the given node,
            /// accounting for the given offset.  This always creates a TextRange, regardless
            /// of whether node is an image node or other control range type node.</summary>
            /// <param name="node" type="Node">The node to place a caret at.</param>
            /// <param name="offset" type="number">The offset within the node to place the caret at.</param>
            /// <returns type="goog.dom.AbstractRange">A range wrapper object.</returns>
        }, 
        
        createFromNodes: function(startNode, startOffset, endNode, endOffset) {
            /// <summary>Create a new range wrapper that selects the area between the given nodes,
            /// accounting for the given offsets.</summary>
            /// <param name="startNode" type="Node">The node to start with.</param>
            /// <param name="startOffset" type="number">The offset within the node to start.</param>
            /// <param name="endNode" type="Node">The node to end with.</param>
            /// <param name="endOffset" type="number">The offset within the node to end.</param>
            /// <returns type="goog.dom.AbstractRange">A range wrapper object.</returns>
        }, 
        
        clearSelection: function(opt_win) {
            /// <summary>Clears the window&apos;s selection.</summary>
            /// <param name="opt_win" type="Window=">The window to get the selection of.  Defaults to the
            ///     window this class was defined in.</param>
        }, 
        
        hasSelection: function(opt_win) {
            /// <summary>Tests if the window has a selection.</summary>
            /// <param name="opt_win" type="Window=">The window to check the selection of.  Defaults to
            ///     the window this class was defined in.</param>
            /// <returns type="boolean">Whether the window has a selection.</returns>
        }, 
        
        isReversed: function(anchorNode, anchorOffset, focusNode, focusOffset) {
            /// <summary>Returns whether the focus position occurs before the anchor position.</summary>
            /// <param name="anchorNode" type="Node">The node to start with.</param>
            /// <param name="anchorOffset" type="number">The offset within the node to start.</param>
            /// <param name="focusNode" type="Node">The node to end with.</param>
            /// <param name="focusOffset" type="number">The offset within the node to end.</param>
            /// <returns type="boolean">Whether the focus position occurs before the anchor
            ///     position.</returns>
        }
        
    };

    var $x = window.goog.dom.Range;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.Range";
})(this);
