
/* vsdoc for goog.dom.TagIterator */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.TagIterator = function(opt_node, opt_reversed, opt_unconstrained, opt_tagType, opt_depth){
        /// <summary></summary>
        /// <param name="opt_node" type="Node=">The start node.  If unspecified or null, defaults to
        ///     an empty iterator.</param>
        /// <param name="opt_reversed" type="boolean=">Whether to traverse the tree in reverse.</param>
        /// <param name="opt_unconstrained" type="boolean=">Whether the iterator is not constrained
        ///     to the starting node and its children.</param>
        /// <param name="opt_tagType" type="goog.dom.TagWalkType?=">The type of the position.
        ///     Defaults to the start of the given node for forward iterators, and
        ///     the end of the node for reverse iterators.</param>
        /// <param name="opt_depth" type="number=">The starting tree depth.</param>
        /// <field name="node" type="Node">The node this position is located on.</field>
        /// <field name="tagType" type="goog.dom.TagWalkType">The type of this position.</field>
        /// <returns type="goog.dom.TagIterator"/>
    };

    var $x = window.goog.dom.TagIterator;
    $x.prototype = {
                
        setPosition: function(node, opt_tagType, opt_depth) {
            /// <summary>Set the position of the iterator.  Overwrite the tree node and the position
            /// type which can be one of the {@link goog.dom.TagWalkType} token types.
            /// Only overwrites the tree depth when the parameter is specified.</summary>
            /// <param name="node" type="Node">The node to set the position to.</param>
            /// <param name="opt_tagType" type="goog.dom.TagWalkType?=">The type of the position
            ///     Defaults to the start of the given node.</param>
            /// <param name="opt_depth" type="number=">The tree depth.</param>
        }, 
        
        copyFrom: function(other) {
            /// <summary>Replace this iterator&apos;s values with values from another. The two iterators
            /// must be of the same type.</summary>
            /// <param name="other" type="goog.dom.TagIterator">The iterator to copy.</param>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="goog.dom.TagIterator">A copy of this iterator.</returns>
        }, 
        
        skipTag: function() {
            /// <summary>Skip the current tag.</summary>
        }, 
        
        restartTag: function() {
            /// <summary>Restart the current tag.</summary>
        }, 
        
        next: function() {
            /// <summary>Move to the next position in the DOM tree.</summary>
            /// <returns type="Node">Returns the next node, or throws a goog.iter.StopIteration
            ///     exception if the end of the iterator&apos;s range has been reached.</returns>
        }, 
        
        isStarted: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether next has ever been called on this iterator.</returns>
        }, 
        
        isStartTag: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this iterator&apos;s position is a start tag position.</returns>
        }, 
        
        isEndTag: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this iterator&apos;s position is an end tag position.</returns>
        }, 
        
        isNonElement: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this iterator&apos;s position is not at an element node.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Test if two iterators are at the same position - i.e. if the node and tagType
            /// is the same.  This will still return true if the two iterators are moving in
            /// opposite directions or have different constraints.</summary>
            /// <param name="other" type="goog.dom.TagIterator">The iterator to compare to.</param>
            /// <returns type="boolean">Whether the two iterators are at the same position.</returns>
        }, 
        
        splice: function(var_args) {
            /// <summary>Replace the current node with the list of nodes. Reset the iterator so that
            /// it visits the first of the nodes next.</summary>
            /// <param name="var_args" type="...Object">A list of nodes to replace the current node with.
            ///     If the first argument is array-like, it will be used, otherwise all the
            ///     arguments are assumed to be nodes.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.dom.TagIterator";
})(this);
