
/* vsdoc for goog.dom.a11y */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.a11y = {
        /// <summary></summary>
        /// <field name="State" type="">Enumeration of ARIA states and properties.</field>
        /// <field name="Role" type="">Enumeration of ARIA roles.</field>
        /// <field name="LivePriority" type="">Enumeration of ARIA state values for live regions.
        /// 
        /// See http://www.w3.org/TR/wai-aria/states_and_properties#aria-live
        /// for more information.</field>
        /// <returns type="goog.dom.a11y"/>
                
        setRole: function(element, roleName) {
            /// <summary>Sets the role of an element.</summary>
            /// <param name="element" type="Element">DOM node to set role of.</param>
            /// <param name="roleName" type="string">role name(s).</param>
        }, 
        
        getRole: function(element) {
            /// <summary>Gets role of an element.</summary>
            /// <param name="element" type="Element">DOM node to get role of.</param>
            /// <returns type="string">rolename.</returns>
        }, 
        
        setState: function(element, state, value) {
            /// <summary>Sets the state or property of an element.</summary>
            /// <param name="element" type="Element">DOM node where we set state.</param>
            /// <param name="state" type="string">State attribute being set. Automatically adds prefix
            ///     &apos;aria-&apos; to the state name.</param>
            /// <param name="value" type="string|boolean|number">Value for the state attribute.</param>
        }, 
        
        getState: function(element, stateName) {
            /// <summary>Gets value of specified state or property.</summary>
            /// <param name="element" type="Element">DOM node to get state from.</param>
            /// <param name="stateName" type="string">State name.</param>
            /// <returns type="string">Value of the state attribute.</returns>
        }, 
        
        getActiveDescendant: function(element) {
            /// <summary>Gets the activedescendant of the given element.</summary>
            /// <param name="element" type="Element">DOM node to get activedescendant from.</param>
            /// <returns type="Element">DOM node of the activedescendant.</returns>
        }, 
        
        setActiveDescendant: function(element, activeElement) {
            /// <summary>Sets the activedescendant value for an element.</summary>
            /// <param name="element" type="Element">DOM node to set activedescendant to.</param>
            /// <param name="activeElement" type="Element">DOM node being set as activedescendant.</param>
        }
        
    };

    var $x = window.goog.dom.a11y;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.a11y";
})(this);
