
/* vsdoc for goog.dom.annotate */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.annotate = {
        /// <summary></summary>
        /// <returns type="goog.dom.annotate"/>
                
        annotateTerms: function(node, terms, annotateFn, opt_ignoreCase, opt_classesToSkip, opt_maxMs) {
            /// <summary>Calls {@code annotateFn} for each occurrence of a search term in text nodes
            /// under {@code node}. Returns the number of hits.</summary>
            /// <param name="node" type="Node">A DOM node.</param>
            /// <param name="terms" type="Array">An array of [searchTerm, matchWholeWordOnly] tuples.
            ///   The matchWholeWordOnly value is a per-term attribute because some terms
            ///   may be CJK, while others are not. (For correctness, matchWholeWordOnly
            ///   should always be false for CJK terms.).</param>
            /// <param name="annotateFn" type="Function">A function that takes
            ///   (1) the number of the term that is &quot;hit&quot;,
            ///   (2) the HTML string (search term) to be annotated,
            ///   and returns the annotated term as an HTML string.</param>
            /// <param name="opt_ignoreCase" type="*=">Whether to ignore the case of the query
            ///   terms when looking for matches.</param>
            /// <param name="opt_classesToSkip" type="Array.string=">Nodes with one of these CSS class
            ///   names (and its descendants) will be skipped.</param>
            /// <param name="opt_maxMs" type="number=">Number of milliseconds after which this function,
            ///   if still annotating, should stop and return.</param>
            /// <returns type="boolean">Whether any terms were annotated.</returns>
        }, 
        
        annotateText: function(text, terms, annotateFn, opt_ignoreCase) {
            /// <summary>Annotates occurrences of query terms in plain text. This process consists of
            /// identifying all occurrences of all query terms, calling a provided function
            /// to get the appropriate replacement HTML for each occurrence, and
            /// HTML-escaping all the text.</summary>
            /// <param name="text" type="string">The plain text to be searched.</param>
            /// <param name="terms" type="Array">An array of
            ///   [{string} searchTerm, {boolean} matchWholeWordOnly] tuples.
            ///   The matchWholeWordOnly value is a per-term attribute because some terms
            ///   may be CJK, while others are not. (For correctness, matchWholeWordOnly
            ///   should always be false for CJK terms.).</param>
            /// <param name="annotateFn" type="Function">{function(number, string) : string} A function
            ///   that takes
            ///   (1) the number of the term that is &quot;hit&quot;,
            ///   (2) the HTML string (search term) to be annotated,
            ///   and returns the annotated term as an HTML string.</param>
            /// <param name="opt_ignoreCase" type="*=">Whether to ignore the case of the query
            ///   terms when looking for matches.</param>
            /// <returns type="?string">The HTML equivalent of {@code text} with terms
            ///   annotated, or null if the text did not contain any of the terms.</returns>
        }
        
    };

    var $x = window.goog.dom.annotate;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.annotate";
})(this);
