
/* vsdoc for goog.dom.classes */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.classes = {
        /// <summary></summary>
        /// <returns type="goog.dom.classes"/>
                
        set: function(element, className) {
            /// <summary>Sets the entire class name of an element.</summary>
            /// <param name="element" type="Node">DOM node to set class of.</param>
            /// <param name="className" type="string">Class name(s) to apply to element.</param>
        }, 
        
        get: function(element) {
            /// <summary>Gets an array of class names on an element</summary>
            /// <param name="element" type="Node">DOM node to get class of.</param>
            /// <returns type="!Array">Class names on {@code element}. Some browsers add extra
            ///     properties to the array. Do not depend on any of these!</returns>
        }, 
        
        add: function(element, var_args) {
            /// <summary>Adds a class or classes to an element. Does not add multiples of class names.</summary>
            /// <param name="element" type="Node">DOM node to add class to.</param>
            /// <param name="var_args" type="...string">Class names to add.</param>
            /// <returns type="boolean">Whether class was added (or all classes were added).</returns>
        }, 
        
        remove: function(element, var_args) {
            /// <summary>Removes a class or classes from an element.</summary>
            /// <param name="element" type="Node">DOM node to remove class from.</param>
            /// <param name="var_args" type="...string">Class name(s) to remove.</param>
            /// <returns type="boolean">Whether all classes in {@code var_args} were found and
            ///     removed.</returns>
        }, 
        
        swap: function(element, fromClass, toClass) {
            /// <summary>Switches a class on an element from one to another without disturbing other
            /// classes. If the fromClass isn&apos;t removed, the toClass won&apos;t be added.</summary>
            /// <param name="element" type="Node">DOM node to swap classes on.</param>
            /// <param name="fromClass" type="string">Class to remove.</param>
            /// <param name="toClass" type="string">Class to add.</param>
            /// <returns type="boolean">Whether classes were switched.</returns>
        }, 
        
        addRemove: function(element, classesToRemove, classesToAdd) {
            /// <summary>Adds zero or more classes to an element and removes zero or more as a single
            /// operation. Unlike calling {@link goog.dom.classes.add} and
            /// {@link goog.dom.classes.remove} separately, this is more efficient as it only
            /// parses the class property once.
            /// 
            /// If a class is in both the remove and add lists, it will be added. Thus,
            /// you can use this instead of {@link goog.dom.classes.swap} when you have
            /// more than two class names that you want to swap.</summary>
            /// <param name="element" type="Node">DOM node to swap classes on.</param>
            /// <param name="classesToRemove" type="?(string|Array.string)">Class or classes to
            ///     remove, if null no classes are removed.</param>
            /// <param name="classesToAdd" type="?(string|Array.string)">Class or classes to add, if
            ///     null no classes are added.</param>
        }, 
        
        has: function(element, className) {
            /// <summary>Returns true if an element has a class.</summary>
            /// <param name="element" type="Node">DOM node to test.</param>
            /// <param name="className" type="string">Class name to test for.</param>
            /// <returns type="boolean">Whether element has the class.</returns>
        }, 
        
        enable: function(element, className, enabled) {
            /// <summary>Adds or removes a class depending on the enabled argument.</summary>
            /// <param name="element" type="Node">DOM node to add or remove the class on.</param>
            /// <param name="className" type="string">Class name to add or remove.</param>
            /// <param name="enabled" type="boolean">Whether to add or remove the class (true adds,
            ///     false removes).</param>
        }, 
        
        toggle: function(element, className) {
            /// <summary>Removes a class if an element has it, and adds it the element doesn&apos;t have
            /// it.  Won&apos;t affect other classes on the node.</summary>
            /// <param name="element" type="Node">DOM node to toggle class on.</param>
            /// <param name="className" type="string">Class to toggle.</param>
            /// <returns type="boolean">True if class was added, false if it was removed
            ///     (in other words, whether element has the class after this function has
            ///     been called).</returns>
        }
        
    };

    var $x = window.goog.dom.classes;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.classes";
})(this);
