
/* vsdoc for goog.dom.dataset */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.dataset = {
        /// <summary></summary>
        /// <returns type="goog.dom.dataset"/>
                
        set: function(element, key, value) {
            /// <summary>Sets a custom data attribute on an element. The key should be
            /// in camelCase format (e.g &quot;keyName&quot; for the &quot;data-key-name&quot; attribute).</summary>
            /// <param name="element" type="Element">DOM node to set the custom data attribute on.</param>
            /// <param name="key" type="string">Key for the custom data attribute.</param>
            /// <param name="value" type="string">Value for the custom data attribute.</param>
        }, 
        
        get: function(element, key) {
            /// <summary>Gets a custom data attribute from an element. The key should be
            /// in camelCase format (e.g &quot;keyName&quot; for the &quot;data-key-name&quot; attribute).</summary>
            /// <param name="element" type="Element">DOM node to get the custom data attribute from.</param>
            /// <param name="key" type="string">Key for the custom data attribute.</param>
            /// <returns type="?string">The attribute value, if it exists.</returns>
        }, 
        
        remove: function(element, key) {
            /// <summary>Removes a custom data attribute from an element. The key should be
            /// in camelCase format (e.g &quot;keyName&quot; for the &quot;data-key-name&quot; attribute).</summary>
            /// <param name="element" type="Element">DOM node to get the custom data attribute from.</param>
            /// <param name="key" type="string">Key for the custom data attribute.</param>
        }, 
        
        has: function(element, key) {
            /// <summary>Checks whether custom data attribute exists on an element. The key should be
            /// in camelCase format (e.g &quot;keyName&quot; for the &quot;data-key-name&quot; attribute).</summary>
            /// <param name="element" type="Element">DOM node to get the custom data attribute from.</param>
            /// <param name="key" type="string">Key for the custom data attribute.</param>
            /// <returns type="boolean">Whether the attibute exists.</returns>
        }, 
        
        getAll: function(element) {
            /// <summary>Gets all custom data attributes as a string map.  The attribute names will be
            /// camel cased (e.g., data-foo-bar -> dataset[&apos;foobar&apos;]).  This operation is not
            /// safe for attributes having camel-cased names clashing with already existing
            /// properties (e.g., data-to-string -> dataset[&apos;toString&apos;]).</summary>
            /// <param name="element" type="!Element">DOM node to get the data attributes from.</param>
            /// <returns type="!Object">The string map containing data attributes and their
            ///     respective values.</returns>
        }
        
    };

    var $x = window.goog.dom.dataset;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.dataset";
})(this);
