
/* vsdoc for goog.dom.forms */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.forms = {
        /// <summary></summary>
        /// <returns type="goog.dom.forms"/>
                
        getFormDataMap: function(form) {
            /// <summary>Returns form data as a map of name to value arrays. This doesn&apos;t
            /// support file inputs.</summary>
            /// <param name="form" type="HTMLFormElement">The form.</param>
            /// <returns type="!goog.structs.Map">A map of the form data as form name to arrays of
            ///     values.</returns>
        }, 
        
        getFormDataString: function(form) {
            /// <summary>Returns the form data as an application/x-www-url-encoded string. This
            /// doesn&apos;t support file inputs.</summary>
            /// <param name="form" type="HTMLFormElement">The form.</param>
            /// <returns type="string">An application/x-www-url-encoded string.</returns>
        }, 
        
        hasFileInput: function(form) {
            /// <summary>Whether the form has a file input.</summary>
            /// <param name="form" type="HTMLFormElement">The form.</param>
            /// <returns type="boolean">Whether the form has a file input.</returns>
        }, 
        
        setDisabled: function(el, disabled) {
            /// <summary>Enables or disables either all elements in a form or a single form element.</summary>
            /// <param name="el" type="Element">The element, either a form or an element within a form.</param>
            /// <param name="disabled" type="boolean">Whether the element should be disabled.</param>
        }, 
        
        focusAndSelect: function(el) {
            /// <summary>Focuses, and optionally selects the content of, a form element.</summary>
            /// <param name="el" type="Element">The form element.</param>
        }, 
        
        hasValue: function(el) {
            /// <summary>Whether a form element has a value.</summary>
            /// <param name="el" type="Element">The element.</param>
            /// <returns type="boolean">Whether the form has a value.</returns>
        }, 
        
        hasValueByName: function(form, name) {
            /// <summary>Whether a named form field has a value.</summary>
            /// <param name="form" type="HTMLFormElement">The form element.</param>
            /// <param name="name" type="string">Name of an input to the form.</param>
            /// <returns type="boolean">Whether the form has a value.</returns>
        }, 
        
        getValue: function(el) {
            /// <summary>Gets the current value of any element with a type.</summary>
            /// <param name="el" type="Element">The element.</param>
            /// <returns type="string|Array.string|null">The current value of the element
            ///     (or null).</returns>
        }, 
        
        getValueByName: function(form, name) {
            /// <summary>Returns the value of the named form field. In the case of radio buttons,
            /// returns the value of the checked button with the given name.</summary>
            /// <param name="form" type="HTMLFormElement">The form element.</param>
            /// <param name="name" type="string">Name of an input to the form.</param>
            /// <returns type="Array.string|string|null">The value of the form element, or
            ///     null if the form element does not exist or has no value.</returns>
        }, 
        
        setValue: function(el, opt_value) {
            /// <summary>Sets the current value of any element with a type.</summary>
            /// <param name="el" type="Element">The element.</param>
            /// <param name="opt_value" type="*=">The value to give to the element, which will be coerced
            ///     by the browser in the default case using toString. This value should be
            ///     an array for setting the value of select multiple elements.</param>
        }
        
    };

    var $x = window.goog.dom.forms;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.forms";
})(this);
