
/* vsdoc for goog.dom.iframe */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.iframe = {
        /// <summary></summary>
        /// <field name="BLANK_SOURCE" type="string">Safe source for a blank iframe.
        /// 
        /// Intentionally not about:blank, which gives mixed content warnings in IE6
        /// over HTTPS.</field>
        /// <returns type="goog.dom.iframe"/>
                
        createBlank: function(domHelper, opt_styles) {
            /// <summary>Creates a completely blank iframe element.
            /// 
            /// The iframe will not caused mixed-content warnings for IE6 under HTTPS.
            /// The iframe will also have no borders or padding, so that the styled width
            /// and height will be the actual width and height of the iframe.
            /// 
            /// This function currently only attempts to create a blank iframe.  There
            /// are no guarantees to the contents of the iframe or whether it is rendered
            /// in quirks mode.</summary>
            /// <param name="domHelper" type="goog.dom.DomHelper">The dom helper to use.</param>
            /// <param name="opt_styles" type="string=">CSS styles for the iframe.</param>
            /// <returns type="!HTMLIFrameElement">A completely blank iframe.</returns>
        }, 
        
        writeContent: function(iframe, content) {
            /// <summary>Writes the contents of a blank iframe that has already been inserted
            /// into the document.</summary>
            /// <param name="iframe" type="!HTMLIFrameElement">An iframe with no contents, such as
            ///     one created by goog.dom.iframe.createBlank, but already appended to
            ///     a parent document.</param>
            /// <param name="content" type="string">Content to write to the iframe, from doctype to
            ///     the HTML close tag.</param>
        }, 
        
        createWithContent: function(parentElement, opt_headContents, opt_bodyContents, opt_styles, opt_quirks) {
            /// <summary>Creates a same-domain iframe containing preloaded content.
            /// 
            /// This is primarily useful for DOM sandboxing.  One use case is to embed
            /// a trusted Javascript app with potentially conflicting CSS styles.  The
            /// second case is to reduce the cost of layout passes by the browser -- for
            /// example, you can perform sandbox sizing of characters in an iframe while
            /// manipulating a heavy DOM in the main window.  The iframe and parent frame
            /// can access each others&apos; properties and functions without restriction.</summary>
            /// <param name="parentElement" type="!Element">The parent element in which to append the
            ///     iframe.</param>
            /// <param name="opt_headContents" type="string=">Contents to go into the iframe&apos;s head.</param>
            /// <param name="opt_bodyContents" type="string=">Contents to go into the iframe&apos;s body.</param>
            /// <param name="opt_styles" type="string=">CSS styles for the iframe itself, before adding
            ///     to the parent element.</param>
            /// <param name="opt_quirks" type="boolean=">Whether to use quirks mode (false by default).</param>
            /// <returns type="HTMLIFrameElement">An iframe that has the specified contents.</returns>
        }
        
    };

    var $x = window.goog.dom.iframe;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.iframe";
})(this);
