
/* vsdoc for goog.dom.selection */

(function (window) {
    window.goog.dom = window.goog.dom || {};

    window.goog.dom.selection = {
        /// <summary></summary>
        /// <returns type="goog.dom.selection"/>
                
        setStart: function(textfield, pos) {
            /// <summary>Sets the place where the selection should start inside a textarea or a text
            /// input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <param name="pos" type="number">The position to set the start of the selection at.</param>
        }, 
        
        getStart: function(textfield) {
            /// <summary>Return the place where the selection starts inside a textarea or a text
            /// input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <returns type="number">The position where the selection starts or 0 if it was
            ///     unable to find the position or no selection exists. Note that we can&apos;t
            ///     reliably tell the difference between an element that has no selection and
            ///     one where it starts at 0.</returns>
        }, 
        
        getEndPoints: function(textfield) {
            /// <summary>Returns the start and end points of the selection inside a textarea or a
            /// text input.</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <returns type="Array.number">An array with the start and end positions where the
            ///     selection starts and ends or [0,0] if it was unable to find the
            ///     positions or no selection exists. Note that we can&apos;t reliably tell the
            ///     difference between an element that has no selection and one where
            ///     it starts and ends at 0.</returns>
        }, 
        
        setEnd: function(textfield, pos) {
            /// <summary>Sets the place where the selection should end inside a text area or a text
            /// input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <param name="pos" type="number">The position to end the selection at.</param>
        }, 
        
        getEnd: function(textfield) {
            /// <summary>Returns the place where the selection ends inside a textarea or a text input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <returns type="number">The position where the selection ends or 0 if it was
            ///     unable to find the position or no selection exists.</returns>
        }, 
        
        setCursorPosition: function(textfield, pos) {
            /// <summary>Sets the cursor position within a textfield.</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <param name="pos" type="number">The position within the text field.</param>
        }, 
        
        setText: function(textfield, text) {
            /// <summary>Sets the selected text inside a textarea or a text input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <param name="text" type="string">The text to change the selection to.</param>
        }, 
        
        getText: function(textfield) {
            /// <summary>Returns the selected text inside a textarea or a text input</summary>
            /// <param name="textfield" type="Element">A textarea or text input.</param>
            /// <returns type="string">The selected text.</returns>
        }
        
    };

    var $x = window.goog.dom.selection;
    $x.__namespace = "true";
    $x.__typeName = "goog.dom.selection";
})(this);
