
/* vsdoc for goog.ds.DataManager */

(function (window) {
    window.goog.ds = window.goog.ds || {};

    window.goog.ds.DataManager = function(){
        /// <summary></summary>
        /// <field name="getLoadState" type="goog.ds.LoadState">Gets the state of the backing data for this node</field>
        /// <returns type="goog.ds.DataManager"/>
    };

    var $x = window.goog.ds.DataManager;
    $x.prototype = {
                
        getInstance: function() {
            /// <summary>Get the global instance</summary>
            /// <returns type="goog.ds.DataManager">The data manager singleton.</returns>
        }, 
        
        clearInstance: function() {
            /// <summary>Clears the global instance (for unit tests to reset state).</summary>
        }, 
        
        addDataSource: function(ds, opt_autoload, opt_name) {
            /// <summary>Add a data source</summary>
            /// <param name="ds" type="goog.ds.DataNode">The data source.</param>
            /// <param name="opt_autoload" type="boolean=">Whether to automatically load the data,
            ///   defaults to false.</param>
            /// <param name="opt_name" type="string=">Optional name, can also get name
            ///   from the datasource.</param>
        }, 
        
        aliasDataSource: function(name, dataPath) {
            /// <summary>Create an alias for a data path, very similar to assigning a variable.
            /// For example, you can set $CurrentContact -> $Request/Contacts[5], and all
            /// references to $CurrentContact will be procesed on $Request/Contacts[5].
            /// 
            /// Aliases will hide datasources of the same name.</summary>
            /// <param name="name" type="string">Alias name, must be a top level path ($Foo).</param>
            /// <param name="dataPath" type="string">Data path being aliased.</param>
        }, 
        
        getDataSource: function(name) {
            /// <summary>Gets a named child node of the current node.</summary>
            /// <param name="name" type="string">The node name.</param>
            /// <returns type="goog.ds.DataNode">The child node,
            ///   or null if no node of this name exists.</returns>
        }, 
        
        get: function() {
            /// <summary>Get the value of the node</summary>
            /// <returns type="Object">The value of the node, or null if no value.</returns>
        }, 
        
        set: function(value) {
            /// <summary></summary>
            /// <param name="value" type=""></param>
        }, 
        
        getChildNodes: function(opt_selector) {
            /// <summary></summary>
            /// <param name="opt_selector" type=""></param>
        }, 
        
        getChildNode: function(name) {
            /// <summary>Gets a named child node of the current node</summary>
            /// <param name="name" type="string">The node name.</param>
            /// <returns type="goog.ds.DataNode">The child node,
            ///     or null if no node of this name exists.</returns>
        }, 
        
        getChildNodeValue: function(name) {
            /// <summary></summary>
            /// <param name="name" type=""></param>
        }, 
        
        getDataName: function() {
            /// <summary>Get the name of the node relative to the parent node</summary>
            /// <returns type="string">The name of the node.</returns>
        }, 
        
        getDataPath: function() {
            /// <summary>Gets the a qualified data path to this node</summary>
            /// <returns type="string">The data path.</returns>
        }, 
        
        load: function() {
            /// <summary>Load or reload the backing data for this node
            /// only loads datasources flagged with autoload</summary>
        }, 
        
        isList: function() {
            /// <summary>Whether the value of this node is a homogeneous list of data</summary>
            /// <returns type="boolean">True if a list.</returns>
        }, 
        
        getEventCount: function() {
            /// <summary>Get the total count of events fired (mostly for debugging)</summary>
            /// <returns type="number">Count of events.</returns>
        }, 
        
        addListener: function(fn, dataPath, opt_id) {
            /// <summary>Adds a listener
            /// Listeners should fire when any data with path that has dataPath as substring
            /// is changed.
            /// TODO(user) Look into better listener handling</summary>
            /// <param name="fn" type="Function">Callback function, signature function(dataPath, id).</param>
            /// <param name="dataPath" type="string">Fully qualified data path.</param>
            /// <param name="opt_id" type="string=">A value passed back to the listener when the dataPath
            ///   is matched.</param>
        }, 
        
        addIndexedListener: function(fn, dataPath, opt_id) {
            /// <summary>Adds an indexed listener.
            /// 
            /// Indexed listeners allow for &apos;*&apos; in data paths. If a * exists, will match
            /// all values and return the matched values in an array to the callback.
            /// 
            /// Currently uses a promiscuous match algorithm: Matches everything before the
            /// first &apos;*&apos;, and then does a regex match for all of the returned events.
            /// Although this isn&apos;t optimized, it is still an improvement as you can collapse
            /// 100&apos;s of listeners into a single regex match</summary>
            /// <param name="fn" type="Function">Callback function, signature (dataPath, id, indexes).</param>
            /// <param name="dataPath" type="string">Fully qualified data path.</param>
            /// <param name="opt_id" type="string=">A value passed back to the listener when the dataPath
            ///   is matched.</param>
        }, 
        
        removeIndexedListeners: function(fn, opt_dataPath, opt_id) {
            /// <summary>Removes indexed listeners with a given callback function, and optional
            /// matching datapath and matching id.</summary>
            /// <param name="fn" type="Function">Callback function, signature function(dataPath, id).</param>
            /// <param name="opt_dataPath" type="string=">Fully qualified data path.</param>
            /// <param name="opt_id" type="string=">A value passed back to the listener when the dataPath
            ///   is matched.</param>
        }, 
        
        removeListeners: function(fn, opt_dataPath, opt_id) {
            /// <summary>Removes listeners with a given callback function, and optional
            /// matching dataPath and matching id</summary>
            /// <param name="fn" type="Function">Callback function, signature function(dataPath, id).</param>
            /// <param name="opt_dataPath" type="string=">Fully qualified data path.</param>
            /// <param name="opt_id" type="string=">A value passed back to the listener when the dataPath
            ///   is matched.</param>
        }, 
        
        getListenerCount: function() {
            /// <summary>Get the total number of listeners (per expression listened to, so may be
            /// more than number of times addListener() has been called</summary>
            /// <returns type="number">Number of listeners.</returns>
        }, 
        
        runWithoutFiringDataChanges: function(callback) {
            /// <summary>Disables the sending of all data events during the execution of the given
            /// callback. This provides a way to avoid useless notifications of small changes
            /// when you will eventually send a data event manually that encompasses them
            /// all.
            /// 
            /// Note that this function can not be called reentrantly.</summary>
            /// <param name="callback" type="Function">Zero-arg function to execute.</param>
        }, 
        
        fireDataChange: function(dataPath) {
            /// <summary>Fire a data change event to all listeners
            /// 
            /// If the path matches the path of a listener, the listener will fire
            /// 
            /// If your path is the parent of a listener, the listener will fire. I.e.
            /// if $Contacts/bob@bob.com changes, then we will fire listener for
            /// $Contacts/bob@bob.com/Name as well, as the assumption is that when
            /// a parent changes, all children are invalidated.
            /// 
            /// If your path is the child of a listener, the listener may fire, depending
            /// on the ancestor depth.
            /// 
            /// A listener for $Contacts might only be interested if the contact name changes
            /// (i.e. $Contacts doesn&apos;t fire on $Contacts/bob@bob.com/Name),
            /// while a listener for a specific contact might
            /// (i.e. $Contacts/bob@bob.com would fire on $Contacts/bob@bob.com/Name).
            /// Adding &quot;/...&quot; to a lisetener path listens to all children, and adding &quot;/*&quot; to
            /// a listener path listens only to direct children</summary>
            /// <param name="dataPath" type="string">Fully qualified data path.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ds.DataManager";
})(this);
