
/* vsdoc for goog.ds.Expr */

(function (window) {
    window.goog.ds = window.goog.ds || {};

    window.goog.ds.Expr = function(opt_expr){
        /// <summary></summary>
        /// <param name="opt_expr" type="string=">The string expression.</param>
        /// <field name="CURRENT" type="">The current node</field>
        /// <field name="ALL_CHILD_NODES" type="">For DOM interop - all DOM child nodes (text + element).
        /// Text nodes have dataName #text</field>
        /// <field name="ALL_ELEMENTS" type="">For DOM interop - all DOM element child nodes</field>
        /// <field name="ALL_ATTRIBUTES" type="">For DOM interop - all DOM attribute nodes
        /// Attribute nodes have dataName starting with &quot;@&quot;</field>
        /// <field name="NAME" type="">Get the dataName of a node</field>
        /// <field name="COUNT" type="">Get the count of nodes matching an expression</field>
        /// <field name="POSITION" type="">Get the position of the &quot;current&quot; node in the current node list
        /// This will only apply for datasources that support the concept of a current
        /// node (none exist yet). This is similar to XPath position() and concept of
        /// current node</field>
        /// <returns type="goog.ds.Expr"/>
    };

    var $x = window.goog.ds.Expr;
    $x.prototype = {
                
        getSource: function() {
            /// <summary>Get the source data path for the expression</summary>
            /// <returns type="string">The path.</returns>
        }, 
        
        getLast: function() {
            /// <summary>Gets the last part of the expression.</summary>
            /// <returns type="?string">Last part of the expression.</returns>
        }, 
        
        getParent: function() {
            /// <summary>Gets the parent expression of this expression, or null if this is top level</summary>
            /// <returns type="goog.ds.Expr">The parent.</returns>
        }, 
        
        getNext: function() {
            /// <summary>Gets the parent expression of this expression, or null if this is top level</summary>
            /// <returns type="goog.ds.Expr">The parent.</returns>
        }, 
        
        getValue: function(opt_ds) {
            /// <summary>Evaluate an expression on a data node, and return a value
            /// Recursively walks through child nodes to evaluate
            /// TODO(user) Support other expression functions</summary>
            /// <param name="opt_ds" type="goog.ds.DataNode=">Optional datasource to evaluate against.
            ///     If not provided, evaluates against DataManager global root.</param>
            /// <returns type="*">Value of the node, or null if doesn&apos;t exist.</returns>
        }, 
        
        getNodes: function(opt_ds, opt_canCreate) {
            /// <summary>Evaluate an expression on a data node, and return matching nodes
            /// Recursively walks through child nodes to evaluate</summary>
            /// <param name="opt_ds" type="goog.ds.DataNode=">Optional datasource to evaluate against.
            ///     If not provided, evaluates against data root.</param>
            /// <param name="opt_canCreate" type="boolean=">If true, will try to create new nodes.</param>
            /// <returns type="goog.ds.DataNodeList">Matching nodes.</returns>
        }, 
        
        getNode: function(opt_ds, opt_canCreate) {
            /// <summary>Evaluate an expression on a data node, and return the first matching node
            /// Recursively walks through child nodes to evaluate</summary>
            /// <param name="opt_ds" type="goog.ds.DataNode=">Optional datasource to evaluate against.
            ///     If not provided, evaluates against DataManager global root.</param>
            /// <param name="opt_canCreate" type="boolean=">If true, will try to create new nodes.</param>
            /// <returns type="goog.ds.DataNode">Matching nodes, or null if doesn&apos;t exist.</returns>
        }, 
        
        create: function(expr) {
            /// <summary>Create an expression from a string, can use cached values</summary>
            /// <param name="expr" type="string">The expression string.</param>
            /// <returns type="goog.ds.Expr">The expression object.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ds.Expr";
})(this);
