
/* vsdoc for goog.ds.FastDataNode */

(function (window) {
    window.goog.ds = window.goog.ds || {};

    window.goog.ds.FastDataNode = function(root, dataName, opt_parent){
        /// <summary></summary>
        /// <param name="root" type="Object">JSON-like object to initialize data node from.</param>
        /// <param name="dataName" type="string">Name of this data node.</param>
        /// <param name="opt_parent" type="goog.ds.DataNode=">Parent of this data node.</param>
        /// <returns type="goog.ds.FastDataNode"/>
    };

    var $x = window.goog.ds.FastDataNode;
    $x.prototype = {
                
        extendWith_: function(object) {
            /// <summary>Add all attributes of object to this data node.</summary>
            /// <param name="object" type="Object">Object to add attributes from.</param>
        }, 
        
        fromJs: function(object, dataName, opt_parent) {
            /// <summary>Creates a new FastDataNode structure initialized from object. This will
            /// return an instance of the most suitable sub-class of FastDataNode.
            /// 
            /// You should not modify object after creating a fast data node from it
            /// or assume that changing object changes the data node. Doing so results
            /// in undefined behaviour.</summary>
            /// <param name="object" type="Object|number|boolean|string">Object to initialize data
            ///     node from.</param>
            /// <param name="dataName" type="string">Name of data node.</param>
            /// <param name="opt_parent" type="goog.ds.DataNode=">Parent of data node.</param>
            /// <returns type="goog.ds.AbstractFastDataNode">Data node representing object.</returns>
        }, 
        
        set: function(value) {
            /// <summary>Not supported for normal FastDataNodes.</summary>
            /// <param name="value" type="*">Value to set data node to.</param>
        }, 
        
        getChildNodes: function(opt_selector) {
            /// <summary></summary>
            /// <param name="opt_selector" type=""></param>
        }, 
        
        getChildNode: function(name, opt_create) {
            /// <summary>Get a child node by name.</summary>
            /// <param name="name" type="string">Name of child node.</param>
            /// <param name="opt_create" type="boolean=">Whether to create the child if it does not
            /// exist.</param>
            /// <returns type="goog.ds.DataNode">Child node.</returns>
        }, 
        
        setChildNode: function(name, value) {
            /// <summary>Sets a child node. Creates the child if it does not exist.
            /// 
            /// Calling  this function makes any child nodes previously obtained for name
            /// invalid. You should not use these child nodes but instead obtain a new
            /// instance by calling getChildNode.</summary>
            /// <param name="name" type=""></param>
            /// <param name="value" type=""></param>
        }, 
        
        getChildNodeValue: function(name) {
            /// <summary>Returns the value of a child node. By using this method you can avoid
            /// the need to create PrimitiveFastData nodes.</summary>
            /// <param name="name" type="string">Name of child node.</param>
            /// <returns type="Object">Value of child node.</returns>
        }, 
        
        isList: function() {
            /// <summary>Returns whether this data node is a list. Always returns false for
            /// instances of FastDataNode but may return true for subclasses.</summary>
            /// <returns type="boolean">Whether this data node is array-like.</returns>
        }, 
        
        getJsObject: function() {
            /// <summary>Returns a javascript object representation of this data node. You should
            /// not modify the object returned by this function.</summary>
            /// <returns type="Object">Javascript object representation of this data node.</returns>
        }, 
        
        clone: function() {
            /// <summary>Creates a deep copy of this data node.</summary>
            /// <returns type="goog.ds.FastDataNode">Clone of this data node.</returns>
        }, 
        
        add: function(value) {
            /// <summary>Adds a child to this data node.</summary>
            /// <param name="value" type="goog.ds.DataNode">Child node to add.</param>
        }, 
        
        get: function(opt_key) {
            /// <summary>Gets the value of this data node (if called without opt_key) or
            /// gets a child node (if called with opt_key).</summary>
            /// <param name="opt_key" type="string=">Name of child node.</param>
            /// <returns type="*">This data node or a child node.</returns>
        }, 
        
        getByIndex: function(index) {
            /// <summary>Gets a child node by index. This method has a complexity of O(n) where
            /// n is the number of children. If you need a faster implementation of this
            /// method, you should use goog.ds.FastListNode.</summary>
            /// <param name="index" type="number">Index of child node (starting from 0).</param>
            /// <returns type="goog.ds.DataNode">Child node at specified index.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Gets the number of child nodes. This method has a complexity of O(n) where
            /// n is the number of children. If you need a faster implementation of this
            /// method, you should use goog.ds.FastListNode.</summary>
            /// <returns type="number">Number of child nodes.</returns>
        }, 
        
        setNode: function(name, value) {
            /// <summary>Sets a child node.</summary>
            /// <param name="name" type="string">Name of child node.</param>
            /// <param name="value" type="Object">Value of child node.</param>
        }, 
        
        removeNode: function(name) {
            /// <summary>Removes a child node.</summary>
            /// <param name="name" type=""></param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ds.FastDataNode";
})(this);
