
/* vsdoc for goog.ds.FastListNode */

(function (window) {
    window.goog.ds = window.goog.ds || {};

    window.goog.ds.FastListNode = function(values, dataName, opt_parent){
        /// <summary></summary>
        /// <param name="values" type="Array">values hold by this list node.</param>
        /// <param name="dataName" type="string">name of this node.</param>
        /// <param name="opt_parent" type="goog.ds.DataNode=">parent of this node.</param>
        /// <returns type="goog.ds.FastListNode"/>
    };

    var $x = window.goog.ds.FastListNode;
    $x.prototype = {
                
        set: function(value) {
            /// <summary>Not supported for FastListNodes.</summary>
            /// <param name="value" type="*">Value to set data node to.</param>
        }, 
        
        getChildNodes: function() {
            /// <summary>Returns child nodes of this data node. Currently, only supports
            /// returning all children.</summary>
            /// <returns type="goog.ds.DataNodeList">List of child nodes.</returns>
        }, 
        
        getChildNode: function(key, opt_create) {
            /// <summary>Get a child node by name.</summary>
            /// <param name="key" type="string">Name of child node.</param>
            /// <param name="opt_create" type="boolean=">Whether to create the child if it does not
            /// exist.</param>
            /// <returns type="goog.ds.DataNode">Child node.</returns>
        }, 
        
        getChildNodeValue: function(key) {
            /// <summary>Returns the value of a child node.</summary>
            /// <param name="key" type="string">Name of child node.</param>
            /// <returns type="*">Value of child node.</returns>
        }, 
        
        setChildNode: function(key, value) {
            /// <summary>Sets a child node. Creates the child if it does not exist. To set
            /// children at a certain index, use a key of the form &apos;[index]&apos;. Note, that
            /// you can only set values at existing numeric indices. To add a new node
            /// to this list, you have to use the add method.
            /// 
            /// Calling  this function makes any child nodes previously obtained for name
            /// invalid. You should not use these child nodes but instead obtain a new
            /// instance by calling getChildNode.</summary>
            /// <param name="key" type=""></param>
            /// <param name="value" type=""></param>
        }, 
        
        isList: function() {
            /// <summary>Returns whether this data node is a list. Always returns true.</summary>
            /// <returns type="boolean">Whether this data node is array-like.</returns>
        }, 
        
        getJsObject: function() {
            /// <summary>Returns a javascript object representation of this data node. You should
            /// not modify the object returned by this function.</summary>
            /// <returns type="Object">Javascript object representation of this data node.</returns>
        }, 
        
        add: function(value) {
            /// <summary>Adds a child to this data node</summary>
            /// <param name="value" type="goog.ds.DataNode">Child node to add.</param>
        }, 
        
        get: function(opt_key) {
            /// <summary>Gets the value of this data node (if called without opt_key) or
            /// gets a child node (if called with opt_key).</summary>
            /// <param name="opt_key" type="string=">Name of child node.</param>
            /// <returns type="Array|goog.ds.DataNode">Array of child nodes (if called without
            ///     opt_key), or a named child node otherwise.</returns>
        }, 
        
        getByIndex: function(index) {
            /// <summary>Gets a child node by (numeric) index.</summary>
            /// <param name="index" type="number">Index of child node (starting from 0).</param>
            /// <returns type="goog.ds.DataNode">Child node at specified index.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Gets the number of child nodes.</summary>
            /// <returns type="number">Number of child nodes.</returns>
        }, 
        
        setNode: function(name, value) {
            /// <summary>Sets a child node.</summary>
            /// <param name="name" type="string">Name of child node.</param>
            /// <param name="value" type="Object">Value of child node.</param>
        }, 
        
        removeNode: function(name) {
            /// <summary>Removes a child node.</summary>
            /// <param name="name" type=""></param>
        }, 
        
        indexOf: function(name) {
            /// <summary>Returns the index of a named child nodes. This method only works if
            /// this list uses mixed name/indexed lookup, i.e. if its child node have
            /// an &apos;id&apos; attribute.</summary>
            /// <param name="name" type="string">Name of child node to determine index of.</param>
            /// <returns type="number">Index of child node named name.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ds.FastListNode";
})(this);
