
/* vsdoc for goog.editor.Field */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.Field = function(id, opt_doc){
        /// <summary></summary>
        /// <param name="id" type="string">An identifer for the field. This is used to find the
        ///    field and the element associated with this field.</param>
        /// <param name="opt_doc" type="Document=">The document that the element with the given
        ///     id can be found in.  If not provided, the default document is used.</param>
        /// <field name="id" type="string">The id for this editable field, which must match the id of the element
        /// associated with this field.</field>
        /// <field name="editableDomHelper" type="goog.dom.DomHelper">Dom helper for the editable node.</field>
        /// <field name="cssStyles" type="string">Additional styles to install for the editable field.</field>
        /// <field name="eventRegister" type="goog.events.EventHandler"></field>
        /// <field name="originalDomHelper" type="!goog.dom.DomHelper"></field>
        /// <field name="field" type="TODO(user): Make this private!">The editable dom node.</field>
        /// <field name="originalElement" type="Element">The original node that is being made editable, or null if it has
        /// not yet been found.</field>
        /// <field name="logger" type="goog.debug.Logger">Logging object.</field>
        /// <field name="EventType" type="">Event types that can be stopped/started.</field>
        /// <field name="CHANGE_FREQUENCY" type="number">Number of milliseconds after a change when the change event should be fired.</field>
        /// <field name="DELAYED_CHANGE_FREQUENCY" type="number">Number of milliseconds between delayed change events.</field>
        /// <field name="usesIframe" type="boolean"></field>
        /// <field name="isFixedHeight" type="boolean"></field>
        /// <field name="shouldRefocusOnInputMobileSafari" type="boolean"></field>
        /// <field name="MUTATION_EVENTS_GECKO" type="Array.<string>">List of mutation events in Gecko browsers.</field>
        /// <returns type="goog.editor.Field"/>
    };

    var $x = window.goog.editor.Field;
    $x.prototype = {
                
        setActiveFieldId: function(fieldId) {
            /// <summary>Sets the active field id.</summary>
            /// <param name="fieldId" type="?string">The active field id.</param>
        }, 
        
        getActiveFieldId: function() {
            /// <summary></summary>
            /// <returns type="?string">The id of the active field.</returns>
        }, 
        
        setUseWindowMouseUp: function(flag) {
            /// <summary>Sets flag to control whether to use window mouse up after seeing
            /// a mouse down operation on the field.</summary>
            /// <param name="flag" type="boolean">True to track window mouse up.</param>
        }, 
        
        inModalMode: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether we&apos;re in modal interaction mode. When this
            ///     returns true, another plugin is interacting with the field contents
            ///     in a synchronous way, and expects you not to make changes to
            ///     the field&apos;s DOM structure or selection.</returns>
        }, 
        
        setModalMode: function(inModalMode) {
            /// <summary></summary>
            /// <param name="inModalMode" type="boolean">Sets whether we&apos;re in modal interaction mode.</param>
        }, 
        
        getHashCode: function() {
            /// <summary>Returns a string usable as a hash code for this field. For field&apos;s
            /// that were created with an id, the hash code is guaranteed to be the id.
            /// TODO(user): I think we can get rid of this.  Seems only used from editor.</summary>
            /// <returns type="string">The hash code for this editable field.</returns>
        }, 
        
        getElement: function() {
            /// <summary>Returns the editable DOM element or null if this field
            /// is not editable.
            /// &lt;p&gt;On IE or Safari this is the element with contentEditable=true
            /// (in whitebox mode, the iFrame body).
            /// &lt;p&gt;On Gecko this is the iFrame body
            /// TODO(user): How do we word this for subclass version?</summary>
            /// <returns type="Element">The editable DOM element, defined as above.</returns>
        }, 
        
        getOriginalElement: function() {
            /// <summary>Returns original DOM element that is being made editable by Trogedit or
            /// null if that element has not yet been found in the appropriate document.</summary>
            /// <returns type="Element">The original element.</returns>
        }, 
        
        addListener: function(type, listener, opt_capture, opt_handler) {
            /// <summary>Registers a keyboard event listener on the field.  This is necessary for
            /// Gecko since the fields are contained in an iFrame and there is no way to
            /// auto-propagate key events up to the main window.</summary>
            /// <param name="type" type="string|Array.string">Event type to listen for or array of
            ///    event types, for example goog.events.EventType.KEYDOWN.</param>
            /// <param name="listener" type="Function">Function to be used as the listener.</param>
            /// <param name="opt_capture" type="boolean=">Whether to use capture phase (optional,
            ///    defaults to false).</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
        }, 
        
        getPluginByClassId: function(classId) {
            /// <summary>Returns the registered plugin with the given classId.</summary>
            /// <param name="classId" type="string">classId of the plugin.</param>
            /// <returns type="goog.editor.Plugin">Registered plugin with the given classId.</returns>
        }, 
        
        registerPlugin: function(plugin) {
            /// <summary>Registers the plugin with the editable field.</summary>
            /// <param name="plugin" type="goog.editor.Plugin">The plugin to register.</param>
        }, 
        
        unregisterPlugin: function(plugin) {
            /// <summary>Unregisters the plugin with this field.</summary>
            /// <param name="plugin" type="goog.editor.Plugin">The plugin to unregister.</param>
        }, 
        
        setInitialStyle: function(cssText) {
            /// <summary>Sets the value that will replace the style attribute of this field&apos;s
            /// element when the field is made non-editable. This method is called with the
            /// current value of the style attribute when the field is made editable.</summary>
            /// <param name="cssText" type="string">The value of the style attribute.</param>
        }, 
        
        resetOriginalElemProperties: function() {
            /// <summary>Reset the properties on the original field element to how it was before
            /// it was made editable.</summary>
        }, 
        
        isModified: function(opt_useIsEverModified) {
            /// <summary>Checks the modified state of the field.
            /// Note: Changes that take place while the goog.editor.Field.EventType.CHANGE
            /// event is stopped do not effect the modified state.</summary>
            /// <param name="opt_useIsEverModified" type="boolean=">Set to true to check if the field
            ///   has ever been modified since it was created, otherwise checks if the field
            ///   has been modified since the last goog.editor.Field.EventType.DELAYEDCHANGE
            ///   event was dispatched.</param>
            /// <returns type="boolean">Whether the field has been modified.</returns>
        }, 
        
        setAppWindow: function(appWindow) {
            /// <summary>Sets the application window.</summary>
            /// <param name="appWindow" type="!Window">The window where dialogs and bubbles should be
            ///     rendered.</param>
        }, 
        
        getAppWindow: function() {
            /// <summary>Returns the &quot;application&quot; window, where dialogs and bubbles
            /// should be rendered.</summary>
            /// <returns type="!Window">The window.</returns>
        }, 
        
        setBaseZindex: function(zindex) {
            /// <summary>Sets the zIndex that the field should be based off of.
            /// TODO(user): Get rid of this completely.  Here for Sites.
            ///     Should this be set directly on UI plugins?</summary>
            /// <param name="zindex" type="number">The base zIndex of the editor.</param>
        }, 
        
        getBaseZindex: function() {
            /// <summary>Returns the zindex of the base level of the field.</summary>
            /// <returns type="number">The base zindex of the editor.</returns>
        }, 
        
        setupFieldObject: function(field) {
            /// <summary>Sets up the field object and window util of this field, and enables this
            /// editable field with all registered plugins.
            /// This is essential to the initialization of the field.
            /// It must be called when the field becomes fully loaded and editable.</summary>
            /// <param name="field" type="Element">The field property.</param>
        }, 
        
        clearListeners: function() {
            /// <summary>Stops all listeners and timers.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        attachWrapper: function(wrapper) {
            /// <summary>Attach an wrapper to this field, to be thrown out when the field
            /// is disposed.</summary>
            /// <param name="wrapper" type="goog.Disposable">The wrapper to attach.</param>
        }, 
        
        removeAllWrappers: function() {
            /// <summary>Removes all wrappers and destroys them.</summary>
        }, 
        
        setupMutationEventHandlersGecko: function() {
            /// <summary>Mutation events tell us when something has changed for mozilla.</summary>
        }, 
        
        injectContents: function(contents, field) {
            /// <summary>Prepare the given contents, then inject them into the editable field.</summary>
            /// <param name="contents" type="?string">The contents to prepare.</param>
            /// <param name="field" type="Element">The field element.</param>
        }, 
        
        getInjectableContents: function(contents, styles) {
            /// <summary>Returns prepared contents that can be injected into the editable field.</summary>
            /// <param name="contents" type="?string">The contents to prepare.</param>
            /// <param name="styles" type="Object">A map that will be populated with styles that should
            ///     be applied to the field element together with the contents.</param>
            /// <returns type="string">The prepared contents.</returns>
        }, 
        
        execCommand: function(command, var_args) {
            /// <summary>Executes an editing command as per the registered plugins.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="var_args" type="...*">Any additional parameters needed to execute the
            ///     command.</param>
            /// <returns type="*">False if the command wasn&apos;t handled, otherwise, the result of
            ///     the command.</returns>
        }, 
        
        queryCommandValue: function(commands) {
            /// <summary>Gets the value of command(s).</summary>
            /// <param name="commands" type="string|Array.string">String name(s) of the command.</param>
            /// <returns type="*">Value of each command. Returns false (or array of falses)
            ///     if designMode is off or the field is otherwise uneditable, and
            ///     there are no activeOnUneditable plugins for the command.</returns>
        }, 
        
        handleDomAttrChange: function(handler, browserEvent) {
            /// <summary>Fires a change event only if the attribute change effects the editiable
            /// field. We ignore events that are internal browser events (ie scrollbar
            /// state change)</summary>
            /// <param name="handler" type="Function">The function to call if this is not an internal
            ///     browser event.</param>
            /// <param name="browserEvent" type="goog.events.BrowserEvent">The browser event.</param>
        }, 
        
        getEditableIframe: function() {
            /// <summary></summary>
            /// <returns type="HTMLIFrameElement">The iframe that&apos;s body is editable.</returns>
        }, 
        
        getEditableDomHelper: function() {
            /// <summary></summary>
            /// <returns type="goog.dom.DomHelper?">The dom helper for the editable node.</returns>
        }, 
        
        getRange: function() {
            /// <summary></summary>
            /// <returns type="goog.dom.AbstractRange?">Closure range object wrapping the selection
            ///     in this field or null if this field is not currently editable.</returns>
        }, 
        
        dispatchSelectionChangeEvent: function(opt_e, opt_target) {
            /// <summary>Dispatch a selection change event, optionally caused by the given browser
            /// event or selecting the given target.</summary>
            /// <param name="opt_e" type="goog.events.BrowserEvent=">Optional browser event causing this
            ///     event.</param>
            /// <param name="opt_target" type="Node=">The node the selection changed to.</param>
        }, 
        
        dispatchBeforeChange: function() {
            /// <summary>This dispatches the beforechange event on the editable field</summary>
        }, 
        
        stopChangeEvents: function(opt_stopChange, opt_stopDelayedChange) {
            /// <summary>Temporarily ignore change events. If the time has already been set, it will
            /// fire immediately now.  Further setting of the timer is stopped and
            /// dispatching of events is stopped until startChangeEvents is called.</summary>
            /// <param name="opt_stopChange" type="boolean=">Whether to ignore base change events.</param>
            /// <param name="opt_stopDelayedChange" type="boolean=">Whether to ignore delayed change
            ///     events.</param>
        }, 
        
        startChangeEvents: function(opt_fireChange, opt_fireDelayedChange) {
            /// <summary>Start change events again and fire once if desired.</summary>
            /// <param name="opt_fireChange" type="boolean=">Whether to fire the change event
            ///      immediately.</param>
            /// <param name="opt_fireDelayedChange" type="boolean=">Whether to fire the delayed change
            ///      event immediately.</param>
        }, 
        
        stopEvent: function(eventType) {
            /// <summary>Stops the event of the given type from being dispatched.</summary>
            /// <param name="eventType" type="goog.editor.Field.EventType">type of event to stop.</param>
        }, 
        
        startEvent: function(eventType) {
            /// <summary>Re-starts the event of the given type being dispatched, if it had
            /// previously been stopped with stopEvent().</summary>
            /// <param name="eventType" type="goog.editor.Field.EventType">type of event to start.</param>
        }, 
        
        debounceEvent: function(eventType) {
            /// <summary>Block an event for a short amount of time. Intended
            /// for the situation where an event pair fires in quick succession
            /// (e.g., mousedown/mouseup, keydown/keyup, focus/blur),
            /// and we want the second event in the pair to get &quot;debounced.&quot;
            /// 
            /// WARNING: This should never be used to solve race conditions or for
            /// mission-critical actions. It should only be used for UI improvements,
            /// where it&apos;s okay if the behavior is non-deterministic.</summary>
            /// <param name="eventType" type="goog.editor.Field.EventType">type of event to debounce.</param>
        }, 
        
        isEventStopped: function(eventType) {
            /// <summary>Checks if the event of the given type has stopped being dispatched</summary>
            /// <param name="eventType" type="goog.editor.Field.EventType">type of event to check.</param>
            /// <returns type="boolean">true if the event has been stopped with stopEvent().</returns>
        }, 
        
        manipulateDom: function(func, opt_preventDelayedChange, opt_handler) {
            /// <summary>Calls a function to manipulate the dom of this field. This method should be
            /// used whenever Trogedit clients need to modify the dom of the field, so that
            /// delayed change events are handled appropriately. Extra delayed change events
            /// will cause undesired states to be added to the undo-redo stack. This method
            /// will always fire at most one delayed change event, depending on the value of
            /// {@code opt_preventDelayedChange}.</summary>
            /// <param name="func" type="function()">The function to call that will manipulate the dom.</param>
            /// <param name="opt_preventDelayedChange" type="boolean=">Whether delayed change should be
            ///      prevented after calling {@code func}. Defaults to always firing
            ///      delayed change.</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
        }, 
        
        dispatchCommandValueChange: function(opt_commands) {
            /// <summary>Dispatches a command value change event.</summary>
            /// <param name="opt_commands" type="Array.string=">Commands whose state has
            ///     changed.</param>
        }, 
        
        dispatchChange: function(opt_noDelay) {
            /// <summary>Dispatches the appropriate set of change events. This only fires
            /// synchronous change events in blended-mode, iframe-using mozilla. It just
            /// starts the appropriate timer for goog.editor.Field.EventType.DELAYEDCHANGE.
            /// This also starts up change events again if they were stopped.</summary>
            /// <param name="opt_noDelay" type="boolean=">True if
            ///      goog.editor.Field.EventType.DELAYEDCHANGE should be fired syncronously.</param>
        }, 
        
        handleChange: function() {
            /// <summary>Handle a change in the Editable Field.  Marks the field has modified,
            /// dispatches the change event on the editable field (moz only), starts the
            /// timer for the delayed change event.  Note that these actions only occur if
            /// the proper events are not stopped.</summary>
        }, 
        
        clearDelayedChange: function() {
            /// <summary>Don&apos;t wait for the timer and just fire the delayed change event if it&apos;s
            /// pending.</summary>
        }, 
        
        dispatchBlur: function() {
            /// <summary>Dispatches a blur event.</summary>
        }, 
        
        isSelectionEditable: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the selection is editable.</returns>
        }, 
        
        getCleanContents: function() {
            /// <summary>Retrieve the HTML contents of a field.
            /// 
            /// Do NOT just get the innerHTML of a field directly--there&apos;s a lot of
            /// processing that needs to happen.</summary>
            /// <returns type="string">The scrubbed contents of the field.</returns>
        }, 
        
        getFieldCopy: function() {
            /// <summary>Get the copy of the editable field element, which has the innerHTML set
            /// correctly.</summary>
            /// <returns type="Element">The copy of the editable field.</returns>
        }, 
        
        setHtml: function(addParas, html, opt_dontFireDelayedChange, opt_applyLorem) {
            /// <summary>Sets the contents of the field.</summary>
            /// <param name="addParas" type="boolean">Boolean to specify whether to add paragraphs
            ///    to long fields.</param>
            /// <param name="html" type="?string">html to insert.  If html=null, then this defaults
            ///    to a nsbp for mozilla and an empty string for IE.</param>
            /// <param name="opt_dontFireDelayedChange" type="boolean=">True to make this content change
            ///    not fire a delayed change event.</param>
            /// <param name="opt_applyLorem" type="boolean=">Whether to apply lorem ipsum styles.</param>
        }, 
        
        turnOnDesignModeGecko: function() {
            /// <summary>Attemps to turn on designMode for a document.  This function can fail under
            /// certain circumstances related to the load event, and will throw an exception.</summary>
        }, 
        
        installStyles: function() {
            /// <summary>Installs styles if needed. Only writes styles when they can&apos;t be written
            /// inline directly into the field.</summary>
        }, 
        
        isUneditable: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the field is uneditable.</returns>
        }, 
        
        isLoaded: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the field has finished loading.</returns>
        }, 
        
        isLoading: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the field is in the process of loading.</returns>
        }, 
        
        focus: function() {
            /// <summary>Gives the field focus.</summary>
        }, 
        
        focusAndPlaceCursorAtStart: function() {
            /// <summary>Gives the field focus and places the cursor at the start of the field.</summary>
        }, 
        
        placeCursorAtStart: function() {
            /// <summary>Place the cursor at the start of this field. It&apos;s recommended that you only
            /// use this method (and manipulate the selection in general) when there is not
            /// an existing selection in the field.</summary>
        }, 
        
        placeCursorAtEnd: function() {
            /// <summary>Place the cursor at the start of this field. It&apos;s recommended that you only
            /// use this method (and manipulate the selection in general) when there is not
            /// an existing selection in the field.</summary>
        }, 
        
        makeEditable: function(opt_iframeSrc) {
            /// <summary>Makes a field editable.</summary>
            /// <param name="opt_iframeSrc" type="string=">URL to set the iframe src to if necessary.</param>
        }, 
        
        makeEditableInternal: function(opt_iframeSrc) {
            /// <summary>Handles actually making something editable - creating necessary nodes,
            /// injecting content, etc.</summary>
            /// <param name="opt_iframeSrc" type="string=">URL to set the iframe src to if necessary.</param>
        }, 
        
        handleFieldLoad: function() {
            /// <summary>Handle the loading of the field (e.g. once the field is ready to setup).
            /// TODO(user): this should probably just be moved into dispatchLoadEvent_.</summary>
        }, 
        
        makeUneditable: function(opt_skipRestore) {
            /// <summary>Closes the field and cancels all pending change timers.  Note that this
            /// means that if a change event has not fired yet, it will not fire.  Clients
            /// should check fieldOj.isModified() if they depend on the final change event.
            /// Throws an error if the field is already uneditable.</summary>
            /// <param name="opt_skipRestore" type="boolean=">True to prevent copying of editable field
            ///     contents back into the original node.</param>
        }, 
        
        restoreDom: function() {
            /// <summary>Restores the dom to how it was before being made editable.</summary>
        }, 
        
        shouldLoadAsynchronously: function() {
            /// <summary>Returns true if the field needs to be loaded asynchrnously.</summary>
            /// <returns type="boolean">True if loads are async.</returns>
        }, 
        
        attachIframe: function(iframe) {
            /// <summary>Given the original field element, and the iframe that is destined to
            /// become the editable field, styles them appropriately and add the iframe
            /// to the dom.</summary>
            /// <param name="iframe" type="HTMLIFrameElement">The iframe element.</param>
        }, 
        
        getFieldFormatInfo: function(extraStyles) {
            /// <summary></summary>
            /// <param name="extraStyles" type="Object">A map of extra styles.</param>
            /// <returns type="goog.editor.icontent.FieldFormatInfo">The FieldFormatInfo object for
            ///     this field&apos;s configuration.</returns>
        }, 
        
        writeIframeContent: function(iframe, innerHtml, extraStyles) {
            /// <summary>Writes the html content into the iframe.  Handles writing any aditional
            /// styling as well.</summary>
            /// <param name="iframe" type="HTMLIFrameElement">Iframe to write contents into.</param>
            /// <param name="innerHtml" type="string">The html content to write into the iframe.</param>
            /// <param name="extraStyles" type="Object">A map of extra style attributes.</param>
        }, 
        
        iframeFieldLoadHandler: function(iframe, innerHtml, styles) {
            /// <summary>The function to call when the editable iframe loads.</summary>
            /// <param name="iframe" type="HTMLIFrameElement">Iframe that just loaded.</param>
            /// <param name="innerHtml" type="string">Html to put inside the body of the iframe.</param>
            /// <param name="styles" type="Object">Property-value map of CSS styles to install on
            ///     editable field.</param>
        }, 
        
        getIframeAttributes: function() {
            /// <summary></summary>
            /// <returns type="Object">Get the HTML attributes for this field&apos;s iframe.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.Field";
})(this);
