
/* vsdoc for goog.editor.Link */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.Link = function(anchor, isNew){
        /// <summary></summary>
        /// <param name="anchor" type="HTMLAnchorElement">The anchor element.</param>
        /// <param name="isNew" type="boolean">Whether this is a new link.</param>
        /// <returns type="goog.editor.Link"/>
    };

    var $x = window.goog.editor.Link;
    $x.prototype = {
                
        getAnchor: function() {
            /// <summary></summary>
            /// <returns type="HTMLAnchorElement">The anchor element.</returns>
        }, 
        
        getExtraAnchors: function() {
            /// <summary></summary>
            /// <returns type="!Array.HTMLAnchorElement">The extra anchor elements, if any,
            ///     created by the browser from a selection.</returns>
        }, 
        
        getCurrentText: function() {
            /// <summary></summary>
            /// <returns type="string">The inner text for the anchor.</returns>
        }, 
        
        isNew: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the link is new.</returns>
        }, 
        
        initializeUrl: function(url) {
            /// <summary>Set the url without affecting the isNew() status of the link.</summary>
            /// <param name="url" type="string">A URL.</param>
        }, 
        
        removeLink: function() {
            /// <summary>Removes the link, leaving its contents in the document.  Note that this
            /// object will no longer be usable/useful after this call.</summary>
        }, 
        
        setTextAndUrl: function(newText, newUrl) {
            /// <summary>Change the link.</summary>
            /// <param name="newText" type="string">New text for the link. If the link contains all its
            ///     text in one descendent, newText will only replace the text in that
            ///     one node. Otherwise, we&apos;ll change the innerHTML of the whole
            ///     link to newText.</param>
            /// <param name="newUrl" type="string">A new URL.</param>
        }, 
        
        placeCursorRightOf: function() {
            /// <summary>Places the cursor to the right of the anchor.
            /// Note that this is different from goog.editor.range&apos;s placeCursorNextTo
            /// in that it specifically handles the placement of a cursor in browsers
            /// that trap you in links, by adding a space when necessary and placing the
            /// cursor after that space.</summary>
        }, 
        
        getValidLinkFromText: function() {
            /// <summary></summary>
            /// <returns type="string?">The modified string for the link if the link
            ///     text appears to be a valid link. Returns null if this is not
            ///     a valid link address.</returns>
        }, 
        
        finishLinkCreation: function(field) {
            /// <summary>After link creation, finish creating the link depending on the type
            /// of link being created.</summary>
            /// <param name="field" type="goog.editor.Field">The field where this link is being created.</param>
        }, 
        
        createNewLink: function(anchor, url, opt_target, opt_extraAnchors) {
            /// <summary>Initialize a new link.</summary>
            /// <param name="anchor" type="HTMLAnchorElement">The anchor element.</param>
            /// <param name="url" type="string">The initial URL.</param>
            /// <param name="opt_target" type="string=">The target.</param>
            /// <param name="opt_extraAnchors" type="Array.HTMLAnchorElement=">Extra anchors created
            ///     by the browser when parsing a selection.</param>
            /// <returns type="goog.editor.Link">The link.</returns>
        }, 
        
        isLikelyUrl: function(str) {
            /// <summary>Returns true if str could be a URL, false otherwise
            /// 
            /// Ex: TR_Util.isLikelyUrl_(&quot;http://www.google.com&quot;) == true
            ///     TR_Util.isLikelyUrl_(&quot;www.google.com&quot;) == true</summary>
            /// <param name="str" type="string">String to check if it looks like a URL.</param>
            /// <returns type="boolean">Whether str could be a URL.</returns>
        }, 
        
        isLikelyEmailAddress: function(str) {
            /// <summary>Returns true if str could be an email address, false otherwise
            /// 
            /// Ex: goog.editor.Link.isLikelyEmailAddress_(&quot;some word&quot;) == false
            ///     goog.editor.Link.isLikelyEmailAddress_(&quot;foo@foo.com&quot;) == true</summary>
            /// <param name="str" type="string">String to test for being email address.</param>
            /// <returns type="boolean">Whether &quot;str&quot; looks like an email address.</returns>
        }, 
        
        isMailto: function(url) {
            /// <summary>Determines whether or not a url is an email link.</summary>
            /// <param name="url" type="string">A url.</param>
            /// <returns type="boolean">Whether the url is a mailto link.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.Link";
})(this);
