
/* vsdoc for goog.editor.Plugin */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.Plugin = function(){
        /// <summary></summary>
        /// <field name="fieldObject" type="goog.editor.Field">The field object this plugin is attached to.</field>
        /// <field name="logger" type="goog.debug.Logger">The logger for this plugin.</field>
        /// <field name="activeOnUneditableFields" type="boolean"></field>
        /// <field name="isSilentCommand" type="boolean"></field>
        /// <field name="Op" type="">An enum of operations that plugins may support.</field>
        /// <field name="OPCODE" type="">A map from plugin operations to the names of the methods that
        /// invoke those operations.</field>
        /// <field name="IRREPRESSIBLE_OPS" type="">A set of op codes that run even on disabled plugins.</field>
        /// <returns type="goog.editor.Plugin"/>
    };

    var $x = window.goog.editor.Plugin;
    $x.prototype = {
                
        getFieldDomHelper: function() {
            /// <summary></summary>
            /// <returns type="goog.dom.DomHelper?">The dom helper object associated with the
            ///     currently active field.</returns>
        }, 
        
        getFieldObject: function() {
            /// <summary>Sets the field object for use with this plugin.</summary>
            /// <returns type="goog.editor.Field">The editable field object.</returns>
        }, 
        
        setFieldObject: function(fieldObject) {
            /// <summary>Sets the field object for use with this plugin.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The editable field object.</param>
        }, 
        
        registerFieldObject: function(fieldObject) {
            /// <summary>Registers the field object for use with this plugin.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The editable field object.</param>
        }, 
        
        unregisterFieldObject: function(fieldObj) {
            /// <summary>Unregisters and disables this plugin for the current field object.</summary>
            /// <param name="fieldObj" type="goog.editor.Field">The field object. For single-field
            ///     plugins, this parameter is ignored.</param>
        }, 
        
        enable: function(fieldObject) {
            /// <summary>Enables this plugin for the specified, registered field object. A field
            /// object should only be enabled when it is loaded.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The field object.</param>
        }, 
        
        disable: function(fieldObject) {
            /// <summary>Disables this plugin for the specified, registered field object.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The field object.</param>
        }, 
        
        isEnabled: function(fieldObject) {
            /// <summary>Returns whether this plugin is enabled for the field object.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The field object.</param>
            /// <returns type="boolean">Whether this plugin is enabled for the field object.</returns>
        }, 
        
        setAutoDispose: function(autoDispose) {
            /// <summary>Set if this plugin should automatically be disposed when the registered
            /// field is disposed.</summary>
            /// <param name="autoDispose" type="boolean">Whether to autoDispose.</param>
        }, 
        
        isAutoDispose: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether or not this plugin should automatically be disposed
            ///     when it&apos;s registered field is disposed.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        execCommand: function(command, var_args) {
            /// <summary>Handles execCommand. This default implementation handles dispatching
            /// BEFORECHANGE, CHANGE, and SELECTIONCHANGE events, and calls
            /// execCommandInternal to perform the actual command. Plugins that want to
            /// do their own event dispatching should override execCommand, otherwise
            /// it is preferred to only override execCommandInternal.
            /// 
            /// This version of execCommand will only work for single field plugins.
            /// Multi-field plugins must override execCommand.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="var_args" type="...*">Any additional parameters needed to
            ///     execute the command.</param>
            /// <returns type="*">The result of the execCommand, if any.</returns>
        }, 
        
        isSupportedCommand: function(command) {
            /// <summary>Whether the string corresponds to a command this plugin handles.</summary>
            /// <param name="command" type="string">Command string to check.</param>
            /// <returns type="boolean">Whether the plugin handles this type of command.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.Plugin";
})(this);
