
/* vsdoc for goog.editor.Table */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.Table = function(node){
        /// <summary></summary>
        /// <param name="node" type="Element">Element that is a table or descendant of a table.</param>
        /// <field name="OPTIMUM_EMPTY_CELL_WIDTH" type="number">Optimum size of empty cells (in pixels), if possible.</field>
        /// <field name="OPTIMUM_MAX_NEW_TABLE_WIDTH" type="number">Maximum width for new tables.</field>
        /// <field name="DEFAULT_BORDER_COLOR" type="string">Default color for table borders.</field>
        /// <returns type="goog.editor.Table"/>
    };

    var $x = window.goog.editor.Table;
    $x.prototype = {
                
        refresh: function() {
            /// <summary>Walks the dom structure of this object&apos;s table element and populates
            /// this.rows with goog.editor.TableRow objects. This is done initially
            /// to populate the internal data structures, and also after each time the
            /// DOM structure is modified. Currently this means that the all existing
            /// information is discarded and re-read from the DOM.</summary>
        }, 
        
        getChildCellElements: function(tr) {
            /// <summary>Returns all child elements of a TR element that are of type TD or TH.</summary>
            /// <param name="tr" type="Element">TR element in which to find children.</param>
            /// <returns type="Array.Element">array of child cell elements.</returns>
        }, 
        
        insertRow: function(opt_rowIndex) {
            /// <summary>Inserts a new row in the table. The row will be populated with new
            /// cells, and existing rowspanned cells that overlap the new row will
            /// be extended.</summary>
            /// <param name="opt_rowIndex" type="number=">Index at which to insert the row. If
            ///     this is omitted the row will be appended to the end of the table.</param>
            /// <returns type="Element">The new row.</returns>
        }, 
        
        insertColumn: function(opt_colIndex) {
            /// <summary>Inserts a new column in the table. The column will be created by
            /// inserting new TD elements in each row, or extending the colspan
            /// of existing TD elements.</summary>
            /// <param name="opt_colIndex" type="number=">Index at which to insert the column. If
            ///     this is omitted the column will be appended to the right side of
            ///     the table.</param>
            /// <returns type="Array.Element">Array of new cell elements that were created
            ///     to populate the new column.</returns>
        }, 
        
        removeRow: function(rowIndex) {
            /// <summary>Removes a row from the table, removing the TR element and
            /// decrementing the rowspan of any cells in other rows that overlap the row.</summary>
            /// <param name="rowIndex" type="number">Index of the row to delete.</param>
        }, 
        
        removeColumn: function(colIndex) {
            /// <summary>Removes a column from the table. This is done by removing cell elements,
            /// or shrinking the colspan of elements that span multiple columns.</summary>
            /// <param name="colIndex" type="number">Index of the column to delete.</param>
        }, 
        
        mergeCells: function(startRowIndex, startColIndex, endRowIndex, endColIndex) {
            /// <summary>Merges multiple cells into a single cell, and sets the rowSpan and colSpan
            /// attributes of the cell to take up the same space as the original cells.</summary>
            /// <param name="startRowIndex" type="number">Top coordinate of the cells to merge.</param>
            /// <param name="startColIndex" type="number">Left coordinate of the cells to merge.</param>
            /// <param name="endRowIndex" type="number">Bottom coordinate of the cells to merge.</param>
            /// <param name="endColIndex" type="number">Right coordinate of the cells to merge.</param>
            /// <returns type="boolean">Whether or not the merge was possible. If the cells
            ///     in the supplied coordinates can&apos;t be merged this will return false.</returns>
        }, 
        
        splitCell: function(rowIndex, colIndex) {
            /// <summary>Splits a cell with colspans or rowspans into multiple descrete cells.</summary>
            /// <param name="rowIndex" type="number">y coordinate of the cell to split.</param>
            /// <param name="colIndex" type="number">x coordinate of the cell to split.</param>
            /// <returns type="Array.Element">Array of new cell elements created by splitting
            ///     the cell.</returns>
        }, 
        
        insertCellElement: function(td, rowIndex, colIndex) {
            /// <summary>Inserts a cell element at the given position. The colIndex is the logical
            /// column index, not the position in the dom. This takes into consideration
            /// that cells in a given logical  row may actually be children of a previous
            /// DOM row that have used rowSpan to extend into the row.</summary>
            /// <param name="td" type="Element">The new cell element to insert.</param>
            /// <param name="rowIndex" type="number">Row in which to insert the element.</param>
            /// <param name="colIndex" type="number">Column in which to insert the element.</param>
        }, 
        
        createEmptyTd: function() {
            /// <summary>Creates an empty TD element and fill it with some empty content so it will
            /// show up with borders even in IE pre-7 or if empty-cells is set to &apos;hide&apos;</summary>
            /// <returns type="Element">a new TD element.</returns>
        }, 
        
        createDomTable: function(doc, columns, rows, opt_tableStyle) {
            /// <summary>Creates a new table element, populated with cells and formatted.</summary>
            /// <param name="doc" type="Document">Document in which to create the table element.</param>
            /// <param name="columns" type="number">Number of columns in the table.</param>
            /// <param name="rows" type="number">Number of rows in the table.</param>
            /// <param name="opt_tableStyle" type="Object=">Object containing borderWidth and borderColor
            ///    properties, used to set the inital style of the table.</param>
            /// <returns type="Element">a table element.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.Table";
})(this);
