
/* vsdoc for goog.editor.node */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.node = {
        /// <summary></summary>
        /// <returns type="goog.editor.node"/>
                
        isStandardsMode: function(node) {
            /// <summary>Check if the node is in a standards mode document.</summary>
            /// <param name="node" type="Node">The node to test.</param>
            /// <returns type="boolean">Whether the node is in a standards mode document.</returns>
        }, 
        
        getRightMostLeaf: function(parent) {
            /// <summary>Get the right-most non-ignorable leaf node of the given node.</summary>
            /// <param name="parent" type="Node">The parent ndoe.</param>
            /// <returns type="Node">The right-most non-ignorable leaf node.</returns>
        }, 
        
        getLeftMostLeaf: function(parent) {
            /// <summary>Get the left-most non-ignorable leaf node of the given node.</summary>
            /// <param name="parent" type="Node">The parent ndoe.</param>
            /// <returns type="Node">The left-most non-ignorable leaf node.</returns>
        }, 
        
        getFirstChild: function(parent) {
            /// <summary>Version of firstChild that skips nodes that are entirely
            /// whitespace and comments.</summary>
            /// <param name="parent" type="Node">The reference node.</param>
            /// <returns type="Node">The first child of sibling that is important according to
            ///     goog.editor.node.isImportant, or null if no such node exists.</returns>
        }, 
        
        getLastChild: function(parent) {
            /// <summary>Version of lastChild that skips nodes that are entirely whitespace or
            /// comments.  (Normally lastChild is a property of all DOM nodes that gives the
            /// last of the nodes contained directly in the reference node.)</summary>
            /// <param name="parent" type="Node">The reference node.</param>
            /// <returns type="Node">The last child of sibling that is important according to
            ///     goog.editor.node.isImportant, or null if no such node exists.</returns>
        }, 
        
        getPreviousSibling: function(sibling) {
            /// <summary>Version of previoussibling that skips nodes that are entirely
            /// whitespace or comments.  (Normally previousSibling is a property
            /// of all DOM nodes that gives the sibling node, the node that is
            /// a child of the same parent, that occurs immediately before the
            /// reference node.)</summary>
            /// <param name="sibling" type="Node">The reference node.</param>
            /// <returns type="Node">The closest previous sibling to sibling that is
            ///     important according to goog.editor.node.isImportant, or null if no such
            ///     node exists.</returns>
        }, 
        
        getNextSibling: function(sibling) {
            /// <summary>Version of nextSibling that skips nodes that are entirely whitespace or
            /// comments.</summary>
            /// <param name="sibling" type="Node">The reference node.</param>
            /// <returns type="Node">The closest next sibling to sibling that is important
            ///     according to goog.editor.node.isImportant, or null if no
            ///     such node exists.</returns>
        }, 
        
        isImportant: function(node) {
            /// <summary>Determine if a node should be returned by the iterator functions.</summary>
            /// <param name="node" type="Node">An object implementing the DOM1 Node interface.</param>
            /// <returns type="boolean">Whether the node is an element, or a text node that
            ///     is not all whitespace.</returns>
        }, 
        
        isAllNonNbspWhiteSpace: function(textNode) {
            /// <summary>Determine whether a node&apos;s text content is entirely whitespace.</summary>
            /// <param name="textNode" type="Node">A node implementing the CharacterData interface (i.e.,
            ///     a Text, Comment, or CDATASection node.</param>
            /// <returns type="boolean">Whether the text content of node is whitespace,
            ///     otherwise false.</returns>
        }, 
        
        isEmpty: function(node, opt_prohibitSingleNbsp) {
            /// <summary>Returns true if the node contains only whitespace and is not and does not
            /// contain any images, iframes or embed tags.</summary>
            /// <param name="node" type="Node">The node to check.</param>
            /// <param name="opt_prohibitSingleNbsp" type="boolean=">By default, this function treats a
            ///     single nbsp as empty.  Set this to true to treat this case as non-empty.</param>
            /// <returns type="boolean">Whether the node contains only whitespace.</returns>
        }, 
        
        getLength: function(node) {
            /// <summary>Returns the length of the text in node if it is a text node, or the number
            /// of children of the node, if it is an element. Useful for range-manipulation
            /// code where you need to know the offset for the right side of the node.</summary>
            /// <param name="node" type="Node">The node to get the length of.</param>
            /// <returns type="number">The length of the node.</returns>
        }, 
        
        findInChildren: function(parent, hasProperty) {
            /// <summary>Search child nodes using a predicate function and return the first node that
            /// satisfies the condition.</summary>
            /// <param name="parent" type="Node">The parent node to search.</param>
            /// <param name="hasProperty" type="function(Node):boolean">A function that takes a child
            ///    node as a parameter and returns true if it meets the criteria.</param>
            /// <returns type="?number">The index of the node found, or null if no node is found.</returns>
        }, 
        
        findHighestMatchingAncestor: function(node, hasProperty) {
            /// <summary>Search ancestor nodes using a predicate function and returns the topmost
            /// ancestor in the chain of consecutive ancestors that satisfies the condition.</summary>
            /// <param name="node" type="Node">The node whose ancestors have to be searched.</param>
            /// <param name="hasProperty" type="function(Node): boolean">A function that takes a parent
            ///     node as a parameter and returns true if it meets the criteria.</param>
            /// <returns type="Node">The topmost ancestor or null if no ancestor satisfies the
            ///     predicate function.</returns>
        }, 
        
        isBlockTag: function(node) {
            /// <summary>Checks if node is a block-level html element. The &lt;tt&gt;display&lt;/tt&gt; css
            /// property is ignored.</summary>
            /// <param name="node" type="Node">The node to test.</param>
            /// <returns type="boolean">Whether the node is a block-level node.</returns>
        }, 
        
        skipEmptyTextNodes: function(node) {
            /// <summary>Skips siblings of a node that are empty text nodes.</summary>
            /// <param name="node" type="Node">A node. May be null.</param>
            /// <returns type="Node">The node or the first sibling of the node that is not an
            ///     empty text node. May be null.</returns>
        }, 
        
        isEditableContainer: function(element) {
            /// <summary>Checks if an element is a top-level editable container (meaning that
            /// it itself is not editable, but all its child nodes are editable).</summary>
            /// <param name="element" type="Node">The element to test.</param>
            /// <returns type="boolean">Whether the element is a top-level editable container.</returns>
        }, 
        
        isEditable: function(node) {
            /// <summary>Checks if a node is inside an editable container.</summary>
            /// <param name="node" type="Node">The node to test.</param>
            /// <returns type="boolean">Whether the node is in an editable container.</returns>
        }, 
        
        findTopMostEditableAncestor: function(node, criteria) {
            /// <summary>Finds the top-most DOM node inside an editable field that is an ancestor
            /// (or self) of a given DOM node and meets the specified criteria.</summary>
            /// <param name="node" type="Node">The DOM node where the search starts.</param>
            /// <param name="criteria" type="function(Node) : boolean">A function that takes a DOM node
            ///     as a parameter and returns a boolean to indicate whether the node meets
            ///     the criteria or not.</param>
            /// <returns type="Node">The DOM node if found, or null.</returns>
        }, 
        
        splitDomTreeAt: function(currentNode, opt_secondHalf, opt_root) {
            /// <summary>Splits off a subtree.</summary>
            /// <param name="currentNode" type="!Node">The starting splitting point.</param>
            /// <param name="opt_secondHalf" type="Node=">The initial leftmost leaf the new subtree.
            ///     If null, siblings after currentNode will be placed in the subtree, but
            ///     no additional node will be.</param>
            /// <param name="opt_root" type="Node=">The top of the tree where splitting stops at.</param>
            /// <returns type="!Node">The new subtree.</returns>
        }, 
        
        transferChildren: function(newNode, oldNode) {
            /// <summary>Appends all of oldNode&apos;s children to newNode. This removes all children from
            /// oldNode and appends them to newNode. oldNode is left with no children.</summary>
            /// <param name="newNode" type="!Node">Node to transfer children to.</param>
            /// <param name="oldNode" type="Node">Node to transfer children from.</param>
        }
        
    };

    var $x = window.goog.editor.node;
    $x.__namespace = "true";
    $x.__typeName = "goog.editor.node";
})(this);
