
/* vsdoc for goog.editor.plugins.AbstractBubblePlugin */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.AbstractBubblePlugin = function(){
        /// <summary></summary>
        /// <field name="eventRegister" type="goog.events.EventHandler">Place to register events the plugin listens to.</field>
        /// <field name="DASH_NBSP_STRING" type="string">The constant string used to separate option links.</field>
        /// <field name="getTrogClassId" type=""></field>
        /// <field name="createBubbleContents" type="">Should be overriden by subclasses to add the type specific contents to the
        ///     bubble.</field>
        /// <field name="onShow" type="">Called after the bubble is shown. The default implementation does nothing.
        /// Override it to provide your own one.</field>
        /// <returns type="goog.editor.plugins.AbstractBubblePlugin"/>
    };

    var $x = window.goog.editor.plugins.AbstractBubblePlugin;
    $x.prototype = {
                
        setBubbleFactory: function(bubbleFactory) {
            /// <summary>Sets the bubble factory function.</summary>
            /// <param name="bubbleFactory" type="function(!Element|number): !goog.ui.editor.Bubble">Function that creates a bubble for the given bubble parent
            ///     element and z index.</param>
        }, 
        
        enableKeyboardNavigation: function(keyboardNavigationEnabled) {
            /// <summary>Sets whether the bubble should support tabbing through the link elements.</summary>
            /// <param name="keyboardNavigationEnabled" type="boolean">Whether the bubble should support
            ///     tabbing through the link elements.</param>
        }, 
        
        setBubbleParent: function(bubbleParent) {
            /// <summary>Sets the bubble parent.</summary>
            /// <param name="bubbleParent" type="Element">An element where the bubble will be
            ///     anchored. If null, we will use the application document. This
            ///     is useful when you have an editor embedded in a scrolling div.</param>
        }, 
        
        getBubbleDom: function() {
            /// <summary></summary>
            /// <returns type="goog.dom.DomHelper">The dom helper for the bubble window.</returns>
        }, 
        
        getTargetElement: function() {
            /// <summary>Returns the element whose properties the bubble manipulates.</summary>
            /// <returns type="Element">The target element.</returns>
        }, 
        
        handleKeyUp: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        handleSelectionChange: function(opt_e, opt_target) {
            /// <summary>Pops up a property bubble for the given selection if appropriate and closes
            /// open property bubbles if no longer needed.  This should not be overridden.</summary>
            /// <param name="opt_e" type=""></param>
            /// <param name="opt_target" type=""></param>
        }, 
        
        disable: function(field) {
            /// <summary></summary>
            /// <param name="field" type=""></param>
        }, 
        
        createBubble: function(targetElement) {
            /// <summary>Creates and shows the property bubble.</summary>
            /// <param name="targetElement" type="Element">The target element of the bubble.</param>
        }, 
        
        getBubbleType: function() {
            /// <summary></summary>
            /// <returns type="string">The type of bubble shown by this plugin.  Usually the tag
            ///     name of the element this bubble targets.</returns>
        }, 
        
        getBubbleTitle: function() {
            /// <summary></summary>
            /// <returns type="string">The title for bubble shown by this plugin.  Defaults to no
            ///     title.  Should be overridden by subclasses.</returns>
        }, 
        
        registerClickHandler: function(target, handler) {
            /// <summary>Register the handler for the target&apos;s CLICK event.</summary>
            /// <param name="target" type="Element">The event source element.</param>
            /// <param name="handler" type="Function">The event handler.</param>
        }, 
        
        registerActionHandler: function(target, handler) {
            /// <summary>Register the handler for the target&apos;s CLICK and ENTER key events.</summary>
            /// <param name="target" type="Element">The event source element.</param>
            /// <param name="handler" type="Function">The event handler.</param>
        }, 
        
        closeBubble: function() {
            /// <summary>Closes the bubble.</summary>
        }, 
        
        handleKeyDown: function(e) {
            /// <summary>In case the keyboard navigation is enabled, this will focus to the first link
            /// element in the bubble when TAB is clicked. The user could still go through
            /// the rest of tabbable UI elements using shift + TAB.</summary>
            /// <param name="e" type=""></param>
        }, 
        
        isVisible: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the bubble is visible.</returns>
        }, 
        
        reposition: function() {
            /// <summary>Reposition the property bubble.</summary>
        }, 
        
        createLinkOption: function(id) {
            /// <summary>Helper method that creates option links (such as edit, test, remove)</summary>
            /// <param name="id" type="string">String id for the span id.</param>
            /// <returns type="Element">The option link element.</returns>
        }, 
        
        createLink: function(linkId, linkText, opt_onClick, opt_container) {
            /// <summary>Helper method that creates a link with text set to linkText and optionaly
            /// wires up a listener for the CLICK event or the link.</summary>
            /// <param name="linkId" type="string">The id of the link.</param>
            /// <param name="linkText" type="string">Text of the link.</param>
            /// <param name="opt_onClick" type="Function=">Optional function to call when the link is
            ///     clicked.</param>
            /// <param name="opt_container" type="Element=">If specified, location to insert link. If no
            ///     container is specified, the old link is removed and replaced.</param>
            /// <returns type="Element">The link element.</returns>
        }, 
        
        createLinkHelper: function(linkId, linkText, isAnchor, opt_container) {
            /// <summary>Helper method to create a link to insert into the bubble.</summary>
            /// <param name="linkId" type="string">The id of the link.</param>
            /// <param name="linkText" type="string">Text of the link.</param>
            /// <param name="isAnchor" type="boolean">Set to true to create an actual anchor tag
            ///     instead of a span.  Actual links are right clickable (e.g. to open in
            ///     a new window) and also update window status on hover.</param>
            /// <param name="opt_container" type="Element=">If specified, location to insert link. If no
            ///     container is specified, the old link is removed and replaced.</param>
            /// <returns type="Element">The link element.</returns>
        }, 
        
        setupLink: function(link, linkId, opt_container) {
            /// <summary>Inserts a link in the given container if it is specified or removes
            /// the old link with this id and replaces it with the new link</summary>
            /// <param name="link" type="Element">Html element to insert.</param>
            /// <param name="linkId" type="string">Id of the link.</param>
            /// <param name="opt_container" type="Element=">If specified, location to insert link.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.AbstractBubblePlugin";
})(this);
