
/* vsdoc for goog.editor.plugins.AbstractDialogPlugin */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.AbstractDialogPlugin = function(command){
        /// <summary></summary>
        /// <param name="command" type="string">The command that this plugin handles.</param>
        /// <field name="EventType" type="">Event type constants for events the dialog plugins fire.</field>
        /// <field name="createDialog" type="goog.ui.editor.AbstractDialog">Creates a new instance of this plugin&apos;s dialog. Must be overridden by
        /// subclasses.</field>
        /// <returns type="goog.editor.plugins.AbstractDialogPlugin"/>
    };

    var $x = window.goog.editor.plugins.AbstractDialogPlugin;
    $x.prototype = {
                
        isSupportedCommand: function(command) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
        }, 
        
        execCommand: function(command, var_args) {
            /// <summary>Handles execCommand. Dialog plugins don&apos;t make any changes when they open a
            /// dialog, just when the dialog closes (because only modal dialogs are
            /// supported). Hence this method does not dispatch the change events that the
            /// superclass method does.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="var_args" type="...*">Any additional parameters needed to
            ///     execute the command.</param>
            /// <returns type="*">The result of the execCommand, if any.</returns>
        }, 
        
        getDialog: function() {
            /// <summary>Returns the current dialog that was created and opened by this plugin.</summary>
            /// <returns type="goog.ui.editor.AbstractDialog">The current dialog that was created
            ///     and opened by this plugin.</returns>
        }, 
        
        setReuseDialog: function(reuse) {
            /// <summary>Sets whether this plugin should reuse the same instance of the dialog each
            /// time execCommand is called or create a new one. This is intended for use by
            /// subclasses only, hence protected.</summary>
            /// <param name="reuse" type="boolean">Whether to reuse the dialog.</param>
        }, 
        
        execCommandInternal: function(command, opt_arg) {
            /// <summary>Handles execCommand by opening the dialog. Dispatches
            /// {@link goog.editor.plugins.AbstractDialogPlugin.EventType.OPENED} after the
            /// dialog is shown.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="opt_arg" type="*=">The dialog specific argument. Should be the same as
            ///     {@link createDialog}.</param>
            /// <returns type="*">Always returns true, indicating the dialog was shown.</returns>
        }, 
        
        handleAfterHide: function(e) {
            /// <summary>Cleans up after the dialog has closed, including restoring the selection to
            /// what it was before the dialog was opened. If a subclass modifies the editable
            /// field&apos;s content such that the original selection is no longer valid (usually
            /// the case when the user clicks OK, and sometimes also on Cancel), it is that
            /// subclass&apos; responsibility to place the selection in the desired place during
            /// the OK or Cancel (or other) handler. In that case, this method will leave the
            /// selection in place.</summary>
            /// <param name="e" type="goog.events.Event">The AFTER_HIDE event object.</param>
        }, 
        
        restoreOriginalSelection: function() {
            /// <summary>Restores the selection in the editable field to what it was before the dialog
            /// was opened. This is not guaranteed to work if the contents of the field
            /// have changed.</summary>
        }, 
        
        disposeOriginalSelection: function() {
            /// <summary>Cleans up the structure used to save the original selection before the dialog
            /// was opened. Should be used by subclasses that don&apos;t restore the original
            /// selection via restoreOriginalSelection.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.AbstractDialogPlugin";
})(this);
