
/* vsdoc for goog.editor.plugins.Blockquote */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.Blockquote = function(requiresClassNameToSplit, opt_className){
        /// <summary></summary>
        /// <param name="requiresClassNameToSplit" type="boolean">Whether to split only blockquotes
        ///     that have the given classname.</param>
        /// <param name="opt_className" type="string=">The classname to apply to generated
        ///     blockquotes.  Defaults to &apos;tr_bq&apos;.</param>
        /// <field name="SPLIT_COMMAND" type="string">Command implemented by this plugin.</field>
        /// <field name="CLASS_ID" type="string">Class ID used to identify this plugin.</field>
        /// <field name="logger" type="goog.debug.Logger">Logging object.</field>
        /// <field name="isSilentCommand" type="">Since our exec command is always called from elsewhere, we make it silent.</field>
        /// <returns type="goog.editor.plugins.Blockquote"/>
    };

    var $x = window.goog.editor.plugins.Blockquote;
    $x.prototype = {
                
        getTrogClassId: function() {
            /// <summary></summary>
        }, 
        
        isBlockquote: function(node, isAlreadySetup, requiresClassNameToSplit, className) {
            /// <summary>Checks if a node is a blockquote node.  If isAlreadySetup is set, it also
            /// makes sure the node has the blockquote classname applied.  Otherwise, it
            /// ensures that the blockquote does not already have the classname applied.</summary>
            /// <param name="node" type="Node">DOM node to check.</param>
            /// <param name="isAlreadySetup" type="boolean">True to enforce that the classname must be
            ///                  set in order for it to count as a blockquote, false to
            ///                  enforce that the classname must not be set in order for
            ///                  it to count as a blockquote.</param>
            /// <param name="requiresClassNameToSplit" type="boolean">Whether only blockquotes with the
            ///     class name should be split.</param>
            /// <param name="className" type="string">The official blockquote class name.</param>
            /// <returns type="boolean">Whether node is a blockquote and if isAlreadySetup is
            ///    true, then whether this is a setup blockquote.</returns>
        }, 
        
        isSplittableBlockquote: function(node) {
            /// <summary>Checks if a node is a blockquote which can be split. A splittable blockquote
            /// meets the following criteria:
            /// &lt;ol&gt;
            ///   &lt;li&gt;Node is a blockquote element&lt;/li&gt;
            ///   &lt;li&gt;Node has the blockquote classname if the classname is required to
            ///       split&lt;/li&gt;
            /// &lt;/ol&gt;</summary>
            /// <param name="node" type="Node">DOM node in question.</param>
            /// <returns type="boolean">Whether the node is a splittable blockquote.</returns>
        }, 
        
        isSetupBlockquote: function(node) {
            /// <summary>Checks if a node is a blockquote element which has been setup.</summary>
            /// <param name="node" type="Node">DOM node to check.</param>
            /// <returns type="boolean">Whether the node is a blockquote with the required class
            ///     name applied.</returns>
        }, 
        
        isUnsetupBlockquote: function(node) {
            /// <summary>Checks if a node is a blockquote element which has not been setup yet.</summary>
            /// <param name="node" type="Node">DOM node to check.</param>
            /// <returns type="boolean">Whether the node is a blockquote without the required
            ///     class name applied.</returns>
        }, 
        
        getBlockquoteClassName: function() {
            /// <summary>Gets the class name required for setup blockquotes.</summary>
            /// <returns type="string">The blockquote class name.</returns>
        }, 
        
        isSupportedCommand: function(command) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
        }, 
        
        execCommandInternal: function(command, var_args) {
            /// <summary>Splits a quoted region if any.  To be called on a key press event.  When this
            /// function returns true, the event that caused it to be called should be
            /// canceled.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="var_args" type="...*">Single additional argument representing the
            ///     current cursor position.  In IE, it is a single node.  In any other
            ///     browser, it is an object with a {@code node} key and an {@code offset}
            ///     key.</param>
            /// <returns type="boolean|undefined">Boolean true when the quoted region has been
            ///     split, false or undefined otherwise.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.Blockquote";
})(this);
