
/* vsdoc for goog.editor.plugins.EnterHandler */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.EnterHandler = function(){
        /// <summary></summary>
        /// <field name="tag" type="goog.dom.TagName">The type of block level tag to add on enter, for browsers that support
        /// specifying the default block-level tag. Can be overriden by subclasses; must
        /// be either DIV or P.</field>
        /// <field name="getNonCollapsingBlankHtml" type="string">Gets HTML with no contents that won&apos;t collapse, for browsers that
        /// collapse the empty string.</field>
        /// <field name="handleEnterWebkitInternal" type="">Handle an enter key press in WebKit.</field>
        /// <field name="handleEnterAtCursorGeckoInternal" type="">Handle an enter key press on collapsed selection.  handleEnterGecko_ ensures
        /// the selection is collapsed by deleting its contents if it is not.  The
        /// default implementation does nothing.</field>
        /// <returns type="goog.editor.plugins.EnterHandler"/>
    };

    var $x = window.goog.editor.plugins.EnterHandler;
    $x.prototype = {
                
        getTrogClassId: function() {
            /// <summary></summary>
        }, 
        
        enable: function(fieldObject) {
            /// <summary></summary>
            /// <param name="fieldObject" type=""></param>
        }, 
        
        prepareContentsHtml: function(html) {
            /// <summary>If the contents are empty, return the &apos;default&apos; html for the field.
            /// The &apos;default&apos; contents depend on the enter handling mode, so it
            /// makes the most sense in this plugin.</summary>
            /// <param name="html" type="string">The html to prepare.</param>
            /// <returns type="string">The original HTML, or default contents if that
            ///    html is empty.</returns>
        }, 
        
        handleBackspaceInternal: function(e, range) {
            /// <summary>Internal backspace handler.</summary>
            /// <param name="e" type="goog.events.Event">The keypress event.</param>
            /// <param name="range" type="goog.dom.AbstractRange">The closure range object.</param>
        }, 
        
        processParagraphTagsInternal: function(e, split) {
            /// <summary>Fix paragraphs to be the correct type of node.</summary>
            /// <param name="e" type="goog.events.Event">The &lt;enter&gt; key event.</param>
            /// <param name="split" type="boolean">Whether we already split up a blockquote by
            ///     manually inserting elements.</param>
        }, 
        
        isDirectlyInBlockquote: function(n) {
            /// <summary>Determines whether the lowest containing block node is a blockquote.</summary>
            /// <param name="n" type="Node">The node.</param>
            /// <returns type="boolean">Whether the deepest block ancestor of n is a blockquote.</returns>
        }, 
        
        handleDeleteGecko: function(e) {
            /// <summary>Internal delete key handler.</summary>
            /// <param name="e" type="goog.events.Event">The keypress event.</param>
        }, 
        
        "delete": function(e) {
            /// <summary>Deletes the element at the cursor if it is a BR node, and if it does, calls
            /// e.preventDefault to stop the browser from deleting. Only necessary in Gecko
            /// as a workaround for mozilla bug 205350 where deleting a BR that is followed
            /// by a block element doesn&apos;t work (the BR gets immediately replaced). We also
            /// need to account for an ill-formed cursor which occurs from us trying to
            /// stop the browser from deleting.</summary>
            /// <param name="e" type="goog.events.Event">The DELETE keypress event.</param>
        }, 
        
        handleKeyPress: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        handleKeyUp: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        handleKeyUpInternal: function(e) {
            /// <summary>Internal handler for keyup events.</summary>
            /// <param name="e" type="goog.events.Event">The key event.</param>
        }, 
        
        isBrElem: function(node) {
            /// <summary>Whether this is a node that contains a single BR tag and non-nbsp
            /// whitespace.</summary>
            /// <param name="node" type="Node">Node to check.</param>
            /// <returns type="boolean">Whether this is an element that only contains a BR.</returns>
        }, 
        
        ensureBlockIeOpera: function(tag, opt_keyUp) {
            /// <summary>Ensures all text in IE and Opera to be in the given tag in order to control
            /// Enter spacing. Call this when Enter is pressed if desired.
            /// 
            /// We want to make sure the user is always inside of a block (or other nodes
            /// listed in goog.editor.plugins.EnterHandler.IGNORE_ENSURE_BLOCK_NODES_).  We
            /// listen to keypress to force nodes that the user is leaving to turn into
            /// blocks, but we also need to listen to keyup to force nodes that the user is
            /// entering to turn into blocks.
            /// Example:  html is: &quot;&lt;h2&gt;foo[cursor]&lt;/h2&gt;&quot;, and the user hits enter.  We
            /// don&apos;t want to format the h2, but we do want to format the P that is
            /// created on enter.  The P node is not available until keyup.</summary>
            /// <param name="tag" type="goog.dom.TagName">The tag name to convert to.</param>
            /// <param name="opt_keyUp" type="boolean=">Whether the function is being called on key up.
            ///     When called on key up, the cursor is in the newly created node, so the
            ///     semantics for when to change it to a block are different.  Specifically,
            ///     if the resulting node contains only a BR, it is converted to &lt;tag&gt;.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.EnterHandler";
})(this);
