
/* vsdoc for goog.editor.plugins.LinkBubble */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.LinkBubble = function(var_args){
        /// <summary></summary>
        /// <param name="var_args" type="...!goog.editor.plugins.LinkBubble.Action">List of
        ///     extra actions supported by the bubble.</param>
        /// <field name="isInvalidUrl" type="boolean">Returns whether the URL should be considered invalid.  This always returns
        /// false in the base class, and should be overridden by subclasses that wish
        /// to impose validity rules on URLs.</field>
        /// <returns type="goog.editor.plugins.LinkBubble"/>
    };

    var $x = window.goog.editor.plugins.LinkBubble;
    $x.prototype = {
                
        stopReferrerLeaks: function() {
            /// <summary>Tells the plugin to stop leaking the page&apos;s url via the referrer header when
            /// the link text link is clicked. When the user clicks on a link, the
            /// browser makes a request for the link url, passing the url of the current page
            /// in the request headers. If the user wants the current url to be kept secret
            /// (e.g. an unpublished document), the owner of the url that was clicked will
            /// see the secret url in the request headers, and it will no longer be a secret.
            /// Calling this method will not send a referrer header in the request, just as
            /// if the user had opened a blank window and typed the url in themselves.</summary>
        }, 
        
        setBlockOpeningUnsafeSchemes: function(blockOpeningUnsafeSchemes) {
            /// <summary>Tells the plugin whether to block URLs with schemes not in the whitelist.
            /// If blocking is enabled, this plugin will not linkify the link in the bubble
            /// popup.</summary>
            /// <param name="blockOpeningUnsafeSchemes" type="boolean">Whether to block non-whitelisted
            ///     schemes.</param>
        }, 
        
        setSafeToOpenSchemes: function(schemes) {
            /// <summary>Sets a whitelist of allowed URL schemes that are safe to open.
            /// Schemes should all be in lowercase. If the plugin is set to block opening
            /// unsafe schemes, user-entered URLs will be converted to lowercase and checked
            /// against this list. The whitelist has no effect if blocking is not enabled.</summary>
            /// <param name="schemes" type="Array.String">String array of URL schemes to allow (http,
            ///     https, etc.).</param>
        }, 
        
        getTrogClassId: function() {
            /// <summary></summary>
        }, 
        
        isSupportedCommand: function(command) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
        }, 
        
        execCommandInternal: function(command, var_args) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
            /// <param name="var_args" type=""></param>
        }, 
        
        getBubbleTargetFromSelection: function(selectedElement) {
            /// <summary></summary>
            /// <param name="selectedElement" type=""></param>
        }, 
        
        setTestLinkUrlFn: function(func) {
            /// <summary>Set the optional function for getting the &quot;test&quot; link of a url.</summary>
            /// <param name="func" type="function(string) : string">The function to use.</param>
        }, 
        
        getTargetUrl: function() {
            /// <summary>Returns the target element url for the bubble.</summary>
            /// <returns type="string">The url href.</returns>
        }, 
        
        getBubbleType: function() {
            /// <summary></summary>
        }, 
        
        getBubbleTitle: function() {
            /// <summary></summary>
        }, 
        
        createBubbleContents: function(bubbleContainer) {
            /// <summary></summary>
            /// <param name="bubbleContainer" type=""></param>
        }, 
        
        testLink: function() {
            /// <summary>Tests the link by opening it in a new tab/window. Should be used as the
            /// click event handler for the test pseudo-link.</summary>
        }, 
        
        onShow: function() {
            /// <summary>Sets the proper state for the action links.</summary>
        }, 
        
        shouldOpenUrl: function(url) {
            /// <summary>Checks whether the plugin should open the given url in a new window.</summary>
            /// <param name="url" type="string">The url to check.</param>
            /// <returns type="boolean">If the plugin should open the given url in a new window.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.LinkBubble";
})(this);
