
/* vsdoc for goog.editor.plugins.LinkDialogPlugin */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.LinkDialogPlugin = function(){
        /// <summary></summary>
        /// <field name="getTrogClassId" type=""></field>
        /// <returns type="goog.editor.plugins.LinkDialogPlugin"/>
    };

    var $x = window.goog.editor.plugins.LinkDialogPlugin;
    $x.prototype = {
                
        setBlockOpeningUnsafeSchemes: function(blockOpeningUnsafeSchemes) {
            /// <summary>Tells the plugin whether to block URLs with schemes not in the whitelist.
            /// If blocking is enabled, this plugin will stop the &apos;Test Link&apos; popup
            /// window from being created. Blocking doesn&apos;t affect link creation--if the
            /// user clicks the &apos;OK&apos; button with an unsafe URL, the link will still be
            /// created as normal.</summary>
            /// <param name="blockOpeningUnsafeSchemes" type="boolean">Whether to block non-whitelisted
            ///     schemes.</param>
        }, 
        
        setSafeToOpenSchemes: function(schemes) {
            /// <summary>Sets a whitelist of allowed URL schemes that are safe to open.
            /// Schemes should all be in lowercase. If the plugin is set to block opening
            /// unsafe schemes, user-entered URLs will be converted to lowercase and checked
            /// against this list. The whitelist has no effect if blocking is not enabled.</summary>
            /// <param name="schemes" type="Array.String">String array of URL schemes to allow (http,
            ///     https, etc.).</param>
        }, 
        
        showOpenLinkInNewWindow: function(startChecked) {
            /// <summary>Tells the dialog to show a checkbox where the user can choose to have the
            /// link open in a new window.</summary>
            /// <param name="startChecked" type="boolean">Whether to check the checkbox the first
            ///     time the dialog is shown. Subesquent times the checkbox will remember its
            ///     previous state.</param>
        }, 
        
        showRelNoFollow: function() {
            /// <summary>Tells the dialog to show a checkbox where the user can choose to have
            /// &apos;rel=nofollow&apos; attribute added to the link.</summary>
        }, 
        
        stopReferrerLeaks: function() {
            /// <summary>Tells the plugin to stop leaking the page&apos;s url via the referrer header when
            /// the &quot;test this link&quot; link is clicked. When the user clicks on a link, the
            /// browser makes a request for the link url, passing the url of the current page
            /// in the request headers. If the user wants the current url to be kept secret
            /// (e.g. an unpublished document), the owner of the url that was clicked will
            /// see the secret url in the request headers, and it will no longer be a secret.
            /// Calling this method will not send a referrer header in the request, just as
            /// if the user had opened a blank window and typed the url in themselves.</summary>
        }, 
        
        setEmailWarning: function(emailWarning) {
            /// <summary>Sets the warning message to show to users about including email addresses on
            /// public web pages.</summary>
            /// <param name="emailWarning" type="string">Warning message to show users about including
            ///     email addresses on the web.</param>
        }, 
        
        execCommandInternal: function(command, opt_arg) {
            /// <summary>Handles execCommand by opening the dialog.</summary>
            /// <param name="command" type="string">The command to execute.</param>
            /// <param name="opt_arg" type="*=">{@link A goog.editor.Link} object representing the link
            ///     being edited.</param>
            /// <returns type="*">Always returns true, indicating the dialog was shown.</returns>
        }, 
        
        handleAfterHide: function(e) {
            /// <summary>Handles when the dialog closes.</summary>
            /// <param name="e" type="goog.events.Event">The AFTER_HIDE event object.</param>
        }, 
        
        getEventHandler: function() {
            /// <summary></summary>
            /// <returns type="goog.events.EventHandler">The event handler.</returns>
        }, 
        
        getCurrentLink: function() {
            /// <summary></summary>
            /// <returns type="goog.editor.Link">The link being edited.</returns>
        }, 
        
        createDialog: function(dialogDomHelper, opt_link) {
            /// <summary>Creates a new instance of the dialog and registers for the relevant events.</summary>
            /// <param name="dialogDomHelper" type="goog.dom.DomHelper">The dom helper to be used to
            ///     create the dialog.</param>
            /// <param name="opt_link" type="*=">The target link (should be a goog.editor.Link).</param>
            /// <returns type="goog.ui.editor.LinkDialog">The dialog.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        handleOk: function(e) {
            /// <summary>Handles the OK event from the dialog by updating the link in the field.</summary>
            /// <param name="e" type="goog.ui.editor.LinkDialog.OkEvent">OK event object.</param>
        }, 
        
        handleBeforeTestLink: function(e) {
            /// <summary>Handles the BeforeTestLink event fired when the &apos;test&apos; link is clicked.</summary>
            /// <param name="e" type="goog.ui.editor.LinkDialog.BeforeTestLinkEvent">BeforeTestLink event
            ///     object.</param>
        }, 
        
        shouldOpenUrl: function(url) {
            /// <summary>Checks whether the plugin should open the given url in a new window.</summary>
            /// <param name="url" type="string">The url to check.</param>
            /// <returns type="boolean">If the plugin should open the given url in a new window.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.LinkDialogPlugin";
})(this);
