
/* vsdoc for goog.editor.plugins.UndoRedo */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.UndoRedo = function(opt_manager){
        /// <summary></summary>
        /// <param name="opt_manager" type="goog.editor.plugins.UndoRedoManager=">An undo redo
        ///    manager to be used by this plugin. If none is provided one is created.</param>
        /// <field name="logger" type="goog.debug.Logger">The logger for this class.</field>
        /// <field name="COMMAND" type="">Commands implemented by this plugin.</field>
        /// <returns type="goog.editor.plugins.UndoRedo"/>
    };

    var $x = window.goog.editor.plugins.UndoRedo;
    $x.prototype = {
                
        setMaxUndoDepth: function(depth) {
            /// <summary>Set the max undo stack depth (not the real memory usage).</summary>
            /// <param name="depth" type="number">Depth of the stack.</param>
        }, 
        
        setUndoRedoManager: function(manager) {
            /// <summary>Set the undo-redo manager used by this plugin. Any state on a previous
            /// undo-redo manager is lost.</summary>
            /// <param name="manager" type="goog.editor.plugins.UndoRedoManager">The undo-redo manager.</param>
        }, 
        
        isSupportedCommand: function(command) {
            /// <summary>Whether the string corresponds to a command this plugin handles.</summary>
            /// <param name="command" type="string">Command string to check.</param>
            /// <returns type="boolean">Whether the string corresponds to a command
            ///     this plugin handles.</returns>
        }, 
        
        unregisterFieldObject: function(fieldObject) {
            /// <summary>Unregisters and disables the fieldObject with this plugin. Thie does *not*
            /// clobber the undo stack for the fieldObject though.
            /// TODO(user): For the multifield version, we really should add a way to
            /// ignore undo actions on field&apos;s that have been made uneditable.
            /// This is probably as simple as skipping over entries in the undo stack
            /// that have a hashcode of an uneditable field.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The field to register with the plugin.</param>
        }, 
        
        getCurrentFieldObject: function() {
            /// <summary>This is so subclasses can deal with multifield undo-redo.</summary>
            /// <returns type="goog.editor.Field">The active field object for this field. This is
            ///     the one registered field object for the single-plugin case and the
            ///     focused field for the multi-field plugin case.</returns>
        }, 
        
        getFieldObjectForHash: function(fieldHashCode) {
            /// <summary>This is so subclasses can deal with multifield undo-redo.</summary>
            /// <param name="fieldHashCode" type="string">The Field&apos;s hashcode.</param>
            /// <returns type="goog.editor.Field">The field object with the hashcode.</returns>
        }, 
        
        getCurrentEventTarget: function() {
            /// <summary>This is so subclasses can deal with multifield undo-redo.</summary>
            /// <returns type="goog.editor.Field">Target for COMMAND_VALUE_CHANGE events.</returns>
        }, 
        
        enable: function(fieldObject) {
            /// <summary></summary>
            /// <param name="fieldObject" type=""></param>
        }, 
        
        disable: function(fieldObject) {
            /// <summary></summary>
            /// <param name="fieldObject" type=""></param>
        }, 
        
        isEnabled: function(fieldObject) {
            /// <summary></summary>
            /// <param name="fieldObject" type=""></param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getTrogClassId: function() {
            /// <summary></summary>
        }, 
        
        execCommand: function(command, var_args) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
            /// <param name="var_args" type=""></param>
        }, 
        
        queryCommandValue: function(command) {
            /// <summary></summary>
            /// <param name="command" type=""></param>
        }, 
        
        restoreState: function(state, content, cursorPosition) {
            /// <summary>Restores the state of the editable field.</summary>
            /// <param name="state" type="goog.editor.plugins.UndoRedo.UndoState_">The state initiating
            ///    the restore.</param>
            /// <param name="content" type="string">The content to restore.</param>
            /// <param name="cursorPosition" type="goog.editor.plugins.UndoRedo.CursorPosition_?">The cursor position within the content.</param>
        }, 
        
        handleKeyboardShortcut: function(e, key, isModifierPressed) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
            /// <param name="key" type=""></param>
            /// <param name="isModifierPressed" type=""></param>
        }, 
        
        clearHistory: function() {
            /// <summary>Clear the undo/redo stack.</summary>
        }, 
        
        refreshCurrentState: function(fieldObject) {
            /// <summary>Refreshes the current state of the editable field as maintained by undo-redo,
            /// without adding any undo-redo states to the stack.</summary>
            /// <param name="fieldObject" type="goog.editor.Field">The editable field.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.UndoRedo";
})(this);
