
/* vsdoc for goog.editor.plugins.UndoRedoManager */

(function (window) {
    window.goog.editor.plugins = window.goog.editor.plugins || {};

    window.goog.editor.plugins.UndoRedoManager = function(){
        /// <summary></summary>
        /// <field name="EventType" type="">Event types for the events dispatched by undo-redo manager.</field>
        /// <returns type="goog.editor.plugins.UndoRedoManager"/>
    };

    var $x = window.goog.editor.plugins.UndoRedoManager;
    $x.prototype = {
                
        setMaxUndoDepth: function(depth) {
            /// <summary>Set the max undo stack depth (not the real memory usage).</summary>
            /// <param name="depth" type="number">Depth of the stack.</param>
        }, 
        
        addState: function(state) {
            /// <summary>Add state to the undo stack. This clears the redo stack.</summary>
            /// <param name="state" type="goog.editor.plugins.UndoRedoState">The state to add to the undo
            ///     stack.</param>
        }, 
        
        undo: function() {
            /// <summary>Performs the undo operation of the state at the top of the undo stack, moving
            /// that state to the top of the redo stack. If the undo stack is empty, does
            /// nothing.</summary>
        }, 
        
        redo: function() {
            /// <summary>Performs the redo operation of the state at the top of the redo stack, moving
            /// that state to the top of the undo stack. If redo undo stack is empty, does
            /// nothing.</summary>
        }, 
        
        hasUndoState: function() {
            /// <summary></summary>
            /// <returns type="boolean">Wether the undo stack has items on it, i.e., if it is
            ///     possible to perform an undo operation.</returns>
        }, 
        
        hasRedoState: function() {
            /// <summary></summary>
            /// <returns type="boolean">Wether the redo stack has items on it, i.e., if it is
            ///     possible to perform a redo operation.</returns>
        }, 
        
        clearHistory: function() {
            /// <summary>Clears the undo and redo stacks.</summary>
        }, 
        
        undoPeek: function() {
            /// <summary></summary>
            /// <returns type="goog.editor.plugins.UndoRedoState|undefined">The state at the top of
            ///     the undo stack without removing it from the stack.</returns>
        }, 
        
        redoPeek: function() {
            /// <summary></summary>
            /// <returns type="goog.editor.plugins.UndoRedoState|undefined">The state at the top of
            ///     the redo stack without removing it from the stack.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.editor.plugins.UndoRedoManager";
})(this);
