
/* vsdoc for goog.editor.range */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.range = {
        /// <summary></summary>
        /// <returns type="goog.editor.range"/>
                
        narrow: function(range, el) {
            /// <summary>Given a range and an element, create a narrower range that is limited to the
            /// boundaries of the element. If the range starts (or ends) outside the
            /// element, the narrowed range&apos;s start point (or end point) will be the
            /// leftmost (or rightmost) leaf of the element.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The range.</param>
            /// <param name="el" type="Element">The element to limit the range to.</param>
            /// <returns type="goog.dom.AbstractRange">A new narrowed range, or null if the
            ///     element does not contain any part of the given range.</returns>
        }, 
        
        expand: function(range, opt_stopNode) {
            /// <summary>Given a range, expand the range to include outer tags if the full contents of
            /// those tags are entirely selected.  This essentially changes the dom position,
            /// but not the visible position of the range.
            /// Ex. &lt;li&gt;foo&lt;/li&gt; if &quot;foo&quot; is selected, instead of returning start and end
            /// nodes as the foo text node, return the li.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The range.</param>
            /// <param name="opt_stopNode" type="Node=">Optional node to stop expanding past.</param>
            /// <returns type="goog.dom.AbstractRange">The expanded range.</returns>
        }, 
        
        selectNodeStart: function(node) {
            /// <summary>Cause the window&apos;s selection to be the start of this node.</summary>
            /// <param name="node" type="Node">The node to select the start of.</param>
        }, 
        
        placeCursorNextTo: function(node, toLeft) {
            /// <summary>Position the cursor immediately to the left or right of &quot;node&quot;.
            /// In Firefox, the selection parent is outside of &quot;node&quot;, so the cursor can
            /// effectively be moved to the end of a link node, without being considered
            /// inside of it.
            /// Note: This does not always work in WebKit. In particular, if you try to
            /// place a cursor to the right of a link, typing still puts you in the link.
            /// Bug: http://bugs.webkit.org/show_bug.cgi?id=17697</summary>
            /// <param name="node" type="Node">The node to position the cursor relative to.</param>
            /// <param name="toLeft" type="boolean">True to place it to the left, false to the right.</param>
            /// <returns type="goog.dom.AbstractRange">The newly selected range.</returns>
        }, 
        
        selectionPreservingNormalize: function(node) {
            /// <summary>Normalizes the node, preserving the selection of the document.
            /// 
            /// May also normalize things outside the node, if it is more efficient to do so.</summary>
            /// <param name="node" type="Node">The node to normalize.</param>
        }, 
        
        normalizeNode: function(node) {
            /// <summary>Normalizes the given node.</summary>
            /// <param name="node" type="Node">The node to normalize.</param>
        }, 
        
        rangePreservingNormalize: function(node, range) {
            /// <summary>Normalizes the node, preserving a range of the document.
            /// 
            /// May also normalize things outside the node, if it is more efficient to do so.</summary>
            /// <param name="node" type="Node">The node to normalize.</param>
            /// <param name="range" type="goog.dom.AbstractRange?">The range to normalize.</param>
            /// <returns type="goog.dom.AbstractRange?">The range, adjusted for normalization.</returns>
        }, 
        
        getDeepEndPoint: function(range, atStart) {
            /// <summary>Get the deepest point in the DOM that&apos;s equivalent to the endpoint of the
            /// given range.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">A range.</param>
            /// <param name="atStart" type="boolean">True for the start point, false for the end point.</param>
            /// <returns type="goog.editor.range.Point">The end point, expressed as a node
            ///    and an offset.</returns>
        }, 
        
        normalize: function(range) {
            /// <summary>Given a range in the current DOM, create a factory for a range that
            /// represents the same selection in a normalized DOM. The factory function
            /// should be invoked after the DOM is normalized.
            /// 
            /// All browsers do a bad job preserving ranges across DOM normalization.
            /// The issue is best described in this 5-year-old bug report:
            /// https://bugzilla.mozilla.org/show_bug.cgi?id=191864
            /// For most applications, this isn&apos;t a problem. The browsers do a good job
            /// handling un-normalized text, so there&apos;s usually no reason to normalize.
            /// 
            /// The exception to this rule is the rich text editing commands
            /// execCommand and queryCommandValue, which will fail often if there are
            /// un-normalized text nodes.
            /// 
            /// The factory function creates new ranges so that we can normalize the DOM
            /// without problems. It must be created before any normalization happens,
            /// and invoked after normalization happens.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The range to normalize. It may
            ///    become invalid after body.normalize() is called.</param>
            /// <returns type="function(): goog.dom.AbstractRange">A factory for a normalized
            ///    range. Should be called after body.normalize() is called.</returns>
        }, 
        
        isEditable: function(range) {
            /// <summary>Checks if a range is completely inside an editable region.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The range to test.</param>
            /// <returns type="boolean">Whether the range is completely inside an editable region.</returns>
        }, 
        
        intersectsTag: function(range, tagName) {
            /// <summary>Returns whether the given range intersects with any instance of the given
            /// tag.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The range to check.</param>
            /// <param name="tagName" type="goog.dom.TagName">The name of the tag.</param>
            /// <returns type="boolean">Whether the given range intersects with any instance of
            ///     the given tag.</returns>
        }, 
        
        saveUsingNormalizedCarets: function(range) {
            /// <summary>Saves the range by inserting carets into the HTML.
            /// 
            /// Unlike the regular saveUsingCarets, this SavedRange normalizes text nodes.
            /// Browsers have other bugs where they don&apos;t handle split text nodes in
            /// contentEditable regions right.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">The abstract range object.</param>
            /// <returns type="goog.dom.SavedCaretRange">A saved caret range that normalizes
            ///     text nodes.</returns>
        }
        
    };

    var $x = window.goog.editor.range;
    $x.__namespace = "true";
    $x.__typeName = "goog.editor.range";
})(this);
