
/* vsdoc for goog.editor.style */

(function (window) {
    window.goog.editor = window.goog.editor || {};

    window.goog.editor.style = {
        /// <summary></summary>
        /// <returns type="goog.editor.style"/>
                
        isDisplayBlock: function(node) {
            /// <summary>Checks whether the given element inherits display: block.</summary>
            /// <param name="node" type="Node">The Node to check.</param>
            /// <returns type="boolean">Whether the element inherits CSS display: block.</returns>
        }, 
        
        isContainer: function(element) {
            /// <summary>Returns true if the element is a container of other non-inline HTML
            /// Note that span, strong and em tags, being inline can only contain
            /// other inline elements and are thus, not containers. Containers are elements
            /// that should not be broken up when wrapping selections with a node of an
            /// inline block styling.</summary>
            /// <param name="element" type="Node">The element to check.</param>
            /// <returns type="boolean">Whether the element is a container.</returns>
        }, 
        
        getContainer: function(node) {
            /// <summary>Return the first ancestor of this node that is a container, inclusive.</summary>
            /// <param name="node" type="Node">Node to find the container of.</param>
            /// <returns type="Element">The element which contains node.</returns>
        }, 
        
        makeUnselectable: function(element, eventHandler) {
            /// <summary>Makes the given element unselectable, as well as all of its children, except
            /// for text areas, text, file and url inputs.</summary>
            /// <param name="element" type="Element">The element to make unselectable.</param>
            /// <param name="eventHandler" type="goog.events.EventHandler">An EventHandler to register
            ///     the event with. Assumes when the node is destroyed, the eventHandler&apos;s
            ///     listeners are destroyed as well.</param>
        }, 
        
        makeSelectable: function(element) {
            /// <summary>Make the given element selectable.
            /// 
            /// For IE this simply turns off the &quot;unselectable&quot; property.
            /// 
            /// Under FF no descendent of an unselectable node can be selectable:
            /// 
            /// https://bugzilla.mozilla.org/show_bug.cgi?id=203291
            /// 
            /// So we make each ancestor of node selectable, while trying to preserve the
            /// unselectability of other nodes along that path
            /// 
            /// This may cause certain text nodes which should be unselectable, to become
            /// selectable. For example:
            /// 
            /// &lt;div id=div1 style=&quot;-moz-user-select: none&quot;&gt;
            ///   Text1
            ///   &lt;span id=span1&gt;Text2&lt;/span&gt;
            /// &lt;/div&gt;
            /// 
            /// If we call makeSelectable on span1, then it will cause &quot;Text1&quot; to become
            /// selectable, since it had to make div1 selectable in order for span1 to be
            /// selectable.
            /// 
            /// If &quot;Text1&quot; were enclosed within a &lt;p&gt; or &lt;span&gt;, then this problem would
            /// not arise.  Text nodes do not have styles, so its style can&apos;t be set to
            /// unselectable.</summary>
            /// <param name="element" type="Element">The element to make selectable.</param>
        }
        
    };

    var $x = window.goog.editor.style;
    $x.__namespace = "true";
    $x.__typeName = "goog.editor.style";
})(this);
