
/* vsdoc for goog.events */

(function (window) {
    window.goog = window.goog || {};

    window.goog.events = {
        /// <summary></summary>
        /// <field name="actionEventWrapper" type="goog.events.ActionEventWrapper_">Singleton instance of ActionEventWrapper_.</field>
        /// <field name="BrowserFeature" type="">Enum of browser capabilities.</field>
        /// <field name="handleBrowserEvent_" type=""></field>
        /// <field name="EventType" type="">Constants for event names.</field>
        /// <field name="KeyCodes" type="">Key codes for common characters.
        /// 
        /// This list is not localized and therefore some of the key codes are not
        /// correct for non US keyboard layouts. See comments below.</field>
        /// <field name="KeyNames" type="">Key names for common characters.
        /// 
        /// This list is not localized and therefore some of the key codes are not
        /// correct for non-US keyboard layouts.</field>
        /// <returns type="goog.events"/>
                
        listen: function(src, type, listener, opt_capt, opt_handler) {
            /// <summary>Adds an event listener for a specific event on a DOM Node or an object that
            /// has implemented {@link goog.events.EventTarget}. A listener can only be
            /// added once to an object and if it is added again the key for the listener
            /// is returned.</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The node to listen to
            ///     events on.</param>
            /// <param name="type" type="string|Array.string">Event type or array of event types.</param>
            /// <param name="listener" type="Function|Object">Callback method, or an object with a
            ///     handleEvent function.</param>
            /// <param name="opt_capt" type="boolean=">Whether to fire in capture phase (defaults to
            ///     false).</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="?number">Unique key for the listener.</returns>
        }, 
        
        getProxy: function() {
            /// <summary>Helper function for returning a proxy function.</summary>
            /// <returns type="Function">A new or reused function object.</returns>
        }, 
        
        listenOnce: function(src, type, listener, opt_capt, opt_handler) {
            /// <summary>Adds an event listener for a specific event on a DomNode or an object that
            /// has implemented {@link goog.events.EventTarget}. After the event has fired
            /// the event listener is removed from the target.</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The node to listen to
            ///     events on.</param>
            /// <param name="type" type="string|Array.string">Event type or array of event types.</param>
            /// <param name="listener" type="Function|Object">Callback method.</param>
            /// <param name="opt_capt" type="boolean=">Fire in capture phase?.</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="?number">Unique key for the listener.</returns>
        }, 
        
        listenWithWrapper: function(src, wrapper, listener, opt_capt, opt_handler) {
            /// <summary>Adds an event listener with a specific event wrapper on a DOM Node or an
            /// object that has implemented {@link goog.events.EventTarget}. A listener can
            /// only be added once to an object.</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The node to listen to
            ///     events on.</param>
            /// <param name="wrapper" type="goog.events.EventWrapper">Event wrapper to use.</param>
            /// <param name="listener" type="Function|Object">Callback method, or an object with a
            ///     handleEvent function.</param>
            /// <param name="opt_capt" type="boolean=">Whether to fire in capture phase (defaults to
            ///     false).</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
        }, 
        
        unlisten: function(src, type, listener, opt_capt, opt_handler) {
            /// <summary>Removes an event listener which was added with listen().</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The target to stop
            ///     listening to events on.</param>
            /// <param name="type" type="string|Array.string">The name of the event without the &apos;on&apos;
            ///     prefix.</param>
            /// <param name="listener" type="Function|Object">The listener function to remove.</param>
            /// <param name="opt_capt" type="boolean=">In DOM-compliant browsers, this determines
            ///     whether the listener is fired during the capture or bubble phase of the
            ///     event.</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="?boolean">indicating whether the listener was there to remove.</returns>
        }, 
        
        unlistenByKey: function(key) {
            /// <summary>Removes an event listener which was added with listen() by the key
            /// returned by listen().</summary>
            /// <param name="key" type="?number">The key returned by listen() for this event listener.</param>
            /// <returns type="boolean">indicating whether the listener was there to remove.</returns>
        }, 
        
        unlistenWithWrapper: function(src, wrapper, listener, opt_capt, opt_handler) {
            /// <summary>Removes an event listener which was added with listenWithWrapper().</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The target to stop
            ///     listening to events on.</param>
            /// <param name="wrapper" type="goog.events.EventWrapper">Event wrapper to use.</param>
            /// <param name="listener" type="Function|Object">The listener function to remove.</param>
            /// <param name="opt_capt" type="boolean=">In DOM-compliant browsers, this determines
            ///     whether the listener is fired during the capture or bubble phase of the
            ///     event.</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
        }, 
        
        removeAll: function(opt_obj, opt_type, opt_capt) {
            /// <summary>Removes all listeners from an object, if no object is specified it will
            /// remove all listeners that have been registered.  You can also optionally
            /// remove listeners of a particular type or capture phase.</summary>
            /// <param name="opt_obj" type="Object=">Object to remove listeners from.</param>
            /// <param name="opt_type" type="string=">Type of event to, default is all types.</param>
            /// <param name="opt_capt" type="boolean=">Whether to remove the listeners from the capture
            ///     or bubble phase.  If unspecified, will remove both.</param>
            /// <returns type="number">Number of listeners removed.</returns>
        }, 
        
        getListeners: function(obj, type, capture) {
            /// <summary>Gets the listeners for a given object, type and capture phase.</summary>
            /// <param name="obj" type="Object">Object to get listeners for.</param>
            /// <param name="type" type="string">Event type.</param>
            /// <param name="capture" type="boolean">Capture phase?.</param>
            /// <returns type="Array.goog.events.Listener">Array of listener objects.</returns>
        }, 
        
        getListener: function(src, type, listener, opt_capt, opt_handler) {
            /// <summary>Gets the goog.events.Listener for the event or null if no such listener is
            /// in use.</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The node from which to get
            ///     listeners.</param>
            /// <param name="type" type="?string">The name of the event without the &apos;on&apos; prefix.</param>
            /// <param name="listener" type="Function|Object">The listener function to get.</param>
            /// <param name="opt_capt" type="boolean=">In DOM-compliant browsers, this determines
            ///                            whether the listener is fired during the
            ///                            capture or bubble phase of the event.</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="goog.events.Listener?">the found listener or null if not found.</returns>
        }, 
        
        hasListener: function(obj, opt_type, opt_capture) {
            /// <summary>Returns whether an event target has any active listeners matching the
            /// specified signature. If either the type or capture parameters are
            /// unspecified, the function will match on the remaining criteria.</summary>
            /// <param name="obj" type="EventTarget|goog.events.EventTarget">Target to get listeners for.</param>
            /// <param name="opt_type" type="string=">Event type.</param>
            /// <param name="opt_capture" type="boolean=">Whether to check for capture or bubble-phase
            ///     listeners.</param>
            /// <returns type="boolean">Whether an event target has one or more listeners matching
            ///     the requested type and/or capture phase.</returns>
        }, 
        
        expose: function(e) {
            /// <summary>Provides a nice string showing the normalized event objects public members</summary>
            /// <param name="e" type="Object">Event Object.</param>
            /// <returns type="string">String of the public members of the normalized event object.</returns>
        }, 
        
        fireListeners: function(obj, type, capture, eventObject) {
            /// <summary>Fires an object&apos;s listeners of a particular type and phase</summary>
            /// <param name="obj" type="Object">Object whose listeners to call.</param>
            /// <param name="type" type="string">Event type.</param>
            /// <param name="capture" type="boolean">Which event phase.</param>
            /// <param name="eventObject" type="Object">Event object to be passed to listener.</param>
            /// <returns type="boolean">True if all listeners returned true else false.</returns>
        }, 
        
        fireListener: function(listener, eventObject) {
            /// <summary>Fires a listener with a set of arguments</summary>
            /// <param name="listener" type="goog.events.Listener">The listener object to call.</param>
            /// <param name="eventObject" type="Object">The event object to pass to the listener.</param>
            /// <returns type="boolean">Result of listener.</returns>
        }, 
        
        getTotalListenerCount: function() {
            /// <summary>Gets the total number of listeners currently in the system.</summary>
            /// <returns type="number">Number of listeners.</returns>
        }, 
        
        dispatchEvent: function(src, e) {
            /// <summary>Dispatches an event (or event like object) and calls all listeners
            /// listening for events of this type. The type of the event is decided by the
            /// type property on the event object.
            /// 
            /// If any of the listeners returns false OR calls preventDefault then this
            /// function will return false.  If one of the capture listeners calls
            /// stopPropagation, then the bubble listeners won&apos;t fire.</summary>
            /// <param name="src" type="goog.events.EventTarget">The event target.</param>
            /// <param name="e" type="string|Object|goog.events.Event">Event object.</param>
            /// <returns type="boolean">If anyone called preventDefault on the event object (or
            ///     if any of the handlers returns false) this will also return false.
            ///     If there are no handlers, or if all handlers return true, this returns
            ///     true.</returns>
        }, 
        
        protectBrowserEventEntryPoint: function(errorHandler) {
            /// <summary>Installs exception protection for the browser event entry point using the
            /// given error handler.</summary>
            /// <param name="errorHandler" type="goog.debug.ErrorHandler">Error handler with which to
            ///     protect the entry point.</param>
        }, 
        
        getUniqueId: function(identifier) {
            /// <summary>Creates a unique event id.</summary>
            /// <param name="identifier" type="string">The identifier.</param>
            /// <returns type="string">A unique identifier.</returns>
        }, 
        
        EventWrapper: function() {
            /// <summary>Interface for event wrappers.</summary>
        }
        
    };

    var $x = window.goog.events;
    $x.__namespace = "true";
    $x.__typeName = "goog.events";
})(this);
