
/* vsdoc for goog.events.BrowserEvent */

(function (window) {
    window.goog.events = window.goog.events || {};

    window.goog.events.BrowserEvent = function(opt_e, opt_currentTarget){
        /// <summary></summary>
        /// <param name="opt_e" type="Event=">Browser event object.</param>
        /// <param name="opt_currentTarget" type="Node=">Current target for event.</param>
        /// <field name="MouseButton" type="">Normalized button constants for the mouse.</field>
        /// <field name="IEButtonMap" type="Array.<number>">Static data for mapping mouse buttons.</field>
        /// <field name="target" type="Node">Target that fired the event.</field>
        /// <field name="relatedTarget" type="Node">For mouseover and mouseout events, the related object for the event.</field>
        /// <field name="offsetX" type="number">X-coordinate relative to target.</field>
        /// <field name="offsetY" type="number">Y-coordinate relative to target.</field>
        /// <field name="clientX" type="number">X-coordinate relative to the window.</field>
        /// <field name="clientY" type="number">Y-coordinate relative to the window.</field>
        /// <field name="screenX" type="number">X-coordinate relative to the monitor.</field>
        /// <field name="screenY" type="number">Y-coordinate relative to the monitor.</field>
        /// <field name="button" type="number">Which mouse button was pressed.</field>
        /// <field name="keyCode" type="number">Keycode of key press.</field>
        /// <field name="charCode" type="number">Keycode of key press.</field>
        /// <field name="ctrlKey" type="boolean">Whether control was pressed at time of event.</field>
        /// <field name="altKey" type="boolean">Whether alt was pressed at time of event.</field>
        /// <field name="shiftKey" type="boolean">Whether shift was pressed at time of event.</field>
        /// <field name="metaKey" type="boolean">Whether the meta key was pressed at time of event.</field>
        /// <field name="platformModifierKey" type="boolean">Whether the default platform modifier key was pressed at time of event.
        /// (This is control for all platforms except Mac, where it&apos;s Meta.</field>
        /// <returns type="goog.events.BrowserEvent"/>
    };

    var $x = window.goog.events.BrowserEvent;
    $x.prototype = {
                
        init: function(e, opt_currentTarget) {
            /// <summary>Accepts a browser event object and creates a patched, cross browser event
            /// object.</summary>
            /// <param name="e" type="Event">Browser event object.</param>
            /// <param name="opt_currentTarget" type="Node=">Current target for event.</param>
        }, 
        
        isButton: function(button) {
            /// <summary>Tests to see which button was pressed during the event. This is really only
            /// useful in IE and Gecko browsers. And in IE, it&apos;s only useful for
            /// mousedown/mouseup events, because click only fires for the left mouse button.
            /// 
            /// Safari 2 only reports the left button being clicked, and uses the value &apos;1&apos;
            /// instead of 0. Opera only reports a mousedown event for the middle button, and
            /// no mouse events for the right button. Opera has default behavior for left and
            /// middle click that can only be overridden via a configuration setting.
            /// 
            /// There&apos;s a nice table of this mess at http://www.unixpapa.com/js/mouse.html.</summary>
            /// <param name="button" type="goog.events.BrowserEvent.MouseButton">The button
            ///     to test for.</param>
            /// <returns type="boolean">True if button was pressed.</returns>
        }, 
        
        isMouseActionButton: function() {
            /// <summary>Whether this has an &quot;action&quot;-producing mouse button.
            /// 
            /// By definition, this includes left-click on windows/linux, and left-click
            /// without the ctrl key on Macs.</summary>
            /// <returns type="boolean">The result.</returns>
        }, 
        
        stopPropagation: function() {
            /// <summary></summary>
        }, 
        
        preventDefault: function() {
            /// <summary></summary>
        }, 
        
        getBrowserEvent: function() {
            /// <summary></summary>
            /// <returns type="Event">The underlying browser event object.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.events.BrowserEvent";
})(this);
