
/* vsdoc for goog.events.Event */

(function (window) {
    window.goog.events = window.goog.events || {};

    window.goog.events.Event = function(type, opt_target){
        /// <summary></summary>
        /// <param name="type" type="string">Event Type.</param>
        /// <param name="opt_target" type="Object=">Reference to the object that is the target of
        ///     this event. It has to implement the {@code EventTarget} interface
        ///     declared at {@link http://developer.mozilla.org/en/DOM/EventTarget}.</param>
        /// <field name="type" type="string">Event type.</field>
        /// <field name="target" type="Object|undefined">Target of the event.</field>
        /// <field name="currentTarget" type="Object|undefined">Object that had the listener attached.</field>
        /// <field name="propagationStopped_" type="boolean">Whether to cancel the event in internal capture/bubble processing for IE.</field>
        /// <field name="defaultPrevented" type="boolean">Whether the default action has been prevented.
        /// This is a property to match the W3C specification at {@link
        /// http://www.w3.org/TR/DOM-Level-3-Events/#events-event-type-defaultPrevented}.
        /// Must be treated as read-only outside the class.</field>
        /// <field name="returnValue_" type="boolean">Return value for in internal capture/bubble processing for IE.</field>
        /// <returns type="goog.events.Event"/>
    };

    var $x = window.goog.events.Event;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary>For backwards compatibility (goog.events.Event used to inherit
            /// goog.Disposable).</summary>
        }, 
        
        dispose: function() {
            /// <summary>For backwards compatibility (goog.events.Event used to inherit
            /// goog.Disposable).</summary>
        }, 
        
        stopPropagation: function() {
            /// <summary>Stops event propagation.</summary>
        }, 
        
        preventDefault: function() {
            /// <summary>Prevents the default action, for example a link redirecting to a url.</summary>
        }, 
        
        stopPropagation: function(e) {
            /// <summary>Stops the propagation of the event. It is equivalent to
            /// {@code e.stopPropagation()}, but can be used as the callback argument of
            /// {@link goog.events.listen} without declaring another function.</summary>
            /// <param name="e" type="!goog.events.Event">An event.</param>
        }, 
        
        preventDefault: function(e) {
            /// <summary>Prevents the default action. It is equivalent to
            /// {@code e.preventDefault()}, but can be used as the callback argument of
            /// {@link goog.events.listen} without declaring another function.</summary>
            /// <param name="e" type="!goog.events.Event">An event.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.events.Event";
})(this);
