
/* vsdoc for goog.events.EventHandler */

(function (window) {
    window.goog.events = window.goog.events || {};

    window.goog.events.EventHandler = function(opt_handler){
        /// <summary></summary>
        /// <param name="opt_handler" type="Object=">Object in whose scope to call the listeners.</param>
        /// <returns type="goog.events.EventHandler"/>
    };

    var $x = window.goog.events.EventHandler;
    $x.prototype = {
                
        listen: function(src, type, opt_fn, opt_capture, opt_handler) {
            /// <summary>Listen to an event on a DOM node or EventTarget.  If the function is omitted
            /// then the EventHandler&apos;s handleEvent method will be used.</summary>
            /// <param name="src" type="goog.events.EventTarget|EventTarget">Event source.</param>
            /// <param name="type" type="string|Array.string">Event type to listen for or array of
            ///     event types.</param>
            /// <param name="opt_fn" type="Function|Object=">Optional callback function to be used as the
            ///    listener or an object with handleEvent function.</param>
            /// <param name="opt_capture" type="boolean=">Optional whether to use capture phase.</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
            /// <returns type="goog.events.EventHandler">This object, allowing for chaining of
            ///     calls.</returns>
        }, 
        
        listenOnce: function(src, type, opt_fn, opt_capture, opt_handler) {
            /// <summary>Listen to an event on a DOM node or EventTarget.  If the function is omitted
            /// then the EventHandler&apos;s handleEvent method will be used. After the event has
            /// fired the event listener is removed from the target. If an array of event
            /// types is provided, each event type will be listened to once.</summary>
            /// <param name="src" type="goog.events.EventTarget|EventTarget">Event source.</param>
            /// <param name="type" type="string|Array.string">Event type to listen for or array of
            ///     event types.</param>
            /// <param name="opt_fn" type="Function|Object=">Optional callback function to be used as the
            ///    listener or an object with handleEvent function.</param>
            /// <param name="opt_capture" type="boolean=">Optional whether to use capture phase.</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
            /// <returns type="goog.events.EventHandler">This object, allowing for chaining of
            ///     calls.</returns>
        }, 
        
        listenWithWrapper: function(src, wrapper, listener, opt_capt, opt_handler) {
            /// <summary>Adds an event listener with a specific event wrapper on a DOM Node or an
            /// object that has implemented {@link goog.events.EventTarget}. A listener can
            /// only be added once to an object.</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The node to listen to
            ///     events on.</param>
            /// <param name="wrapper" type="goog.events.EventWrapper">Event wrapper to use.</param>
            /// <param name="listener" type="Function|Object">Callback method, or an object with a
            ///     handleEvent function.</param>
            /// <param name="opt_capt" type="boolean=">Whether to fire in capture phase (defaults to
            ///     false).</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="goog.events.EventHandler">This object, allowing for chaining of
            ///     calls.</returns>
        }, 
        
        getListenerCount: function() {
            /// <summary></summary>
            /// <returns type="number">Number of listeners registered by this handler.</returns>
        }, 
        
        unlisten: function(src, type, opt_fn, opt_capture, opt_handler) {
            /// <summary>Unlistens on an event.</summary>
            /// <param name="src" type="goog.events.EventTarget|EventTarget">Event source.</param>
            /// <param name="type" type="string|Array.string">Event type to listen for.</param>
            /// <param name="opt_fn" type="Function|Object=">Optional callback function to be used as the
            ///    listener or an object with handleEvent function.</param>
            /// <param name="opt_capture" type="boolean=">Optional whether to use capture phase.</param>
            /// <param name="opt_handler" type="Object=">Object in whose scope to call the listener.</param>
            /// <returns type="goog.events.EventHandler">This object, allowing for chaining of
            ///     calls.</returns>
        }, 
        
        unlistenWithWrapper: function(src, wrapper, listener, opt_capt, opt_handler) {
            /// <summary>Removes an event listener which was added with listenWithWrapper().</summary>
            /// <param name="src" type="EventTarget|goog.events.EventTarget">The target to stop
            ///     listening to events on.</param>
            /// <param name="wrapper" type="goog.events.EventWrapper">Event wrapper to use.</param>
            /// <param name="listener" type="Function|Object">The listener function to remove.</param>
            /// <param name="opt_capt" type="boolean=">In DOM-compliant browsers, this determines
            ///     whether the listener is fired during the capture or bubble phase of the
            ///     event.</param>
            /// <param name="opt_handler" type="Object=">Element in whose scope to call the listener.</param>
            /// <returns type="goog.events.EventHandler">This object, allowing for chaining of
            ///     calls.</returns>
        }, 
        
        removeAll: function() {
            /// <summary>Unlistens to all events.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of this EventHandler and removes all listeners that it registered.</summary>
        }, 
        
        handleEvent: function(e) {
            /// <summary>Default event handler</summary>
            /// <param name="e" type="goog.events.Event">Event object.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.events.EventHandler";
})(this);
