
/* vsdoc for goog.events.EventTarget */

(function (window) {
    window.goog.events = window.goog.events || {};

    window.goog.events.EventTarget = function(){
        /// <summary></summary>
        /// <returns type="goog.events.EventTarget"/>
    };

    var $x = window.goog.events.EventTarget;
    $x.prototype = {
                
        getParentEventTarget: function() {
            /// <summary>Returns the parent of this event target to use for bubbling.</summary>
            /// <returns type="goog.events.EventTarget">The parent EventTarget or null if there
            /// is no parent.</returns>
        }, 
        
        setParentEventTarget: function(parent) {
            /// <summary>Sets the parent of this event target to use for bubbling.</summary>
            /// <param name="parent" type="goog.events.EventTarget?">Parent EventTarget (null if none).</param>
        }, 
        
        addEventListener: function(type, handler, opt_capture, opt_handlerScope) {
            /// <summary>Adds an event listener to the event target. The same handler can only be
            /// added once per the type. Even if you add the same handler multiple times
            /// using the same type then it will only be called once when the event is
            /// dispatched.
            /// 
            /// Supported for legacy but use goog.events.listen(src, type, handler) instead.</summary>
            /// <param name="type" type="string">The type of the event to listen for.</param>
            /// <param name="handler" type="Function|Object">The function to handle the event. The
            ///     handler can also be an object that implements the handleEvent method
            ///     which takes the event object as argument.</param>
            /// <param name="opt_capture" type="boolean=">In DOM-compliant browsers, this determines
            ///     whether the listener is fired during the capture or bubble phase
            ///     of the event.</param>
            /// <param name="opt_handlerScope" type="Object=">Object in whose scope to call the listener.</param>
        }, 
        
        removeEventListener: function(type, handler, opt_capture, opt_handlerScope) {
            /// <summary>Removes an event listener from the event target. The handler must be the
            /// same object as the one added. If the handler has not been added then
            /// nothing is done.</summary>
            /// <param name="type" type="string">The type of the event to listen for.</param>
            /// <param name="handler" type="Function|Object">The function to handle the event. The
            ///     handler can also be an object that implements the handleEvent method
            ///     which takes the event object as argument.</param>
            /// <param name="opt_capture" type="boolean=">In DOM-compliant browsers, this determines
            ///     whether the listener is fired during the capture or bubble phase
            ///     of the event.</param>
            /// <param name="opt_handlerScope" type="Object=">Object in whose scope to call the listener.</param>
        }, 
        
        dispatchEvent: function(e) {
            /// <summary>Dispatches an event (or event like object) and calls all listeners
            /// listening for events of this type. The type of the event is decided by the
            /// type property on the event object.
            /// 
            /// If any of the listeners returns false OR calls preventDefault then this
            /// function will return false.  If one of the capture listeners calls
            /// stopPropagation, then the bubble listeners won&apos;t fire.</summary>
            /// <param name="e" type="string|Object|goog.events.Event">Event object.</param>
            /// <returns type="boolean">If anyone called preventDefault on the event object (or
            ///     if any of the handlers returns false this will also return false.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary>Unattach listeners from this object.  Classes that extend EventTarget may
            /// need to override this method in order to remove references to DOM Elements
            /// and additional listeners, it should be something like this:
            /// &lt;pre&gt;
            /// MyClass.prototype.disposeInternal = function() {
            ///   MyClass.superClass_.disposeInternal.call(this);
            ///   // Dispose logic for MyClass
            /// };
            /// &lt;/pre&gt;</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.events.EventTarget";
})(this);
