
/* vsdoc for goog.format */

(function (window) {
    window.goog = window.goog || {};

    window.goog.format = {
        /// <summary></summary>
        /// <field name="WORD_BREAK_HTML" type="string">Constant for the WBR replacement used by insertWordBreaks.  Safari requires
        /// &lt;wbr&gt;&lt;/wbr&gt;, Opera needs the &amp;shy; entity, though this will give a visible
        /// hyphen at breaks.  IE8 uses a zero width space.
        /// Other browsers just use &lt;wbr&gt;.</field>
        /// <returns type="goog.format"/>
                
        fileSize: function(bytes, opt_decimals) {
            /// <summary>Formats a number of bytes in human readable form.
            /// 54, 450K, 1.3M, 5G etc.</summary>
            /// <param name="bytes" type="number">The number of bytes to show.</param>
            /// <param name="opt_decimals" type="number=">The number of decimals to use.  Defaults to 2.</param>
            /// <returns type="string">The human readable form of the byte size.</returns>
        }, 
        
        isConvertableScaledNumber: function(val) {
            /// <summary>Checks whether string value containing scaling units (K, M, G, T, P, m,
            /// u, n) can be converted to a number.
            /// 
            /// Where there is a decimal, there must be a digit to the left of the
            /// decimal point.
            /// 
            /// Negative numbers are valid.
            /// 
            /// Examples:
            ///   0, 1, 1.0, 10.4K, 2.3M, -0.3P, 1.2m</summary>
            /// <param name="val" type="string">String value to check.</param>
            /// <returns type="boolean">True if string could be converted to a numeric value.</returns>
        }, 
        
        stringToNumericValue: function(stringValue) {
            /// <summary>Converts a string to numeric value, taking into account the units.
            /// If string ends in &apos;B&apos;, use binary conversion.</summary>
            /// <param name="stringValue" type="string">String to be converted to numeric value.</param>
            /// <returns type="number">Numeric value for string.</returns>
        }, 
        
        stringToNumBytes: function(stringValue) {
            /// <summary>Converts a string to number of bytes, taking into account the units.
            /// Binary conversion.</summary>
            /// <param name="stringValue" type="string">String to be converted to numeric value.</param>
            /// <returns type="number">Numeric value for string.</returns>
        }, 
        
        numericValueToString: function(val, opt_decimals) {
            /// <summary>Converts a numeric value to string representation. SI conversion.</summary>
            /// <param name="val" type="number">Value to be converted.</param>
            /// <param name="opt_decimals" type="number=">The number of decimals to use.  Defaults to 2.</param>
            /// <returns type="string">String representation of number.</returns>
        }, 
        
        numBytesToString: function(val, opt_decimals, opt_suffix) {
            /// <summary>Converts number of bytes to string representation. Binary conversion.
            /// Default is to return the additional &apos;B&apos; suffix, e.g. &apos;10.5KB&apos; to minimize
            /// confusion with counts that are scaled by powers of 1000.</summary>
            /// <param name="val" type="number">Value to be converted.</param>
            /// <param name="opt_decimals" type="number=">The number of decimals to use.  Defaults to 2.</param>
            /// <param name="opt_suffix" type="boolean=">If true, include trailing &apos;B&apos; in returned
            ///     string.  Default is true.</param>
            /// <returns type="string">String representation of number of bytes.</returns>
        }, 
        
        insertWordBreaks: function(str, opt_maxlen) {
            /// <summary>Inserts word breaks into an HTML string at a given interval.
            /// 
            /// This method is as aggressive as possible, using a full table of Unicode
            /// characters where it is legal to insert word breaks; however, this table
            /// comes at a 2.5k pre-gzip (~1k post-gzip) size cost.  Consider using
            /// insertWordBreaksBasic to minimize the size impact.</summary>
            /// <param name="str" type="string">HTML to insert word breaks into.</param>
            /// <param name="opt_maxlen" type="number=">Maximum length after which to ensure there is a
            ///     break.  Default is 10 characters.</param>
            /// <returns type="string">The string including word breaks.</returns>
        }, 
        
        insertWordBreaksBasic: function(str, opt_maxlen) {
            /// <summary>Inserts word breaks into an HTML string at a given interval.
            /// 
            /// This method is less aggressive than insertWordBreaks, only inserting
            /// breaks next to punctuation and between Latin or Cyrillic characters.
            /// However, this is good enough for the common case of URLs.  It also
            /// works for all Latin and Cyrillic languages, plus CJK has no need for word
            /// breaks.  When this method is used, goog.i18n.GraphemeBreak may be dead
            /// code eliminated.</summary>
            /// <param name="str" type="string">HTML to insert word breaks into.</param>
            /// <param name="opt_maxlen" type="number=">Maximum length after which to ensure there is a
            ///     break.  Default is 10 characters.</param>
            /// <returns type="string">The string including word breaks.</returns>
        }
        
    };

    var $x = window.goog.format;
    $x.__namespace = "true";
    $x.__typeName = "goog.format";
})(this);
