
/* vsdoc for goog.fs */

(function (window) {
    window.goog = window.goog || {};

    window.goog.fs = {
        /// <summary></summary>
        /// <returns type="goog.fs"/>
                
        getTemporary: function(size) {
            /// <summary>Returns a temporary FileSystem object. A temporary filesystem may be deleted
            /// by the user agent at its discretion.</summary>
            /// <param name="size" type="number">The size requested for the filesystem, in bytes.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.FileSystem}. If an
            ///     error occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        getPersistent: function(size) {
            /// <summary>Returns a persistent FileSystem object. A persistent filesystem will never be
            /// deleted without the user&apos;s or application&apos;s authorization.</summary>
            /// <param name="size" type="number">The size requested for the filesystem, in bytes.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.FileSystem}. If an
            ///     error occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        createObjectUrl: function(blob) {
            /// <summary>Creates a blob URL for a blob object.</summary>
            /// <param name="blob" type="!Blob">The object for which to create the URL.</param>
            /// <returns type="string">The URL for the object.</returns>
        }, 
        
        revokeObjectUrl: function(url) {
            /// <summary>Revokes a URL created by {@link goog.fs.createObjectUrl}.</summary>
            /// <param name="url" type="string">The URL to revoke.</param>
        }, 
        
        getBlob: function(var_args) {
            /// <summary>Concatenates one or more values together and converts them to a Blob.</summary>
            /// <param name="var_args" type="...(string|!Blob|!ArrayBuffer)">The values that will make up
            ///     the resulting blob.</param>
            /// <returns type="!Blob">The blob.</returns>
        }, 
        
        blobToString: function(blob, opt_encoding) {
            /// <summary>Converts a Blob or a File into a string. This should only be used when the
            /// blob is known to be small.</summary>
            /// <param name="blob" type="!Blob">The blob to convert.</param>
            /// <param name="opt_encoding" type="string=">The name of the encoding to use.</param>
            /// <returns type="!goog.async.Deferred">The deferred string. If an error occurrs, the
            ///     errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        sliceBlob: function(blob, start, opt_end) {
            /// <summary>Slices the blob. The returned blob contains data from the start byte
            /// (inclusive) till the end byte (exclusive). Negative indices can be used
            /// to count bytes from the end of the blob (-1 == blob.size - 1). Indices
            /// are always clamped to blob range. If end is omitted, all the data till
            /// the end of the blob is taken.</summary>
            /// <param name="blob" type="!Blob">The blob to be sliced.</param>
            /// <param name="start" type="number">Index of the starting byte.</param>
            /// <param name="opt_end" type="number=">Index of the ending byte.</param>
            /// <returns type="Blob">The blob slice or null if not supported.</returns>
        }
        
    };

    var $x = window.goog.fs;
    $x.__namespace = "true";
    $x.__typeName = "goog.fs";
})(this);
