
/* vsdoc for goog.fs.DirectoryEntry */

(function (window) {
    window.goog.fs = window.goog.fs || {};

    window.goog.fs.DirectoryEntry = function(fs, dir){
        /// <summary></summary>
        /// <param name="fs" type="!goog.fs.FileSystem">The wrapped filesystem.</param>
        /// <param name="dir" type="!DirectoryEntry">The underlying DirectoryEntry object.</param>
        /// <field name="Behavior" type="">Behaviors for getting files and directories.</field>
        /// <returns type="goog.fs.DirectoryEntry"/>
    };

    var $x = window.goog.fs.DirectoryEntry;
    $x.prototype = {
                
        getFile: function(path, opt_behavior) {
            /// <summary>Get a file in the directory.</summary>
            /// <param name="path" type="string">The path to the file, relative to this directory.</param>
            /// <param name="opt_behavior" type="goog.fs.DirectoryEntry.Behavior=">The behavior for
            ///     handling an existing file, or the lack thereof.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.FileEntry}. If an
            ///     error occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        getDirectory: function(path, opt_behavior) {
            /// <summary>Get a directory within this directory.</summary>
            /// <param name="path" type="string">The path to the directory, relative to this directory.</param>
            /// <param name="opt_behavior" type="goog.fs.DirectoryEntry.Behavior=">The behavior for
            ///     handling an existing directory, or the lack thereof.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.DirectoryEntry}.
            ///     If an error occurs, the errback is called a {@link goog.fs.Error}.</returns>
        }, 
        
        createPath: function(path) {
            /// <summary>Opens the directory for the specified path, creating the directory and any
            /// intermediate directories as necessary.</summary>
            /// <param name="path" type="string">The directory path to create. May be absolute or
            ///     relative to the current directory. The parent directory &quot;..&quot; and current
            ///     directory &quot;.&quot; are supported.</param>
            /// <returns type="!goog.async.Deferred">A deferred {@link goog.fs.DirectoryEntry} for
            ///     the requested path. If an error occurs, the errback is called with a
            ///     {@link goog.fs.Error}.</returns>
        }, 
        
        listDirectory: function() {
            /// <summary>Gets a list of all entries in this directory.</summary>
            /// <returns type="!goog.async.Deferred">The deferred list of {@link goog.fs.Entry}
            ///     results. If an error occurs, the errback is called with a
            ///     {@link goog.fs.Error}.</returns>
        }, 
        
        removeRecursively: function() {
            /// <summary>Removes this directory and all its contents.</summary>
            /// <returns type="!goog.async.Deferred">A deferred object. If the removal succeeds,
            ///     the callback is called with true. If an error occurs, the errback is
            ///     called a {@link goog.fs.Error}.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fs.DirectoryEntry";
})(this);
