
/* vsdoc for goog.fs.Entry */

(function (window) {
    window.goog.fs = window.goog.fs || {};

    window.goog.fs.Entry = function(fs, entry){
        /// <summary></summary>
        /// <param name="fs" type="!goog.fs.FileSystem">The wrapped filesystem.</param>
        /// <param name="entry" type="!Entry">The underlying Entry object.</param>
        /// <field name="toUri" type="string">Get the URI for this file.</field>
        /// <returns type="goog.fs.Entry"/>
    };

    var $x = window.goog.fs.Entry;
    $x.prototype = {
                
        isFile: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether or not this entry is a file.</returns>
        }, 
        
        isDirectory: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether or not this entry is a directory.</returns>
        }, 
        
        getName: function() {
            /// <summary></summary>
            /// <returns type="string">The name of this entry.</returns>
        }, 
        
        getFullPath: function() {
            /// <summary></summary>
            /// <returns type="string">The full path to this entry.</returns>
        }, 
        
        getFileSystem: function() {
            /// <summary></summary>
            /// <returns type="!goog.fs.FileSystem">The filesystem backing this entry.</returns>
        }, 
        
        getLastModified: function() {
            /// <summary>Retrieves the last modified date for this entry.</summary>
            /// <returns type="!goog.async.Deferred">The deferred Date for this entry. If an error
            ///     occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        getMetadata: function() {
            /// <summary>Retrieves the metadata for this entry.</summary>
            /// <returns type="!goog.async.Deferred">The deferred Metadata for this entry. If an
            ///     error occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        moveTo: function(parent, opt_newName) {
            /// <summary>Move this entry to a new location.</summary>
            /// <param name="parent" type="!goog.fs.DirectoryEntry">The new parent directory.</param>
            /// <param name="opt_newName" type="string=">The new name of the entry. If omitted, the entry
            ///     retains its original name.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.FileEntry | @link goog.fs.DirectoryEntry} for the new entry. If an error occurs, the
            ///     errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        copyTo: function(parent, opt_newName) {
            /// <summary>Copy this entry to a new location.</summary>
            /// <param name="parent" type="!goog.fs.DirectoryEntry">The new parent directory.</param>
            /// <param name="opt_newName" type="string=">The name of the new entry. If omitted, the new
            ///     entry has the same name as the original.</param>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.FileEntry | @link goog.fs.DirectoryEntry} for the new entry. If an error occurs, the
            ///     errback is called with a {@link goog.fs.Error}.</returns>
        }, 
        
        wrapEntry: function(entry) {
            /// <summary>Wrap an HTML5 entry object in an appropriate subclass instance.</summary>
            /// <param name="entry" type="!Entry">The underlying Entry object.</param>
            /// <returns type="!goog.fs.Entry">The appropriate subclass wrapper.</returns>
        }, 
        
        toUrl: function(opt_mimeType) {
            /// <summary>Get the URL for this file.</summary>
            /// <param name="opt_mimeType" type="string=">The MIME type that will be served for the URL.</param>
            /// <returns type="string">The URL.</returns>
        }, 
        
        remove: function() {
            /// <summary>Remove this entry.</summary>
            /// <returns type="!goog.async.Deferred">A deferred object. If the removal succeeds,
            ///     the callback is called with true. If an error occurs, the errback is
            ///     called a {@link goog.fs.Error}.</returns>
        }, 
        
        getParent: function() {
            /// <summary>Gets the parent directory.</summary>
            /// <returns type="!goog.async.Deferred">The deferred {@link goog.fs.DirectoryEntry}.
            ///     If an error occurs, the errback is called with a {@link goog.fs.Error}.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fs.Entry";
})(this);
