
/* vsdoc for goog.functions */

(function (window) {
    window.goog = window.goog || {};

    window.goog.functions = {
        /// <summary></summary>
        /// <field name="FALSE" type="function(...): boolean">Always returns false.</field>
        /// <field name="TRUE" type="function(...): boolean">Always returns true.</field>
        /// <field name="NULL" type="function(...): null">Always returns NULL.</field>
        /// <returns type="goog.functions"/>
                
        constant: function(retValue) {
            /// <summary>Creates a function that always returns the same value.</summary>
            /// <param name="retValue" type="*">The value to return.</param>
            /// <returns type="!Function">The new function.</returns>
        }, 
        
        identity: function(opt_returnValue, var_args) {
            /// <summary>A simple function that returns the first argument of whatever is passed
            /// into it.</summary>
            /// <param name="opt_returnValue" type="*=">The single value that will be returned.</param>
            /// <param name="var_args" type="...*">Optional trailing arguments. These are ignored.</param>
            /// <returns type="?">The first argument passed in, or undefined if nothing was passed.
            ///     We can&apos;t know the type -- just pass it along without type.</returns>
        }, 
        
        error: function(message) {
            /// <summary>Creates a function that always throws an error with the given message.</summary>
            /// <param name="message" type="string">The error message.</param>
            /// <returns type="!Function">The error-throwing function.</returns>
        }, 
        
        lock: function(f, opt_numArgs) {
            /// <summary>Given a function, create a function that keeps opt_numArgs arguments and
            /// silently discards all additional arguments.</summary>
            /// <param name="f" type="Function">The original function.</param>
            /// <param name="opt_numArgs" type="number=">The number of arguments to keep. Defaults to 0.</param>
            /// <returns type="!Function">A version of f that only keeps the first opt_numArgs
            ///     arguments.</returns>
        }, 
        
        withReturnValue: function(f, retValue) {
            /// <summary>Given a function, create a new function that swallows its return value
            /// and replaces it with a new one.</summary>
            /// <param name="f" type="Function">A function.</param>
            /// <param name="retValue" type="*">A new return value.</param>
            /// <returns type="!Function">A new function.</returns>
        }, 
        
        compose: function(var_args) {
            /// <summary>Creates the composition of the functions passed in.
            /// For example, (goog.functions.compose(f, g))(a) is equivalent to f(g(a)).</summary>
            /// <param name="var_args" type="...Function">A list of functions.</param>
            /// <returns type="!Function">The composition of all inputs.</returns>
        }, 
        
        sequence: function(var_args) {
            /// <summary>Creates a function that calls the functions passed in in sequence, and
            /// returns the value of the last function. For example,
            /// (goog.functions.sequence(f, g))(x) is equivalent to f(x),g(x).</summary>
            /// <param name="var_args" type="...Function">A list of functions.</param>
            /// <returns type="!Function">A function that calls all inputs in sequence.</returns>
        }, 
        
        and: function(var_args) {
            /// <summary>Creates a function that returns true if each of its components evaluates
            /// to true. The components are evaluated in order, and the evaluation will be
            /// short-circuited as soon as a function returns false.
            /// For example, (goog.functions.and(f, g))(x) is equivalent to f(x) &amp;&amp; g(x).</summary>
            /// <param name="var_args" type="...Function">A list of functions.</param>
            /// <returns type="!Function">A function that ANDs its component functions.</returns>
        }, 
        
        or: function(var_args) {
            /// <summary>Creates a function that returns true if any of its components evaluates
            /// to true. The components are evaluated in order, and the evaluation will be
            /// short-circuited as soon as a function returns true.
            /// For example, (goog.functions.or(f, g))(x) is equivalent to f(x) || g(x).</summary>
            /// <param name="var_args" type="...Function">A list of functions.</param>
            /// <returns type="!Function">A function that ORs its component functions.</returns>
        }, 
        
        not: function(f) {
            /// <summary>Creates a function that returns the Boolean opposite of a provided function.
            /// For example, (goog.functions.not(f))(x) is equivalent to !f(x).</summary>
            /// <param name="f" type="!Function">The original function.</param>
            /// <returns type="!Function">A function that delegates to f and returns opposite.</returns>
        }, 
        
        create: function(constructor, var_args) {
            /// <summary>Generic factory function to construct an object given the constructor
            /// and the arguments. Intended to be bound to create object factories.
            /// 
            /// Callers should cast the result to the appropriate type for proper type
            /// checking by the compiler.</summary>
            /// <param name="constructor" type="!Function">The constructor for the Object.</param>
            /// <param name="var_args" type="...*">The arguments to be passed to the constructor.</param>
            /// <returns type="!Object">A new instance of the class given in {@code constructor}.</returns>
        }
        
    };

    var $x = window.goog.functions;
    $x.__namespace = "true";
    $x.__typeName = "goog.functions";
})(this);
