
/* vsdoc for goog.fx.AbstractDragDrop */

(function (window) {
    window.goog.fx = window.goog.fx || {};

    window.goog.fx.AbstractDragDrop = function(){
        /// <summary></summary>
        /// <field name="items_" type="Array.<goog.fx.DragDropItem>">List of items that makes up the drag source or drop target.</field>
        /// <field name="EventType" type="Object">Constants for event names</field>
        /// <field name="initDragDistanceThreshold" type="number">Constant for distance threshold, in pixels, an element has to be moved to
        /// initiate a drag operation.</field>
        /// <field name="addItem" type="">Add item to drag object.</field>
        /// <returns type="goog.fx.AbstractDragDrop"/>
    };

    var $x = window.goog.fx.AbstractDragDrop;
    $x.prototype = {
                
        setDragClass: function(className) {
            /// <summary>Set class to add to source elements being dragged.</summary>
            /// <param name="className" type="string">Class to be added.</param>
        }, 
        
        setSourceClass: function(className) {
            /// <summary>Set class to add to source elements.</summary>
            /// <param name="className" type="string">Class to be added.</param>
        }, 
        
        setTargetClass: function(className) {
            /// <summary>Set class to add to target elements.</summary>
            /// <param name="className" type="string">Class to be added.</param>
        }, 
        
        isInitialized: function() {
            /// <summary>Whether the control has been initialized.</summary>
            /// <returns type="boolean">True if it&apos;s been initialized.</returns>
        }, 
        
        addTarget: function(target) {
            /// <summary>Associate drop target with drag element.</summary>
            /// <param name="target" type="goog.fx.AbstractDragDrop">Target to add.</param>
        }, 
        
        setScrollTarget: function(scrollTarget) {
            /// <summary>Sets the SCROLL event target to make drag element follow scrolling.</summary>
            /// <param name="scrollTarget" type="EventTarget">The element that dispatches SCROLL events.</param>
        }, 
        
        init: function() {
            /// <summary>Initialize drag and drop functionality for sources/targets already added.
            /// Sources/targets added after init has been called will initialize themselves
            /// one by one.</summary>
        }, 
        
        initItem: function(item) {
            /// <summary>Initializes a single item.</summary>
            /// <param name="item" type="goog.fx.DragDropItem">Item to initialize.</param>
        }, 
        
        disposeItem: function(item) {
            /// <summary>Called when removing an item. Removes event listeners and classes.</summary>
            /// <param name="item" type="goog.fx.DragDropItem">Item to dispose.</param>
        }, 
        
        removeItems: function() {
            /// <summary>Removes all items.</summary>
        }, 
        
        maybeStartDrag: function(event, item) {
            /// <summary>Starts a drag event for an item if the mouse button stays pressed and the
            /// cursor moves a few pixels. Allows dragging of items without first having to
            /// register them with addItem.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse down event.</param>
            /// <param name="item" type="goog.fx.DragDropItem">Item that&apos;s being dragged.</param>
        }, 
        
        startDrag: function(event, item) {
            /// <summary>Event handler that&apos;s used to start drag.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse move event.</param>
            /// <param name="item" type="goog.fx.DragDropItem">Item that&apos;s being dragged.</param>
        }, 
        
        recalculateDragTargets: function() {
            /// <summary>Recalculates the geometry of this source&apos;s drag targets.  Call this
            /// if the position or visibility of a drag target has changed during
            /// a drag, or if targets are added or removed.
            /// 
            /// TODO(user): this is an expensive operation;  more efficient APIs
            /// may be necessary.</summary>
        }, 
        
        recalculateScrollableContainers: function() {
            /// <summary>Recalculates the current scroll positions of scrollable containers and
            /// allocates targets. Call this if the position of a container changed or if
            /// targets are added or removed.</summary>
        }, 
        
        createDraggerFor: function(sourceEl, el, event) {
            /// <summary>Creates the Dragger for the drag element.</summary>
            /// <param name="sourceEl" type="Element">Drag source element.</param>
            /// <param name="el" type="Element">the element created by createDragElement().</param>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse down event for start of drag.</param>
            /// <returns type="goog.fx.Dragger">The new Dragger.</returns>
        }, 
        
        endDrag: function(event) {
            /// <summary>Event handler that&apos;s used to stop drag. Fires a drop event if over a valid
            /// target.</summary>
            /// <param name="event" type="goog.fx.DragEvent">Drag event.</param>
        }, 
        
        afterEndDrag: function(opt_dropTarget) {
            /// <summary>Called after a drag operation has finished.</summary>
            /// <param name="opt_dropTarget" type="goog.fx.DragDropItem=">Target for successful drop.</param>
        }, 
        
        disposeDrag: function() {
            /// <summary>Called once a drag operation has finished. Removes event listeners and
            /// elements.</summary>
        }, 
        
        addScrollableContainer: function(element) {
            /// <summary>Makes drag and drop aware of a target container that could scroll mid drag.</summary>
            /// <param name="element" type="Element">The scroll container.</param>
        }, 
        
        removeAllScrollableContainers: function() {
            /// <summary>Removes all scrollable containers.</summary>
        }, 
        
        setSubtargetFunction: function(f) {
            /// <summary>Set a function that provides subtargets. A subtargeting function
            /// returns an arbitrary identifier for each subtarget of an element.
            /// DnD code will generate additional drag over / out events when
            /// switching from subtarget to subtarget. This is useful for instance
            /// if you are interested if you are on the top half or the bottom half
            /// of the element.
            /// The provided function will be given the DragDropItem, box, x, y
            /// box is the current window coordinates occupied by element
            /// x, y is the mouse position in window coordinates</summary>
            /// <param name="f" type="Function">The new subtarget function.</param>
        }, 
        
        createDragElement: function(sourceEl) {
            /// <summary>Creates an element for the item being dragged.</summary>
            /// <param name="sourceEl" type="Element">Drag source element.</param>
            /// <returns type="Element">The new drag element.</returns>
        }, 
        
        getDragElementPosition: function(el, dragEl, event) {
            /// <summary>Returns the position for the drag element.</summary>
            /// <param name="el" type="Element">Drag source element.</param>
            /// <param name="dragEl" type="Element">The dragged element created by createDragElement().</param>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse down event for start of drag.</param>
            /// <returns type="goog.math.Coordinate">The position for the drag element.</returns>
        }, 
        
        getDragger: function() {
            /// <summary>Returns the dragger object.</summary>
            /// <returns type="goog.fx.Dragger">The dragger object used by this drag and drop
            ///     instance.</returns>
        }, 
        
        isInside: function(x, y, box) {
            /// <summary>Checks whatever a given point is inside a given box.</summary>
            /// <param name="x" type="number">Cursor position on the x-axis.</param>
            /// <param name="y" type="number">Cursor position on the y-axis.</param>
            /// <param name="box" type="goog.math.Box">Box to check position against.</param>
            /// <returns type="boolean">Whether the given point is inside {@code box}.</returns>
        }, 
        
        getScrollPos: function() {
            /// <summary>Gets the scroll distance as a coordinate object, using
            /// the window of the current drag element&apos;s dom.</summary>
            /// <returns type="goog.math.Coordinate">Object with scroll offsets &apos;x&apos; and &apos;y&apos;.</returns>
        }, 
        
        getEventPosition: function(event) {
            /// <summary>Get the position of a drag event.</summary>
            /// <param name="event" type="goog.fx.DragEvent">Drag event.</param>
            /// <returns type="goog.math.Coordinate">Position of the event.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fx.AbstractDragDrop";
})(this);
