
/* vsdoc for goog.fx.Animation */

(function (window) {
    window.goog.fx = window.goog.fx || {};

    window.goog.fx.Animation = function(start, end, duration, opt_acc){
        /// <summary></summary>
        /// <param name="start" type="Array.number">Array for start coordinates.</param>
        /// <param name="end" type="Array.number">Array for end coordinates.</param>
        /// <param name="duration" type="number">Length of animation in milliseconds.</param>
        /// <param name="opt_acc" type="Function=">Acceleration function, returns 0-1 for inputs 0-1.</param>
        /// <field name="startPoint" type="Array.<number>">Start point.</field>
        /// <field name="endPoint" type="Array.<number>">End point.</field>
        /// <field name="duration" type="number">Duration of animation in milliseconds.</field>
        /// <field name="coords" type="Array.<number>">Current coordinate for animation.</field>
        /// <field name="EventType" type="">Events fired by the animation.</field>
        /// <field name="TIMEOUT" type=""></field>
        /// <field name="State" type="">Enum for the possible states of an animation.</field>
        /// <field name="progress" type="number">Percent of the way through the animation.</field>
        /// <field name="lastFrame" type="?number">Timestamp for when last frame was run.</field>
        /// <returns type="goog.fx.Animation"/>
    };

    var $x = window.goog.fx.Animation;
    $x.prototype = {
                
        enableRightPositioningForRtl: function(useRightPositioningForRtl) {
            /// <summary>Sets whether the animation should use &quot;right&quot; rather than &quot;left&quot; to position
            /// elements.  This is a temporary flag to allow clients to transition
            /// to the new component at their convenience.  At some point &quot;right&quot; will be
            /// used for RTL elements by default.</summary>
            /// <param name="useRightPositioningForRtl" type="boolean">True if &quot;right&quot; should be used for
            ///     positioning, false if &quot;left&quot; should be used for positioning.</param>
        }, 
        
        isRightPositioningForRtlEnabled: function() {
            /// <summary>Whether the animation should use &quot;right&quot; rather than &quot;left&quot; to position
            /// elements.  This is a temporary flag to allow clients to transition
            /// to the new component at their convenience.  At some point &quot;right&quot; will be
            /// used for RTL elements by default.</summary>
            /// <returns type="boolean">True if &quot;right&quot; should be used for positioning, false if
            ///     &quot;left&quot; should be used for positioning.</returns>
        }, 
        
        setAnimationWindow: function(animationWindow) {
            /// <summary></summary>
            /// <param name="animationWindow" type="Window">The window in which to animate elements.</param>
        }, 
        
        play: function(opt_restart) {
            /// <summary>Starts or resumes an animation.</summary>
            /// <param name="opt_restart" type="boolean=">Whether to restart the
            ///     animation from the beginning if it has been paused.</param>
            /// <returns type="boolean">Whether animation was started.</returns>
        }, 
        
        stop: function(opt_gotoEnd) {
            /// <summary>Stops the animation.</summary>
            /// <param name="opt_gotoEnd" type="boolean=">If true the animation will move to the
            ///     end coords.</param>
        }, 
        
        pause: function() {
            /// <summary>Pauses the animation (iff it&apos;s playing).</summary>
        }, 
        
        getProgress: function() {
            /// <summary></summary>
            /// <returns type="number">The current progress of the animation, the number
            ///     is between 0 and 1 inclusive.</returns>
        }, 
        
        setProgress: function(progress) {
            /// <summary>Sets the progress of the animation.</summary>
            /// <param name="progress" type="number">The new progress of the animation.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the animation.  Stops an animation, fires a &apos;destroy&apos; event and
            /// then removes all the event handlers to clean up memory.</summary>
        }, 
        
        destroy: function() {
            /// <summary>Stops an animation, fires a &apos;destroy&apos; event and then removes all the event
            /// handlers to clean up memory.</summary>
        }, 
        
        onAnimationFrame: function(now) {
            /// <summary></summary>
            /// <param name="now" type=""></param>
        }, 
        
        cycle: function(now) {
            /// <summary>Handles the actual iteration of the animation in a timeout</summary>
            /// <param name="now" type="number">The current time.</param>
        }, 
        
        onAnimate: function() {
            /// <summary>Dispatches the ANIMATE event. Sub classes should override this instead
            /// of listening to the event.</summary>
        }, 
        
        onDestroy: function() {
            /// <summary>Dispatches the DESTROY event. Sub classes should override this instead
            /// of listening to the event.</summary>
        }, 
        
        dispatchAnimationEvent: function(type) {
            /// <summary></summary>
            /// <param name="type" type=""></param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fx.Animation";
})(this);
