
/* vsdoc for goog.fx.DragListGroup */

(function (window) {
    window.goog.fx = window.goog.fx || {};

    window.goog.fx.DragListGroup = function(){
        /// <summary></summary>
        /// <field name="EventType" type="Object">Events dispatched by this class.</field>
        /// <returns type="goog.fx.DragListGroup"/>
    };

    var $x = window.goog.fx.DragListGroup;
    $x.prototype = {
                
        setIsCurrDragItemAlwaysDisplayed: function() {
            /// <summary>Sets the property of the currDragItem that it is always displayed in the
            /// list.</summary>
        }, 
        
        setNoUpdateWhileDragging: function() {
            /// <summary>Sets the private property updateWhileDragging_ to false. This disables the
            /// update of the position of the currDragItem while dragging. It will only be
            /// placed to its new location once the drag ends.</summary>
        }, 
        
        setHysteresis: function(distance) {
            /// <summary>Sets the distance the user has to drag the element before a drag operation
            /// is started.</summary>
            /// <param name="distance" type="number">The number of pixels after which a mousedown and
            ///     move is considered a drag.</param>
        }, 
        
        getHysteresis: function() {
            /// <summary></summary>
            /// <returns type="number">distance The number of pixels after which a mousedown and
            ///     move is considered a drag.</returns>
        }, 
        
        addDragList: function(dragListElement, growthDirection, opt_unused, opt_dragHoverClass) {
            /// <summary>Adds a drag list to this DragListGroup.
            /// All calls to this method must happen before the call to init().
            /// Remember that all child nodes (except text nodes) will be made draggable to
            /// any other drag list in this group.</summary>
            /// <param name="dragListElement" type="Element">Must be a container for a list of items
            ///     that should all be made draggable.</param>
            /// <param name="growthDirection" type="goog.fx.DragListDirection">The direction that this
            ///     drag list grows in (i.e. if an item is appended to the DOM, the list&apos;s
            ///     bounding box expands in this direction).</param>
            /// <param name="opt_unused" type="boolean=">Unused argument.</param>
            /// <param name="opt_dragHoverClass" type="string=">CSS class to apply to this drag list when
            ///     the draggerEl hovers over it during a drag action.</param>
        }, 
        
        setFunctionToGetHandleForDragItem: function(getHandleForDragItemFn) {
            /// <summary>Sets a user-supplied function used to get the &quot;handle&quot; element for a drag
            /// item. The function must accept exactly one argument. The argument may be
            /// any drag item element.
            /// 
            /// If not set, the default implementation uses the whole drag item as the
            /// handle.</summary>
            /// <param name="getHandleForDragItemFn" type="function(Element): Element">A function that,
            ///     given any drag item, returns a reference to its &quot;handle&quot; element
            ///     (which may be the drag item element itself).</param>
        }, 
        
        setDragItemHoverClass: function(var_args) {
            /// <summary>Sets a user-supplied CSS class to add to a drag item on hover (not during a
            /// drag action).</summary>
            /// <param name="var_args" type="...!string">The CSS class or classes.</param>
        }, 
        
        setDragItemHandleHoverClass: function(var_args) {
            /// <summary>Sets a user-supplied CSS class to add to a drag item handle on hover (not
            /// during a drag action).</summary>
            /// <param name="var_args" type="...!string">The CSS class or classes.</param>
        }, 
        
        setCurrDragItemClass: function(var_args) {
            /// <summary>Sets a user-supplied CSS class to add to the current drag item (during a
            /// drag action).
            /// 
            /// If not set, the default behavior adds visibility:hidden to the current drag
            /// item so that it is a block of empty space in the hover drag list (if any).
            /// If this class is set by the user, then the default behavior does not happen
            /// (unless, of course, the class also contains visibility:hidden).</summary>
            /// <param name="var_args" type="...!string">The CSS class or classes.</param>
        }, 
        
        setDraggerElClass: function(draggerElClass) {
            /// <summary>Sets a user-supplied CSS class to add to the clone of the current drag item
            /// that&apos;s actually being dragged around (during a drag action).</summary>
            /// <param name="draggerElClass" type="string">The CSS class.</param>
        }, 
        
        init: function() {
            /// <summary>Performs the initial setup to make all items in all lists draggable.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        updateCurrHoverItem: function(hoverNextItem, opt_draggerElCenter) {
            /// <summary>Updates the value of currHoverItem_.
            /// 
            /// This method is used for insertion only when updateWhileDragging_ is false.
            /// The below implementation is the basic one. This method can be extended by
            /// a subclass to support changes to hovered item (eg: highlighting). Parametr
            /// opt_draggerElCenter can be used for more sophisticated effects.</summary>
            /// <param name="hoverNextItem" type="Element">element of the list that is hovered over.</param>
            /// <param name="opt_draggerElCenter" type="goog.math.Coordinate=">current position of
            ///     the dragged element.</param>
        }, 
        
        insertCurrHoverItem: function() {
            /// <summary>Inserts the currently dragged item in its new place.
            /// 
            /// This method is used for insertion only when updateWhileDragging_ is false
            /// (otherwise there is no need for that). In the basic implementation
            /// the element is inserted before the currently hovered over item (this can
            /// be changed by overriding the method in subclasses).</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fx.DragListGroup";
})(this);
