
/* vsdoc for goog.fx.DragScrollSupport */

(function (window) {
    window.goog.fx = window.goog.fx || {};

    window.goog.fx.DragScrollSupport = function(containerNode, opt_margin, opt_externalMouseMoveTracking){
        /// <summary></summary>
        /// <param name="containerNode" type="Element">A container that can be scrolled.</param>
        /// <param name="opt_margin" type="number=">Optional margin to use while scrolling.</param>
        /// <param name="opt_externalMouseMoveTracking" type="boolean=">Whether mouse move events
        ///     are tracked externally by the client object which calls the mouse move
        ///     event handler, useful when events are generated for more than one source
        ///     element and/or are not real mousemove events.</param>
        /// <field name="MARGIN" type="number">The suggested scrolling margin.</field>
        /// <returns type="goog.fx.DragScrollSupport"/>
    };

    var $x = window.goog.fx.DragScrollSupport;
    $x.prototype = {
                
        setConstrainScroll: function(constrain) {
            /// <summary>Sets whether scrolling should be constrained to happen only when the cursor
            /// is inside the container node.
            /// NOTE: If a margin is not set, then it does not make sense to
            /// contain the scroll, because in that case scroll will never be triggered.</summary>
            /// <param name="constrain" type="boolean">Whether scrolling should be constrained to happen
            ///     only when the cursor is inside the container node.</param>
        }, 
        
        setHorizontalScrolling: function(scrolling) {
            /// <summary>Sets whether horizontal scrolling is allowed.</summary>
            /// <param name="scrolling" type="boolean">Whether horizontal scrolling is allowed.</param>
        }, 
        
        onMouseMove: function(event) {
            /// <summary>Handler for mouse moves events.</summary>
            /// <param name="event" type="goog.events.Event">Mouse move event.</param>
        }, 
        
        calculateScrollDelta: function(coordinate, min, rangeLength) {
            /// <summary>Calculates scroll delta.</summary>
            /// <param name="coordinate" type="number">Current mouse pointer coordinate.</param>
            /// <param name="min" type="number">The coordinate value below which scrolling up should be
            ///     started.</param>
            /// <param name="rangeLength" type="number">The length of the range in which scrolling should
            ///     be disabled and above which scrolling down should be started.</param>
            /// <returns type="number">The calculated scroll delta.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fx.DragScrollSupport";
})(this);
