
/* vsdoc for goog.fx.Dragger */

(function (window) {
    window.goog.fx = window.goog.fx || {};

    window.goog.fx.Dragger = function(target, opt_handle, opt_limits){
        /// <summary></summary>
        /// <param name="target" type="Element">The element that will be dragged.</param>
        /// <param name="opt_handle" type="Element=">An optional handle to control the drag, if null
        ///     the target is used.</param>
        /// <param name="opt_limits" type="goog.math.Rect=">Object containing left, top, width,
        ///     and height.</param>
        /// <field name="EventType" type="">Constants for event names.</field>
        /// <field name="clientX" type="number">Current x position of mouse or touch relative to viewport.</field>
        /// <field name="clientY" type="number">Current y position of mouse or touch relative to viewport.</field>
        /// <field name="screenX" type="number">Current x position of mouse or touch relative to screen. Deprecated because
        /// it doesn&apos;t take into affect zoom level or pixel density.</field>
        /// <field name="screenY" type="number">Current y position of mouse or touch relative to screen. Deprecated because
        /// it doesn&apos;t take into affect zoom level or pixel density.</field>
        /// <field name="startX" type="number">The x position where the first mousedown or touchstart occurred.</field>
        /// <field name="startY" type="number">The y position where the first mousedown or touchstart occurred.</field>
        /// <field name="deltaX" type="number">Current x position of drag relative to target&apos;s parent.</field>
        /// <field name="deltaY" type="number">Current y position of drag relative to target&apos;s parent.</field>
        /// <returns type="goog.fx.Dragger"/>
    };

    var $x = window.goog.fx.Dragger;
    $x.prototype = {
                
        enableRightPositioningForRtl: function(useRightPositioningForRtl) {
            /// <summary>Turns on/off true RTL behavior.  This should be called immediately after
            /// construction.  This is a temporary flag to allow clients to transition
            /// to the new component at their convenience.  At some point true will be the
            /// default.</summary>
            /// <param name="useRightPositioningForRtl" type="boolean">True if &quot;right&quot; should be used for
            ///     positioning, false if &quot;left&quot; should be used for positioning.</param>
        }, 
        
        getHandler: function() {
            /// <summary>Returns the event handler, intended for subclass use.</summary>
            /// <returns type="goog.events.EventHandler">The event handler.</returns>
        }, 
        
        setLimits: function(limits) {
            /// <summary>Sets (or reset) the Drag limits after a Dragger is created.</summary>
            /// <param name="limits" type="goog.math.Rect?">Object containing left, top, width,
            ///     height for new Dragger limits. If target is right-to-left and
            ///     enableRightPositioningForRtl(true) is called, then rect is interpreted as
            ///     right, top, width, and height.</param>
        }, 
        
        setHysteresis: function(distance) {
            /// <summary>Sets the distance the user has to drag the element before a drag operation is
            /// started.</summary>
            /// <param name="distance" type="number">The number of pixels after which a mousedown and
            ///     move is considered a drag.</param>
        }, 
        
        getHysteresis: function() {
            /// <summary>Gets the distance the user has to drag the element before a drag operation is
            /// started.</summary>
            /// <returns type="number">distance The number of pixels after which a mousedown and
            ///     move is considered a drag.</returns>
        }, 
        
        setScrollTarget: function(scrollTarget) {
            /// <summary>Sets the SCROLL event target to make drag element follow scrolling.</summary>
            /// <param name="scrollTarget" type="EventTarget">The event target that dispatches SCROLL
            ///     events.</param>
        }, 
        
        setCancelIeDragStart: function(cancelIeDragStart) {
            /// <summary>Enables cancelling of built-in IE drag events.</summary>
            /// <param name="cancelIeDragStart" type="boolean">Whether to enable cancelling of IE
            ///     dragstart event.</param>
        }, 
        
        getEnabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the dragger is enabled.</returns>
        }, 
        
        setEnabled: function(enabled) {
            /// <summary>Set whether dragger is enabled</summary>
            /// <param name="enabled" type="boolean">Whether dragger is enabled.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        startDrag: function(e) {
            /// <summary>Event handler that is used to start the drag</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        setupDragHandlers: function() {
            /// <summary>Sets up event handlers when dragging starts.</summary>
        }, 
        
        endDrag: function(e, opt_dragCanceled) {
            /// <summary>Event handler that is used to end the drag.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Event object.</param>
            /// <param name="opt_dragCanceled" type="boolean=">Whether the drag has been canceled.</param>
        }, 
        
        endDragCancel: function(e) {
            /// <summary>Event handler that is used to end the drag by cancelling it.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        doDrag: function(e, x, y, dragFromScroll) {
            /// <summary></summary>
            /// <param name="e" type="goog.events.BrowserEvent">The closure object
            ///     representing the browser event that caused a drag event.</param>
            /// <param name="x" type="number">The new horizontal position for the drag element.</param>
            /// <param name="y" type="number">The new vertical position for the drag element.</param>
            /// <param name="dragFromScroll" type="boolean">Whether dragging was caused by scrolling
            ///     the associated scroll target.</param>
        }, 
        
        limitX: function(x) {
            /// <summary>Returns the &apos;real&apos; x after limits are applied (allows for some
            /// limits to be undefined).</summary>
            /// <param name="x" type="number">X-coordinate to limit.</param>
            /// <returns type="number">The &apos;real&apos; X-coordinate after limits are applied.</returns>
        }, 
        
        limitY: function(y) {
            /// <summary>Returns the &apos;real&apos; y after limits are applied (allows for some
            /// limits to be undefined).</summary>
            /// <param name="y" type="number">Y-coordinate to limit.</param>
            /// <returns type="number">The &apos;real&apos; Y-coordinate after limits are applied.</returns>
        }, 
        
        defaultAction: function(x, y) {
            /// <summary>Overridable function for handling the default action of the drag behaviour.
            /// Normally this is simply moving the element to x,y though in some cases it
            /// might be used to resize the layer.  This is basically a shortcut to
            /// implementing a default ondrag event handler.</summary>
            /// <param name="x" type="number">X-coordinate for target element. In right-to-left, x this
            ///     is the number of pixels the target should be moved to from the right.</param>
            /// <param name="y" type="number">Y-coordinate for target element.</param>
        }, 
        
        isDragging: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the dragger is currently in the midst of a drag.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.fx.Dragger";
})(this);
