
/* vsdoc for goog.gears.BaseStore */

(function (window) {
    window.goog.gears = window.goog.gears || {};

    window.goog.gears.BaseStore = function(database){
        /// <summary></summary>
        /// <param name="database" type="goog.gears.Database">The data base to store the data in.</param>
        /// <field name="SchemaType" type="">Schema definition types</field>
        /// <field name="name" type="string">The name of the store. Subclasses should override and choose their own
        /// name. That name is used for the maintaining the version string</field>
        /// <field name="version" type="number">The version number of the database schema. It is used to determine whether
        /// the store&apos;s portion of the database needs to be updated. Subclassses should
        /// override this value.</field>
        /// <field name="schema" type="Array.<Object>">The database schema for the store. This is an array of objects, where each
        /// object describes a database object (table, index, trigger). Documentation
        /// about the object&apos;s fields can be found in the #createSchema documentation.
        /// This is in the prototype so that it can be overriden by the subclass. This
        /// field is read only.</field>
        /// <returns type="goog.gears.BaseStore"/>
    };

    var $x = window.goog.gears.BaseStore;
    $x.prototype = {
                
        getDatabaseInternal: function() {
            /// <summary>Gets the underlying database.</summary>
            /// <returns type="goog.gears.Database"></returns>
        }, 
        
        updateStore: function(persistedVersion) {
            /// <summary>Updates the tables for the message store in the case where
            /// they are out of date.</summary>
            /// <param name="persistedVersion" type="number">the current version of the tables in the
            /// database.</param>
        }, 
        
        loadData: function() {
            /// <summary>Preloads any applicable data into the tables.</summary>
        }, 
        
        getCachedData: function() {
            /// <summary>Creates in memory cache of data that is stored in the tables.</summary>
        }, 
        
        informOtherStores: function() {
            /// <summary>Informs other stores that this store exists .</summary>
        }, 
        
        ensureStoreExists: function() {
            /// <summary>Makes sure that tables needed for the store exist and are up to date.</summary>
        }, 
        
        removeStore: function() {
            /// <summary>Removes the tables for the MessageStore</summary>
        }, 
        
        getName: function() {
            /// <summary>Returns the name of the store.</summary>
            /// <returns type="string">The name of the store.</returns>
        }, 
        
        getStoreVersion: function() {
            /// <summary>Returns the version number for the specified store</summary>
            /// <returns type="number">The version number of the store. Returns 0 if the
            ///     store does not exist.</returns>
        }, 
        
        removeStoreVersion: function() {
            /// <summary>Removes the version number for the specified store</summary>
        }, 
        
        createSchema: function(defs, opt_ifNotExists) {
            /// <summary>Creates tables and indicies in the target database.</summary>
            /// <param name="defs" type="Array">definition arrays. This is an array of objects
            ///    where each object describes a database object to create and drop.
            ///    each object contains a &apos;type&apos; field which of type
            ///    goog.gears.BaseStore.SchemaType. Each object also contains a
            ///    &apos;name&apos; which contains the name of the object to create.
            ///    A table object contains a &apos;columns&apos; field which is an array
            ///       that contains the column definitions for the table.
            ///    A virtual table object contains c &apos;columns&apos; field which contains
            ///       the name of the columns. They are assumed to be of type text.
            ///    An index object contains a &apos;tableName&apos; field which is the name
            ///       of the table that the index is on. It contains an &apos;isUnique&apos;
            ///       field which is a boolean indicating whether the index is
            ///       unqiue or not. It also contains a &apos;columns&apos; field which is
            ///       an array that contains the columns names (possibly along with the
            ///       ordering) that form the index.
            ///    The trigger objects contain a &apos;tableName&apos; field indicating the
            ///       table the trigger is on. The type indicates the type of trigger.
            ///       The trigger object may include a &apos;when&apos; field which contains
            ///       the when clause for the trigger. The trigger object also contains
            ///       an &apos;actions&apos; field which is an array of strings containing
            ///       the actions for this trigger.</param>
            /// <param name="opt_ifNotExists" type="boolean=">true if the table or index should be
            ///     created only if it does not exist. Otherwise trying to create a table
            ///     or index that already exists will result in an exception being thrown.</param>
        }, 
        
        dropSchema: function(defs) {
            /// <summary>Drops tables and indicies in a target database.</summary>
            /// <param name="defs" type="Array">Definition arrays.</param>
        }, 
        
        createTriggers: function(defs) {
            /// <summary>Creates triggers specified in definitions. Will first attempt
            /// to drop the trigger with this name first.</summary>
            /// <param name="defs" type="Array">Definition arrays.</param>
        }, 
        
        hasTable: function(name) {
            /// <summary>Returns true if the table exists in the database</summary>
            /// <param name="name" type="string">The table name.</param>
            /// <returns type="boolean">Whether the table exists in the database.</returns>
        }, 
        
        hasIndex: function(name) {
            /// <summary>Returns true if the index exists in the database</summary>
            /// <param name="name" type="string">The index name.</param>
            /// <returns type="boolean">Whether the index exists in the database.</returns>
        }, 
        
        hasTrigger: function(name) {
            /// <summary></summary>
            /// <param name="name" type="string">The name of the trigger.</param>
            /// <returns type="boolean">Whether the schema contains a trigger with the given name.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.gears.BaseStore";
})(this);
