
/* vsdoc for goog.gears.Database */

(function (window) {
    window.goog.gears = window.goog.gears || {};

    window.goog.gears.Database = function(userId, appName){
        /// <summary></summary>
        /// <param name="userId" type="string">the id token for this user.</param>
        /// <param name="appName" type="string">the name of the application creating this database.</param>
        /// <field name="EventType" type="">Constants for transaction event names.</field>
        /// <returns type="goog.gears.Database"/>
    };

    var $x = window.goog.gears.Database;
    $x.prototype = {
                
        resultSetToArrays: function(rs) {
            /// <summary>Returns an array of arrays, where each sub array contains the selected
            /// values for each row in the result set.
            /// result values</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="Array">An array of arrays. Returns an empty array if
            ///                  there are no matching rows.</returns>
        }, 
        
        resultSetToObjectArray: function(rs) {
            /// <summary>Returns a array of hash objects, one per row in the result set,
            /// where the column names in the query are used as the members of
            /// the object.</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="Array.Object">An array containing hashes. Returns an empty
            ///     array if there are no matching rows.</returns>
        }, 
        
        resultSetToValueArray: function(rs) {
            /// <summary>Returns an array containing the first item of each row in a result set.
            /// This is useful for query that returns one column</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="Array.Object">An array containing the values in the first column
            ///                     Returns an empty array if there are no matching rows.</returns>
        }, 
        
        resultSetToValue: function(rs) {
            /// <summary>Returns a single value from the results (first column in first row).</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="(number|string|null)">The first item in the first row of the
            ///     result set. Returns null if there are no matching rows.</returns>
        }, 
        
        resultSetToObject: function(rs) {
            /// <summary>Returns a single hashed object from the result set (the first row),
            /// where the column names in the query are used as the members of
            /// the object.</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="Object">a hash map with the key-value-pairs from the first row.
            ///     Returns null is there are no matching rows.</returns>
        }, 
        
        resultSetToArray: function(rs) {
            /// <summary>Returns an array of the first row in the result set</summary>
            /// <param name="rs" type="GearsResultSet">the result set returned by execute.</param>
            /// <returns type="Array">An array containing the values in the
            ///     first result set. Returns an empty array if there no
            ///     matching rows.</returns>
        }, 
        
        execute: function(sql, var_args) {
            /// <summary>Execute a sql statement with a set of arguments</summary>
            /// <param name="sql" type="string">The sql statement to execute.</param>
            /// <param name="var_args" type="...*">The arguments to execute, either as a single
            /// array argument or as var_args.</param>
            /// <returns type="GearsResultSet">The results.</returns>
        }, 
        
        queryArrays: function(sql, var_args) {
            /// <summary>This calls query on the database and builds a two dimensional array
            /// containing the result.</summary>
            /// <param name="sql" type="string">The SQL statement.</param>
            /// <param name="var_args" type="...*">Query params. An array or multiple arguments.</param>
            /// <returns type="Array">An array of arrays containing the results of the query.</returns>
        }, 
        
        queryObjectArray: function(sql, var_args) {
            /// <summary>This calls query on the database and builds an array containing hashes</summary>
            /// <param name="sql" type="string">Ths SQL statement.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
            /// <returns type="Array">An array of hashes containing the results of the query.</returns>
        }, 
        
        queryValueArray: function(sql, var_args) {
            /// <summary>This calls query on the database and returns an array containing the values
            /// in the first column. This is useful if the result set only contains one
            /// column.</summary>
            /// <param name="sql" type="string">SQL statement.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
            /// <returns type="Array">The values in the first column.</returns>
        }, 
        
        queryValue: function(sql, var_args) {
            /// <summary>This calls query on the database and returns the first value in the first
            /// row.</summary>
            /// <param name="sql" type="string">SQL statement.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
            /// <returns type="(number|string|null)">The first value in
            ///     the first row.</returns>
        }, 
        
        queryObject: function(sql, var_args) {
            /// <summary>This calls query on the database and returns the first row as a hash map
            /// where the keys are the column names.</summary>
            /// <param name="sql" type="string">SQL statement.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
            /// <returns type="Object">The first row as a hash map.</returns>
        }, 
        
        queryArray: function(sql, var_args) {
            /// <summary>This calls query on the database and returns the first row as an array</summary>
            /// <param name="sql" type="string">SQL statement.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
            /// <returns type="Array">The first row as an array.</returns>
        }, 
        
        forEachValue: function(sql, f, opt_this, var_args) {
            /// <summary>For each value in the result set f will be called with the following
            /// parameters; value, rowIndex, columnIndex, columnName. Values will continue
            /// being processed as long as f returns true.</summary>
            /// <param name="sql" type="string">The SQL statement to execute.</param>
            /// <param name="f" type="Function">Function to call for each value.</param>
            /// <param name="opt_this" type="Object=">If present f will be called using this object as
            ///                          &apos;this&apos;.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
        }, 
        
        forEachRow: function(sql, f, opt_this, var_args) {
            /// <summary>For each row in the result set f will be called with the following
            /// parameters: row (array of values), rowIndex and columnNames.  Rows will
            /// continue being processed as long as f returns true.</summary>
            /// <param name="sql" type="string">The SQL statement to execute.</param>
            /// <param name="f" type="Function">Function to call for each row.</param>
            /// <param name="opt_this" type="Object=">If present f will be called using this
            ///                          object as &apos;this&apos;.</param>
            /// <param name="var_args" type="...*">query params. An array or multiple arguments.</param>
        }, 
        
        transact: function(func) {
            /// <summary>Executes a function transactionally.</summary>
            /// <param name="func" type="Function">the function to execute transactionally.
            /// Takes no params.</param>
            /// <returns type="Object|number|boolean|string|null|undefined">the return value
            ///     of &apos;func()&apos;.</returns>
        }, 
        
        setUseTransactions: function(b) {
            /// <summary>Whether transactions are used for the database</summary>
            /// <param name="b" type="boolean">Whether to use transactions or not.</param>
        }, 
        
        getUseTransactions: function() {
            /// <summary>Whether transactions are used for the database</summary>
            /// <returns type="boolean">true if transactions should be used.</returns>
        }, 
        
        setDefaultBeginType: function(beginType) {
            /// <summary>Sets the default begin type.</summary>
            /// <param name="beginType" type="string">The default begin type.</param>
        }, 
        
        begin: function() {
            /// <summary>Marks the beginning of a database transaction using the default begin
            /// type. Does a real BEGIN operation if useTransactions is true for this
            /// database and this is the first opened transaction. This will throw
            /// an exception if this is a nested begin and is trying to elevate the
            /// begin type from the original BEGIN that was processed.</summary>
            /// <returns type="boolean">true if the BEGIN has been executed.</returns>
        }, 
        
        beginDeferred: function() {
            /// <summary>Marks the beginning of a deferred database transaction.
            /// Does a real BEGIN operation if useTransactions is true for this
            /// database and this is the first opened transaction.</summary>
            /// <returns type="boolean">true if the BEGIN has been executed.</returns>
        }, 
        
        beginImmediate: function() {
            /// <summary>Marks the beginning of an immediate database transaction.
            /// Does a real BEGIN operation if useTransactions is true for this
            /// database and this is the first opened transaction. This will throw
            /// an exception if this is a nested begin and is trying to elevate the
            /// begin type from the original BEGIN that was processed.</summary>
            /// <returns type="boolean">true if the BEGIN has been executed.</returns>
        }, 
        
        beginExclusive: function() {
            /// <summary>Marks the beginning of an exclusive database transaction.
            /// Does a real BEGIN operation if useTransactions is true for this
            /// database and this is the first opened transaction. This will throw
            /// an exception if this is a nested begin and is trying to elevate the
            /// begin type from the original BEGIN that was processed.</summary>
            /// <returns type="boolean">true if the BEGIN has been executed.</returns>
        }, 
        
        commit: function() {
            /// <summary>Marks the end of a successful transaction. Will do a real COMMIT
            /// if this the last outstanding transaction unless a nested transaction
            /// was closed with a ROLLBACK in which case a real ROLLBACK will be performed.</summary>
            /// <returns type="boolean">true if the COMMIT has been executed.</returns>
        }, 
        
        rollback: function(opt_e) {
            /// <summary>Marks the end of an unsuccessful transaction. Will do a real ROLLBACK
            /// if this the last outstanding transaction, otherwise the real ROLLBACK will
            /// be deferred until the last outstanding transaction is closed.</summary>
            /// <param name="opt_e" type="Error=">the exception that caused this rollback. If it
            ///                          is provided then that exception is rethown if
            ///                          the rollback does not take place.</param>
            /// <returns type="boolean">true if the ROLLBACK has been executed or if we are not
            ///                   using transactions.</returns>
        }, 
        
        isInTransaction: function() {
            /// <summary>Returns whether or not we&apos;re in a transaction.</summary>
            /// <returns type="boolean">true if a transaction has been started and is not yet
            ///                   complete.</returns>
        }, 
        
        ensureNoTransaction: function(opt_logMsgPrefix) {
            /// <summary>Ensures there is no open transaction upon return. An existing open
            /// transaction is rolled back.</summary>
            /// <param name="opt_logMsgPrefix" type="string=">a prefix to the message that is logged when
            ///     an unexpected open transaction is found.</param>
        }, 
        
        needsRollback: function() {
            /// <summary>Returns whether or not the current transaction has a pending rollback.
            /// Returns false if there is no current transaction.</summary>
            /// <returns type="boolean">Whether a started transaction has a rollback pending.</returns>
        }, 
        
        getExecutionTime: function() {
            /// <summary>Returns the time in Ms that database operations have currently
            /// consumed. This only exists in debug builds, but it still may be useful
            /// for goog.gears.Trace.</summary>
            /// <returns type="number">The time in Ms that database operations have currently
            ///     consumed.</returns>
        }, 
        
        getLastInsertRowId: function() {
            /// <summary></summary>
            /// <returns type="number">The id of the last inserted row.</returns>
        }, 
        
        open: function() {
            /// <summary>Opens the database.</summary>
        }, 
        
        close: function() {
            /// <summary>Closes the database.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        isLockedException: function(ex) {
            /// <summary>Determines if the exception is a locking error.</summary>
            /// <param name="ex" type="Error|string">The exception object or error string.</param>
            /// <returns type="boolean">Whether this is a database locked exception.</returns>
        }, 
        
        remove: function() {
            /// <summary>Removes the database.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.gears.Database";
})(this);
