
/* vsdoc for goog.gears.ManagedResourceStore */

(function (window) {
    window.goog.gears = window.goog.gears || {};

    window.goog.gears.ManagedResourceStore = function(name, requiredCookie, opt_localServer){
        /// <summary></summary>
        /// <param name="name" type="string">The name of the managed store.</param>
        /// <param name="requiredCookie" type="?string">A cookie that must be present for the
        ///     managed store to be active. Should have the form &quot;foo=bar&quot;. Can be null
        ///     if not required.</param>
        /// <param name="opt_localServer" type="GearsLocalServer=">Gears local server -- if not set,
        ///     create a new one internally.</param>
        /// <field name="UPDATE_INTERVAL_MS" type="number">The amount of time between status checks during an update</field>
        /// <field name="UpdateStatus" type="">Enum for possible values of Gears ManagedResourceStore.updatedStatus</field>
        /// <field name="EventType" type="">Enum for event types fired by ManagedResourceStore.</field>
        /// <returns type="goog.gears.ManagedResourceStore"/>
    };

    var $x = window.goog.gears.ManagedResourceStore;
    $x.prototype = {
                
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether there is an active request.</returns>
        }, 
        
        isComplete: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the update has completed.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the update completed with a success.</returns>
        }, 
        
        getFilesTotal: function() {
            /// <summary>Number of total files to load.  This is always 1 if the Gears version does
            /// not support progress events.  If the Gears version supports progress events
            /// this will reflect the number of files that needs to be loaded.</summary>
            /// <returns type="number">The number of files to load.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>Get the last error message.</summary>
            /// <returns type="string">Last error message.</returns>
        }, 
        
        getFilesComplete: function() {
            /// <summary>Number of files completed.  This is 0 or 1 if the Gears version does not
            /// support progress events.  If the Gears version supports progress events
            /// this will reflect the number of files that have been completed.</summary>
            /// <returns type="number">The number of completed files.</returns>
        }, 
        
        exists: function() {
            /// <summary>Determine if the ManagedResourceStore has been created in Gears yet</summary>
            /// <returns type="boolean">true if it has been created.</returns>
        }, 
        
        create: function(opt_manifestUrl) {
            /// <summary>Create the ManagedResourceStore in gears</summary>
            /// <param name="opt_manifestUrl" type="string=">The url of the manifest to associate.</param>
        }, 
        
        update: function() {
            /// <summary>Starts an asynchronous process to update the ManagedResourcStore</summary>
        }, 
        
        getManifestUrl: function() {
            /// <summary></summary>
            /// <returns type="string">Store&apos;s current manifest URL.</returns>
        }, 
        
        setManifestUrl: function(url) {
            /// <summary></summary>
            /// <param name="url" type="string">Store&apos;s new manifest URL.</param>
        }, 
        
        getVersion: function() {
            /// <summary></summary>
            /// <returns type="?string">The version of the managed store that is currently being
            ///     served.</returns>
        }, 
        
        getStatus: function() {
            /// <summary></summary>
            /// <returns type="goog.gears.ManagedResourceStore.UpdateStatus">The current update
            ///     status.</returns>
        }, 
        
        isEnabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the store is currently enabled to serve local
            ///     content.</returns>
        }, 
        
        setEnabled: function(isEnabled) {
            /// <summary>Sets whether the store is currently enabled to serve local content.</summary>
            /// <param name="isEnabled" type="boolean">True if the store is enabled and false otherwise.</param>
        }, 
        
        remove: function() {
            /// <summary>Remove managed store.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.gears.ManagedResourceStore";
})(this);
