
/* vsdoc for goog.graphics.AbstractGraphics */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.AbstractGraphics = function(width, height, opt_coordWidth, opt_coordHeight, opt_domHelper){
        /// <summary></summary>
        /// <param name="width" type="number|string">The width in pixels or percent.</param>
        /// <param name="height" type="number|string">The height in pixels or percent.</param>
        /// <param name="opt_coordWidth" type="?number=">Optional coordinate system width - if
        ///     omitted or null, defaults to same as width.</param>
        /// <param name="opt_coordHeight" type="?number=">Optional coordinate system height - if
        ///     omitted or null, defaults to same as height.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The DOM helper object for the
        ///     document we want to render in.</param>
        /// <field name="width" type="number|string">Width of graphics in pixels or percentage points.</field>
        /// <field name="height" type="number|string">Height of graphics in pixels or precentage points.</field>
        /// <field name="coordWidth" type="?number">Width of coordinate system in units.</field>
        /// <field name="coordHeight" type="?number">Height of coordinate system in units.</field>
        /// <field name="canvasElement" type="goog.graphics.GroupElement?">The root level group element.</field>
        /// <field name="coordLeft" type="number">Left coordinate of the view box</field>
        /// <field name="coordTop" type="number">Top coordinate of the view box</field>
        /// <field name="setCoordOrigin" type="">Changes the coordinate system position.</field>
        /// <field name="setSize" type="">Change the size of the canvas.</field>
        /// <field name="clear" type="">Remove all drawing elements from the graphics.</field>
        /// <field name="setElementFill" type="">Sets the fill for the given element.</field>
        /// <field name="setElementStroke" type="">Sets the stroke for the given element.</field>
        /// <field name="setElementTransform" type="">Set the transformation of an element.</field>
        /// <field name="drawEllipse" type="goog.graphics.EllipseElement">Draw an ellipse</field>
        /// <field name="drawRect" type="goog.graphics.RectElement">Draw a rectangle</field>
        /// <field name="drawTextOnLine" type="goog.graphics.TextElement">Draw a text string vertically centered on a given line.</field>
        /// <field name="drawPath" type="goog.graphics.PathElement">Draw a path.</field>
        /// <field name="createGroup" type="goog.graphics.GroupElement">Create an empty group of drawing elements.</field>
        /// <field name="getTextWidth" type="number">Measure and return the width (in pixels) of a given text string.
        /// Text measurement is needed to make sure a text can fit in the allocated
        /// area. The way text length is measured is by writing it into a div that is
        /// after the visible area, measure the div width, and immediatly erase the
        /// written value.</field>
        /// <returns type="goog.graphics.AbstractGraphics"/>
    };

    var $x = window.goog.graphics.AbstractGraphics;
    $x.prototype = {
                
        getCanvasElement: function() {
            /// <summary></summary>
            /// <returns type="goog.graphics.GroupElement">The root level canvas element.</returns>
        }, 
        
        setCoordSize: function(coordWidth, coordHeight) {
            /// <summary>Changes the coordinate size.</summary>
            /// <param name="coordWidth" type="number">The coordinate width.</param>
            /// <param name="coordHeight" type="number">The coordinate height.</param>
        }, 
        
        getCoordSize: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Size">The coordinate size.</returns>
        }, 
        
        getCoordOrigin: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Coordinate">The coordinate system position.</returns>
        }, 
        
        getSize: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Size">The size of canvas.</returns>
        }, 
        
        getPixelSize: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Size?">Returns the number of pixels spanned by the
            ///     surface, or null if the size could not be computed due to the size being
            ///     specified in percentage points and the component not being in the
            ///     document.</returns>
        }, 
        
        getPixelScaleX: function() {
            /// <summary></summary>
            /// <returns type="number">Returns the number of pixels per unit in the x direction.</returns>
        }, 
        
        getPixelScaleY: function() {
            /// <summary></summary>
            /// <returns type="number">Returns the number of pixels per unit in the y direction.</returns>
        }, 
        
        removeElement: function(element) {
            /// <summary>Remove a single drawing element from the surface.  The default implementation
            /// assumes a DOM based drawing surface.</summary>
            /// <param name="element" type="goog.graphics.Element">The element to remove.</param>
        }, 
        
        drawCircle: function(cx, cy, r, stroke, fill, opt_group) {
            /// <summary>Draw a circle</summary>
            /// <param name="cx" type="number">Center X coordinate.</param>
            /// <param name="cy" type="number">Center Y coordinate.</param>
            /// <param name="r" type="number">Radius length.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element to
            ///     append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.EllipseElement">The newly created element.</returns>
        }, 
        
        drawText: function(text, x, y, width, height, align, vAlign, font, stroke, fill, opt_group) {
            /// <summary>Draw a text string within a rectangle (drawing is horizontal)</summary>
            /// <param name="text" type="string">The text to draw.</param>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of rectangle.</param>
            /// <param name="height" type="number">Height of rectangle.</param>
            /// <param name="align" type="string">Horizontal alignment: left (default), center, right.</param>
            /// <param name="vAlign" type="string">Vertical alignment: top (default), center, bottom.</param>
            /// <param name="font" type="goog.graphics.Font">Font describing the font properties.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element to
            ///     append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.TextElement">The newly created element.</returns>
        }, 
        
        createPath: function() {
            /// <summary>Create an empty path.</summary>
            /// <returns type="goog.graphics.Path">The path.</returns>
        }, 
        
        isDomClonable: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the underlying element can be cloned resulting in
            ///     an accurate reproduction of the graphics contents.</returns>
        }, 
        
        suspend: function() {
            /// <summary>Start preventing redraws - useful for chaining large numbers of changes
            /// together.  Not guaranteed to do anything - i.e. only use this for
            /// optimization of a single code path.</summary>
        }, 
        
        resume: function() {
            /// <summary>Stop preventing redraws.  If any redraws had been prevented, a redraw will
            /// be done now.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.AbstractGraphics";
})(this);
