
/* vsdoc for goog.graphics.AffineTransform */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.AffineTransform = function(opt_m00, opt_m10, opt_m01, opt_m11, opt_m02, opt_m12){
        /// <summary></summary>
        /// <param name="opt_m00" type="number=">The m00 coordinate of the transform.</param>
        /// <param name="opt_m10" type="number=">The m10 coordinate of the transform.</param>
        /// <param name="opt_m01" type="number=">The m01 coordinate of the transform.</param>
        /// <param name="opt_m11" type="number=">The m11 coordinate of the transform.</param>
        /// <param name="opt_m02" type="number=">The m02 coordinate of the transform.</param>
        /// <param name="opt_m12" type="number=">The m12 coordinate of the transform.</param>
        /// <returns type="goog.graphics.AffineTransform"/>
    };

    var $x = window.goog.graphics.AffineTransform;
    $x.prototype = {
                
        isIdentity: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this transform is the identity transform.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.graphics.AffineTransform">A copy of this transform.</returns>
        }, 
        
        setTransform: function(m00, m10, m01, m11, m02, m12) {
            /// <summary>Sets this transform to the matrix specified by the 6 values.</summary>
            /// <param name="m00" type="number">The m00 coordinate of the transform.</param>
            /// <param name="m10" type="number">The m10 coordinate of the transform.</param>
            /// <param name="m01" type="number">The m01 coordinate of the transform.</param>
            /// <param name="m11" type="number">The m11 coordinate of the transform.</param>
            /// <param name="m02" type="number">The m02 coordinate of the transform.</param>
            /// <param name="m12" type="number">The m12 coordinate of the transform.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        copyFrom: function(tx) {
            /// <summary>Sets this transform to be identical to the given transform.</summary>
            /// <param name="tx" type="!goog.graphics.AffineTransform">The transform to copy.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        scale: function(sx, sy) {
            /// <summary>Concatenates this transform with a scaling transformation.</summary>
            /// <param name="sx" type="number">The x-axis scaling factor.</param>
            /// <param name="sy" type="number">The y-axis scaling factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        preScale: function(sx, sy) {
            /// <summary>Pre-concatenates this transform with a scaling transformation,
            /// i.e. calculates the following matrix product:
            /// 
            /// &lt;pre&gt;
            /// [sx  0 0] [m00 m01 m02]
            /// [ 0 sy 0] [m10 m11 m12]
            /// [ 0  0 1] [  0   0   1]
            /// &lt;/pre&gt;</summary>
            /// <param name="sx" type="number">The x-axis scaling factor.</param>
            /// <param name="sy" type="number">The y-axis scaling factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        translate: function(dx, dy) {
            /// <summary>Concatenates this transform with a translate transformation.</summary>
            /// <param name="dx" type="number">The distance to translate in the x direction.</param>
            /// <param name="dy" type="number">The distance to translate in the y direction.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        preTranslate: function(dx, dy) {
            /// <summary>Pre-concatenates this transform with a translate transformation,
            /// i.e. calculates the following matrix product:
            /// 
            /// &lt;pre&gt;
            /// [1 0 dx] [m00 m01 m02]
            /// [0 1 dy] [m10 m11 m12]
            /// [0 0  1] [  0   0   1]
            /// &lt;/pre&gt;</summary>
            /// <param name="dx" type="number">The distance to translate in the x direction.</param>
            /// <param name="dy" type="number">The distance to translate in the y direction.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        rotate: function(theta, x, y) {
            /// <summary>Concatenates this transform with a rotation transformation around an anchor
            /// point.</summary>
            /// <param name="theta" type="number">The angle of rotation measured in radians.</param>
            /// <param name="x" type="number">The x coordinate of the anchor point.</param>
            /// <param name="y" type="number">The y coordinate of the anchor point.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        preRotate: function(theta, x, y) {
            /// <summary>Pre-concatenates this transform with a rotation transformation around an
            /// anchor point.</summary>
            /// <param name="theta" type="number">The angle of rotation measured in radians.</param>
            /// <param name="x" type="number">The x coordinate of the anchor point.</param>
            /// <param name="y" type="number">The y coordinate of the anchor point.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        shear: function(shx, shy) {
            /// <summary>Concatenates this transform with a shear transformation.</summary>
            /// <param name="shx" type="number">The x shear factor.</param>
            /// <param name="shy" type="number">The y shear factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        preShear: function(shx, shy) {
            /// <summary>Pre-concatenates this transform with a shear transformation.
            /// i.e. calculates the following matrix product:
            /// 
            /// &lt;pre&gt;
            /// [  1 shx 0] [m00 m01 m02]
            /// [shy   1 0] [m10 m11 m12]
            /// [  0   0 1] [  0   0   1]
            /// &lt;/pre&gt;</summary>
            /// <param name="shx" type="number">The x shear factor.</param>
            /// <param name="shy" type="number">The y shear factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        toString: function() {
            /// <summary></summary>
            /// <returns type="string">A string representation of this transform. The format of
            ///     of the string is compatible with SVG matrix notation, i.e.
            ///     &quot;matrix(a,b,c,d,e,f)&quot;.</returns>
        }, 
        
        getScaleX: function() {
            /// <summary></summary>
            /// <returns type="number">The scaling factor in the x-direction (m00).</returns>
        }, 
        
        getScaleY: function() {
            /// <summary></summary>
            /// <returns type="number">The scaling factor in the y-direction (m11).</returns>
        }, 
        
        getTranslateX: function() {
            /// <summary></summary>
            /// <returns type="number">The translation in the x-direction (m02).</returns>
        }, 
        
        getTranslateY: function() {
            /// <summary></summary>
            /// <returns type="number">The translation in the y-direction (m12).</returns>
        }, 
        
        getShearX: function() {
            /// <summary></summary>
            /// <returns type="number">The shear factor in the x-direction (m01).</returns>
        }, 
        
        getShearY: function() {
            /// <summary></summary>
            /// <returns type="number">The shear factor in the y-direction (m10).</returns>
        }, 
        
        concatenate: function(tx) {
            /// <summary>Concatenates an affine transform to this transform.</summary>
            /// <param name="tx" type="!goog.graphics.AffineTransform">The transform to concatenate.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        preConcatenate: function(tx) {
            /// <summary>Pre-concatenates an affine transform to this transform.</summary>
            /// <param name="tx" type="!goog.graphics.AffineTransform">The transform to preconcatenate.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        transform: function(src, srcOff, dst, dstOff, numPts) {
            /// <summary>Transforms an array of coordinates by this transform and stores the result
            /// into a destination array.</summary>
            /// <param name="src" type="!Array.number">The array containing the source points
            ///     as x, y value pairs.</param>
            /// <param name="srcOff" type="number">The offset to the first point to be transformed.</param>
            /// <param name="dst" type="!Array.number">The array into which to store the transformed
            ///     point pairs.</param>
            /// <param name="dstOff" type="number">The offset of the location of the first transformed
            ///     point in the destination array.</param>
            /// <param name="numPts" type="number">The number of points to tranform.</param>
        }, 
        
        getDeterminant: function() {
            /// <summary></summary>
            /// <returns type="number">The determinant of this transform.</returns>
        }, 
        
        isInvertible: function() {
            /// <summary>Returns whether the transform is invertible. A transform is not invertible
            /// if the determinant is 0 or any value is non-finite or NaN.</summary>
            /// <returns type="boolean">Whether the transform is invertible.</returns>
        }, 
        
        createInverse: function() {
            /// <summary></summary>
            /// <returns type="!goog.graphics.AffineTransform">An AffineTransform object
            ///     representing the inverse transformation.</returns>
        }, 
        
        getScaleInstance: function(sx, sy) {
            /// <summary>Creates a transform representing a scaling transformation.</summary>
            /// <param name="sx" type="number">The x-axis scaling factor.</param>
            /// <param name="sy" type="number">The y-axis scaling factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">A transform representing a scaling
            ///     transformation.</returns>
        }, 
        
        getTranslateInstance: function(dx, dy) {
            /// <summary>Creates a transform representing a translation transformation.</summary>
            /// <param name="dx" type="number">The distance to translate in the x direction.</param>
            /// <param name="dy" type="number">The distance to translate in the y direction.</param>
            /// <returns type="!goog.graphics.AffineTransform">A transform representing a
            ///     translation transformation.</returns>
        }, 
        
        getShearInstance: function(shx, shy) {
            /// <summary>Creates a transform representing a shearing transformation.</summary>
            /// <param name="shx" type="number">The x-axis shear factor.</param>
            /// <param name="shy" type="number">The y-axis shear factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">A transform representing a shearing
            ///     transformation.</returns>
        }, 
        
        getRotateInstance: function(theta, x, y) {
            /// <summary>Creates a transform representing a rotation transformation.</summary>
            /// <param name="theta" type="number">The angle of rotation measured in radians.</param>
            /// <param name="x" type="number">The x coordinate of the anchor point.</param>
            /// <param name="y" type="number">The y coordinate of the anchor point.</param>
            /// <returns type="!goog.graphics.AffineTransform">A transform representing a rotation
            ///     transformation.</returns>
        }, 
        
        setToScale: function(sx, sy) {
            /// <summary>Sets this transform to a scaling transformation.</summary>
            /// <param name="sx" type="number">The x-axis scaling factor.</param>
            /// <param name="sy" type="number">The y-axis scaling factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        setToTranslation: function(dx, dy) {
            /// <summary>Sets this transform to a translation transformation.</summary>
            /// <param name="dx" type="number">The distance to translate in the x direction.</param>
            /// <param name="dy" type="number">The distance to translate in the y direction.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        setToShear: function(shx, shy) {
            /// <summary>Sets this transform to a shearing transformation.</summary>
            /// <param name="shx" type="number">The x-axis shear factor.</param>
            /// <param name="shy" type="number">The y-axis shear factor.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        setToRotation: function(theta, x, y) {
            /// <summary>Sets this transform to a rotation transformation.</summary>
            /// <param name="theta" type="number">The angle of rotation measured in radians.</param>
            /// <param name="x" type="number">The x coordinate of the anchor point.</param>
            /// <param name="y" type="number">The y coordinate of the anchor point.</param>
            /// <returns type="!goog.graphics.AffineTransform">This affine transform.</returns>
        }, 
        
        equals: function(tx) {
            /// <summary>Compares two affine transforms for equality.</summary>
            /// <param name="tx" type="goog.graphics.AffineTransform">The other affine transform.</param>
            /// <returns type="boolean">whether the two transforms are equal.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.AffineTransform";
})(this);
