
/* vsdoc for goog.graphics.CanvasGraphics */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.CanvasGraphics = function(width, height, opt_coordWidth, opt_coordHeight, opt_domHelper){
        /// <summary></summary>
        /// <param name="width" type="string|number">The (non-zero) width in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="height" type="string|number">The (non-zero) height in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="opt_coordWidth" type="?number=">The coordinate width - if
        ///     omitted or null, defaults to same as width.</param>
        /// <param name="opt_coordHeight" type="?number=">The coordinate height - if
        ///     omitted or null, defaults to same as height.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The DOM helper object for the
        ///     document we want to render in.</param>
        /// <field name="canvasElement" type="goog.graphics.CanvasGroupElement">The main canvas element.</field>
        /// <field name="getTextWidth" type="">Measure and return the width (in pixels) of a given text string.
        /// Text measurement is needed to make sure a text can fit in the allocated
        /// area. The way text length is measured is by writing it into a div that is
        /// after the visible area, measure the div width, and immediatly erase the
        /// written value.</field>
        /// <returns type="goog.graphics.CanvasGraphics"/>
    };

    var $x = window.goog.graphics.CanvasGraphics;
    $x.prototype = {
                
        setElementFill: function(element, fill) {
            /// <summary>Sets the fill for the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element
            ///     wrapper.</param>
            /// <param name="fill" type="goog.graphics.Fill">The fill object.</param>
        }, 
        
        setElementStroke: function(element, stroke) {
            /// <summary>Sets the stroke for the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element
            ///     wrapper.</param>
            /// <param name="stroke" type="goog.graphics.Stroke">The stroke object.</param>
        }, 
        
        setElementTransform: function(element, x, y, angle, centerX, centerY) {
            /// <summary>Set the transformation of an element.</summary>
            /// <param name="element" type="goog.graphics.Element">The element wrapper.</param>
            /// <param name="x" type="number">The x coordinate of the translation transform.</param>
            /// <param name="y" type="number">The y coordinate of the translation transform.</param>
            /// <param name="angle" type="number">The angle of the rotation transform.</param>
            /// <param name="centerX" type="number">The horizontal center of the rotation transform.</param>
            /// <param name="centerY" type="number">The vertical center of the rotation transform.</param>
        }, 
        
        pushElementTransform: function(element) {
            /// <summary>Push an element transform on to the transform stack.</summary>
            /// <param name="element" type="goog.graphics.Element">The transformed element.</param>
        }, 
        
        popElementTransform: function() {
            /// <summary>Pop an element transform off of the transform stack.</summary>
        }, 
        
        createDom: function() {
            /// <summary>Creates the DOM representation of the graphics area.</summary>
        }, 
        
        getContext: function() {
            /// <summary>Returns the drawing context.</summary>
            /// <returns type="Object">The canvas element rendering context.</returns>
        }, 
        
        setCoordOrigin: function(left, top) {
            /// <summary>Changes the coordinate system position.</summary>
            /// <param name="left" type="number">The coordinate system left bound.</param>
            /// <param name="top" type="number">The coordinate system top bound.</param>
        }, 
        
        setCoordSize: function(coordWidth, coordHeight) {
            /// <summary>Changes the coordinate size.</summary>
            /// <param name="coordWidth" type="number">The coordinate width.</param>
            /// <param name="coordHeight" type="number">The coordinate height.</param>
        }, 
        
        setSize: function(pixelWidth, pixelHeight) {
            /// <summary>Change the size of the canvas.</summary>
            /// <param name="pixelWidth" type="number">The width in pixels.</param>
            /// <param name="pixelHeight" type="number">The height in pixels.</param>
        }, 
        
        getPixelSize: function() {
            /// <summary></summary>
        }, 
        
        updateSize: function() {
            /// <summary>Update the size of the canvas.</summary>
        }, 
        
        reset: function() {
            /// <summary>Reset the canvas.</summary>
        }, 
        
        clear: function() {
            /// <summary>Remove all drawing elements from the graphics.</summary>
        }, 
        
        redraw: function() {
            /// <summary>Redraw the entire canvas.</summary>
        }, 
        
        drawElement: function(element) {
            /// <summary>Draw an element, including any stroke or fill.</summary>
            /// <param name="element" type="goog.graphics.Element">The element to draw.</param>
        }, 
        
        append: function(element, group) {
            /// <summary>Append an element.</summary>
            /// <param name="element" type="goog.graphics.Element">The element to draw.</param>
            /// <param name="group" type="goog.graphics.GroupElement|undefined">The group to draw
            ///     it in. If null or undefined, defaults to the root group.</param>
        }, 
        
        drawEllipse: function(cx, cy, rx, ry, stroke, fill, opt_group) {
            /// <summary>Draw an ellipse.</summary>
            /// <param name="cx" type="number">Center X coordinate.</param>
            /// <param name="cy" type="number">Center Y coordinate.</param>
            /// <param name="rx" type="number">Radius length for the x-axis.</param>
            /// <param name="ry" type="number">Radius length for the y-axis.</param>
            /// <param name="stroke" type="goog.graphics.Stroke">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to.  If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.EllipseElement">The newly created element.</returns>
        }, 
        
        drawRect: function(x, y, width, height, stroke, fill, opt_group) {
            /// <summary>Draw a rectangle.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of rectangle.</param>
            /// <param name="height" type="number">Height of rectangle.</param>
            /// <param name="stroke" type="goog.graphics.Stroke">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.RectElement">The newly created element.</returns>
        }, 
        
        drawImage: function(x, y, width, height, src, opt_group) {
            /// <summary>Draw an image.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of image.</param>
            /// <param name="height" type="number">Height of image.</param>
            /// <param name="src" type="string">Source of the image.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.ImageElement">The newly created element.</returns>
        }, 
        
        drawTextOnLine: function(text, x1, y1, x2, y2, align, font, stroke, fill, opt_group) {
            /// <summary>Draw a text string vertically centered on a given line.</summary>
            /// <param name="text" type="string">The text to draw.</param>
            /// <param name="x1" type="number">X coordinate of start of line.</param>
            /// <param name="y1" type="number">Y coordinate of start of line.</param>
            /// <param name="x2" type="number">X coordinate of end of line.</param>
            /// <param name="y2" type="number">Y coordinate of end of line.</param>
            /// <param name="align" type="?string">Horizontal alignment: left (default), center, right.</param>
            /// <param name="font" type="goog.graphics.Font">Font describing the font properties.</param>
            /// <param name="stroke" type="goog.graphics.Stroke">Stroke object describing the stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.TextElement">The newly created element.</returns>
        }, 
        
        drawPath: function(path, stroke, fill, opt_group) {
            /// <summary>Draw a path.</summary>
            /// <param name="path" type="!goog.graphics.Path">The path object to draw.</param>
            /// <param name="stroke" type="goog.graphics.Stroke">Stroke object describing the stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.PathElement">The newly created element.</returns>
        }, 
        
        isDrawable: function(group) {
            /// <summary></summary>
            /// <param name="group" type="goog.graphics.GroupElement">The group to possibly
            ///     draw to.</param>
            /// <returns type="boolean">Whether drawing can occur now.</returns>
        }, 
        
        isRedrawRequired: function(group) {
            /// <summary>Returns true if drawing to the given group means a redraw is required.</summary>
            /// <param name="group" type="goog.graphics.GroupElement">The group to draw to.</param>
            /// <returns type="boolean">Whether drawing to this group should force a redraw.</returns>
        }, 
        
        createGroup: function(opt_group) {
            /// <summary>Create an empty group of drawing elements.</summary>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper
            ///     element to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.CanvasGroupElement">The newly created group.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the component by removing event handlers, detacing DOM nodes from
            /// the document body, and removing references to them.</summary>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        suspend: function() {
            /// <summary>Start preventing redraws - useful for chaining large numbers of changes
            /// together.  Not guaranteed to do anything - i.e. only use this for
            /// optimization of a single code path.</summary>
        }, 
        
        resume: function() {
            /// <summary>Stop preventing redraws.  If any redraws had been prevented, a redraw will
            /// be done now.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.CanvasGraphics";
})(this);
