
/* vsdoc for goog.graphics.Path */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.Path = function(){
        /// <summary></summary>
        /// <field name="Segment" type="">Path segment types.</field>
        /// <returns type="goog.graphics.Path"/>
    };

    var $x = window.goog.graphics.Path;
    $x.prototype = {
                
        getSegmentCount: function(segment) {
            /// <summary>Returns the number of points for a segment type.</summary>
            /// <param name="segment" type="number">The segment type.</param>
            /// <returns type="number">The number of points.</returns>
        }, 
        
        appendPath: function(path) {
            /// <summary>Appends another path to the end of this path.</summary>
            /// <param name="path" type="!goog.graphics.Path">The path to append.</param>
            /// <returns type="!goog.graphics.Path">This path.</returns>
        }, 
        
        clear: function() {
            /// <summary>Clears the path.</summary>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        moveTo: function(x, y) {
            /// <summary>Adds a point to the path by moving to the specified point. Repeated moveTo
            /// commands are collapsed into a single moveTo.</summary>
            /// <param name="x" type="number">X coordinate of destination point.</param>
            /// <param name="y" type="number">Y coordinate of destination point.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        lineTo: function(var_args) {
            /// <summary>Adds points to the path by drawing a straight line to each point.</summary>
            /// <param name="var_args" type="...number">The coordinates of each destination point as x, y
            ///     value pairs.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        curveTo: function(var_args) {
            /// <summary>Adds points to the path by drawing cubic Bezier curves. Each curve is
            /// specified using 3 points (6 coordinates) - two control points and the end
            /// point of the curve.</summary>
            /// <param name="var_args" type="...number">The coordinates specifiying each curve in sets of
            ///     6 points: {@code [x1, y1]} the first control point, {@code [x2, y2]} the
            ///     second control point and {@code [x, y]} the end point.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        close: function() {
            /// <summary>Adds a path command to close the path by connecting the
            /// last point to the first point.</summary>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        arc: function(cx, cy, rx, ry, fromAngle, extent, connect) {
            /// <summary>Adds a path command to draw an arc centered at the point {@code (cx, cy)}
            /// with radius {@code rx} along the x-axis and {@code ry} along the y-axis from
            /// {@code startAngle} through {@code extent} degrees. Positive rotation is in
            /// the direction from positive x-axis to positive y-axis.</summary>
            /// <param name="cx" type="number">X coordinate of center of ellipse.</param>
            /// <param name="cy" type="number">Y coordinate of center of ellipse.</param>
            /// <param name="rx" type="number">Radius of ellipse on x axis.</param>
            /// <param name="ry" type="number">Radius of ellipse on y axis.</param>
            /// <param name="fromAngle" type="number">Starting angle measured in degrees from the
            ///     positive x-axis.</param>
            /// <param name="extent" type="number">The span of the arc in degrees.</param>
            /// <param name="connect" type="boolean">If true, the starting point of the arc is connected
            ///     to the current point.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        arcTo: function(rx, ry, fromAngle, extent) {
            /// <summary>Adds a path command to draw an arc starting at the path&apos;s current point,
            /// with radius {@code rx} along the x-axis and {@code ry} along the y-axis from
            /// {@code startAngle} through {@code extent} degrees. Positive rotation is in
            /// the direction from positive x-axis to positive y-axis.
            /// 
            /// This method makes the path non-simple.</summary>
            /// <param name="rx" type="number">Radius of ellipse on x axis.</param>
            /// <param name="ry" type="number">Radius of ellipse on y axis.</param>
            /// <param name="fromAngle" type="number">Starting angle measured in degrees from the
            ///     positive x-axis.</param>
            /// <param name="extent" type="number">The span of the arc in degrees.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        arcToAsCurves: function(rx, ry, fromAngle, extent) {
            /// <summary>Same as {@code arcTo}, but approximates the arc using bezier curves.
            /// .* As a result, this method does not affect the simplified status of this path.
            /// The algorithm is adapted from {@code java.awt.geom.ArcIterator}.</summary>
            /// <param name="rx" type="number">Radius of ellipse on x axis.</param>
            /// <param name="ry" type="number">Radius of ellipse on y axis.</param>
            /// <param name="fromAngle" type="number">Starting angle measured in degrees from the
            ///     positive x-axis.</param>
            /// <param name="extent" type="number">The span of the arc in degrees.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        forEachSegment: function(callback) {
            /// <summary>Iterates over the path calling the supplied callback once for each path
            /// segment. The arguments to the callback function are the segment type and
            /// an array of its arguments.
            /// 
            /// The {@code LINETO} and {@code CURVETO} arrays can contain multiple
            /// segments of the same type. The number of segments is the length of the
            /// array divided by the segment length (2 for lines, 6 for  curves).
            /// 
            /// As a convenience the {@code ARCTO} segment also includes the end point as the
            /// last two arguments: {@code rx, ry, fromAngle, extent, x, y}.</summary>
            /// <param name="callback" type="function(number|Array)">The function to call with each
            ///     path segment.</param>
        }, 
        
        getCurrentPoint: function() {
            /// <summary>Returns the coordinates most recently added to the end of the path.</summary>
            /// <returns type="Array.number?">An array containing the ending coordinates of the
            ///     path of the form {@code [x, y]}.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.graphics.Path">A copy of this path.</returns>
        }, 
        
        isSimple: function() {
            /// <summary>Returns true if this path contains no arcs. Simplified paths can be
            /// created using {@code createSimplifiedPath}.</summary>
            /// <returns type="boolean">True if the path contains no arcs.</returns>
        }, 
        
        createSimplifiedPath: function(src) {
            /// <summary>Creates a copy of the given path, replacing {@code arcTo} with
            /// {@code arcToAsCurves}. The resulting path is simplified and can
            /// be transformed.</summary>
            /// <param name="src" type="!goog.graphics.Path">The path to simplify.</param>
            /// <returns type="!goog.graphics.Path">A new simplified path.</returns>
        }, 
        
        createTransformedPath: function(tx) {
            /// <summary>Creates a transformed copy of this path. The path is simplified
            /// {@see #createSimplifiedPath} prior to transformation.</summary>
            /// <param name="tx" type="!goog.graphics.AffineTransform">The transformation to perform.</param>
            /// <returns type="!goog.graphics.Path">A new, transformed path.</returns>
        }, 
        
        transform: function(tx) {
            /// <summary>Transforms the path. Only simple paths are transformable. Attempting
            /// to transform a non-simple path will throw an error.</summary>
            /// <param name="tx" type="!goog.graphics.AffineTransform">The transformation to perform.</param>
            /// <returns type="!goog.graphics.Path">The path itself.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the path is empty.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.Path";
})(this);
