
/* vsdoc for goog.graphics.SvgGraphics */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.SvgGraphics = function(width, height, opt_coordWidth, opt_coordHeight, opt_domHelper){
        /// <summary></summary>
        /// <param name="width" type="string|number">The width in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="height" type="string|number">The height in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="opt_coordWidth" type="?number=">The coordinate width - if
        ///     omitted or null, defaults to same as width.</param>
        /// <param name="opt_coordHeight" type="?number=">The coordinate height - if
        ///     omitted or null, defaults to same as height.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The DOM helper object for the
        ///     document we want to render in.</param>
        /// <returns type="goog.graphics.SvgGraphics"/>
    };

    var $x = window.goog.graphics.SvgGraphics;
    $x.prototype = {
                
        setElementAttributes: function(element, attributes) {
            /// <summary>Sets properties to an SVG element. Used internally and by different
            /// SVG elements.</summary>
            /// <param name="element" type="Element">The svg element.</param>
            /// <param name="attributes" type="Object">Map of name-value pairs for attributes.</param>
        }, 
        
        setElementFill: function(element, fill) {
            /// <summary>Sets the fill of the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element wrapper.</param>
            /// <param name="fill" type="goog.graphics.Fill?">The fill object.</param>
        }, 
        
        setElementStroke: function(element, stroke) {
            /// <summary>Sets the stroke of the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element wrapper.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">The stroke object.</param>
        }, 
        
        setElementTransform: function(element, x, y, angle, centerX, centerY) {
            /// <summary>Set the transformation of an element.</summary>
            /// <param name="element" type="goog.graphics.Element">The element wrapper.</param>
            /// <param name="x" type="number">The x coordinate of the translation transform.</param>
            /// <param name="y" type="number">The y coordinate of the translation transform.</param>
            /// <param name="angle" type="number">The angle of the rotation transform.</param>
            /// <param name="centerX" type="number">The horizontal center of the rotation transform.</param>
            /// <param name="centerY" type="number">The vertical center of the rotation transform.</param>
        }, 
        
        createDom: function() {
            /// <summary>Creates the DOM representation of the graphics area.</summary>
        }, 
        
        setCoordOrigin: function(left, top) {
            /// <summary>Changes the coordinate system position.</summary>
            /// <param name="left" type="number">The coordinate system left bound.</param>
            /// <param name="top" type="number">The coordinate system top bound.</param>
        }, 
        
        setCoordSize: function(coordWidth, coordHeight) {
            /// <summary>Changes the coordinate size.</summary>
            /// <param name="coordWidth" type="number">The coordinate width.</param>
            /// <param name="coordHeight" type="number">The coordinate height.</param>
        }, 
        
        setSize: function(pixelWidth, pixelHeight) {
            /// <summary>Change the size of the canvas.</summary>
            /// <param name="pixelWidth" type="number">The width in pixels.</param>
            /// <param name="pixelHeight" type="number">The height in pixels.</param>
        }, 
        
        getPixelSize: function() {
            /// <summary></summary>
        }, 
        
        clear: function() {
            /// <summary>Remove all drawing elements from the graphics.</summary>
        }, 
        
        drawEllipse: function(cx, cy, rx, ry, stroke, fill, opt_group) {
            /// <summary>Draw an ellipse.</summary>
            /// <param name="cx" type="number">Center X coordinate.</param>
            /// <param name="cy" type="number">Center Y coordinate.</param>
            /// <param name="rx" type="number">Radius length for the x-axis.</param>
            /// <param name="ry" type="number">Radius length for the y-axis.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.EllipseElement">The newly created element.</returns>
        }, 
        
        drawRect: function(x, y, width, height, stroke, fill, opt_group) {
            /// <summary>Draw a rectangle.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of rectangle.</param>
            /// <param name="height" type="number">Height of rectangle.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.RectElement">The newly created element.</returns>
        }, 
        
        drawImage: function(x, y, width, height, src, opt_group) {
            /// <summary>Draw an image.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of the image.</param>
            /// <param name="height" type="number">Height of the image.</param>
            /// <param name="src" type="string">The source fo the image.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.ImageElement">The newly created image wrapped in a
            ///     rectangle element.</returns>
        }, 
        
        drawTextOnLine: function(text, x1, y1, x2, y2, align, font, stroke, fill, opt_group) {
            /// <summary>Draw a text string vertically centered on a given line.</summary>
            /// <param name="text" type="string">The text to draw.</param>
            /// <param name="x1" type="number">X coordinate of start of line.</param>
            /// <param name="y1" type="number">Y coordinate of start of line.</param>
            /// <param name="x2" type="number">X coordinate of end of line.</param>
            /// <param name="y2" type="number">Y coordinate of end of line.</param>
            /// <param name="align" type="string">Horizontal alignment: left (default), center, right.</param>
            /// <param name="font" type="goog.graphics.Font">Font describing the font properties.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.TextElement">The newly created element.</returns>
        }, 
        
        drawPath: function(path, stroke, fill, opt_group) {
            /// <summary>Draw a path.</summary>
            /// <param name="path" type="!goog.graphics.Path">The path object to draw.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.PathElement">The newly created element.</returns>
        }, 
        
        getSvgPath: function(path) {
            /// <summary>Returns a string representation of a logical path suitable for use in
            /// an SVG element.</summary>
            /// <param name="path" type="goog.graphics.Path">The logical path.</param>
            /// <returns type="string">The SVG path representation.</returns>
        }, 
        
        createGroup: function(opt_group) {
            /// <summary>Create an empty group of drawing elements.</summary>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.GroupElement">The newly created group.</returns>
        }, 
        
        getTextWidth: function(text, font) {
            /// <summary>Measure and return the width (in pixels) of a given text string.
            /// Text measurement is needed to make sure a text can fit in the allocated area.
            /// The way text length is measured is by writing it into a div that is after
            /// the visible area, measure the div width, and immediatly erase the written
            /// value.</summary>
            /// <param name="text" type="string">The text string to measure.</param>
            /// <param name="font" type="goog.graphics.Font">The font object describing the font style.</param>
        }, 
        
        addDef: function(defKey, defElement) {
            /// <summary>Adds a defintion of an element to the global definitions.</summary>
            /// <param name="defKey" type="string">This is a key that should be unique in a way that
            ///     if two definitions are equal the should have the same key.</param>
            /// <param name="defElement" type="Element">DOM element to add as a definition. It must
            ///     have an id attribute set.</param>
            /// <returns type="string">The assigned id of the defElement.</returns>
        }, 
        
        getDef: function(defKey) {
            /// <summary>Returns the id of a definition element.</summary>
            /// <param name="defKey" type="string">This is a key that should be unique in a way that
            ///     if two definitions are equal the should have the same key.</param>
            /// <returns type="?string">The id of the found definition element or null if
            ///     not found.</returns>
        }, 
        
        removeDef: function(defKey) {
            /// <summary>Removes a definition of an elemnt from the global definitions.</summary>
            /// <param name="defKey" type="string">This is a key that should be unique in a way that
            ///     if two definitions are equal they should have the same key.</param>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the component by removing event handlers, detacing DOM nodes from
            /// the document body, and removing references to them.</summary>
        }, 
        
        isDomClonable: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.SvgGraphics";
})(this);
