
/* vsdoc for goog.graphics.VmlGraphics */

(function (window) {
    window.goog.graphics = window.goog.graphics || {};

    window.goog.graphics.VmlGraphics = function(width, height, opt_coordWidth, opt_coordHeight, opt_domHelper){
        /// <summary></summary>
        /// <param name="width" type="string|number">The (non-zero) width in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="height" type="string|number">The (non-zero) height in pixels.  Strings
        ///     expressing percentages of parent with (e.g. &apos;80%&apos;) are also accepted.</param>
        /// <param name="opt_coordWidth" type="?number=">The coordinate width - if
        ///     omitted or null, defaults to same as width.</param>
        /// <param name="opt_coordHeight" type="?number=">The coordinate height - if
        ///     omitted or null, defaults to same as height.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The DOM helper object for the
        ///     document we want to render in.</param>
        /// <field name="COORD_MULTIPLIER" type="number">The coordinate multiplier to allow sub-pixel rendering</field>
        /// <returns type="goog.graphics.VmlGraphics"/>
    };

    var $x = window.goog.graphics.VmlGraphics;
    $x.prototype = {
                
        toCssSize: function(size) {
            /// <summary>Converts the given size to a css size.  If it is a percentage, leaves it
            /// alone.  Otherwise assumes px.</summary>
            /// <param name="size" type="number|string">The size to use.</param>
            /// <returns type="string">The position adjusted for COORD_MULTIPLIER.</returns>
        }, 
        
        toPosCoord: function(number) {
            /// <summary>Multiplies positioning coordinates by COORD_MULTIPLIER to allow sub-pixel
            /// coordinates.  Also adds a half pixel offset to match SVG.
            /// 
            /// This function is internal for the VML supporting classes, and
            /// should not be used externally.</summary>
            /// <param name="number" type="number|string">A position in pixels.</param>
            /// <returns type="number">The position adjusted for COORD_MULTIPLIER.</returns>
        }, 
        
        toPosPx: function(number) {
            /// <summary>Add a &quot;px&quot; suffix to a number of pixels, and multiplies all coordinates by
            /// COORD_MULTIPLIER to allow sub-pixel coordinates.
            /// 
            /// This function is internal for the VML supporting classes, and
            /// should not be used externally.</summary>
            /// <param name="number" type="number|string">A position in pixels.</param>
            /// <returns type="string">The position with suffix &apos;px&apos;.</returns>
        }, 
        
        toSizeCoord: function(number) {
            /// <summary>Multiplies the width or height coordinate by COORD_MULTIPLIER to allow
            /// sub-pixel coordinates.
            /// 
            /// This function is internal for the VML supporting classes, and
            /// should not be used externally.</summary>
            /// <param name="number" type="string|number">A size in units.</param>
            /// <returns type="number">The size multiplied by the correct factor.</returns>
        }, 
        
        toSizePx: function(number) {
            /// <summary>Add a &quot;px&quot; suffix to a number of pixels, and multiplies all coordinates by
            /// COORD_MULTIPLIER to allow sub-pixel coordinates.
            /// 
            /// This function is internal for the VML supporting classes, and
            /// should not be used externally.</summary>
            /// <param name="number" type="number|string">A size in pixels.</param>
            /// <returns type="string">The size with suffix &apos;px&apos;.</returns>
        }, 
        
        setAttribute: function(element, name, value) {
            /// <summary>Sets an attribute on the given VML element, in the way best suited to the
            /// current version of IE.  Should only be used in the goog.graphics package.</summary>
            /// <param name="element" type="Element">The element to set an attribute
            ///     on.</param>
            /// <param name="name" type="string">The name of the attribute to set.</param>
            /// <param name="value" type="string">The value to set it to.</param>
        }, 
        
        createVmlElement: function(tagName) {
            /// <summary>Creates a VML element. Used internally and by different VML classes.</summary>
            /// <param name="tagName" type="string">The type of element to create.</param>
            /// <returns type="Element">The created element.</returns>
        }, 
        
        getVmlElement: function(id) {
            /// <summary>Returns the VML element with the given id that is a child of this graphics
            /// object.
            /// Should be considered package private, and not used externally.</summary>
            /// <param name="id" type="string">The element id to find.</param>
            /// <returns type="Element">The element with the given id, or null if none is found.</returns>
        }, 
        
        setElementFill: function(element, fill) {
            /// <summary>Sets the fill for the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element wrapper.</param>
            /// <param name="fill" type="goog.graphics.Fill?">The fill object.</param>
        }, 
        
        setElementStroke: function(element, stroke) {
            /// <summary>Sets the stroke for the given element.</summary>
            /// <param name="element" type="goog.graphics.StrokeAndFillElement">The element wrapper.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">The stroke object.</param>
        }, 
        
        setElementTransform: function(element, x, y, angle, centerX, centerY) {
            /// <summary>Set the transformation of an element.</summary>
            /// <param name="element" type="goog.graphics.Element">The element wrapper.</param>
            /// <param name="x" type="number">The x coordinate of the translation transform.</param>
            /// <param name="y" type="number">The y coordinate of the translation transform.</param>
            /// <param name="angle" type="number">The angle of the rotation transform.</param>
            /// <param name="centerX" type="number">The horizontal center of the rotation transform.</param>
            /// <param name="centerY" type="number">The vertical center of the rotation transform.</param>
        }, 
        
        removeFill: function(element) {
            /// <summary>Removes the fill information from a dom element.</summary>
            /// <param name="element" type="Element">DOM element.</param>
        }, 
        
        setPositionAndSize: function(element, left, top, width, height) {
            /// <summary>Set top, left, width and height for an element.
            /// This function is internal for the VML supporting classes, and
            /// should not be used externally.</summary>
            /// <param name="element" type="Element">DOM element.</param>
            /// <param name="left" type="number">Left ccordinate in pixels.</param>
            /// <param name="top" type="number">Top ccordinate in pixels.</param>
            /// <param name="width" type="number">Width in pixels.</param>
            /// <param name="height" type="number">Height in pixels.</param>
        }, 
        
        createDom: function() {
            /// <summary>Creates the DOM representation of the graphics area.</summary>
        }, 
        
        setCoordOrigin: function(left, top) {
            /// <summary>Changes the coordinate system position.</summary>
            /// <param name="left" type="number">The coordinate system left bound.</param>
            /// <param name="top" type="number">The coordinate system top bound.</param>
        }, 
        
        setCoordSize: function(coordWidth, coordHeight) {
            /// <summary>Changes the coordinate size.</summary>
            /// <param name="coordWidth" type="number">The coordinate width.</param>
            /// <param name="coordHeight" type="number">The coordinate height.</param>
        }, 
        
        setSize: function(pixelWidth, pixelHeight) {
            /// <summary>Change the size of the canvas.</summary>
            /// <param name="pixelWidth" type="number">The width in pixels.</param>
            /// <param name="pixelHeight" type="number">The height in pixels.</param>
        }, 
        
        getPixelSize: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Size">Returns the number of pixels spanned by the surface.</returns>
        }, 
        
        clear: function() {
            /// <summary>Remove all drawing elements from the graphics.</summary>
        }, 
        
        drawEllipse: function(cx, cy, rx, ry, stroke, fill, opt_group) {
            /// <summary>Draw an ellipse.</summary>
            /// <param name="cx" type="number">Center X coordinate.</param>
            /// <param name="cy" type="number">Center Y coordinate.</param>
            /// <param name="rx" type="number">Radius length for the x-axis.</param>
            /// <param name="ry" type="number">Radius length for the y-axis.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.EllipseElement">The newly created element.</returns>
        }, 
        
        drawRect: function(x, y, width, height, stroke, fill, opt_group) {
            /// <summary>Draw a rectangle.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of rectangle.</param>
            /// <param name="height" type="number">Height of rectangle.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the
            ///    stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.RectElement">The newly created element.</returns>
        }, 
        
        drawImage: function(x, y, width, height, src, opt_group) {
            /// <summary>Draw an image.</summary>
            /// <param name="x" type="number">X coordinate (left).</param>
            /// <param name="y" type="number">Y coordinate (top).</param>
            /// <param name="width" type="number">Width of image.</param>
            /// <param name="height" type="number">Height of image.</param>
            /// <param name="src" type="string">Source of the image.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.ImageElement">The newly created element.</returns>
        }, 
        
        drawTextOnLine: function(text, x1, y1, x2, y2, align, font, stroke, fill, opt_group) {
            /// <summary>Draw a text string vertically centered on a given line.</summary>
            /// <param name="text" type="string">The text to draw.</param>
            /// <param name="x1" type="number">X coordinate of start of line.</param>
            /// <param name="y1" type="number">Y coordinate of start of line.</param>
            /// <param name="x2" type="number">X coordinate of end of line.</param>
            /// <param name="y2" type="number">Y coordinate of end of line.</param>
            /// <param name="align" type="?string">Horizontal alignment: left (default), center, right.</param>
            /// <param name="font" type="goog.graphics.Font">Font describing the font properties.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.TextElement">The newly created element.</returns>
        }, 
        
        drawPath: function(path, stroke, fill, opt_group) {
            /// <summary>Draw a path.</summary>
            /// <param name="path" type="!goog.graphics.Path">The path object to draw.</param>
            /// <param name="stroke" type="goog.graphics.Stroke?">Stroke object describing the stroke.</param>
            /// <param name="fill" type="goog.graphics.Fill?">Fill object describing the fill.</param>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.PathElement">The newly created element.</returns>
        }, 
        
        getVmlPath: function(path) {
            /// <summary>Returns a string representation of a logical path suitable for use in
            /// a VML element.</summary>
            /// <param name="path" type="goog.graphics.Path">The logical path.</param>
            /// <returns type="string">The VML path representation.</returns>
        }, 
        
        createGroup: function(opt_group) {
            /// <summary>Create an empty group of drawing elements.</summary>
            /// <param name="opt_group" type="goog.graphics.GroupElement=">The group wrapper element
            ///     to append to. If not specified, appends to the main canvas.</param>
            /// <returns type="goog.graphics.GroupElement">The newly created group.</returns>
        }, 
        
        getTextWidth: function(text, font) {
            /// <summary>Measure and return the width (in pixels) of a given text string.
            /// Text measurement is needed to make sure a text can fit in the allocated
            /// area. The way text length is measured is by writing it into a div that is
            /// after the visible area, measure the div width, and immediatly erase the
            /// written value.</summary>
            /// <param name="text" type="string">The text string to measure.</param>
            /// <param name="font" type="goog.graphics.Font">The font object describing the font style.</param>
            /// <returns type="number">The width in pixels of the text strings.</returns>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the component by removing event handlers, detacing DOM nodes from
            /// the document body, and removing references to them.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.VmlGraphics";
})(this);
