
/* vsdoc for goog.graphics.ext.Element */

(function (window) {
    window.goog.graphics.ext = window.goog.graphics.ext || {};

    window.goog.graphics.ext.Element = function(group, wrapper){
        /// <summary></summary>
        /// <param name="group" type="goog.graphics.ext.Group?">Parent for this element.</param>
        /// <param name="wrapper" type="goog.graphics.Element">The thin wrapper to wrap.</param>
        /// <field name="redraw" type="">Overridable function for subclass specific reset.</field>
        /// <field name="checkParentDependent" type="boolean">Overridable function for subclass specific parent dependency.</field>
        /// <returns type="goog.graphics.ext.Element"/>
    };

    var $x = window.goog.graphics.ext.Element;
    $x.prototype = {
                
        getWrapper: function() {
            /// <summary></summary>
            /// <returns type="goog.graphics.Element">The underlying thin wrapper.</returns>
        }, 
        
        getGraphics: function() {
            /// <summary></summary>
            /// <returns type="goog.graphics.ext.Element|goog.graphics.ext.Graphics">The graphics
            ///     surface the element is a part of.</returns>
        }, 
        
        getGraphicsImplementation: function() {
            /// <summary>Returns the graphics implementation.</summary>
            /// <returns type="goog.graphics.AbstractGraphics">The underlying graphics
            ///     implementation drawing this element&apos;s wrapper.</returns>
        }, 
        
        getParent: function() {
            /// <summary></summary>
            /// <returns type="goog.graphics.ext.Group|undefined">The parent of this element.</returns>
        }, 
        
        getLeft: function() {
            /// <summary></summary>
            /// <returns type="number">The distance from the left edge of this element to the left
            ///     edge of its parent, specified in units of the parent&apos;s coordinate system.</returns>
        }, 
        
        setLeft: function(left, opt_chain) {
            /// <summary>Sets the left coordinate of the element.  Overwrites any previous value of
            /// left, center, or right for this element.</summary>
            /// <param name="left" type="string|number">The left coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getRight: function() {
            /// <summary></summary>
            /// <returns type="number">The right coordinate of the element, in units of the
            ///     parent&apos;s coordinate system.</returns>
        }, 
        
        setRight: function(right, opt_chain) {
            /// <summary>Sets the right coordinate of the element.  Overwrites any previous value of
            /// left, center, or right for this element.</summary>
            /// <param name="right" type="string|number">The right coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getCenter: function() {
            /// <summary></summary>
            /// <returns type="number">The center coordinate of the element, in units of the
            /// parent&apos;s coordinate system.</returns>
        }, 
        
        setCenter: function(center, opt_chain) {
            /// <summary>Sets the center coordinate of the element.  Overwrites any previous value of
            /// left, center, or right for this element.</summary>
            /// <param name="center" type="string|number">The center coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getTop: function() {
            /// <summary></summary>
            /// <returns type="number">The distance from the top edge of this element to the top
            ///     edge of its parent, specified in units of the parent&apos;s coordinate system.</returns>
        }, 
        
        setTop: function(top, opt_chain) {
            /// <summary>Sets the top coordinate of the element.  Overwrites any previous value of
            /// top, middle, or bottom for this element.</summary>
            /// <param name="top" type="string|number">The top coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getBottom: function() {
            /// <summary></summary>
            /// <returns type="number">The bottom coordinate of the element, in units of the
            ///     parent&apos;s coordinate system.</returns>
        }, 
        
        setBottom: function(bottom, opt_chain) {
            /// <summary>Sets the bottom coordinate of the element.  Overwrites any previous value of
            /// top, middle, or bottom for this element.</summary>
            /// <param name="bottom" type="string|number">The bottom coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getMiddle: function() {
            /// <summary></summary>
            /// <returns type="number">The middle coordinate of the element, in units of the
            ///     parent&apos;s coordinate system.</returns>
        }, 
        
        setMiddle: function(middle, opt_chain) {
            /// <summary>Sets the middle coordinate of the element.  Overwrites any previous value of
            /// top, middle, or bottom for this element</summary>
            /// <param name="middle" type="string|number">The middle coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getWidth: function() {
            /// <summary></summary>
            /// <returns type="number">The width of the element, in units of the parent&apos;s
            ///     coordinate system.</returns>
        }, 
        
        setWidth: function(width, opt_chain) {
            /// <summary>Sets the width of the element.</summary>
            /// <param name="width" type="string|number">The new width value.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getMinWidth: function() {
            /// <summary></summary>
            /// <returns type="number">The minimum width of the element, in units of the parent&apos;s
            ///     coordinate system.</returns>
        }, 
        
        setMinWidth: function(minWidth) {
            /// <summary>Sets the minimum width of the element.</summary>
            /// <param name="minWidth" type="string|number">The minimum width of the element.</param>
        }, 
        
        getHeight: function() {
            /// <summary></summary>
            /// <returns type="number">The height of the element, in units of the parent&apos;s
            ///     coordinate system.</returns>
        }, 
        
        setHeight: function(height, opt_chain) {
            /// <summary>Sets the height of the element.</summary>
            /// <param name="height" type="string|number">The new height value.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getMinHeight: function() {
            /// <summary></summary>
            /// <returns type="number">The minimum height of the element, in units of the parent&apos;s
            ///     coordinate system.</returns>
        }, 
        
        setMinHeight: function(minHeight) {
            /// <summary>Sets the minimum height of the element.</summary>
            /// <param name="minHeight" type="string|number">The minimum height of the element.</param>
        }, 
        
        setPosition: function(left, top, opt_chain) {
            /// <summary>Shortcut for setting the left and top position.</summary>
            /// <param name="left" type="string|number">The left coordinate.</param>
            /// <param name="top" type="string|number">The top coordinate.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        setSize: function(width, height, opt_chain) {
            /// <summary>Shortcut for setting the width and height.</summary>
            /// <param name="width" type="string|number">The new width value.</param>
            /// <param name="height" type="string|number">The new height value.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        setBounds: function(left, top, width, height, opt_chain) {
            /// <summary>Shortcut for setting the left, top, width, and height.</summary>
            /// <param name="left" type="string|number">The left coordinate.</param>
            /// <param name="top" type="string|number">The top coordinate.</param>
            /// <param name="width" type="string|number">The new width value.</param>
            /// <param name="height" type="string|number">The new height value.</param>
            /// <param name="opt_chain" type="boolean=">Optional flag to specify this function is part
            ///     of a chain of calls and therefore transformations should be set as
            ///     pending but not yet performed.</param>
        }, 
        
        getMaxX: function() {
            /// <summary></summary>
            /// <returns type="number">An estimate of the maximum x extent this element would have
            ///     in a parent of no width.</returns>
        }, 
        
        getMaxY: function() {
            /// <summary></summary>
            /// <returns type="number">An estimate of the maximum y extent this element would have
            ///     in a parent of no height.</returns>
        }, 
        
        reset: function() {
            /// <summary>Reset the element.  This is called when the element changes size, or when
            /// the coordinate system changes in a way that would affect pixel based
            /// rendering</summary>
        }, 
        
        isParentDependent: function() {
            /// <summary>Returns whether this element&apos;s bounds depend on its parents.
            /// 
            /// This function should be treated as if it has package scope.</summary>
            /// <returns type="boolean">Whether this element&apos;s bounds depend on its parents.</returns>
        }, 
        
        setRotation: function(angle) {
            /// <summary>Set the rotation of this element.</summary>
            /// <param name="angle" type="number">The angle of rotation, in degrees.</param>
        }, 
        
        getRotation: function() {
            /// <summary></summary>
            /// <returns type="number">The angle of rotation of this element, in degrees.</returns>
        }, 
        
        parentTransform: function() {
            /// <summary>Called by the parent when the parent has transformed.
            /// 
            /// Should be treated as package scope.</summary>
        }, 
        
        isPendingTransform: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this element has pending transforms.</returns>
        }, 
        
        transform: function() {
            /// <summary>Performs a pending transform.</summary>
        }, 
        
        getPixelScaleX: function() {
            /// <summary></summary>
            /// <returns type="number">Returns the number of pixels per unit in the x direction.</returns>
        }, 
        
        getPixelScaleY: function() {
            /// <summary></summary>
            /// <returns type="number">Returns the number of pixels per unit in the y direction.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.ext.Element";
})(this);
