
/* vsdoc for goog.graphics.ext.Group */

(function (window) {
    window.goog.graphics.ext = window.goog.graphics.ext || {};

    window.goog.graphics.ext.Group = function(group, opt_wrapper){
        /// <summary></summary>
        /// <param name="group" type="goog.graphics.ext.Group">Parent for this element. Can
        ///     be null if this is a Graphics instance.</param>
        /// <param name="opt_wrapper" type="goog.graphics.GroupElement=">The thin wrapper
        ///     to wrap. If omitted, a new group will be created. Must be included
        ///     when group is null.</param>
        /// <returns type="goog.graphics.ext.Group"/>
    };

    var $x = window.goog.graphics.ext.Group;
    $x.prototype = {
                
        addChild: function(element, opt_chain) {
            /// <summary>Add an element to the group.  This should be treated as package local, as
            /// it is called by the draw* methods.</summary>
            /// <param name="element" type="!goog.graphics.ext.Element">The element to add.</param>
            /// <param name="opt_chain" type="boolean=">Whether this addition is part of a longer set
            ///     of element additions.</param>
        }, 
        
        removeChild: function(element) {
            /// <summary>Remove an element from the group.</summary>
            /// <param name="element" type="goog.graphics.ext.Element">The element to remove.</param>
        }, 
        
        forEachChild: function(f, opt_obj) {
            /// <summary>Calls the given function on each of this component&apos;s children in order.  If
            /// {@code opt_obj} is provided, it will be used as the &apos;this&apos; object in the
            /// function when called.  The function should take two arguments:  the child
            /// component and its 0-based index.  The return value is ignored.</summary>
            /// <param name="f" type="Function">The function to call for every child component; should
            ///    take 2 arguments (the child and its index).</param>
            /// <param name="opt_obj" type="Object=">Used as the &apos;this&apos; object in f when called.</param>
        }, 
        
        reset: function() {
            /// <summary>Reset the element.</summary>
        }, 
        
        redraw: function() {
            /// <summary>Called from the parent class, this method resets any pre-computed positions
            /// and sizes.</summary>
        }, 
        
        transformChildren: function() {
            /// <summary>Transform the children that need to be transformed.</summary>
        }, 
        
        updateChildren: function() {
            /// <summary>As part of the reset process, update child elements.</summary>
        }, 
        
        getCoordinateWidth: function() {
            /// <summary></summary>
            /// <returns type="number">The width of the element&apos;s coordinate space.</returns>
        }, 
        
        getCoordinateHeight: function() {
            /// <summary></summary>
            /// <returns type="number">The height of the element&apos;s coordinate space.</returns>
        }, 
        
        clear: function() {
            /// <summary>Remove all drawing elements from the group.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.graphics.ext.Group";
})(this);
