
/* vsdoc for goog.history.Html5History */

(function (window) {
    window.goog.history = window.goog.history || {};

    window.goog.history.Html5History = function(opt_win, opt_transformer){
        /// <summary></summary>
        /// <param name="opt_win" type="Window=">The window to listen/dispatch history events on.</param>
        /// <param name="opt_transformer" type="goog.history.Html5History.TokenTransformer=">The token transformer that is used to create URL from the token
        ///     when storing token without using hash fragment.</param>
        /// <returns type="goog.history.Html5History"/>
    };

    var $x = window.goog.history.Html5History;
    $x.prototype = {
                
        isSupported: function(opt_win) {
            /// <summary>Returns whether Html5History is supported.</summary>
            /// <param name="opt_win" type="Window=">Optional window to check.</param>
            /// <returns type="boolean">Whether html5 history is supported.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Starts or stops the History.  When enabled, the History object
            /// will immediately fire an event for the current location. The caller can set
            /// up event listeners between the call to the constructor and the call to
            /// setEnabled.</summary>
            /// <param name="enable" type="boolean">Whether to enable history.</param>
        }, 
        
        getToken: function() {
            /// <summary>Returns the current token.</summary>
            /// <returns type="string">The current token.</returns>
        }, 
        
        setToken: function(token, opt_title) {
            /// <summary>Sets the history state.</summary>
            /// <param name="token" type="string">The history state identifier.</param>
            /// <param name="opt_title" type="string=">Optional title to associate with history entry.</param>
        }, 
        
        replaceToken: function(token, opt_title) {
            /// <summary>Replaces the current history state without affecting the rest of the history
            /// stack.</summary>
            /// <param name="token" type="string">The history state identifier.</param>
            /// <param name="opt_title" type="string=">Optional title to associate with history entry.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setUseFragment: function(useFragment) {
            /// <summary>Sets whether to use the fragment to store tokens.</summary>
            /// <param name="useFragment" type="boolean">Whether to use the fragment.</param>
        }, 
        
        setPathPrefix: function(pathPrefix) {
            /// <summary>Sets the path prefix to use if storing tokens in the path. The path
            /// prefix should start and end with slash.</summary>
            /// <param name="pathPrefix" type="string">Sets the path prefix.</param>
        }, 
        
        getPathPrefix: function() {
            /// <summary>Gets the path prefix.</summary>
            /// <returns type="string">The path prefix.</returns>
        }, 
        
        TokenTransformer: function() {
            /// <summary>A token transformer that can create a URL from a history
            /// token. This is used by {@code goog.history.Html5History} to create
            /// URL when storing token without the hash fragment.
            /// 
            /// Given a {@code window.location} object containing the location
            /// created by {@code createUrl}, the token transformer allows
            /// retrieval of the token back via {@code retrieveToken}.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.history.Html5History";
})(this);
