
/* vsdoc for goog.i18n.BidiFormatter */

(function (window) {
    window.goog.i18n = window.goog.i18n || {};

    window.goog.i18n.BidiFormatter = function(contextDir, opt_alwaysSpan){
        /// <summary></summary>
        /// <param name="contextDir" type="goog.i18n.bidi.Dir|number|boolean">The context
        ///     directionality. May be supplied either as a goog.i18n.bidi.Dir constant,
        ///     as a number (positive = LRT, negative = RTL, 0 = unknown) or as a boolean
        ///     (true = RTL, false = LTR).</param>
        /// <param name="opt_alwaysSpan" type="boolean=">Whether {@link #spanWrap} should always
        ///     use a &apos;span&apos; tag, even when the input directionality is neutral or
        ///     matches the context, so that the DOM structure of the output does not
        ///     depend on the combination of directionalities. Default: false.</param>
        /// <field name="estimateDirection" type="goog.i18n.bidi.Dir">Returns the directionality of input argument {@code str}.
        /// Identical to {@link goog.i18n.bidi.estimateDirection}.</field>
        /// <returns type="goog.i18n.BidiFormatter"/>
    };

    var $x = window.goog.i18n.BidiFormatter;
    $x.prototype = {
                
        getContextDir: function() {
            /// <summary></summary>
            /// <returns type="goog.i18n.bidi.Dir">The context directionality.</returns>
        }, 
        
        getAlwaysSpan: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether alwaysSpan is set.</returns>
        }, 
        
        setContextDir: function(contextDir) {
            /// <summary></summary>
            /// <param name="contextDir" type="goog.i18n.bidi.Dir|number|boolean">The context
            ///     directionality. May be supplied either as a goog.i18n.bidi.Dir constant,
            ///     as a number (positive = LRT, negative = RTL, 0 = unknown) or as a boolean
            ///     (true = RTL, false = LTR).</param>
        }, 
        
        setAlwaysSpan: function(alwaysSpan) {
            /// <summary></summary>
            /// <param name="alwaysSpan" type="boolean">Whether {@link #spanWrap} should always use a
            ///     &apos;span&apos; tag, even when the input directionality is neutral or matches the
            ///     context, so that the DOM structure of the output does not depend on the
            ///     combination of directionalities.</param>
        }, 
        
        dirAttrValue: function(str, opt_isHtml) {
            /// <summary>Returns &quot;rtl&quot; if {@code str}&apos;s estimated directionality is RTL, and &quot;ltr&quot; if
            /// it is LTR. In case it&apos;s UNKNOWN, returns &quot;rtl&quot; if the context directionality
            /// is RTL, and &quot;ltr&quot; otherwise.
            /// Needed for GXP, which can&apos;t handle dirAttr.
            /// Example use case:
            /// &lt;td expr:dir=&apos;bidiFormatter.dirAttrValue(foo)&apos;&gt;&lt;gxp:eval expr=&apos;foo&apos;&gt;&lt;/td&gt;</summary>
            /// <param name="str" type="string">Text whose directionality is to be estimated.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="string">&quot;rtl&quot; or &quot;ltr&quot;, according to the logic described above.</returns>
        }, 
        
        knownDirAttrValue: function(dir) {
            /// <summary>Returns &quot;rtl&quot; if the given directionality is RTL, and &quot;ltr&quot; if it is LTR. In
            /// case it&apos;s UNKNOWN, returns &quot;rtl&quot; if the context directionality is RTL, and
            /// &quot;ltr&quot; otherwise.</summary>
            /// <param name="dir" type="goog.i18n.bidi.Dir">A directionality.</param>
            /// <returns type="string">&quot;rtl&quot; or &quot;ltr&quot;, according to the logic described above.</returns>
        }, 
        
        dirAttr: function(str, opt_isHtml) {
            /// <summary>Returns &apos;dir=&quot;ltr&quot;&apos; or &apos;dir=&quot;rtl&quot;&apos;, depending on {@code str}&apos;s estimated
            /// directionality, if it is not the same as the context directionality.
            /// Otherwise, returns the empty string.</summary>
            /// <param name="str" type="string">Text whose directionality is to be estimated.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="string">&apos;dir=&quot;rtl&quot;&apos; for RTL text in non-RTL context; &apos;dir=&quot;ltr&quot;&apos; for
            ///     LTR text in non-LTR context; else, the empty string.</returns>
        }, 
        
        knownDirAttr: function(dir) {
            /// <summary>Returns &apos;dir=&quot;ltr&quot;&apos; or &apos;dir=&quot;rtl&quot;&apos;, depending on the given directionality, if
            /// it is not the same as the context directionality. Otherwise, returns the
            /// empty string.</summary>
            /// <param name="dir" type="goog.i18n.bidi.Dir">A directionality.</param>
            /// <returns type="string">&apos;dir=&quot;rtl&quot;&apos; for RTL text in non-RTL context; &apos;dir=&quot;ltr&quot;&apos; for
            ///     LTR text in non-LTR context; else, the empty string.</returns>
        }, 
        
        spanWrap: function(str, opt_isHtml, opt_dirReset) {
            /// <summary>Formats a string of unknown directionality for use in HTML output of the
            /// context directionality, so an opposite-directionality string is neither
            /// garbled nor garbles what follows it.
            /// The algorithm: estimates the directionality of input argument {@code str}. In
            /// case its directionality doesn&apos;t match the context directionality, wraps it
            /// with a &apos;span&apos; tag and adds a &quot;dir&quot; attribute (either &apos;dir=&quot;rtl&quot;&apos; or
            /// &apos;dir=&quot;ltr&quot;&apos;). If setAlwaysSpan(true) was used, the input is always wrapped
            /// with &apos;span&apos;, skipping just the dir attribute when it&apos;s not needed.
            /// 
            /// If {@code opt_dirReset}, and if the overall directionality or the exit
            /// directionality of {@code str} are opposite to the context directionality, a
            /// trailing unicode BiDi mark matching the context directionality is appened
            /// (LRM or RLM).
            /// 
            /// If !{@code opt_isHtml}, HTML-escapes {@code str} regardless of wrapping.</summary>
            /// <param name="str" type="string">The input text.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <param name="opt_dirReset" type="boolean=">Whether to append a trailing unicode bidi mark
            ///     matching the context directionality, when needed, to prevent the possible
            ///     garbling of whatever may follow {@code str}. Default: true.</param>
            /// <returns type="string">Input text after applying the above processing.</returns>
        }, 
        
        spanWrapWithKnownDir: function(dir, str, opt_isHtml, opt_dirReset) {
            /// <summary>Formats a string of given directionality for use in HTML output of the
            /// context directionality, so an opposite-directionality string is neither
            /// garbled nor garbles what follows it.
            /// The algorithm: If {@code dir} doesn&apos;t match the context directionality, wraps
            /// {@code str} with a &apos;span&apos; tag and adds a &quot;dir&quot; attribute (either &apos;dir=&quot;rtl&quot;&apos;
            /// or &apos;dir=&quot;ltr&quot;&apos;). If setAlwaysSpan(true) was used, the input is always wrapped
            /// with &apos;span&apos;, skipping just the dir attribute when it&apos;s not needed.
            /// 
            /// If {@code opt_dirReset}, and if {@code dir} or the exit directionality of
            /// {@code str} are opposite to the context directionality, a trailing unicode
            /// BiDi mark matching the context directionality is appened (LRM or RLM).
            /// 
            /// If !{@code opt_isHtml}, HTML-escapes {@code str} regardless of wrapping.</summary>
            /// <param name="dir" type="goog.i18n.bidi.Dir">{@code str}&apos;s overall directionality.</param>
            /// <param name="str" type="string">The input text.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <param name="opt_dirReset" type="boolean=">Whether to append a trailing unicode bidi mark
            ///     matching the context directionality, when needed, to prevent the possible
            ///     garbling of whatever may follow {@code str}. Default: true.</param>
            /// <returns type="string">Input text after applying the above processing.</returns>
        }, 
        
        unicodeWrap: function(str, opt_isHtml, opt_dirReset) {
            /// <summary>Formats a string of unknown directionality for use in plain-text output of
            /// the context directionality, so an opposite-directionality string is neither
            /// garbled nor garbles what follows it.
            /// As opposed to {@link #spanWrap}, this makes use of unicode BiDi formatting
            /// characters. In HTML, its *only* valid use is inside of elements that do not
            /// allow mark-up, e.g. an &apos;option&apos; tag.
            /// The algorithm: estimates the directionality of input argument {@code str}.
            /// In case it doesn&apos;t match  the context directionality, wraps it with Unicode
            /// BiDi formatting characters: RLE{@code str}PDF for RTL text, and
            /// LRE{@code str}PDF for LTR text.
            /// 
            /// If {@code opt_dirReset}, and if the overall directionality or the exit
            /// directionality of {@code str} are opposite to the context directionality, a
            /// trailing unicode BiDi mark matching the context directionality is appended
            /// (LRM or RLM).
            /// 
            /// Does *not* do HTML-escaping regardless of the value of {@code opt_isHtml}.
            /// The return value can be HTML-escaped as necessary.</summary>
            /// <param name="str" type="string">The input text.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <param name="opt_dirReset" type="boolean=">Whether to append a trailing unicode bidi mark
            ///     matching the context directionality, when needed, to prevent the possible
            ///     garbling of whatever may follow {@code str}. Default: true.</param>
            /// <returns type="string">Input text after applying the above processing.</returns>
        }, 
        
        unicodeWrapWithKnownDir: function(dir, str, opt_isHtml, opt_dirReset) {
            /// <summary>Formats a string of given directionality for use in plain-text output of the
            /// context directionality, so an opposite-directionality string is neither
            /// garbled nor garbles what follows it.
            /// As opposed to {@link #spanWrapWithKnownDir}, makes use of unicode BiDi
            /// formatting characters. In HTML, its *only* valid use is inside of elements
            /// that do not allow mark-up, e.g. an &apos;option&apos; tag.
            /// The algorithm: If {@code dir} doesn&apos;t match the context directionality, wraps
            /// {@code str} with Unicode BiDi formatting characters: RLE{@code str}PDF for
            /// RTL text, and LRE{@code str}PDF for LTR text.
            /// 
            /// If {@code opt_dirReset}, and if the overall directionality or the exit
            /// directionality of {@code str} are opposite to the context directionality, a
            /// trailing unicode BiDi mark matching the context directionality is appended
            /// (LRM or RLM).
            /// 
            /// Does *not* do HTML-escaping regardless of the value of {@code opt_isHtml}.
            /// The return value can be HTML-escaped as necessary.</summary>
            /// <param name="dir" type="goog.i18n.bidi.Dir">{@code str}&apos;s overall directionality.</param>
            /// <param name="str" type="string">The input text.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <param name="opt_dirReset" type="boolean=">Whether to append a trailing unicode bidi mark
            ///     matching the context directionality, when needed, to prevent the possible
            ///     garbling of whatever may follow {@code str}. Default: true.</param>
            /// <returns type="string">Input text after applying the above processing.</returns>
        }, 
        
        markAfter: function(str, opt_isHtml) {
            /// <summary>Returns a Unicode BiDi mark matching the context directionality (LRM or RLM)
            /// if the directionality or the exit directionality of {@code str} are opposite
            /// to the context directionality. Otherwise returns the empty string.</summary>
            /// <param name="str" type="string">The input text.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether {@code str} is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="string">A Unicode bidi mark matching the global directionality or
            ///     the empty string.</returns>
        }, 
        
        mark: function() {
            /// <summary>Returns the Unicode BiDi mark matching the context directionality (LRM for
            /// LTR context directionality, RLM for RTL context directionality), or the
            /// empty string for neutral / unknown context directionality.</summary>
            /// <returns type="string">LRM for LTR context directionality and RLM for RTL context
            ///     directionality.</returns>
        }, 
        
        startEdge: function() {
            /// <summary>Returns &apos;right&apos; for RTL context directionality. Otherwise (LTR or neutral /
            /// unknown context directionality) returns &apos;left&apos;.</summary>
            /// <returns type="string">&apos;right&apos; for RTL context directionality and &apos;left&apos; for other
            ///     context directionality.</returns>
        }, 
        
        endEdge: function() {
            /// <summary>Returns &apos;left&apos; for RTL context directionality. Otherwise (LTR or neutral /
            /// unknown context directionality) returns &apos;right&apos;.</summary>
            /// <returns type="string">&apos;left&apos; for RTL context directionality and &apos;right&apos; for other
            ///     context directionality.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.i18n.BidiFormatter";
})(this);
