
/* vsdoc for goog.i18n.TimeZone */

(function (window) {
    window.goog.i18n = window.goog.i18n || {};

    window.goog.i18n.TimeZone = function(){
        /// <summary></summary>
        /// <field name="NameType" type="">Indices into the array of time zone names.</field>
        /// <returns type="goog.i18n.TimeZone"/>
    };

    var $x = window.goog.i18n.TimeZone;
    $x.prototype = {
                
        createTimeZone: function(timeZoneData) {
            /// <summary>This factory method creates a time zone instance.  It takes either an object
            /// containing complete time zone information, or a single number representing a
            /// constant time zone offset.  If the latter form is used, DST functionality is
            /// not available.</summary>
            /// <param name="timeZoneData" type="number|Object">If this parameter is a number, it should
            ///     indicate minutes WEST of UTC to be used as a constant time zone offset.
            ///     Otherwise, it should be an object with these four fields:
            ///     &lt;ul&gt;
            ///     &lt;li&gt;id: A string ID for the time zone.
            ///     &lt;li&gt;std_offset: The standard time zone offset in minutes EAST of UTC.
            ///     &lt;li&gt;names: An array of four names (standard short name, standard long
            ///           name, daylight short name, daylight long, name)
            ///     &lt;li&gt;transitions: An array of numbers which are interpreted in pairs:
            ///           [time1, adjustment1, time2, adjustment2, ...] where each time is
            ///           a DST transition point given as a number of hours since 00:00 UTC,
            ///           January 1, 1970, and each adjustment is the adjustment to apply
            ///           for times after the DST transition, given as minutes EAST of UTC.
            ///     &lt;/ul&gt;</param>
            /// <returns type="goog.i18n.TimeZone">A goog.i18n.TimeZone object for the given
            ///     time zone data.</returns>
        }, 
        
        getTimeZoneData: function() {
            /// <summary>Convert the contents of time zone object to a timeZoneData object, suitable
            /// for passing to goog.i18n.TimeZone.createTimeZone.</summary>
            /// <returns type="Object">A timeZoneData object (see the documentation for
            ///     goog.i18n.TimeZone.createTimeZone).</returns>
        }, 
        
        getDaylightAdjustment: function(date) {
            /// <summary>Return the DST adjustment to the time zone offset for a given time.
            /// While Daylight Saving Time is in effect, this number is positive.
            /// Otherwise, it is zero.</summary>
            /// <param name="date" type="goog.date.DateLike">The time to check.</param>
            /// <returns type="number">The DST adjustment in minutes EAST of UTC.</returns>
        }, 
        
        getGMTString: function(date) {
            /// <summary>Return the GMT representation of this time zone object.</summary>
            /// <param name="date" type="goog.date.DateLike">The date for which time to retrieve
            ///     GMT string.</param>
            /// <returns type="string">GMT representation string.</returns>
        }, 
        
        getLongName: function(date) {
            /// <summary>Get the long time zone name for a given date/time.</summary>
            /// <param name="date" type="goog.date.DateLike">The time for which to retrieve
            ///     the long time zone name.</param>
            /// <returns type="string">The long time zone name.</returns>
        }, 
        
        getOffset: function(date) {
            /// <summary>Get the time zone offset in minutes WEST of UTC for a given date/time.</summary>
            /// <param name="date" type="goog.date.DateLike">The time for which to retrieve
            ///     the time zone offset.</param>
            /// <returns type="number">The time zone offset in minutes WEST of UTC.</returns>
        }, 
        
        getRFCTimeZoneString: function(date) {
            /// <summary>Get the RFC representation of the time zone for a given date/time.</summary>
            /// <param name="date" type="goog.date.DateLike">The time for which to retrieve the
            ///     RFC time zone string.</param>
            /// <returns type="string">The RFC time zone string.</returns>
        }, 
        
        getShortName: function(date) {
            /// <summary>Get the short time zone name for given date/time.</summary>
            /// <param name="date" type="goog.date.DateLike">The time for which to retrieve
            ///     the short time zone name.</param>
            /// <returns type="string">The short time zone name.</returns>
        }, 
        
        getTimeZoneId: function() {
            /// <summary>Return the time zone ID for this time zone.</summary>
            /// <returns type="string">The time zone ID.</returns>
        }, 
        
        isDaylightTime: function(date) {
            /// <summary>Check if Daylight Saving Time is in effect at a given time in this time zone.</summary>
            /// <param name="date" type="goog.date.DateLike">The time to check.</param>
            /// <returns type="boolean">True if Daylight Saving Time is in effect.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.i18n.TimeZone";
})(this);
