
/* vsdoc for goog.i18n.bidi */

(function (window) {
    window.goog.i18n = window.goog.i18n || {};

    window.goog.i18n.bidi = {
        /// <summary></summary>
        /// <field name="FORCE_RTL" type=""></field>
        /// <field name="IS_RTL" type="TODO(user): write a test that checks that this is a compile-time constant.">Constant that defines whether or not the current locale is a RTL locale.
        /// If {@link goog.i18n.bidi.FORCE_RTL} is not true, this constant will default
        /// to check that {@link goog.LOCALE} is one of a few major RTL locales.
        /// 
        /// &lt;p&gt;This is designed to be a maximally efficient compile-time constant. For
        /// example, for the default goog.LOCALE, compiling
        /// &quot;if (goog.i18n.bidi.IS_RTL) alert(&apos;rtl&apos;) else {}&quot; should produce no code. It
        /// is this design consideration that limits the implementation to only
        /// supporting a few major RTL locales, as opposed to the broader repertoire of
        /// something like goog.i18n.bidi.isRtlLanguage.
        /// 
        /// &lt;p&gt;Since this constant refers to the directionality of the locale, it is up
        /// to the caller to determine if this constant should also be used for the
        /// direction of the UI.
        /// 
        /// {@see goog.LOCALE}</field>
        /// <field name="Format" type="">Unicode formatting characters and directionality string constants.</field>
        /// <field name="Dir" type="">Directionality enum.</field>
        /// <field name="RIGHT" type="string">&apos;right&apos; string constant.</field>
        /// <field name="LEFT" type="string">&apos;left&apos; string constant.</field>
        /// <field name="I18N_RIGHT" type="string">&apos;left&apos; if locale is RTL, &apos;right&apos; if not.</field>
        /// <field name="I18N_LEFT" type="string">&apos;right&apos; if locale is RTL, &apos;left&apos; if not.</field>
        /// <field name="hasRtlChar" type="boolean">Test whether the given string has any RTL characters in it.</field>
        /// <field name="isRtlText" type="boolean">Check whether the first strongly directional character (if any) is RTL.</field>
        /// <field name="isLtrText" type="boolean">Check whether the first strongly directional character (if any) is LTR.</field>
        /// <field name="isLtrExitText" type="boolean">Check if the exit directionality a piece of text is LTR, i.e. if the last
        /// strongly-directional character in the string is LTR.</field>
        /// <field name="isRtlExitText" type="boolean">Check if the exit directionality a piece of text is RTL, i.e. if the last
        /// strongly-directional character in the string is RTL.</field>
        /// <returns type="goog.i18n.bidi"/>
                
        toDir: function(givenDir) {
            /// <summary>Convert a directionality given in various formats to a goog.i18n.bidi.Dir
            /// constant. Useful for interaction with different standards of directionality
            /// representation.</summary>
            /// <param name="givenDir" type="goog.i18n.bidi.Dir|number|boolean">Directionality given in
            ///     one of the following formats:
            ///     1. A goog.i18n.bidi.Dir constant.
            ///     2. A number (positive = LRT, negative = RTL, 0 = unknown).
            ///     3. A boolean (true = RTL, false = LTR).</param>
            /// <returns type="goog.i18n.bidi.Dir">A goog.i18n.bidi.Dir constant matching the given
            ///     directionality.</returns>
        }, 
        
        hasAnyRtl: function(str, opt_isHtml) {
            /// <summary>Test whether the given string has any RTL characters in it.</summary>
            /// <param name="str" type="string">The given string that need to be tested.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether the string contains RTL characters.</returns>
        }, 
        
        hasAnyLtr: function(str, opt_isHtml) {
            /// <summary>Test whether the given string has any LTR characters in it.</summary>
            /// <param name="str" type="string">The given string that need to be tested.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether the string contains LTR characters.</returns>
        }, 
        
        isRtlChar: function(str) {
            /// <summary>Check if the first character in the string is RTL or not.</summary>
            /// <param name="str" type="string">The given string that need to be tested.</param>
            /// <returns type="boolean">Whether the first character in str is an RTL char.</returns>
        }, 
        
        isLtrChar: function(str) {
            /// <summary>Check if the first character in the string is LTR or not.</summary>
            /// <param name="str" type="string">The given string that need to be tested.</param>
            /// <returns type="boolean">Whether the first character in str is an LTR char.</returns>
        }, 
        
        isNeutralChar: function(str) {
            /// <summary>Check if the first character in the string is neutral or not.</summary>
            /// <param name="str" type="string">The given string that need to be tested.</param>
            /// <returns type="boolean">Whether the first character in str is a neutral char.</returns>
        }, 
        
        startsWithRtl: function(str, opt_isHtml) {
            /// <summary>Check whether the first strongly directional character (if any) is RTL.</summary>
            /// <param name="str" type="string">String being checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether RTL directionality is detected using the first
            ///     strongly-directional character method.</returns>
        }, 
        
        startsWithLtr: function(str, opt_isHtml) {
            /// <summary>Check whether the first strongly directional character (if any) is LTR.</summary>
            /// <param name="str" type="string">String being checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether LTR directionality is detected using the first
            ///     strongly-directional character method.</returns>
        }, 
        
        isNeutralText: function(str, opt_isHtml) {
            /// <summary>Check whether the input string either contains no strongly directional
            /// characters or looks like a url.</summary>
            /// <param name="str" type="string">String being checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether neutral directionality is detected.</returns>
        }, 
        
        endsWithLtr: function(str, opt_isHtml) {
            /// <summary>Check if the exit directionality a piece of text is LTR, i.e. if the last
            /// strongly-directional character in the string is LTR.</summary>
            /// <param name="str" type="string">String being checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether LTR exit directionality was detected.</returns>
        }, 
        
        endsWithRtl: function(str, opt_isHtml) {
            /// <summary>Check if the exit directionality a piece of text is RTL, i.e. if the last
            /// strongly-directional character in the string is RTL.</summary>
            /// <param name="str" type="string">String being checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether RTL exit directionality was detected.</returns>
        }, 
        
        isRtlLanguage: function(lang) {
            /// <summary>Check if a BCP 47 / III language code indicates an RTL language, i.e. either:
            /// - a language code explicitly specifying one of the right-to-left scripts,
            ///   e.g. &quot;az-Arab&quot;, or&lt;p&gt;
            /// - a language code specifying one of the languages normally written in a
            ///   right-to-left script, e.g. &quot;fa&quot; (Farsi), except ones explicitly specifying
            ///   Latin or Cyrillic script (which are the usual LTR alternatives).&lt;p&gt;
            /// The list of right-to-left scripts appears in the 100-199 range in
            /// http://www.unicode.org/iso15924/iso15924-num.html, of which Arabic and
            /// Hebrew are by far the most widely used. We also recognize Thaana, N&apos;Ko, and
            /// Tifinagh, which also have significant modern usage. The rest (Syriac,
            /// Samaritan, Mandaic, etc.) seem to have extremely limited or no modern usage
            /// and are not recognized to save on code size.
            /// The languages usually written in a right-to-left script are taken as those
            /// with Suppress-Script: Hebr|Arab|Thaa|Nkoo|Tfng  in
            /// http://www.iana.org/assignments/language-subtag-registry,
            /// as well as Sindhi (sd) and Uyghur (ug).
            /// Other subtags of the language code, e.g. regions like EG (Egypt), are
            /// ignored.</summary>
            /// <param name="lang" type="string">BCP 47 (a.k.a III) language code.</param>
            /// <returns type="boolean">Whether the language code is an RTL language.</returns>
        }, 
        
        guardBracketInHtml: function(s, opt_isRtlContext) {
            /// <summary>Apply bracket guard using html span tag. This is to address the problem of
            /// messy bracket display frequently happens in RTL layout.</summary>
            /// <param name="s" type="string">The string that need to be processed.</param>
            /// <param name="opt_isRtlContext" type="boolean=">specifies default direction (usually
            ///     direction of the UI).</param>
            /// <returns type="string">The processed string, with all bracket guarded.</returns>
        }, 
        
        guardBracketInText: function(s, opt_isRtlContext) {
            /// <summary>Apply bracket guard using LRM and RLM. This is to address the problem of
            /// messy bracket display frequently happens in RTL layout.
            /// This version works for both plain text and html. But it does not work as
            /// good as guardBracketInHtml in some cases.</summary>
            /// <param name="s" type="string">The string that need to be processed.</param>
            /// <param name="opt_isRtlContext" type="boolean=">specifies default direction (usually
            ///     direction of the UI).</param>
            /// <returns type="string">The processed string, with all bracket guarded.</returns>
        }, 
        
        enforceRtlInHtml: function(html) {
            /// <summary>Enforce the html snippet in RTL directionality regardless overall context.
            /// If the html piece was enclosed by tag, dir will be applied to existing
            /// tag, otherwise a span tag will be added as wrapper. For this reason, if
            /// html snippet start with with tag, this tag must enclose the whole piece. If
            /// the tag already has a dir specified, this new one will override existing
            /// one in behavior (tested on FF and IE).</summary>
            /// <param name="html" type="string">The string that need to be processed.</param>
            /// <returns type="string">The processed string, with directionality enforced to RTL.</returns>
        }, 
        
        enforceRtlInText: function(text) {
            /// <summary>Enforce RTL on both end of the given text piece using unicode BiDi formatting
            /// characters RLE and PDF.</summary>
            /// <param name="text" type="string">The piece of text that need to be wrapped.</param>
            /// <returns type="string">The wrapped string after process.</returns>
        }, 
        
        enforceLtrInHtml: function(html) {
            /// <summary>Enforce the html snippet in RTL directionality regardless overall context.
            /// If the html piece was enclosed by tag, dir will be applied to existing
            /// tag, otherwise a span tag will be added as wrapper. For this reason, if
            /// html snippet start with with tag, this tag must enclose the whole piece. If
            /// the tag already has a dir specified, this new one will override existing
            /// one in behavior (tested on FF and IE).</summary>
            /// <param name="html" type="string">The string that need to be processed.</param>
            /// <returns type="string">The processed string, with directionality enforced to RTL.</returns>
        }, 
        
        enforceLtrInText: function(text) {
            /// <summary>Enforce LTR on both end of the given text piece using unicode BiDi formatting
            /// characters LRE and PDF.</summary>
            /// <param name="text" type="string">The piece of text that need to be wrapped.</param>
            /// <returns type="string">The wrapped string after process.</returns>
        }, 
        
        mirrorCSS: function(cssStr) {
            /// <summary>Swap location parameters and &apos;left&apos;/&apos;right&apos; in CSS specification. The
            /// processed string will be suited for RTL layout. Though this function can
            /// cover most cases, there are always exceptions. It is suggested to put
            /// those exceptions in separate group of CSS string.</summary>
            /// <param name="cssStr" type="string">CSS spefication string.</param>
            /// <returns type="string">Processed CSS specification string.</returns>
        }, 
        
        normalizeHebrewQuote: function(str) {
            /// <summary>Replace the double and single quote directly after a Hebrew character with
            /// GERESH and GERSHAYIM. In such case, most likely that&apos;s user intention.</summary>
            /// <param name="str" type="string">String that need to be processed.</param>
            /// <returns type="string">Processed string with double/single quote replaced.</returns>
        }, 
        
        estimateDirection: function(str, opt_isHtml) {
            /// <summary>Estimates the directionality of a string based on relative word counts.
            /// If the number of RTL words is above a certain percentage of the total number
            /// of strongly directional words, returns RTL.
            /// Otherwise, if any words are strongly or weakly LTR, returns LTR.
            /// Otherwise, returns UNKNOWN, which is used to mean &quot;neutral&quot;.
            /// Numbers are counted as weakly LTR.</summary>
            /// <param name="str" type="string">The string to be checked.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="goog.i18n.bidi.Dir">Estimated overall directionality of {@code str}.</returns>
        }, 
        
        detectRtlDirectionality: function(str, opt_isHtml) {
            /// <summary>Check the directionality of a piece of text, return true if the piece of
            /// text should be laid out in RTL direction.</summary>
            /// <param name="str" type="string">The piece of text that need to be detected.</param>
            /// <param name="opt_isHtml" type="boolean=">Whether str is HTML / HTML-escaped.
            ///     Default: false.</param>
            /// <returns type="boolean">Whether this piece of text should be laid out in RTL.</returns>
        }, 
        
        setElementDirAndAlign: function(element, dir) {
            /// <summary>Sets text input element&apos;s directionality and text alignment based on a
            /// given directionality.</summary>
            /// <param name="element" type="Element">Input field element to set directionality to.</param>
            /// <param name="dir" type="goog.i18n.bidi.Dir|number|boolean">Desired directionality, given
            ///     in one of the following formats:
            ///     1. A goog.i18n.bidi.Dir constant.
            ///     2. A number (positive = LRT, negative = RTL, 0 = unknown).
            ///     3. A boolean (true = RTL, false = LTR).</param>
        }
        
    };

    var $x = window.goog.i18n.bidi;
    $x.__namespace = "true";
    $x.__typeName = "goog.i18n.bidi";
})(this);
