
/* vsdoc for goog.i18n.currency */

(function (window) {
    window.goog.i18n = window.goog.i18n || {};

    window.goog.i18n.currency = {
        /// <summary></summary>
        /// <field name="CurrencyInfo" type="!Object.<!Array>">Tier 1 currency information.</field>
        /// <field name="CurrencyInfoTier2" type="!Object.<!Array>">Tier 2 currency information.</field>
        /// <returns type="goog.i18n.currency"/>
                
        addTier2Support: function() {
            /// <summary>This function will add tier2 currency support. Be default, only tier1
            /// (most popular currencies) are supportted. If an application really need
            /// to support some of the rarely used currency, it should call this function
            /// before any other functions in this namespace.</summary>
        }, 
        
        getGlobalCurrencyPattern: function(currencyCode) {
            /// <summary>Global currency pattern always uses ISO-4217 currency code as prefix. Local
            /// currency sign is added if it is different from currency code. Each currency
            /// is unique in this form. The negative side is that ISO code looks weird in
            /// some countries as poeple normally do not use it. Local currency sign
            /// alleviate the problem, but also make it a little verbose.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Global currency pattern string for given currency.</returns>
        }, 
        
        getGlobalCurrencySign: function(currencyCode) {
            /// <summary>Return global currency sign string for those applications
            /// that want to handle currency sign themselves.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Global currency sign for given currency.</returns>
        }, 
        
        getLocalCurrencyPattern: function(currencyCode) {
            /// <summary>Local currency pattern is the most frequently used pattern in currency&apos;s
            /// native region. It does not care about how it is distinguished from other
            /// currencies.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Local currency pattern string for given currency.</returns>
        }, 
        
        getLocalCurrencySign: function(currencyCode) {
            /// <summary>Returns local currency sign string for those applications that need to
            /// handle currency sign separately.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Local currency sign for given currency.</returns>
        }, 
        
        getPortableCurrencyPattern: function(currencyCode) {
            /// <summary>Portable currency pattern is a compromise between local and global. It is
            /// not a mere blend or mid-way between the two. Currency sign is chosen so that
            /// it looks familiar to native users. It also has enough information to
            /// distinguish itself from other popular currencies in its native region.
            /// In this pattern, currency sign symbols that has availability problem in
            /// popular fonts are also avoided.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Portable currency pattern string for given currency.</returns>
        }, 
        
        getPortableCurrencySign: function(currencyCode) {
            /// <summary>Return portable currency sign string for those applications that need to
            /// handle currency sign themselves.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="string">Portable currency sign for given currency.</returns>
        }, 
        
        isPrefixSignPosition: function(currencyCode) {
            /// <summary>This function returns the default currency sign position. Some application
            /// may want to handle currency sign and currency amount separately. This
            /// function can be used in such situation to position the currency sign
            /// relative to amount field correctly.
            /// To match the behavior of ICU, position is not determined by display locale.
            /// This method will always return true for now (because of the change of
            /// data) and should be avoided if possible.</summary>
            /// <param name="currencyCode" type="string">ISO-4217 3-letter currency code.</param>
            /// <returns type="boolean">true if currency should be positioned before amount field.</returns>
        }, 
        
        adjustPrecision: function(pattern, currencyCode) {
            /// <summary>Modify currency pattern string by adjusting precision for given currency.
            /// Standard currency pattern will have 2 digit after decimal point.
            /// Examples:
            ///   $#,##0.00 ->  $#,##0    (precision == 0)
            ///   $#,##0.00 ->  $#,##0.0  (precision == 1)
            ///   $#,##0.00 ->  $#,##0.000  (precision == 3)</summary>
            /// <param name="pattern" type="string">currency pattern string.</param>
            /// <param name="currencyCode" type="string">3-letter currency code.</param>
            /// <returns type="string">modified currency pattern string.</returns>
        }
        
    };

    var $x = window.goog.i18n.currency;
    $x.__namespace = "true";
    $x.__typeName = "goog.i18n.currency";
})(this);
