
/* vsdoc for goog.iter */

(function (window) {
    window.goog = window.goog || {};

    window.goog.iter = {
        /// <summary></summary>
        /// <field name="StopIteration" type="Error">Singleton Error object that is used to terminate iterations.</field>
        /// <returns type="goog.iter"/>
                
        toIterator: function(iterable) {
            /// <summary>Returns an iterator that knows how to iterate over the values in the object.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">If the object is an iterator it
            ///     will be returned as is.  If the object has a {@code __iterator__} method
            ///     that will be called to get the value iterator.  If the object is an
            ///     array-like object we create an iterator for that.</param>
            /// <returns type="!goog.iter.Iterator">An iterator that knows how to iterate over the
            ///     values in {@code iterable}.</returns>
        }, 
        
        forEach: function(iterable, f, opt_obj) {
            /// <summary>Calls a function for each element in the iterator with the element of the
            /// iterator passed as argument.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to iterate
            ///     over.  If the iterable is an object {@code toIterator} will be called on
            ///     it.</param>
            /// <param name="f" type="Function">The function to call for every element.  This function
            ///     takes 3 arguments (the element, undefined, and the iterator) and the
            ///     return value is irrelevant.  The reason for passing undefined as the
            ///     second argument is so that the same function can be used in
            ///     {@see goog.array#forEach} as well as others.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
        }, 
        
        filter: function(iterable, f, opt_obj) {
            /// <summary>Calls a function for every element in the iterator, and if the function
            /// returns true adds the element to a new iterator.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to iterate over.</param>
            /// <param name="f" type="Function">The function to call for every element.  This function
            ///     takes 3 arguments (the element, undefined, and the iterator) and should
            ///     return a boolean.  If the return value is true the element will be
            ///     included  in the returned iteror.  If it is false the element is not
            ///     included.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
            /// <returns type="!goog.iter.Iterator">A new iterator in which only elements that
            ///     passed the test are present.</returns>
        }, 
        
        range: function(startOrStop, opt_stop, opt_step) {
            /// <summary>Creates a new iterator that returns the values in a range.  This function
            /// can take 1, 2 or 3 arguments:
            /// &lt;pre&gt;
            /// range(5) same as range(0, 5, 1)
            /// range(2, 5) same as range(2, 5, 1)
            /// &lt;/pre&gt;</summary>
            /// <param name="startOrStop" type="number">The stop value if only one argument is provided.
            ///     The start value if 2 or more arguments are provided.  If only one
            ///     argument is used the start value is 0.</param>
            /// <param name="opt_stop" type="number=">The stop value.  If left out then the first
            ///     argument is used as the stop value.</param>
            /// <param name="opt_step" type="number=">The number to increment with between each call to
            ///     next.  This can be negative.</param>
            /// <returns type="!goog.iter.Iterator">A new iterator that returns the values in the
            ///     range.</returns>
        }, 
        
        join: function(iterable, deliminator) {
            /// <summary>Joins the values in a iterator with a delimiter.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to get the values from.</param>
            /// <param name="deliminator" type="string">The text to put between the values.</param>
            /// <returns type="string">The joined value string.</returns>
        }, 
        
        map: function(iterable, f, opt_obj) {
            /// <summary>For every element in the iterator call a function and return a new iterator
            /// with that value.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to iterate over.</param>
            /// <param name="f" type="Function">The function to call for every element.  This function
            ///     takes 3 arguments (the element, undefined, and the iterator) and should
            ///     return a new value.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
            /// <returns type="!goog.iter.Iterator">A new iterator that returns the results of
            ///     applying the function to each element in the original iterator.</returns>
        }, 
        
        reduce: function(iterable, f, val, opt_obj) {
            /// <summary>Passes every element of an iterator into a function and accumulates the
            /// result.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to iterate over.</param>
            /// <param name="f" type="Function">The function to call for every element. This function
            ///     takes 2 arguments (the function&apos;s previous result or the initial value,
            ///     and the value of the current element).
            ///     function(previousValue, currentElement) : newValue.</param>
            /// <param name="val" type="*">The initial value to pass into the function on the first call.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within f.</param>
            /// <returns type="*">Result of evaluating f repeatedly across the values of
            ///     the iterator.</returns>
        }, 
        
        some: function(iterable, f, opt_obj) {
            /// <summary>Goes through the values in the iterator. Calls f for each these and if any of
            /// them returns true, this returns true (without checking the rest). If all
            /// return false this will return false.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function
            ///     takes 3 arguments (the value, undefined, and the iterator) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
            /// <returns type="boolean">true if any value passes the test.</returns>
        }, 
        
        every: function(iterable, f, opt_obj) {
            /// <summary>Goes through the values in the iterator. Calls f for each these and if any of
            /// them returns false this returns false (without checking the rest). If all
            /// return true this will return true.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function
            ///     takes 3 arguments (the value, undefined, and the iterator) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
            /// <returns type="boolean">true if every value passes the test.</returns>
        }, 
        
        chain: function(var_args) {
            /// <summary>Takes zero or more iterators and returns one iterator that will iterate over
            /// them in the order chained.</summary>
            /// <param name="var_args" type="...goog.iter.Iterator">Any number of iterator objects.</param>
            /// <returns type="!goog.iter.Iterator">Returns a new iterator that will iterate over
            ///     all the given iterators&apos; contents.</returns>
        }, 
        
        dropWhile: function(iterable, f, opt_obj) {
            /// <summary>Builds a new iterator that iterates over the original, but skips elements as
            /// long as a supplied function returns true.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function
            ///     takes 3 arguments (the value, undefined, and the iterator) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos; within
            ///     {@code f}.</param>
            /// <returns type="!goog.iter.Iterator">A new iterator that drops elements from the
            ///     original iterator as long as {@code f} is true.</returns>
        }, 
        
        takeWhile: function(iterable, f, opt_obj) {
            /// <summary>Builds a new iterator that iterates over the original, but only as long as a
            /// supplied function returns true.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function
            ///     takes 3 arguments (the value, undefined, and the iterator) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object in f when called.</param>
            /// <returns type="!goog.iter.Iterator">A new iterator that keeps elements in the
            ///     original iterator as long as the function is true.</returns>
        }, 
        
        toArray: function(iterable) {
            /// <summary>Converts the iterator to an array</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterator to convert to an array.</param>
            /// <returns type="!Array">An array of the elements the iterator iterates over.</returns>
        }, 
        
        equals: function(iterable1, iterable2) {
            /// <summary>Iterates over 2 iterators and returns true if they contain the same sequence
            /// of elements and have the same length.</summary>
            /// <param name="iterable1" type="goog.iter.Iterable">The first iterable object.</param>
            /// <param name="iterable2" type="goog.iter.Iterable">The second iterable object.</param>
            /// <returns type="boolean">true if the iterators contain the same sequence of
            ///     elements and have the same length.</returns>
        }, 
        
        nextOrValue: function(iterable, defaultValue) {
            /// <summary>Advances the iterator to the next position, returning the given default value
            /// instead of throwing an exception if the iterator has no more entries.</summary>
            /// <param name="iterable" type="goog.iter.Iterable">The iterable object.</param>
            /// <param name="defaultValue" type="*">The value to return if the iterator is empty.</param>
            /// <returns type="*">The next item in the iteration, or defaultValue if the iterator
            ///     was empty.</returns>
        }, 
        
        product: function(var_args) {
            /// <summary>Cartesian product of zero or more sets.  Gives an iterator that gives every
            /// combination of one element chosen from each set.  For example,
            /// ([1, 2], [3, 4]) gives ([1, 3], [1, 4], [2, 3], [2, 4]).</summary>
            /// <param name="var_args" type="...!goog.array.ArrayLike.*">Zero or more sets, as arrays.</param>
            /// <returns type="!goog.iter.Iterator">An iterator that gives each n-tuple (as an
            ///     array).</returns>
        }, 
        
        cycle: function(iterable) {
            /// <summary>Create an iterator to cycle over the iterable&apos;s elements indefinitely.
            /// For example, ([1, 2, 3]) would return : 1, 2, 3, 1, 2, 3, ...</summary>
            /// <param name="iterable" type="!goog.iter.Iterable">The iterable object.</param>
            /// <returns type="!goog.iter.Iterator">An iterator that iterates indefinitely over
            /// the values in {@code iterable}.</returns>
        }
        
    };

    var $x = window.goog.iter;
    $x.__namespace = "true";
    $x.__typeName = "goog.iter";
})(this);
