
/* vsdoc for goog.labs.structs.Map */

(function (window) {
    window.goog.labs.structs = window.goog.labs.structs || {};

    window.goog.labs.structs.Map = function(){
        /// <summary></summary>
        /// <field name="BrowserFeature" type="">Browser feature enum necessary for map.</field>
        /// <returns type="goog.labs.structs.Map"/>
    };

    var $x = window.goog.labs.structs.Map;
    $x.prototype = {
                
        set: function(key, value) {
            /// <summary>Adds the (key, value) pair, overriding previous entry with the same
            /// key, if any.</summary>
            /// <param name="key" type="string">The key.</param>
            /// <param name="value" type="*">The value.</param>
        }, 
        
        get: function(key, opt_default) {
            /// <summary>Gets the value for the given key.</summary>
            /// <param name="key" type="string">The key whose value we want to retrieve.</param>
            /// <param name="opt_default" type="*=">The default value to return if the key does
            ///     not exist in the map, default to undefined.</param>
            /// <returns type="*">The value corresponding to the given key, or opt_default
            ///     if the key does not exist in this map.</returns>
        }, 
        
        remove: function(key) {
            /// <summary>Removes the map entry with the given key.</summary>
            /// <param name="key" type="string">The key to remove.</param>
            /// <returns type="boolean">True if the entry is removed.</returns>
        }, 
        
        addAll: function(map) {
            /// <summary>Adds the content of the map to this map. If a new entry uses a key
            /// that already exists in this map, the existing key is replaced.</summary>
            /// <param name="map" type="!goog.labs.structs.Map">The map to add.</param>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the map is empty.</returns>
        }, 
        
        getCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of the entries in this map.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary></summary>
            /// <param name="key" type="string">The key to check.</param>
            /// <returns type="boolean">True if the map contains the given key.</returns>
        }, 
        
        containsValue: function(value) {
            /// <summary>Whether the map contains the given value. The comparison is done
            /// using !== comparator. Also returns true if the passed value is NaN
            /// and a NaN value exists in the map.</summary>
            /// <param name="value" type="*">Value to check.</param>
            /// <returns type="boolean">True if the map contains the given value.</returns>
        }, 
        
        getKeys: function() {
            /// <summary></summary>
            /// <returns type="!Array.string">An array of all the keys contained in this map.</returns>
        }, 
        
        getValues: function() {
            /// <summary></summary>
            /// <returns type="!Array.*">An array of all the values contained in this map.
            ///     There may be duplicates.</returns>
        }, 
        
        getEntries: function() {
            /// <summary></summary>
            /// <returns type="!Array.Array">An array of entries. Each entry is of the
            ///     form [key, value]. Do not rely on consistent ordering of entries.</returns>
        }, 
        
        clear: function() {
            /// <summary>Clears the map to the initial state.</summary>
        }, 
        
        clone: function() {
            /// <summary>Clones this map.</summary>
            /// <returns type="!goog.labs.structs.Map">The clone of this map.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.labs.structs.Map";
})(this);
