
/* vsdoc for goog.locale */

(function (window) {
    window.goog = window.goog || {};

    window.goog.locale = {
        /// <summary></summary>
        /// <field name="countries" type="Array">List of codes for countries valid today.</field>
        /// <field name="defaultLocaleNameConstants" type="">Default list of locale specific country and language names</field>
        /// <field name="genericFontNames" type=""></field>
        /// <field name="genericFontNamesData" type="Object">Map from script code or language code to list of pairs of (generic name,
        /// font name fallback list).</field>
        /// <field name="Resource" type="">Enum of resources that can be registered.</field>
        /// <field name="nativeNameConstants" type="Object">Native country and language names</field>
        /// <field name="scriptToLanguages" type="Object">The script code to list of language codes map.</field>
        /// <field name="timeZoneDetection" type=""></field>
        /// <field name="TimeZoneFingerprint" type="">Time zone fingerprint mapping to time zone list.</field>
        /// <field name="TimeZoneList" type=""></field>
        /// <returns type="goog.locale"/>
                
        setLocale: function(localeName) {
            /// <summary>Set currnet locale to the specified one.</summary>
            /// <param name="localeName" type="string">Locale name string. We are following the usage
            ///     in CLDR, but can make a few compromise for existing name compatibility.</param>
        }, 
        
        getLocale: function() {
            /// <summary>Retrieve the currnet locale</summary>
            /// <returns type="string">Current locale name string.</returns>
        }, 
        
        getLanguageSubTag: function(languageCode) {
            /// <summary>Returns the language-subtag of the given language code.</summary>
            /// <param name="languageCode" type="string">Language code to extract language subtag from.</param>
            /// <returns type="string">Language subtag (in lowercase).</returns>
        }, 
        
        getRegionSubTag: function(languageCode) {
            /// <summary>Returns the region-sub-tag of the given language code.</summary>
            /// <param name="languageCode" type="string">Language code to extract region subtag from.</param>
            /// <returns type="string">Region sub-tag (in uppercase).</returns>
        }, 
        
        getScriptSubTag: function(languageCode) {
            /// <summary>Returns the script subtag of the locale with the first alphabet in uppercase
            /// and the rest 3 characters in lower case.</summary>
            /// <param name="languageCode" type="string">Language Code to extract script subtag from.</param>
            /// <returns type="string">Script subtag.</returns>
        }, 
        
        getVariantSubTag: function(languageCode) {
            /// <summary>Returns the variant-sub-tag of the given language code.</summary>
            /// <param name="languageCode" type="string">Language code to extract variant subtag from.</param>
            /// <returns type="string">Variant sub-tag.</returns>
        }, 
        
        getNativeCountryName: function(countryCode) {
            /// <summary>Returns the country name of the provided language code in its native
            /// language.
            /// 
            /// This method depends on goog.locale.nativeNameConstants available from
            /// nativenameconstants.js. User of this method has to add dependency to this.</summary>
            /// <param name="countryCode" type="string">Code to lookup the country name for.</param>
            /// <returns type="string">Country name for the provided language code.</returns>
        }, 
        
        getLocalizedCountryName: function(languageCode, opt_localeSymbols) {
            /// <summary>Returns the localized country name for the provided language code in the
            /// current or provided locale symbols set.
            /// 
            /// This method depends on goog.locale.LocaleNameConstants__&lt;locale&gt; available
            /// from http://go/js_locale_data. User of this method has to add dependency to
            /// this.</summary>
            /// <param name="languageCode" type="string">Language code to lookup the country name for.</param>
            /// <param name="opt_localeSymbols" type="Object=">If omitted the current locale symbol
            ///     set is used.</param>
            /// <returns type="string">Localized country name.</returns>
        }, 
        
        getNativeLanguageName: function(languageCode) {
            /// <summary>Returns the language name of the provided language code in its native
            /// language.
            /// 
            /// This method depends on goog.locale.nativeNameConstants available from
            /// nativenameconstants.js. User of this method has to add dependency to this.</summary>
            /// <param name="languageCode" type="string">Language code to lookup the language name for.</param>
            /// <returns type="string">Language name for the provided language code.</returns>
        }, 
        
        getLocalizedLanguageName: function(languageCode, opt_localeSymbols) {
            /// <summary>Returns the localized language name for the provided language code in
            /// the current or provided locale symbols set.
            /// 
            /// This method depends on goog.locale.LocaleNameConstants__&lt;locale&gt; available
            /// from http://go/js_locale_data. User of this method has to add dependency to
            /// this.</summary>
            /// <param name="languageCode" type="string">Language code to lookup the language name for.</param>
            /// <param name="opt_localeSymbols" type="Object=">locale symbol set if given.</param>
            /// <returns type="string">Localized language name of the provided language code.</returns>
        }, 
        
        registerResource: function(dataObj, resourceName, localeName) {
            /// <summary>Register a resource object for certain locale.</summary>
            /// <param name="dataObj" type="Object">The resource object being registered.</param>
            /// <param name="resourceName" type="goog.locale.Resource|string">String that represents
            ///     the type of resource.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        isResourceRegistered: function(resourceName, localeName) {
            /// <summary>Returns true if the required resource has already been registered.</summary>
            /// <param name="resourceName" type="goog.locale.Resource|string">String that represents
            ///     the type of resource.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
            /// <returns type="boolean">Whether the required resource has already been registered.</returns>
        }, 
        
        registerTimeZoneConstants: function(dataObj, localeName) {
            /// <summary>Registers the timezone constants object for a given locale name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        registerLocaleNameConstants: function(dataObj, localeName) {
            /// <summary>Registers the LocaleNameConstants constants object for a given locale name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        registerTimeZoneSelectedIds: function(dataObj, localeName) {
            /// <summary>Registers the TimeZoneSelectedIds constants object for a given locale name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        registerTimeZoneSelectedShortNames: function(dataObj, localeName) {
            /// <summary>Registers the TimeZoneSelectedShortNames constants object for a given
            ///     locale name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        registerTimeZoneSelectedLongNames: function(dataObj, localeName) {
            /// <summary>Registers the TimeZoneSelectedLongNames constants object for a given locale
            ///     name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        registerTimeZoneAllLongNames: function(dataObj, localeName) {
            /// <summary>Registers the TimeZoneAllLongNames constants object for a given locale name.</summary>
            /// <param name="dataObj" type="Object">The resource object.</param>
            /// <param name="localeName" type="string">Locale ID.</param>
        }, 
        
        getResource: function(resourceName, opt_locale) {
            /// <summary>Retrieve specified resource for certain locale.</summary>
            /// <param name="resourceName" type="string">String that represents the type of resource.</param>
            /// <param name="opt_locale" type="string=">Locale ID, if not given, current locale
            ///     will be assumed.</param>
            /// <returns type="Object|undefined">The resource object that hold all the resource
            ///     data, or undefined if not available.</returns>
        }, 
        
        getResourceWithFallback: function(resourceName, opt_locale) {
            /// <summary>Retrieve specified resource for certain locale with fallback. For example,
            /// request of &apos;zh_CN&apos; will be resolved in following order: zh_CN, zh, en.
            /// If none of the above succeeds, of if the resource as indicated by
            /// resourceName does not exist at all, undefined will be returned.</summary>
            /// <param name="resourceName" type="string">String that represents the type of resource.</param>
            /// <param name="opt_locale" type="string=">locale ID, if not given, current locale
            ///     will be assumed.</param>
            /// <returns type="Object|undefined">The resource object for desired locale.</returns>
        }, 
        
        getTimeZoneSelectedShortNames: function(opt_regionOrLang) {
            /// <summary>Returns the displayable list of short timezone names paired with its id for
            /// the current locale, selected based on the region or language provided.
            /// 
            /// This method depends on goog.locale.TimeZone*__&lt;locale&gt; available
            /// from http://go/js_locale_data. User of this method
            /// has to add dependacy to this.</summary>
            /// <param name="opt_regionOrLang" type="string=">If region tag is provided, timezone ids
            ///    specific this region are considered. If language is provided, all regions
            ///    for which this language is defacto official is considered. If
            ///    this parameter is not speficied, current locale is used to
            ///    extract this information.</param>
            /// <returns type="Array.Object">Localized and relevant list of timezone names
            ///    and ids.</returns>
        }, 
        
        getTimeZoneSelectedLongNames: function(opt_regionOrLang) {
            /// <summary>Returns the displayable list of long timezone names paired with its id for
            /// the current locale, selected based on the region or language provided.
            /// 
            /// This method depends on goog.locale.TimeZone*__&lt;locale&gt; available
            /// from http://go/js_locale_data. User of this method
            /// has to add dependacy to this.</summary>
            /// <param name="opt_regionOrLang" type="string=">If region tag is provided, timezone ids
            ///    specific this region are considered. If language is provided, all regions
            ///    for which this language is defacto official is considered. If
            ///    this parameter is not speficied, current locale is used to
            ///    extract this information.</param>
            /// <returns type="Array.Object">Localized and relevant list of timezone names
            ///    and ids.</returns>
        }, 
        
        getTimeZoneAllLongNames: function() {
            /// <summary>Returns the displayable list of long timezone names paired with its id for
            /// the current locale.
            /// 
            /// This method depends on goog.locale.TimeZoneAllLongNames__&lt;locale&gt; available
            /// from http://go/js_locale_data. User of this method
            /// has to add dependacy to this.</summary>
            /// <returns type="Array.Object">localized and relevant list of timezone names
            ///    and ids.</returns>
        }
        
    };

    var $x = window.goog.locale;
    $x.__namespace = "true";
    $x.__typeName = "goog.locale";
})(this);
