
/* vsdoc for goog.math */

(function (window) {
    window.goog = window.goog || {};

    window.goog.math = {
        /// <summary></summary>
        /// <field name="tdma" type=""></field>
        /// <returns type="goog.math"/>
                
        randomInt: function(a) {
            /// <summary>Returns a random integer greater than or equal to 0 and less than {@code a}.</summary>
            /// <param name="a" type="number">The upper bound for the random integer (exclusive).</param>
            /// <returns type="number">A random integer N such that 0 <= N < a.</returns>
        }, 
        
        uniformRandom: function(a, b) {
            /// <summary>Returns a random number greater than or equal to {@code a} and less than
            /// {@code b}.</summary>
            /// <param name="a" type="number">The lower bound for the random number (inclusive).</param>
            /// <param name="b" type="number">The upper bound for the random number (exclusive).</param>
            /// <returns type="number">A random number N such that a <= N < b.</returns>
        }, 
        
        clamp: function(value, min, max) {
            /// <summary>Takes a number and clamps it to within the provided bounds.</summary>
            /// <param name="value" type="number">The input number.</param>
            /// <param name="min" type="number">The minimum value to return.</param>
            /// <param name="max" type="number">The maximum value to return.</param>
            /// <returns type="number">The input number if it is within bounds, or the nearest
            ///     number within the bounds.</returns>
        }, 
        
        modulo: function(a, b) {
            /// <summary>The % operator in JavaScript returns the remainder of a / b, but differs from
            /// some other languages in that the result will have the same sign as the
            /// dividend. For example, -1 % 8 == -1, whereas in some other languages
            /// (such as Python) the result would be 7. This function emulates the more
            /// correct modulo behavior, which is useful for certain applications such as
            /// calculating an offset index in a circular list.</summary>
            /// <param name="a" type="number">The dividend.</param>
            /// <param name="b" type="number">The divisor.</param>
            /// <returns type="number">a % b where the result is between 0 and b (either 0 <= x < b
            ///     or b < x <= 0, depending on the sign of b).</returns>
        }, 
        
        lerp: function(a, b, x) {
            /// <summary>Performs linear interpolation between values a and b. Returns the value
            /// between a and b proportional to x (when x is between 0 and 1. When x is
            /// outside this range, the return value is a linear extrapolation).</summary>
            /// <param name="a" type="number">A number.</param>
            /// <param name="b" type="number">A number.</param>
            /// <param name="x" type="number">The proportion between a and b.</param>
            /// <returns type="number">The interpolated value between a and b.</returns>
        }, 
        
        nearlyEquals: function(a, b, opt_tolerance) {
            /// <summary>Tests whether the two values are equal to each other, within a certain
            /// tolerance to adjust for floating pount errors.</summary>
            /// <param name="a" type="number">A number.</param>
            /// <param name="b" type="number">A number.</param>
            /// <param name="opt_tolerance" type="number=">Optional tolerance range. Defaults
            ///     to 0.000001. If specified, should be greater than 0.</param>
            /// <returns type="boolean">Whether {@code a} and {@code b} are nearly equal.</returns>
        }, 
        
        standardAngle: function(angle) {
            /// <summary>Standardizes an angle to be in range [0-360). Negative angles become
            /// positive, and values greater than 360 are returned modulo 360.</summary>
            /// <param name="angle" type="number">Angle in degrees.</param>
            /// <returns type="number">Standardized angle.</returns>
        }, 
        
        toRadians: function(angleDegrees) {
            /// <summary>Converts degrees to radians.</summary>
            /// <param name="angleDegrees" type="number">Angle in degrees.</param>
            /// <returns type="number">Angle in radians.</returns>
        }, 
        
        toDegrees: function(angleRadians) {
            /// <summary>Converts radians to degrees.</summary>
            /// <param name="angleRadians" type="number">Angle in radians.</param>
            /// <returns type="number">Angle in degrees.</returns>
        }, 
        
        angleDx: function(degrees, radius) {
            /// <summary>For a given angle and radius, finds the X portion of the offset.</summary>
            /// <param name="degrees" type="number">Angle in degrees (zero points in +X direction).</param>
            /// <param name="radius" type="number">Radius.</param>
            /// <returns type="number">The x-distance for the angle and radius.</returns>
        }, 
        
        angleDy: function(degrees, radius) {
            /// <summary>For a given angle and radius, finds the Y portion of the offset.</summary>
            /// <param name="degrees" type="number">Angle in degrees (zero points in +X direction).</param>
            /// <param name="radius" type="number">Radius.</param>
            /// <returns type="number">The y-distance for the angle and radius.</returns>
        }, 
        
        angle: function(x1, y1, x2, y2) {
            /// <summary>Computes the angle between two points (x1,y1) and (x2,y2).
            /// Angle zero points in the +X direction, 90 degrees points in the +Y
            /// direction (down) and from there we grow clockwise towards 360 degrees.</summary>
            /// <param name="x1" type="number">x of first point.</param>
            /// <param name="y1" type="number">y of first point.</param>
            /// <param name="x2" type="number">x of second point.</param>
            /// <param name="y2" type="number">y of second point.</param>
            /// <returns type="number">Standardized angle in degrees of the vector from
            ///     x1,y1 to x2,y2.</returns>
        }, 
        
        angleDifference: function(startAngle, endAngle) {
            /// <summary>Computes the difference between startAngle and endAngle (angles in degrees).</summary>
            /// <param name="startAngle" type="number">Start angle in degrees.</param>
            /// <param name="endAngle" type="number">End angle in degrees.</param>
            /// <returns type="number">The number of degrees that when added to
            ///     startAngle will result in endAngle. Positive numbers mean that the
            ///     direction is clockwise. Negative numbers indicate a counter-clockwise
            ///     direction.
            ///     The shortest route (clockwise vs counter-clockwise) between the angles
            ///     is used.
            ///     When the difference is 180 degrees, the function returns 180 (not -180)
            ///     angleDifference(30, 40) is 10, and angleDifference(40, 30) is -10.
            ///     angleDifference(350, 10) is 20, and angleDifference(10, 350) is -20.</returns>
        }, 
        
        sign: function(x) {
            /// <summary>Returns the sign of a number as per the &quot;sign&quot; or &quot;signum&quot; function.</summary>
            /// <param name="x" type="number">The number to take the sign of.</param>
            /// <returns type="number">-1 when negative, 1 when positive, 0 when 0.</returns>
        }, 
        
        longestCommonSubsequence: function(array1, array2, opt_compareFn, opt_collectorFn) {
            /// <summary>JavaScript implementation of Longest Common Subsequence problem.
            /// http://en.wikipedia.org/wiki/Longest_common_subsequence
            /// 
            /// Returns the longest possible array that is subarray of both of given arrays.</summary>
            /// <param name="array1" type="Array.Object">First array of objects.</param>
            /// <param name="array2" type="Array.Object">Second array of objects.</param>
            /// <param name="opt_compareFn" type="Function=">Function that acts as a custom comparator
            ///     for the array ojects. Function should return true if objects are equal,
            ///     otherwise false.</param>
            /// <param name="opt_collectorFn" type="Function=">Function used to decide what to return
            ///     as a result subsequence. It accepts 2 arguments: index of common element
            ///     in the first array and index in the second. The default function returns
            ///     element from the first array.</param>
            /// <returns type="Array.Object">A list of objects that are common to both arrays
            ///     such that there is no common subsequence with size greater than the
            ///     length of the list.</returns>
        }, 
        
        sum: function(var_args) {
            /// <summary>Returns the sum of the arguments.</summary>
            /// <param name="var_args" type="...number">Numbers to add.</param>
            /// <returns type="number">The sum of the arguments (0 if no arguments were provided,
            ///     {@code NaN} if any of the arguments is not a valid number).</returns>
        }, 
        
        average: function(var_args) {
            /// <summary>Returns the arithmetic mean of the arguments.</summary>
            /// <param name="var_args" type="...number">Numbers to average.</param>
            /// <returns type="number">The average of the arguments ({@code NaN} if no arguments
            ///     were provided or any of the arguments is not a valid number).</returns>
        }, 
        
        standardDeviation: function(var_args) {
            /// <summary>Returns the sample standard deviation of the arguments.  For a definition of
            /// sample standard deviation, see e.g.
            /// http://en.wikipedia.org/wiki/Standard_deviation</summary>
            /// <param name="var_args" type="...number">Number samples to analyze.</param>
            /// <returns type="number">The sample standard deviation of the arguments (0 if fewer
            ///     than two samples were provided, or {@code NaN} if any of the samples is
            ///     not a valid number).</returns>
        }, 
        
        isInt: function(num) {
            /// <summary>Returns whether the supplied number represents an integer, i.e. that is has
            /// no fractional component.  No range-checking is performed on the number.</summary>
            /// <param name="num" type="number">The number to test.</param>
            /// <returns type="boolean">Whether {@code num} is an integer.</returns>
        }, 
        
        isFiniteNumber: function(num) {
            /// <summary>Returns whether the supplied number is finite and not NaN.</summary>
            /// <param name="num" type="number">The number to test.</param>
            /// <returns type="boolean">Whether {@code num} is a finite number.</returns>
        }
        
    };

    var $x = window.goog.math;
    $x.__namespace = "true";
    $x.__typeName = "goog.math";
})(this);
