
/* vsdoc for goog.math.Bezier */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Bezier = function(x0, y0, x1, y1, x2, y2, x3, y3){
        /// <summary></summary>
        /// <param name="x0" type="number">X coordinate of the start point.</param>
        /// <param name="y0" type="number">Y coordinate of the start point.</param>
        /// <param name="x1" type="number">X coordinate of the first control point.</param>
        /// <param name="y1" type="number">Y coordinate of the first control point.</param>
        /// <param name="x2" type="number">X coordinate of the second control point.</param>
        /// <param name="y2" type="number">Y coordinate of the second control point.</param>
        /// <param name="x3" type="number">X coordinate of the end point.</param>
        /// <param name="y3" type="number">Y coordinate of the end point.</param>
        /// <field name="x0" type="number">X coordinate of the first point.</field>
        /// <field name="y0" type="number">Y coordinate of the first point.</field>
        /// <field name="x1" type="number">X coordinate of the first control point.</field>
        /// <field name="y1" type="number">Y coordinate of the first control point.</field>
        /// <field name="x2" type="number">X coordinate of the second control point.</field>
        /// <field name="y2" type="number">Y coordinate of the second control point.</field>
        /// <field name="x3" type="number">X coordinate of the end point.</field>
        /// <field name="y3" type="number">Y coordinate of the end point.</field>
        /// <field name="KAPPA" type="number">Constant used to approximate ellipses.
        /// See: http://canvaspaint.org/blog/2006/12/ellipse/</field>
        /// <returns type="goog.math.Bezier"/>
    };

    var $x = window.goog.math.Bezier;
    $x.prototype = {
                
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Bezier">A copy of this curve.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Test if the given curve is exactly the same as this one.</summary>
            /// <param name="other" type="goog.math.Bezier">The other curve.</param>
            /// <returns type="boolean">Whether the given curve is the same as this one.</returns>
        }, 
        
        flip: function() {
            /// <summary>Modifies the curve in place to progress in the opposite direction.</summary>
        }, 
        
        getPoint: function(t) {
            /// <summary>Computes the curve at a point between 0 and 1.</summary>
            /// <param name="t" type="number">The point on the curve to find.</param>
            /// <returns type="!goog.math.Coordinate">The computed coordinate.</returns>
        }, 
        
        subdivideLeft: function(t) {
            /// <summary>Changes this curve in place to be the portion of itself from [t, 1].</summary>
            /// <param name="t" type="number">The start of the desired portion of the curve.</param>
        }, 
        
        subdivideRight: function(t) {
            /// <summary>Changes this curve in place to be the portion of itself from [0, t].</summary>
            /// <param name="t" type="number">The end of the desired portion of the curve.</param>
        }, 
        
        subdivide: function(s, t) {
            /// <summary>Changes this curve in place to be the portion of itself from [s, t].</summary>
            /// <param name="s" type="number">The start of the desired portion of the curve.</param>
            /// <param name="t" type="number">The end of the desired portion of the curve.</param>
        }, 
        
        solvePositionFromXValue: function(xVal) {
            /// <summary>Computes the position t of a point on the curve given its x coordinate.
            /// That is, for an input xVal, finds t s.t. getPoint(t).x = xVal.
            /// As such, the following should always be true up to some small epsilon:
            /// t ~ solvePositionFromXValue(getPoint(t).x) for t in [0, 1].</summary>
            /// <param name="xVal" type="number">The x coordinate of the point to find on the curve.</param>
            /// <returns type="number">The position t.</returns>
        }, 
        
        solveYValueFromXValue: function(xVal) {
            /// <summary>Computes the y coordinate of a point on the curve given its x coordinate.</summary>
            /// <param name="xVal" type="number">The x coordinate of the point on the curve.</param>
            /// <returns type="number">The y coordinate of the point on the curve.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Bezier";
})(this);
