
/* vsdoc for goog.math.Box */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Box = function(top, right, bottom, left){
        /// <summary></summary>
        /// <param name="top" type="number">Top.</param>
        /// <param name="right" type="number">Right.</param>
        /// <param name="bottom" type="number">Bottom.</param>
        /// <param name="left" type="number">Left.</param>
        /// <field name="top" type="number">Top</field>
        /// <field name="right" type="number">Right</field>
        /// <field name="bottom" type="number">Bottom</field>
        /// <field name="left" type="number">Left</field>
        /// <returns type="goog.math.Box"/>
    };

    var $x = window.goog.math.Box;
    $x.prototype = {
                
        boundingBox: function(var_args) {
            /// <summary>Creates a Box by bounding a collection of goog.math.Coordinate objects</summary>
            /// <param name="var_args" type="...goog.math.Coordinate">Coordinates to be included inside
            ///     the box.</param>
            /// <returns type="!goog.math.Box">A Box containing all the specified Coordinates.</returns>
        }, 
        
        clone: function() {
            /// <summary>Creates a copy of the box with the same dimensions.</summary>
            /// <returns type="!goog.math.Box">A clone of this Box.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a nice string representing the box.</summary>
            /// <returns type="string">In the form (50t, 73r, 24b, 13l).</returns>
        }, 
        
        contains: function(other) {
            /// <summary>Returns whether the box contains a coordinate or another box.</summary>
            /// <param name="other" type="goog.math.Coordinate|goog.math.Box">A Coordinate or a Box.</param>
            /// <returns type="boolean">Whether the box contains the coordinate or other box.</returns>
        }, 
        
        expand: function(top, opt_right, opt_bottom, opt_left) {
            /// <summary>Expands box with the given margins.</summary>
            /// <param name="top" type="number|goog.math.Box">Top margin or box with all margins.</param>
            /// <param name="opt_right" type="number=">Right margin.</param>
            /// <param name="opt_bottom" type="number=">Bottom margin.</param>
            /// <param name="opt_left" type="number=">Left margin.</param>
            /// <returns type="!goog.math.Box">A reference to this Box.</returns>
        }, 
        
        expandToInclude: function(box) {
            /// <summary>Expand this box to include another box.
            /// NOTE(user): This is used in code that needs to be very fast, please don&apos;t
            /// add functionality to this function at the expense of speed (variable
            /// arguments, accepting multiple argument types, etc).</summary>
            /// <param name="box" type="goog.math.Box">The box to include in this one.</param>
        }, 
        
        equals: function(a, b) {
            /// <summary>Compares boxes for equality.</summary>
            /// <param name="a" type="goog.math.Box">A Box.</param>
            /// <param name="b" type="goog.math.Box">A Box.</param>
            /// <returns type="boolean">True iff the boxes are equal, or if both are null.</returns>
        }, 
        
        contains: function(box, other) {
            /// <summary>Returns whether a box contains a coordinate or another box.</summary>
            /// <param name="box" type="goog.math.Box">A Box.</param>
            /// <param name="other" type="goog.math.Coordinate|goog.math.Box">A Coordinate or a Box.</param>
            /// <returns type="boolean">Whether the box contains the coordinate or other box.</returns>
        }, 
        
        relativePositionX: function(box, coord) {
            /// <summary>Returns the relative x position of a coordinate compared to a box.  Returns
            /// zero if the coordinate is inside the box.</summary>
            /// <param name="box" type="goog.math.Box">A Box.</param>
            /// <param name="coord" type="goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The x position of {@code coord} relative to the nearest
            ///     side of {@code box}, or zero if {@code coord} is inside {@code box}.</returns>
        }, 
        
        relativePositionY: function(box, coord) {
            /// <summary>Returns the relative y position of a coordinate compared to a box.  Returns
            /// zero if the coordinate is inside the box.</summary>
            /// <param name="box" type="goog.math.Box">A Box.</param>
            /// <param name="coord" type="goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The y position of {@code coord} relative to the nearest
            ///     side of {@code box}, or zero if {@code coord} is inside {@code box}.</returns>
        }, 
        
        distance: function(box, coord) {
            /// <summary>Returns the distance between a coordinate and the nearest corner/side of a
            /// box. Returns zero if the coordinate is inside the box.</summary>
            /// <param name="box" type="goog.math.Box">A Box.</param>
            /// <param name="coord" type="goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The distance between {@code coord} and the nearest
            ///     corner/side of {@code box}, or zero if {@code coord} is inside
            ///     {@code box}.</returns>
        }, 
        
        intersects: function(a, b) {
            /// <summary>Returns whether two boxes intersect.</summary>
            /// <param name="a" type="goog.math.Box">A Box.</param>
            /// <param name="b" type="goog.math.Box">A second Box.</param>
            /// <returns type="boolean">Whether the boxes intersect.</returns>
        }, 
        
        intersectsWithPadding: function(a, b, padding) {
            /// <summary>Returns whether two boxes would intersect with additional padding.</summary>
            /// <param name="a" type="goog.math.Box">A Box.</param>
            /// <param name="b" type="goog.math.Box">A second Box.</param>
            /// <param name="padding" type="number">The additional padding.</param>
            /// <returns type="boolean">Whether the boxes intersect.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Box";
})(this);
