
/* vsdoc for goog.math.Coordinate */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Coordinate = function(opt_x, opt_y){
        /// <summary></summary>
        /// <param name="opt_x" type="number=">Left, defaults to 0.</param>
        /// <param name="opt_y" type="number=">Top, defaults to 0.</param>
        /// <field name="x" type="number">X-value</field>
        /// <field name="y" type="number">Y-value</field>
        /// <returns type="goog.math.Coordinate"/>
    };

    var $x = window.goog.math.Coordinate;
    $x.prototype = {
                
        clone: function() {
            /// <summary>Returns a new copy of the coordinate.</summary>
            /// <returns type="!goog.math.Coordinate">A clone of this coordinate.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a nice string representing the coordinate.</summary>
            /// <returns type="string">In the form (50, 73).</returns>
        }, 
        
        equals: function(a, b) {
            /// <summary>Compares coordinates for equality.</summary>
            /// <param name="a" type="goog.math.Coordinate">A Coordinate.</param>
            /// <param name="b" type="goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="boolean">True iff the coordinates are equal, or if both are null.</returns>
        }, 
        
        distance: function(a, b) {
            /// <summary>Returns the distance between two coordinates.</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <param name="b" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The distance between {@code a} and {@code b}.</returns>
        }, 
        
        magnitude: function(a) {
            /// <summary>Returns the magnitude of a coordinate.</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The distance between the origin and {@code a}.</returns>
        }, 
        
        azimuth: function(a) {
            /// <summary>Returns the angle from the origin to a coordinate.</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The angle, in degrees, clockwise from the positive X
            ///     axis to {@code a}.</returns>
        }, 
        
        squaredDistance: function(a, b) {
            /// <summary>Returns the squared distance between two coordinates. Squared distances can
            /// be used for comparisons when the actual value is not required.
            /// 
            /// Performance note: eliminating the square root is an optimization often used
            /// in lower-level languages, but the speed difference is not nearly as
            /// pronounced in JavaScript (only a few percent.)</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <param name="b" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="number">The squared distance between {@code a} and {@code b}.</returns>
        }, 
        
        difference: function(a, b) {
            /// <summary>Returns the difference between two coordinates as a new
            /// goog.math.Coordinate.</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <param name="b" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="!goog.math.Coordinate">A Coordinate representing the difference
            ///     between {@code a} and {@code b}.</returns>
        }, 
        
        sum: function(a, b) {
            /// <summary>Returns the sum of two coordinates as a new goog.math.Coordinate.</summary>
            /// <param name="a" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <param name="b" type="!goog.math.Coordinate">A Coordinate.</param>
            /// <returns type="!goog.math.Coordinate">A Coordinate representing the sum of the two
            ///     coordinates.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Coordinate";
})(this);
