
/* vsdoc for goog.math.Integer */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Integer = function(bits, sign){
        /// <summary></summary>
        /// <param name="bits" type="Array.number">Array containing the bits of the number.</param>
        /// <param name="sign" type="number">The sign of the number: -1 for negative and 0 positive.</param>
        /// <field name="ZERO" type="!goog.math.Integer"></field>
        /// <field name="ONE" type="!goog.math.Integer"></field>
        /// <returns type="goog.math.Integer"/>
    };

    var $x = window.goog.math.Integer;
    $x.prototype = {
                
        fromInt: function(value) {
            /// <summary>Returns an Integer representing the given (32-bit) integer value.</summary>
            /// <param name="value" type="number">A 32-bit integer value.</param>
            /// <returns type="!goog.math.Integer">The corresponding Integer value.</returns>
        }, 
        
        fromNumber: function(value) {
            /// <summary>Returns an Integer representing the given value, provided that it is a finite
            /// number.  Otherwise, zero is returned.</summary>
            /// <param name="value" type="number">The value in question.</param>
            /// <returns type="!goog.math.Integer">The corresponding Integer value.</returns>
        }, 
        
        fromBits: function(bits) {
            /// <summary>Returns a Integer representing the value that comes by concatenating the
            /// given entries, each is assumed to be 32 signed bits, given in little-endian
            /// order (lowest order bits in the lowest index), and sign-extending the highest
            /// order 32-bit value.</summary>
            /// <param name="bits" type="Array.number">The bits of the number, in 32-bit signed pieces,
            ///     in little-endian order.</param>
            /// <returns type="!goog.math.Integer">The corresponding Integer value.</returns>
        }, 
        
        fromString: function(str, opt_radix) {
            /// <summary>Returns an Integer representation of the given string, written using the
            /// given radix.</summary>
            /// <param name="str" type="string">The textual representation of the Integer.</param>
            /// <param name="opt_radix" type="number=">The radix in which the text is written.</param>
            /// <returns type="!goog.math.Integer">The corresponding Integer value.</returns>
        }, 
        
        toInt: function() {
            /// <summary>Returns the value, assuming it is a 32-bit integer.</summary>
            /// <returns type="number">The corresponding int value.</returns>
        }, 
        
        toNumber: function() {
            /// <summary></summary>
            /// <returns type="number">The closest floating-point representation to this value.</returns>
        }, 
        
        toString: function(opt_radix) {
            /// <summary></summary>
            /// <param name="opt_radix" type="number=">The radix in which the text should be written.</param>
            /// <returns type="string">The textual representation of this value.</returns>
        }, 
        
        getBits: function(index) {
            /// <summary>Returns the index-th 32-bit (signed) piece of the Integer according to
            /// little-endian order (i.e., index 0 contains the smallest bits).</summary>
            /// <param name="index" type="number">The index in question.</param>
            /// <returns type="number">The requested 32-bits as a signed number.</returns>
        }, 
        
        getBitsUnsigned: function(index) {
            /// <summary>Returns the index-th 32-bit piece as an unsigned number.</summary>
            /// <param name="index" type="number">The index in question.</param>
            /// <returns type="number">The requested 32-bits as an unsigned number.</returns>
        }, 
        
        getSign: function() {
            /// <summary></summary>
            /// <returns type="number">The sign bit of this number, -1 or 0.</returns>
        }, 
        
        isZero: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is zero.</returns>
        }, 
        
        isNegative: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is negative.</returns>
        }, 
        
        isOdd: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is odd.</returns>
        }, 
        
        equals: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer equals the other.</returns>
        }, 
        
        notEquals: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer does not equal the other.</returns>
        }, 
        
        greaterThan: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer is greater than the other.</returns>
        }, 
        
        greaterThanOrEqual: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer is greater than or equal to the other.</returns>
        }, 
        
        lessThan: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer is less than the other.</returns>
        }, 
        
        lessThanOrEqual: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="boolean">Whether this Integer is less than or equal to the other.</returns>
        }, 
        
        compare: function(other) {
            /// <summary>Compares this Integer with the given one.</summary>
            /// <param name="other" type="goog.math.Integer">Integer to compare against.</param>
            /// <returns type="number">0 if they are the same, 1 if the this is greater, and -1
            ///     if the given one is greater.</returns>
        }, 
        
        shorten: function(numBits) {
            /// <summary>Returns an integer with only the first numBits bits of this value, sign
            /// extended from the final bit.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Integer">The shorted integer value.</returns>
        }, 
        
        negate: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Integer">The negation of this value.</returns>
        }, 
        
        add: function(other) {
            /// <summary>Returns the sum of this and the given Integer.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to add to this.</param>
            /// <returns type="!goog.math.Integer">The Integer result.</returns>
        }, 
        
        subtract: function(other) {
            /// <summary>Returns the difference of this and the given Integer.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to subtract from this.</param>
            /// <returns type="!goog.math.Integer">The Integer result.</returns>
        }, 
        
        multiply: function(other) {
            /// <summary>Returns the product of this and the given Integer.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to multiply against this.</param>
            /// <returns type="!goog.math.Integer">The product of this and the other.</returns>
        }, 
        
        divide: function(other) {
            /// <summary>Returns this Integer divided by the given one.</summary>
            /// <param name="other" type="goog.math.Integer">Th Integer to divide this by.</param>
            /// <returns type="!goog.math.Integer">This value divided by the given one.</returns>
        }, 
        
        modulo: function(other) {
            /// <summary>Returns this Integer modulo the given one.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer by which to mod.</param>
            /// <returns type="!goog.math.Integer">This value modulo the given one.</returns>
        }, 
        
        not: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Integer">The bitwise-NOT of this value.</returns>
        }, 
        
        and: function(other) {
            /// <summary>Returns the bitwise-AND of this Integer and the given one.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to AND with this.</param>
            /// <returns type="!goog.math.Integer">The bitwise-AND of this and the other.</returns>
        }, 
        
        or: function(other) {
            /// <summary>Returns the bitwise-OR of this Integer and the given one.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to OR with this.</param>
            /// <returns type="!goog.math.Integer">The bitwise-OR of this and the other.</returns>
        }, 
        
        xor: function(other) {
            /// <summary>Returns the bitwise-XOR of this Integer and the given one.</summary>
            /// <param name="other" type="goog.math.Integer">The Integer to XOR with this.</param>
            /// <returns type="!goog.math.Integer">The bitwise-XOR of this and the other.</returns>
        }, 
        
        shiftLeft: function(numBits) {
            /// <summary>Returns this value with bits shifted to the left by the given amount.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Integer">This shifted to the left by the given amount.</returns>
        }, 
        
        shiftRight: function(numBits) {
            /// <summary>Returns this value with bits shifted to the right by the given amount.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Integer">This shifted to the right by the given amount.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Integer";
})(this);
