
/* vsdoc for goog.math.Line */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Line = function(x0, y0, x1, y1){
        /// <summary></summary>
        /// <param name="x0" type="number">X coordinate of the start point.</param>
        /// <param name="y0" type="number">Y coordinate of the start point.</param>
        /// <param name="x1" type="number">X coordinate of the end point.</param>
        /// <param name="y1" type="number">Y coordinate of the end point.</param>
        /// <field name="x0" type="number">X coordinate of the first point.</field>
        /// <field name="y0" type="number">Y coordinate of the first point.</field>
        /// <field name="x1" type="number">X coordinate of the first control point.</field>
        /// <field name="y1" type="number">Y coordinate of the first control point.</field>
        /// <returns type="goog.math.Line"/>
    };

    var $x = window.goog.math.Line;
    $x.prototype = {
                
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Line">A copy of this line.</returns>
        }, 
        
        equals: function(other) {
            /// <summary>Tests whether the given line is exactly the same as this one.</summary>
            /// <param name="other" type="goog.math.Line">The other line.</param>
            /// <returns type="boolean">Whether the given line is the same as this one.</returns>
        }, 
        
        getSegmentLengthSquared: function() {
            /// <summary></summary>
            /// <returns type="number">The squared length of the line segment used to define the
            ///     line.</returns>
        }, 
        
        getSegmentLength: function() {
            /// <summary></summary>
            /// <returns type="number">The length of the line segment used to define the line.</returns>
        }, 
        
        getInterpolatedPoint: function(t) {
            /// <summary>Returns the point on the line segment proportional to t, where for t = 0 we
            /// return the starting point and for t = 1 we return the end point.  For t &lt; 0
            /// or t &gt; 1 we extrapolate along the line defined by the line segment.</summary>
            /// <param name="t" type="number">The interpolation parameter along the line segment.</param>
            /// <returns type="!goog.math.Coordinate">The point on the line segment at t.</returns>
        }, 
        
        getClosestPoint: function(x, opt_y) {
            /// <summary>Computes the point on the line closest to a given point.  Note that a line
            /// in this case is defined as the infinite line going through the start and end
            /// points.  To find the closest point on the line segment itself see
            /// {@see #getClosestSegmentPoint}.</summary>
            /// <param name="x" type="number|goog.math.Coordinate">The x coordinate of the point, or
            ///     a coordinate object.</param>
            /// <param name="opt_y" type="number=">The y coordinate of the point - required if x is a
            ///     number, ignored if x is a goog.math.Coordinate.</param>
            /// <returns type="!goog.math.Coordinate">The point on the line closest to the given
            ///     point.</returns>
        }, 
        
        getClosestSegmentPoint: function(x, opt_y) {
            /// <summary>Computes the point on the line segment closest to a given point.</summary>
            /// <param name="x" type="number|goog.math.Coordinate">The x coordinate of the point, or
            ///     a coordinate object.</param>
            /// <param name="opt_y" type="number=">The y coordinate of the point - required if x is a
            ///     number, ignored if x is a goog.math.Coordinate.</param>
            /// <returns type="!goog.math.Coordinate">The point on the line segment closest to the
            ///     given point.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Line";
})(this);
