
/* vsdoc for goog.math.Long */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Long = function(low, high){
        /// <summary></summary>
        /// <param name="low" type="number">The low (signed) 32 bits of the long.</param>
        /// <param name="high" type="number">The high (signed) 32 bits of the long.</param>
        /// <field name="ZERO" type="!goog.math.Long"></field>
        /// <field name="ONE" type="!goog.math.Long"></field>
        /// <field name="NEG_ONE" type="!goog.math.Long"></field>
        /// <field name="MAX_VALUE" type="!goog.math.Long"></field>
        /// <field name="MIN_VALUE" type="!goog.math.Long"></field>
        /// <returns type="goog.math.Long"/>
    };

    var $x = window.goog.math.Long;
    $x.prototype = {
                
        fromInt: function(value) {
            /// <summary>Returns a Long representing the given (32-bit) integer value.</summary>
            /// <param name="value" type="number">The 32-bit integer in question.</param>
            /// <returns type="!goog.math.Long">The corresponding Long value.</returns>
        }, 
        
        fromNumber: function(value) {
            /// <summary>Returns a Long representing the given value, provided that it is a finite
            /// number.  Otherwise, zero is returned.</summary>
            /// <param name="value" type="number">The number in question.</param>
            /// <returns type="!goog.math.Long">The corresponding Long value.</returns>
        }, 
        
        fromBits: function(lowBits, highBits) {
            /// <summary>Returns a Long representing the 64-bit integer that comes by concatenating
            /// the given high and low bits.  Each is assumed to use 32 bits.</summary>
            /// <param name="lowBits" type="number">The low 32-bits.</param>
            /// <param name="highBits" type="number">The high 32-bits.</param>
            /// <returns type="!goog.math.Long">The corresponding Long value.</returns>
        }, 
        
        fromString: function(str, opt_radix) {
            /// <summary>Returns a Long representation of the given string, written using the given
            /// radix.</summary>
            /// <param name="str" type="string">The textual representation of the Long.</param>
            /// <param name="opt_radix" type="number=">The radix in which the text is written.</param>
            /// <returns type="!goog.math.Long">The corresponding Long value.</returns>
        }, 
        
        toInt: function() {
            /// <summary></summary>
            /// <returns type="number">The value, assuming it is a 32-bit integer.</returns>
        }, 
        
        toNumber: function() {
            /// <summary></summary>
            /// <returns type="number">The closest floating-point representation to this value.</returns>
        }, 
        
        toString: function(opt_radix) {
            /// <summary></summary>
            /// <param name="opt_radix" type="number=">The radix in which the text should be written.</param>
            /// <returns type="string">The textual representation of this value.</returns>
        }, 
        
        getHighBits: function() {
            /// <summary></summary>
            /// <returns type="number">The high 32-bits as a signed value.</returns>
        }, 
        
        getLowBits: function() {
            /// <summary></summary>
            /// <returns type="number">The low 32-bits as a signed value.</returns>
        }, 
        
        getLowBitsUnsigned: function() {
            /// <summary></summary>
            /// <returns type="number">The low 32-bits as an unsigned value.</returns>
        }, 
        
        getNumBitsAbs: function() {
            /// <summary></summary>
            /// <returns type="number">Returns the number of bits needed to represent the absolute
            ///     value of this Long.</returns>
        }, 
        
        isZero: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is zero.</returns>
        }, 
        
        isNegative: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is negative.</returns>
        }, 
        
        isOdd: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this value is odd.</returns>
        }, 
        
        equals: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long equals the other.</returns>
        }, 
        
        notEquals: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long does not equal the other.</returns>
        }, 
        
        lessThan: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long is less than the other.</returns>
        }, 
        
        lessThanOrEqual: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long is less than or equal to the other.</returns>
        }, 
        
        greaterThan: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long is greater than the other.</returns>
        }, 
        
        greaterThanOrEqual: function(other) {
            /// <summary></summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="boolean">Whether this Long is greater than or equal to the other.</returns>
        }, 
        
        compare: function(other) {
            /// <summary>Compares this Long with the given one.</summary>
            /// <param name="other" type="goog.math.Long">Long to compare against.</param>
            /// <returns type="number">0 if they are the same, 1 if the this is greater, and -1
            ///     if the given one is greater.</returns>
        }, 
        
        negate: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Long">The negation of this value.</returns>
        }, 
        
        add: function(other) {
            /// <summary>Returns the sum of this and the given Long.</summary>
            /// <param name="other" type="goog.math.Long">Long to add to this one.</param>
            /// <returns type="!goog.math.Long">The sum of this and the given Long.</returns>
        }, 
        
        subtract: function(other) {
            /// <summary>Returns the difference of this and the given Long.</summary>
            /// <param name="other" type="goog.math.Long">Long to subtract from this.</param>
            /// <returns type="!goog.math.Long">The difference of this and the given Long.</returns>
        }, 
        
        multiply: function(other) {
            /// <summary>Returns the product of this and the given long.</summary>
            /// <param name="other" type="goog.math.Long">Long to multiply with this.</param>
            /// <returns type="!goog.math.Long">The product of this and the other.</returns>
        }, 
        
        div: function(other) {
            /// <summary>Returns this Long divided by the given one.</summary>
            /// <param name="other" type="goog.math.Long">Long by which to divide.</param>
            /// <returns type="!goog.math.Long">This Long divided by the given one.</returns>
        }, 
        
        modulo: function(other) {
            /// <summary>Returns this Long modulo the given one.</summary>
            /// <param name="other" type="goog.math.Long">Long by which to mod.</param>
            /// <returns type="!goog.math.Long">This Long modulo the given one.</returns>
        }, 
        
        not: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Long">The bitwise-NOT of this value.</returns>
        }, 
        
        and: function(other) {
            /// <summary>Returns the bitwise-AND of this Long and the given one.</summary>
            /// <param name="other" type="goog.math.Long">The Long with which to AND.</param>
            /// <returns type="!goog.math.Long">The bitwise-AND of this and the other.</returns>
        }, 
        
        or: function(other) {
            /// <summary>Returns the bitwise-OR of this Long and the given one.</summary>
            /// <param name="other" type="goog.math.Long">The Long with which to OR.</param>
            /// <returns type="!goog.math.Long">The bitwise-OR of this and the other.</returns>
        }, 
        
        xor: function(other) {
            /// <summary>Returns the bitwise-XOR of this Long and the given one.</summary>
            /// <param name="other" type="goog.math.Long">The Long with which to XOR.</param>
            /// <returns type="!goog.math.Long">The bitwise-XOR of this and the other.</returns>
        }, 
        
        shiftLeft: function(numBits) {
            /// <summary>Returns this Long with bits shifted to the left by the given amount.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Long">This shifted to the left by the given amount.</returns>
        }, 
        
        shiftRight: function(numBits) {
            /// <summary>Returns this Long with bits shifted to the right by the given amount.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Long">This shifted to the right by the given amount.</returns>
        }, 
        
        shiftRightUnsigned: function(numBits) {
            /// <summary>Returns this Long with bits shifted to the right by the given amount, with
            /// the new top bits matching the current sign bit.</summary>
            /// <param name="numBits" type="number">The number of bits by which to shift.</param>
            /// <returns type="!goog.math.Long">This shifted to the right by the given amount, with
            ///     zeros placed into the new leading bits.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Long";
})(this);
