
/* vsdoc for goog.math.Matrix */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Matrix = function(m, opt_n){
        /// <summary></summary>
        /// <param name="m" type="goog.math.Matrix|Array.Array.<number>|goog.math.Size|number">A matrix to copy, a 2D-array to take as a template, a size object for
        ///     dimensions, or the number of rows.</param>
        /// <param name="opt_n" type="number=">Number of columns of the matrix (only applicable if
        ///     the first argument is also numeric).</param>
        /// <returns type="goog.math.Matrix"/>
    };

    var $x = window.goog.math.Matrix;
    $x.prototype = {
                
        createIdentityMatrix: function(n) {
            /// <summary>Creates a square identity matrix. i.e. for n = 3:
            /// &lt;pre&gt;
            /// [ 1 0 0 ]
            /// [ 0 1 0 ]
            /// [ 0 0 1 ]
            /// &lt;/pre&gt;</summary>
            /// <param name="n" type="number">The size of the square identity matrix.</param>
            /// <returns type="!goog.math.Matrix">Identity matrix of width and height {@code n}.</returns>
        }, 
        
        forEach: function(matrix, fn, opt_obj) {
            /// <summary>Calls a function for each cell in a matrix.</summary>
            /// <param name="matrix" type="goog.math.Matrix">The matrix to iterate over.</param>
            /// <param name="fn" type="Function">The function to call for every element. This function
            ///     takes 4 arguments (value, i, j, and the matrix)
            ///     and the return value is irrelevant.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code fn}.</param>
        }, 
        
        isValidArray: function(arr) {
            /// <summary>Tests whether an array is a valid matrix.  A valid array is an array of
            /// arrays where all arrays are of the same length and all elements are numbers.</summary>
            /// <param name="arr" type="Array">An array to test.</param>
            /// <returns type="boolean">Whether the array is a valid matrix.</returns>
        }, 
        
        map: function(matrix, fn, opt_obj) {
            /// <summary>Calls a function for every cell in a matrix and inserts the result into a
            /// new matrix of equal dimensions.</summary>
            /// <param name="matrix" type="goog.math.Matrix">The matrix to iterate over.</param>
            /// <param name="fn" type="Function">The function to call for every element. This function
            ///                     takes 4 arguments (value, i, j and the matrix)
            ///                     and should return something. The result will be inserted
            ///                     into a new matrix.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code fn}.</param>
            /// <returns type="!goog.math.Matrix">A new matrix with the results from {@code fn}.</returns>
        }, 
        
        add: function(m) {
            /// <summary>Returns a new matrix that is the sum of this and the provided matrix.</summary>
            /// <param name="m" type="goog.math.Matrix">The matrix to add to this one.</param>
            /// <returns type="!goog.math.Matrix">Resultant sum.</returns>
        }, 
        
        appendColumns: function(m) {
            /// <summary>Appends the given matrix to the right side of this matrix.</summary>
            /// <param name="m" type="goog.math.Matrix">The matrix to augment this matrix with.</param>
            /// <returns type="!goog.math.Matrix">A new matrix with additional columns on the
            ///     right.</returns>
        }, 
        
        appendRows: function(m) {
            /// <summary>Appends the given matrix to the bottom of this matrix.</summary>
            /// <param name="m" type="goog.math.Matrix">The matrix to augment this matrix with.</param>
            /// <returns type="!goog.math.Matrix">A new matrix with added columns on the bottom.</returns>
        }, 
        
        equals: function(m, opt_tolerance) {
            /// <summary>Returns whether the given matrix equals this matrix.</summary>
            /// <param name="m" type="goog.math.Matrix">The matrix to compare to this one.</param>
            /// <param name="opt_tolerance" type="number=">The tolerance when comparing array entries.</param>
            /// <returns type="boolean">Whether the given matrix equals this matrix.</returns>
        }, 
        
        getDeterminant: function() {
            /// <summary>Returns the determinant of this matrix.  The determinant of a matrix A is
            /// often denoted as |A| and can only be applied to a square matrix.</summary>
            /// <returns type="number">The determinant of this matrix.</returns>
        }, 
        
        getInverse: function() {
            /// <summary>Returns the inverse of this matrix if it exists or null if the matrix is
            /// not invertible.</summary>
            /// <returns type="goog.math.Matrix">A new matrix which is the inverse of this matrix.</returns>
        }, 
        
        getReducedRowEchelonForm: function() {
            /// <summary>Transforms this matrix into reduced row echelon form.</summary>
            /// <returns type="!goog.math.Matrix">A new matrix reduced row echelon form.</returns>
        }, 
        
        getSize: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Size">The dimensions of the matrix.</returns>
        }, 
        
        getTranspose: function() {
            /// <summary>Return the transpose of this matrix.  For an m-by-n matrix, the transpose
            /// is the n-by-m matrix which results from turning rows into columns and columns
            /// into rows</summary>
            /// <returns type="!goog.math.Matrix">A new matrix A^T.</returns>
        }, 
        
        getValueAt: function(i, j) {
            /// <summary>Retrieves the value of a particular coordinate in the matrix or null if the
            /// requested coordinates are out of range.</summary>
            /// <param name="i" type="number">The i index of the coordinate.</param>
            /// <param name="j" type="number">The j index of the coordinate.</param>
            /// <returns type="?number">The value at the specified coordinate.</returns>
        }, 
        
        isSquare: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the horizontal and vertical dimensions of this
            ///     matrix are the same.</returns>
        }, 
        
        setValueAt: function(i, j, value) {
            /// <summary>Sets the value at a particular coordinate (if the coordinate is within the
            /// bounds of the matrix).</summary>
            /// <param name="i" type="number">The i index of the coordinate.</param>
            /// <param name="j" type="number">The j index of the coordinate.</param>
            /// <param name="value" type="number">The new value for the coordinate.</param>
        }, 
        
        multiply: function(m) {
            /// <summary>Performs matrix or scalar multiplication on a matrix and returns the
            /// resultant matrix.
            /// 
            /// Matrix multiplication is defined between two matrices only if the number of
            /// columns of the first matrix is the same as the number of rows of the second
            /// matrix. If A is an m-by-n matrix and B is an n-by-p matrix, then their
            /// product AB is an m-by-p matrix
            /// 
            /// Scalar multiplication returns a matrix of the same size as the original,
            /// each value multiplied by the given value.</summary>
            /// <param name="m" type="goog.math.Matrix|number">Matrix/number to multiply the matrix by.</param>
            /// <returns type="!goog.math.Matrix">Resultant product.</returns>
        }, 
        
        subtract: function(m) {
            /// <summary>Returns a new matrix that is the difference of this and the provided matrix.</summary>
            /// <param name="m" type="goog.math.Matrix">The matrix to subtract from this one.</param>
            /// <returns type="!goog.math.Matrix">Resultant difference.</returns>
        }, 
        
        toArray: function() {
            /// <summary></summary>
            /// <returns type="!Array.!Array.&lt;number&gt;">A 2D internal array representing this
            ///     matrix.  Not a clone.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a string representation of the matrix.  e.g.
            /// &lt;pre&gt;
            /// [ 12  5  9  1 ]
            /// [  4 16  0 17 ]
            /// [ 12  5  1 23 ]
            /// &lt;/pre&gt;</summary>
            /// <returns type="string">A string representation of this matrix.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Matrix";
})(this);
