
/* vsdoc for goog.math.Range */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Range = function(a, b){
        /// <summary></summary>
        /// <param name="a" type="number">One end of the range.</param>
        /// <param name="b" type="number">The other end of the range.</param>
        /// <field name="start" type="number">The lowest value in the range.</field>
        /// <field name="end" type="number">The highest value in the range.</field>
        /// <returns type="goog.math.Range"/>
    };

    var $x = window.goog.math.Range;
    $x.prototype = {
                
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Range">A clone of this Range.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a string representing the range.</summary>
            /// <returns type="string">In the form [-3.5, 8.13].</returns>
        }, 
        
        equals: function(a, b) {
            /// <summary>Compares ranges for equality.</summary>
            /// <param name="a" type="goog.math.Range">A Range.</param>
            /// <param name="b" type="goog.math.Range">A Range.</param>
            /// <returns type="boolean">True iff both the starts and the ends of the ranges are
            ///     equal, or if both ranges are null.</returns>
        }, 
        
        intersection: function(a, b) {
            /// <summary>Given two ranges on the same dimension, this method returns the intersection
            /// of those ranges.</summary>
            /// <param name="a" type="goog.math.Range">A Range.</param>
            /// <param name="b" type="goog.math.Range">A Range.</param>
            /// <returns type="goog.math.Range">A new Range representing the intersection of two
            ///     ranges, or null if there is no intersection. Ranges are assumed to
            ///     include their end points, and the intersection can be a point.</returns>
        }, 
        
        hasIntersection: function(a, b) {
            /// <summary>Given two ranges on the same dimension, determines whether they intersect.</summary>
            /// <param name="a" type="goog.math.Range">A Range.</param>
            /// <param name="b" type="goog.math.Range">A Range.</param>
            /// <returns type="boolean">Whether they intersect.</returns>
        }, 
        
        boundingRange: function(a, b) {
            /// <summary>Given two ranges on the same dimension, this returns a range that covers
            /// both ranges.</summary>
            /// <param name="a" type="goog.math.Range">A Range.</param>
            /// <param name="b" type="goog.math.Range">A Range.</param>
            /// <returns type="!goog.math.Range">A new Range representing the bounding
            ///     range.</returns>
        }, 
        
        contains: function(a, b) {
            /// <summary>Given two ranges, returns true if the first range completely overlaps the
            /// second.</summary>
            /// <param name="a" type="goog.math.Range">The first Range.</param>
            /// <param name="b" type="goog.math.Range">The second Range.</param>
            /// <returns type="boolean">True if b is contained inside a, false otherwise.</returns>
        }, 
        
        containsPoint: function(range, p) {
            /// <summary>Given a range and a point, returns true if the range contains the point.</summary>
            /// <param name="range" type="goog.math.Range">The range.</param>
            /// <param name="p" type="number">The point.</param>
            /// <returns type="boolean">True if p is contained inside range, false otherwise.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Range";
})(this);
