
/* vsdoc for goog.math.RangeSet */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.RangeSet = function(){
        /// <summary></summary>
        /// <returns type="goog.math.RangeSet"/>
    };

    var $x = window.goog.math.RangeSet;
    $x.prototype = {
                
        toString: function() {
            /// <summary></summary>
            /// <returns type="string">A debug string in the form [[1, 5], [8, 9], [15, 30]].</returns>
        }, 
        
        equals: function(a, b) {
            /// <summary>Compares two sets for equality.</summary>
            /// <param name="a" type="goog.math.RangeSet">A range set.</param>
            /// <param name="b" type="goog.math.RangeSet">A range set.</param>
            /// <returns type="boolean">Whether both sets contain the same values.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.RangeSet">A new RangeSet containing the same values as
            ///      this one.</returns>
        }, 
        
        add: function(a) {
            /// <summary>Adds a range to the set. If the new range overlaps existing values, those
            /// ranges will be merged.</summary>
            /// <param name="a" type="goog.math.Range">The range to add.</param>
        }, 
        
        remove: function(a) {
            /// <summary>Removes a range of values from the set.</summary>
            /// <param name="a" type="goog.math.Range">The range to remove.</param>
        }, 
        
        contains: function(a) {
            /// <summary>Determines whether a given range is in the set. Only succeeds if the entire
            /// range is available.</summary>
            /// <param name="a" type="goog.math.Range">The query range.</param>
            /// <returns type="boolean">Whether the entire requested range is set.</returns>
        }, 
        
        containsValue: function(value) {
            /// <summary>Determines whether a given value is set in the RangeSet.</summary>
            /// <param name="value" type="number">The value to test.</param>
            /// <returns type="boolean">Whether the given value is in the set.</returns>
        }, 
        
        union: function(set) {
            /// <summary>Returns the union of this RangeSet with another.</summary>
            /// <param name="set" type="goog.math.RangeSet">Another RangeSet.</param>
            /// <returns type="!goog.math.RangeSet">A new RangeSet containing all values from
            ///     either set.</returns>
        }, 
        
        difference: function(set) {
            /// <summary>Subtracts the ranges of another set from this one, returning the result
            /// as a new RangeSet.</summary>
            /// <param name="set" type="!goog.math.RangeSet">The RangeSet to subtract.</param>
            /// <returns type="!goog.math.RangeSet">A new RangeSet containing all values in this
            ///     set minus the values of the input set.</returns>
        }, 
        
        intersection: function(set) {
            /// <summary>Intersects this RangeSet with another.</summary>
            /// <param name="set" type="goog.math.RangeSet">The RangeSet to intersect with.</param>
            /// <returns type="!goog.math.RangeSet">A new RangeSet containing all values set in
            ///     both this and the input set.</returns>
        }, 
        
        slice: function(range) {
            /// <summary>Creates a subset of this set over the input range.</summary>
            /// <param name="range" type="goog.math.Range">The range to copy into the slice.</param>
            /// <returns type="!goog.math.RangeSet">A new RangeSet with a copy of the values in the
            ///     input range.</returns>
        }, 
        
        inverse: function(range) {
            /// <summary>Creates an inverted slice of this set over the input range.</summary>
            /// <param name="range" type="goog.math.Range">The range to copy into the slice.</param>
            /// <returns type="!goog.math.RangeSet">A new RangeSet containing inverted values from
            ///     the original over the input range.</returns>
        }, 
        
        coveredLength: function() {
            /// <summary></summary>
            /// <returns type="number">The sum of the lengths of ranges covered in the set.</returns>
        }, 
        
        getBounds: function() {
            /// <summary></summary>
            /// <returns type="goog.math.Range">The total range this set covers, ignoring any
            ///     gaps between ranges.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether any ranges are currently in the set.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all values in the set.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.RangeSet";
})(this);
