
/* vsdoc for goog.math.Rect */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Rect = function(x, y, w, h){
        /// <summary></summary>
        /// <param name="x" type="number">Left.</param>
        /// <param name="y" type="number">Top.</param>
        /// <param name="w" type="number">Width.</param>
        /// <param name="h" type="number">Height.</param>
        /// <field name="left" type="number">Left</field>
        /// <field name="top" type="number">Top</field>
        /// <field name="width" type="number">Width</field>
        /// <field name="height" type="number">Height</field>
        /// <returns type="goog.math.Rect"/>
    };

    var $x = window.goog.math.Rect;
    $x.prototype = {
                
        clone: function() {
            /// <summary>Returns a new copy of the rectangle.</summary>
            /// <returns type="!goog.math.Rect">A clone of this Rectangle.</returns>
        }, 
        
        toBox: function() {
            /// <summary>Returns a new Box object with the same position and dimensions as this
            /// rectangle.</summary>
            /// <returns type="!goog.math.Box">A new Box representation of this Rectangle.</returns>
        }, 
        
        createFromBox: function(box) {
            /// <summary>Creates a new Rect object with the same position and dimensions as a given
            /// Box.  Note that this is only the inverse of toBox if left/top are defined.</summary>
            /// <param name="box" type="goog.math.Box">A box.</param>
            /// <returns type="!goog.math.Rect">A new Rect initialized with the box&apos;s position
            ///     and size.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a nice string representing size and dimensions of rectangle.</summary>
            /// <returns type="string">In the form (50, 73 - 75w x 25h).</returns>
        }, 
        
        equals: function(a, b) {
            /// <summary>Compares rectangles for equality.</summary>
            /// <param name="a" type="goog.math.Rect">A Rectangle.</param>
            /// <param name="b" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="boolean">True iff the rectangles have the same left, top, width,
            ///     and height, or if both are null.</returns>
        }, 
        
        intersection: function(rect) {
            /// <summary>Computes the intersection of this rectangle and the rectangle parameter.  If
            /// there is no intersection, returns false and leaves this rectangle as is.</summary>
            /// <param name="rect" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="boolean">True iff this rectangle intersects with the parameter.</returns>
        }, 
        
        intersection: function(a, b) {
            /// <summary>Returns the intersection of two rectangles. Two rectangles intersect if they
            /// touch at all, for example, two zero width and height rectangles would
            /// intersect if they had the same top and left.</summary>
            /// <param name="a" type="goog.math.Rect">A Rectangle.</param>
            /// <param name="b" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="goog.math.Rect">A new intersection rect (even if width and height
            ///     are 0), or null if there is no intersection.</returns>
        }, 
        
        intersects: function(a, b) {
            /// <summary>Returns whether two rectangles intersect. Two rectangles intersect if they
            /// touch at all, for example, two zero width and height rectangles would
            /// intersect if they had the same top and left.</summary>
            /// <param name="a" type="goog.math.Rect">A Rectangle.</param>
            /// <param name="b" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="boolean">Whether a and b intersect.</returns>
        }, 
        
        intersects: function(rect) {
            /// <summary>Returns whether a rectangle intersects this rectangle.</summary>
            /// <param name="rect" type="goog.math.Rect">A rectangle.</param>
            /// <returns type="boolean">Whether rect intersects this rectangle.</returns>
        }, 
        
        difference: function(a, b) {
            /// <summary>Computes the difference regions between two rectangles. The return value is
            /// an array of 0 to 4 rectangles defining the remaining regions of the first
            /// rectangle after the second has been subtracted.</summary>
            /// <param name="a" type="goog.math.Rect">A Rectangle.</param>
            /// <param name="b" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="!Array.!goog.math.Rect">An array with 0 to 4 rectangles which
            ///     together define the difference area of rectangle a minus rectangle b.</returns>
        }, 
        
        difference: function(rect) {
            /// <summary>Computes the difference regions between this rectangle and {@code rect}. The
            /// return value is an array of 0 to 4 rectangles defining the remaining regions
            /// of this rectangle after the other has been subtracted.</summary>
            /// <param name="rect" type="goog.math.Rect">A Rectangle.</param>
            /// <returns type="!Array.!goog.math.Rect">An array with 0 to 4 rectangles which
            ///     together define the difference area of rectangle a minus rectangle b.</returns>
        }, 
        
        boundingRect: function(rect) {
            /// <summary>Expand this rectangle to also include the area of the given rectangle.</summary>
            /// <param name="rect" type="goog.math.Rect">The other rectangle.</param>
        }, 
        
        boundingRect: function(a, b) {
            /// <summary>Returns a new rectangle which completely contains both input rectangles.</summary>
            /// <param name="a" type="goog.math.Rect">A rectangle.</param>
            /// <param name="b" type="goog.math.Rect">A rectangle.</param>
            /// <returns type="goog.math.Rect">A new bounding rect, or null if either rect is
            ///     null.</returns>
        }, 
        
        contains: function(another) {
            /// <summary>Tests whether this rectangle entirely contains another rectangle or
            /// coordinate.</summary>
            /// <param name="another" type="goog.math.Rect|goog.math.Coordinate">The rectangle or
            ///     coordinate to test for containment.</param>
            /// <returns type="boolean">Whether this rectangle contains given rectangle or
            ///     coordinate.</returns>
        }, 
        
        getSize: function() {
            /// <summary>Returns the size of this rectangle.</summary>
            /// <returns type="!goog.math.Size">The size of this rectangle.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Rect";
})(this);
