
/* vsdoc for goog.math.Size */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Size = function(width, height){
        /// <summary></summary>
        /// <param name="width" type="number">Width.</param>
        /// <param name="height" type="number">Height.</param>
        /// <field name="width" type="number">Width</field>
        /// <field name="height" type="number">Height</field>
        /// <returns type="goog.math.Size"/>
    };

    var $x = window.goog.math.Size;
    $x.prototype = {
                
        equals: function(a, b) {
            /// <summary>Compares sizes for equality.</summary>
            /// <param name="a" type="goog.math.Size">A Size.</param>
            /// <param name="b" type="goog.math.Size">A Size.</param>
            /// <returns type="boolean">True iff the sizes have equal widths and equal
            ///     heights, or if both are null.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Size">A new copy of the Size.</returns>
        }, 
        
        toString: function() {
            /// <summary>Returns a nice string representing size.</summary>
            /// <returns type="string">In the form (50 x 73).</returns>
        }, 
        
        getLongest: function() {
            /// <summary></summary>
            /// <returns type="number">The longer of the two dimensions in the size.</returns>
        }, 
        
        getShortest: function() {
            /// <summary></summary>
            /// <returns type="number">The shorter of the two dimensions in the size.</returns>
        }, 
        
        area: function() {
            /// <summary></summary>
            /// <returns type="number">The area of the size (width * height).</returns>
        }, 
        
        perimeter: function() {
            /// <summary></summary>
            /// <returns type="number">The perimeter of the size (width + height) * 2.</returns>
        }, 
        
        aspectRatio: function() {
            /// <summary></summary>
            /// <returns type="number">The ratio of the size&apos;s width to its height.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the size has zero area, false if both dimensions
            ///     are non-zero numbers.</returns>
        }, 
        
        ceil: function() {
            /// <summary>Clamps the width and height parameters upward to integer values.</summary>
            /// <returns type="!goog.math.Size">This size with ceil&apos;d components.</returns>
        }, 
        
        fitsInside: function(target) {
            /// <summary></summary>
            /// <param name="target" type="!goog.math.Size">The target size.</param>
            /// <returns type="boolean">True if this Size is the same size or smaller than the
            ///     target size in both dimensions.</returns>
        }, 
        
        floor: function() {
            /// <summary>Clamps the width and height parameters downward to integer values.</summary>
            /// <returns type="!goog.math.Size">This size with floored components.</returns>
        }, 
        
        round: function() {
            /// <summary>Rounds the width and height parameters to integer values.</summary>
            /// <returns type="!goog.math.Size">This size with rounded components.</returns>
        }, 
        
        scale: function(s) {
            /// <summary>Scales the size uniformly by a factor.</summary>
            /// <param name="s" type="number">The scale factor.</param>
            /// <returns type="!goog.math.Size">This Size object after scaling.</returns>
        }, 
        
        scaleToFit: function(target) {
            /// <summary>Uniformly scales the size to fit inside the dimensions of a given size. The
            /// original aspect ratio will be preserved.
            /// 
            /// This function assumes that both Sizes contain strictly positive dimensions.</summary>
            /// <param name="target" type="!goog.math.Size">The target size.</param>
            /// <returns type="!goog.math.Size">This Size object, after optional scaling.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Size";
})(this);
