
/* vsdoc for goog.math.Vec2 */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Vec2 = function(x, y){
        /// <summary></summary>
        /// <param name="x" type="number">The x coordinate for the vector.</param>
        /// <param name="y" type="number">The y coordinate for the vector.</param>
        /// <field name="x" type="number">X-value</field>
        /// <field name="y" type="number">Y-value</field>
        /// <field name="distance" type="number">Returns the distance between two vectors.</field>
        /// <field name="squaredDistance" type="number">Returns the squared distance between two vectors.</field>
        /// <field name="equals" type="boolean">Compares vectors for equality.</field>
        /// <returns type="goog.math.Vec2"/>
    };

    var $x = window.goog.math.Vec2;
    $x.prototype = {
                
        randomUnit: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Vec2">A random unit-length vector.</returns>
        }, 
        
        random: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Vec2">A random vector inside the unit-disc.</returns>
        }, 
        
        fromCoordinate: function(a) {
            /// <summary>Returns a new Vec2 object from a given coordinate.</summary>
            /// <param name="a" type="!goog.math.Coordinate">The coordinate.</param>
            /// <returns type="!goog.math.Vec2">A new vector object.</returns>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.math.Vec2">A new vector with the same coordinates as this one.</returns>
        }, 
        
        magnitude: function() {
            /// <summary>Returns the magnitude of the vector measured from the origin.</summary>
            /// <returns type="number">The length of the vector.</returns>
        }, 
        
        squaredMagnitude: function() {
            /// <summary>Returns the squared magnitude of the vector measured from the origin.
            /// NOTE(brenneman): Leaving out the square root is not a significant
            /// optimization in JavaScript.</summary>
            /// <returns type="number">The length of the vector, squared.</returns>
        }, 
        
        scale: function(s) {
            /// <summary>Scales the current vector by a constant.</summary>
            /// <param name="s" type="number">The scale factor.</param>
            /// <returns type="!goog.math.Vec2">The scaled vector.</returns>
        }, 
        
        invert: function() {
            /// <summary>Reverses the sign of the vector. Equivalent to scaling the vector by -1.</summary>
            /// <returns type="!goog.math.Vec2">The inverted vector.</returns>
        }, 
        
        normalize: function() {
            /// <summary>Normalizes the current vector to have a magnitude of 1.</summary>
            /// <returns type="!goog.math.Vec2">The normalized vector.</returns>
        }, 
        
        add: function(b) {
            /// <summary>Adds another vector to this vector in-place.</summary>
            /// <param name="b" type="!goog.math.Coordinate">The vector to add.</param>
            /// <returns type="!goog.math.Vec2">This vector with {@code b} added.</returns>
        }, 
        
        subtract: function(b) {
            /// <summary>Subtracts another vector from this vector in-place.</summary>
            /// <param name="b" type="!goog.math.Coordinate">The vector to subtract.</param>
            /// <returns type="!goog.math.Vec2">This vector with {@code b} subtracted.</returns>
        }, 
        
        rotate: function(angle) {
            /// <summary>Rotates this vector in-place by a given angle, specified in radians.</summary>
            /// <param name="angle" type="number">The angle, in radians.</param>
            /// <returns type="!goog.math.Vec2">This vector rotated {@code angle} radians.</returns>
        }, 
        
        rotateAroundPoint: function(v, axisPoint, angle) {
            /// <summary>Rotates a vector by a given angle, specified in radians, relative to a given
            /// axis rotation point. The returned vector is a newly created instance - no
            /// in-place changes are done.</summary>
            /// <param name="v" type="!goog.math.Vec2">A vector.</param>
            /// <param name="axisPoint" type="!goog.math.Vec2">The rotation axis point.</param>
            /// <param name="angle" type="number">The angle, in radians.</param>
            /// <returns type="!goog.math.Vec2">The rotated vector in a newly created instance.</returns>
        }, 
        
        equals: function(b) {
            /// <summary>Compares this vector with another for equality.</summary>
            /// <param name="b" type="!goog.math.Vec2">The other vector.</param>
            /// <returns type="boolean">Whether this vector has the same x and y as the given
            ///     vector.</returns>
        }, 
        
        sum: function(a, b) {
            /// <summary>Returns the sum of two vectors as a new Vec2.</summary>
            /// <param name="a" type="!goog.math.Coordinate">The first vector.</param>
            /// <param name="b" type="!goog.math.Coordinate">The second vector.</param>
            /// <returns type="!goog.math.Vec2">The sum vector.</returns>
        }, 
        
        difference: function(a, b) {
            /// <summary>Returns the difference between two vectors as a new Vec2.</summary>
            /// <param name="a" type="!goog.math.Coordinate">The first vector.</param>
            /// <param name="b" type="!goog.math.Coordinate">The second vector.</param>
            /// <returns type="!goog.math.Vec2">The difference vector.</returns>
        }, 
        
        dot: function(a, b) {
            /// <summary>Returns the dot-product of two vectors.</summary>
            /// <param name="a" type="!goog.math.Coordinate">The first vector.</param>
            /// <param name="b" type="!goog.math.Coordinate">The second vector.</param>
            /// <returns type="number">The dot-product of the two vectors.</returns>
        }, 
        
        lerp: function(a, b, x) {
            /// <summary>Returns a new Vec2 that is the linear interpolant between vectors a and b at
            /// scale-value x.</summary>
            /// <param name="a" type="!goog.math.Coordinate">Vector a.</param>
            /// <param name="b" type="!goog.math.Coordinate">Vector b.</param>
            /// <param name="x" type="number">The proportion between a and b.</param>
            /// <returns type="!goog.math.Vec2">The interpolated vector.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Vec2";
})(this);
