
/* vsdoc for goog.math.Vec3 */

(function (window) {
    window.goog.math = window.goog.math || {};

    window.goog.math.Vec3 = function(x, y, z){
        /// <summary></summary>
        /// <param name="x" type="number">The x value for the vector.</param>
        /// <param name="y" type="number">The y value for the vector.</param>
        /// <param name="z" type="number">The z value for the vector.</param>
        /// <field name="x" type="number">X-value</field>
        /// <field name="y" type="number">Y-value</field>
        /// <field name="z" type="number">Z-value</field>
        /// <field name="distance" type="number">Returns the distance between two vectors.</field>
        /// <field name="squaredDistance" type="number">Returns the squared distance between two vectors.</field>
        /// <field name="equals" type="boolean">Compares vectors for equality.</field>
        /// <returns type="goog.math.Vec3"/>
    };

    var $x = window.goog.math.Vec3;
    $x.prototype = {
                
        randomUnit: function() {
            /// <summary>Generates a random unit vector.
            /// 
            /// http://mathworld.wolfram.com/SpherePointPicking.html
            /// Using (6), (7), and (8) to generate coordinates.</summary>
            /// <returns type="!goog.math.Vec3">A random unit-length vector.</returns>
        }, 
        
        random: function() {
            /// <summary>Generates a random vector inside the unit sphere.</summary>
            /// <returns type="!goog.math.Vec3">A random vector.</returns>
        }, 
        
        fromCoordinate3: function(a) {
            /// <summary>Returns a new Vec3 object from a given coordinate.</summary>
            /// <param name="a" type="goog.math.Coordinate3">The coordinate.</param>
            /// <returns type="!goog.math.Vec3">A new vector object.</returns>
        }, 
        
        clone: function() {
            /// <summary>Creates a new copy of this Vec3.</summary>
            /// <returns type="!goog.math.Vec3">A new vector with the same coordinates as this one.</returns>
        }, 
        
        magnitude: function() {
            /// <summary>Returns the magnitude of the vector measured from the origin.</summary>
            /// <returns type="number">The length of the vector.</returns>
        }, 
        
        squaredMagnitude: function() {
            /// <summary>Returns the squared magnitude of the vector measured from the origin.
            /// NOTE(brenneman): Leaving out the square root is not a significant
            /// optimization in JavaScript.</summary>
            /// <returns type="number">The length of the vector, squared.</returns>
        }, 
        
        scale: function(s) {
            /// <summary>Scales the current vector by a constant.</summary>
            /// <param name="s" type="number">The scale factor.</param>
            /// <returns type="!goog.math.Vec3">This vector, scaled.</returns>
        }, 
        
        invert: function() {
            /// <summary>Reverses the sign of the vector. Equivalent to scaling the vector by -1.</summary>
            /// <returns type="!goog.math.Vec3">This vector, inverted.</returns>
        }, 
        
        normalize: function() {
            /// <summary>Normalizes the current vector to have a magnitude of 1.</summary>
            /// <returns type="!goog.math.Vec3">This vector, normalized.</returns>
        }, 
        
        add: function(b) {
            /// <summary>Adds another vector to this vector in-place.</summary>
            /// <param name="b" type="goog.math.Vec3">The vector to add.</param>
            /// <returns type="!goog.math.Vec3">This vector with {@code b} added.</returns>
        }, 
        
        subtract: function(b) {
            /// <summary>Subtracts another vector from this vector in-place.</summary>
            /// <param name="b" type="goog.math.Vec3">The vector to subtract.</param>
            /// <returns type="!goog.math.Vec3">This vector with {@code b} subtracted.</returns>
        }, 
        
        equals: function(b) {
            /// <summary>Compares this vector with another for equality.</summary>
            /// <param name="b" type="goog.math.Vec3">The other vector.</param>
            /// <returns type="boolean">True if this vector&apos;s x, y and z equal the given vector&apos;s
            ///     x, y, and z, respectively.</returns>
        }, 
        
        sum: function(a, b) {
            /// <summary>Returns the sum of two vectors as a new Vec3.</summary>
            /// <param name="a" type="goog.math.Vec3">The first vector.</param>
            /// <param name="b" type="goog.math.Vec3">The second vector.</param>
            /// <returns type="!goog.math.Vec3">The sum vector.</returns>
        }, 
        
        difference: function(a, b) {
            /// <summary>Returns the difference of two vectors as a new Vec3.</summary>
            /// <param name="a" type="goog.math.Vec3">The first vector.</param>
            /// <param name="b" type="goog.math.Vec3">The second vector.</param>
            /// <returns type="!goog.math.Vec3">The difference vector.</returns>
        }, 
        
        dot: function(a, b) {
            /// <summary>Returns the dot-product of two vectors.</summary>
            /// <param name="a" type="goog.math.Vec3">The first vector.</param>
            /// <param name="b" type="goog.math.Vec3">The second vector.</param>
            /// <returns type="number">The dot-product of the two vectors.</returns>
        }, 
        
        cross: function(a, b) {
            /// <summary>Returns the cross-product of two vectors.</summary>
            /// <param name="a" type="goog.math.Vec3">The first vector.</param>
            /// <param name="b" type="goog.math.Vec3">The second vector.</param>
            /// <returns type="!goog.math.Vec3">The cross-product of the two vectors.</returns>
        }, 
        
        lerp: function(a, b, x) {
            /// <summary>Returns a new Vec3 that is the linear interpolant between vectors a and b at
            /// scale-value x.</summary>
            /// <param name="a" type="goog.math.Vec3">Vector a.</param>
            /// <param name="b" type="goog.math.Vec3">Vector b.</param>
            /// <param name="x" type="number">The proportion between a and b.</param>
            /// <returns type="!goog.math.Vec3">The interpolated vector.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.math.Vec3";
})(this);
