
/* vsdoc for goog.messaging.AbstractChannel */

(function (window) {
    window.goog.messaging = window.goog.messaging || {};

    window.goog.messaging.AbstractChannel = function(){
        /// <summary></summary>
        /// <field name="logger" type="goog.debug.Logger">Logger for this class.</field>
        /// <field name="send" type=""></field>
        /// <returns type="goog.messaging.AbstractChannel"/>
    };

    var $x = window.goog.messaging.AbstractChannel;
    $x.prototype = {
                
        connect: function(opt_connectCb) {
            /// <summary>Immediately calls opt_connectCb if given, and is otherwise a no-op. If
            /// subclasses have configuration that needs to happen before the channel is
            /// connected, they should override this and {@link #isConnected}.</summary>
            /// <param name="opt_connectCb" type=""></param>
        }, 
        
        isConnected: function() {
            /// <summary>Always returns true. If subclasses have configuration that needs to happen
            /// before the channel is connected, they should override this and
            /// {@link #connect}.</summary>
        }, 
        
        registerService: function(serviceName, callback, opt_objectPayload) {
            /// <summary></summary>
            /// <param name="serviceName" type=""></param>
            /// <param name="callback" type=""></param>
            /// <param name="opt_objectPayload" type=""></param>
        }, 
        
        registerDefaultService: function(callback) {
            /// <summary></summary>
            /// <param name="callback" type=""></param>
        }, 
        
        deliver: function(serviceName, payload) {
            /// <summary>Delivers a message to the appropriate service. This is meant to be called by
            /// subclasses when they receive messages.
            /// 
            /// This method takes into account both explicitly-registered and default
            /// services, as well as making sure that JSON payloads are decoded when
            /// necessary. If the subclass is capable of passing objects as payloads, those
            /// objects can be passed in to this method directly. Otherwise, the (potentially
            /// JSON-encoded) strings should be passed in.</summary>
            /// <param name="serviceName" type="string">The name of the service receiving the message.</param>
            /// <param name="payload" type="string|!Object">The contents of the message.</param>
        }, 
        
        getService: function(serviceName, payload) {
            /// <summary>Find the service object for a given service name. If there&apos;s no service
            /// explicitly registered, but there is a default service, a service object is
            /// constructed for it.</summary>
            /// <param name="serviceName" type="string">The name of the service receiving the message.</param>
            /// <param name="payload" type="string|!Object">The contents of the message.</param>
            /// <returns type="?{callback: function((string|!Object))|objectPayload: boolean}">The
            ///     service object for the given service, or null if none was found.</returns>
        }, 
        
        decodePayload: function(serviceName, payload, objectPayload) {
            /// <summary>Converts the message payload into the format expected by the registered
            /// service (either JSON or string).</summary>
            /// <param name="serviceName" type="string">The name of the service receiving the message.</param>
            /// <param name="payload" type="string|!Object">The contents of the message.</param>
            /// <param name="objectPayload" type="boolean">Whether the service expects an object or a
            ///     plain string.</param>
            /// <returns type="string|Object">The payload in the format expected by the service, or
            ///     null if something went wrong.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.messaging.AbstractChannel";
})(this);
