
/* vsdoc for goog.messaging.PortChannel */

(function (window) {
    window.goog.messaging = window.goog.messaging || {};

    window.goog.messaging.PortChannel = function(underlyingPort){
        /// <summary></summary>
        /// <param name="underlyingPort" type="!MessagePort|!WebWorker">The message-passing
        ///     entity to wrap. If this is a {@link MessagePort}, it should be started.
        ///     The remote end should also be wrapped in a PortChannel. This will be
        ///     disposed along with the PortChannel; this means terminating it if it&apos;s a
        ///     worker or removing it from the DOM if it&apos;s an iframe.</param>
        /// <field name="FLAG" type="string">The flag added to messages that are sent by a PortChannel, and are meant to
        /// be handled by one on the other side.</field>
        /// <field name="logger" type="goog.debug.Logger">Logger for this class.</field>
        /// <returns type="goog.messaging.PortChannel"/>
    };

    var $x = window.goog.messaging.PortChannel;
    $x.prototype = {
                
        forEmbeddedWindow: function(window, peerOrigin, opt_timer) {
            /// <summary>Create a PortChannel that communicates with a window embedded in the current
            /// page (e.g. an iframe contentWindow). The code within the window should call
            /// {@link forGlobalWindow} to establish the connection.
            /// 
            /// It&apos;s possible to use this channel in conjunction with other messages to the
            /// embedded window. However, only one PortChannel should be used for a given
            /// window at a time.</summary>
            /// <param name="window" type="!Window">The window object to communicate with.</param>
            /// <param name="peerOrigin" type="string">The expected origin of the window. See
            ///     http://dev.w3.org/html5/postmsg/#dom-window-postmessage.</param>
            /// <param name="opt_timer" type="goog.Timer=">The timer that regulates how often the initial
            ///     connection message is attempted. This will be automatically disposed once
            ///     the connection is established, or when the connection is cancelled.</param>
            /// <returns type="!goog.messaging.DeferredChannel">The PortChannel. Although this is
            ///     not actually an instance of the PortChannel class, it will behave like
            ///     one in that MessagePorts may be sent across it. The DeferredChannel may
            ///     be cancelled before a connection is established in order to abort the
            ///     attempt to make a connection.</returns>
        }, 
        
        forGlobalWindow: function(peerOrigin) {
            /// <summary>Create a PortChannel that communicates with the document in which this window
            /// is embedded (e.g. within an iframe). The enclosing document should call
            /// {@link forEmbeddedWindow} to establish the connection.
            /// 
            /// It&apos;s possible to use this channel in conjunction with other messages posted
            /// to the global window. However, only one PortChannel should be used for the
            /// global window at a time.</summary>
            /// <param name="peerOrigin" type="string">The expected origin of the enclosing document. See
            ///     http://dev.w3.org/html5/postmsg/#dom-window-postmessage.</param>
            /// <returns type="!goog.messaging.MessageChannel">The PortChannel. Although this may
            ///     not actually be an instance of the PortChannel class, it will behave like
            ///     one in that MessagePorts may be sent across it.</returns>
        }, 
        
        send: function(serviceName, payload) {
            /// <summary>Sends a message over the channel.
            /// 
            /// As an addition to the basic MessageChannel send API, PortChannels can send
            /// objects that contain MessagePorts. Note that only plain Objects and Arrays,
            /// not their subclasses, can contain MessagePorts.
            /// 
            /// As per {@link http://www.w3.org/TR/html5/comms.html#clone-a-port}, once a
            /// port is copied to be sent across a channel, the original port will cease
            /// being able to send or receive messages.</summary>
            /// <param name="serviceName" type="string">The name of the service this message should be
            ///     delivered to.</param>
            /// <param name="payload" type="string|!Object|!MessagePort">The value of the message. May
            ///     contain MessagePorts or be a MessagePort.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.messaging.PortChannel";
})(this);
