
/* vsdoc for goog.module.Loader */

(function (window) {
    window.goog.module = window.goog.module || {};

    window.goog.module.Loader = function(){
        /// <summary></summary>
        /// <field name="LOAD_CALLBACK" type="string">The globally exported name of the load callback. Matches the
        /// definition in the js_modular_binary() BUILD rule.</field>
        /// <returns type="goog.module.Loader"/>
    };

    var $x = window.goog.module.Loader;
    $x.prototype = {
                
        init: function(baseUrl, opt_urlFunction) {
            /// <summary>Initializes the Loader to be fully functional. Also executes load
            /// requests that were received before initialization. Must be called
            /// exactly once, with the URL of the base library. Module URLs are
            /// derived from the URL of the base library by inserting the module
            /// name, preceded by a period, before the .js prefix of the base URL.</summary>
            /// <param name="baseUrl" type="string">The URL of the base library.</param>
            /// <param name="opt_urlFunction" type="Function=">Function that creates the URL for the
            ///     module file. It will be passed the base URL for module files and the
            ///     module name and should return the fully-formed URL to the module file to
            ///     load.</param>
        }, 
        
        require: function(module, symbol, callback) {
            /// <summary>Requests the loading of a symbol from a module. When the module is
            /// loaded, the requested symbol will be passed as argument to the
            /// function callback.</summary>
            /// <param name="module" type="string">The name of the module. Usually, the value
            ///     is defined as a constant whose name starts with MOD_.</param>
            /// <param name="symbol" type="number|string">The ID of the symbol. Usually, the value is
            ///     defined as a constant whose name starts with SYM_.</param>
            /// <param name="callback" type="Function">This function will be called with the
            ///     resolved symbol as the argument once the module is loaded.</param>
        }, 
        
        provide: function(module, opt_symbol, opt_object) {
            /// <summary>Registers a symbol in a loaded module. When called without symbol,
            /// registers the module to be fully loaded and executes all callbacks
            /// from pending require() callbacks for this module.</summary>
            /// <param name="module" type="string">The name of the module. Cf. parameter module
            ///     of method require().</param>
            /// <param name="opt_symbol" type="number|string=">The symbol being defined, or nothing when
            ///     all symbols of the module are defined. Cf. parameter symbol of method
            ///     require().</param>
            /// <param name="opt_object" type="Object=">The object bound to the symbol, or nothing when
            ///     all symbols of the module are defined.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.module.Loader";
})(this);
