
/* vsdoc for goog.module.ModuleInfo */

(function (window) {
    window.goog.module = window.goog.module || {};

    window.goog.module.ModuleInfo = function(deps, id){
        /// <summary></summary>
        /// <param name="deps" type="Array.string">Ids of the modules that must be loaded before
        ///     this one. The ids must be in dependency order (i.e. if the ith module
        ///     depends on the jth module, then i > j).</param>
        /// <param name="id" type="string">The module&apos;s ID.</param>
        /// <returns type="goog.module.ModuleInfo"/>
    };

    var $x = window.goog.module.ModuleInfo;
    $x.prototype = {
                
        getDependencies: function() {
            /// <summary>Gets the dependencies of this module.</summary>
            /// <returns type="Array.string">The ids of the modules that this module depends on.</returns>
        }, 
        
        getId: function() {
            /// <summary>Gets the ID of this module.</summary>
            /// <returns type="string">The ID.</returns>
        }, 
        
        setUris: function(uris) {
            /// <summary>Sets the uris of this module.</summary>
            /// <param name="uris" type="Array.string">Uris for this module&apos;s code.</param>
        }, 
        
        getUris: function() {
            /// <summary>Gets the uris of this module.</summary>
            /// <returns type="Array.string?">Uris for this module&apos;s code.</returns>
        }, 
        
        setModuleConstructor: function(constructor) {
            /// <summary>Sets the constructor to use to instantiate the module object after the
            /// module code is loaded.</summary>
            /// <param name="constructor" type="Function">The constructor of a goog.module.BaseModule
            ///     subclass.</param>
        }, 
        
        registerEarlyCallback: function(fn, opt_handler) {
            /// <summary>Registers a function that should be called after the module is loaded. These
            /// early callbacks are called after {@link Module#initialize} is called but
            /// before the other callbacks are called.</summary>
            /// <param name="fn" type="Function">A callback function that takes a single argument which
            ///    is the module context.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
            /// <returns type="goog.module.ModuleLoadCallback">Reference to the callback
            ///     object.</returns>
        }, 
        
        registerCallback: function(fn, opt_handler) {
            /// <summary>Registers a function that should be called after the module is loaded.</summary>
            /// <param name="fn" type="Function">A callback function that takes a single argument which
            ///    is the module context.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
            /// <returns type="goog.module.ModuleLoadCallback">Reference to the callback
            ///     object.</returns>
        }, 
        
        registerErrback: function(fn, opt_handler) {
            /// <summary>Registers a function that should be called if the module load fails.</summary>
            /// <param name="fn" type="Function">A callback function that takes a single argument which
            ///    is the failure type.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
            /// <returns type="goog.module.ModuleLoadCallback">Reference to the callback
            ///     object.</returns>
        }, 
        
        isLoaded: function() {
            /// <summary>Determines whether the module has been loaded.</summary>
            /// <returns type="boolean">Whether the module has been loaded.</returns>
        }, 
        
        getModule: function() {
            /// <summary>Gets the module.</summary>
            /// <returns type="goog.module.BaseModule?">The module if it has been loaded.
            ///     Otherwise, null.</returns>
        }, 
        
        onLoad: function(contextProvider) {
            /// <summary>Sets this module as loaded.</summary>
            /// <param name="contextProvider" type="function() : Object">A function that provides the
            ///     module context.</param>
            /// <returns type="boolean">Whether any errors occurred while executing the onload
            ///     callbacks.</returns>
        }, 
        
        onError: function(cause) {
            /// <summary>Calls the error callbacks for the module.</summary>
            /// <param name="cause" type="goog.module.ModuleManager.FailureType">What caused the error.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.module.ModuleInfo";
})(this);
