
/* vsdoc for goog.module.ModuleManager */

(function (window) {
    window.goog.module = window.goog.module || {};

    window.goog.module.ModuleManager = function(){
        /// <summary></summary>
        /// <field name="CallbackType" type="">The type of callbacks that can be registered with the module manager,.</field>
        /// <field name="CORRUPT_RESPONSE_STATUS_CODE" type="number">A non-HTTP status code indicating a corruption in loaded module.
        /// This should be used by a ModuleLoader as a replacement for the HTTP code
        /// given to the error handler function to indicated that the module was
        /// corrupted.
        /// This will set the forceReload flag on the loadModules method when retrying
        /// module loading.</field>
        /// <field name="FailureType" type="">The possible reasons for a module load failure callback being fired.</field>
        /// <returns type="goog.module.ModuleManager"/>
    };

    var $x = window.goog.module.ModuleManager;
    $x.prototype = {
                
        setBatchModeEnabled: function(enabled) {
            /// <summary>Sets the batch mode as enabled or disabled for the module manager.</summary>
            /// <param name="enabled" type="boolean">Whether the batch mode is to be enabled or not.</param>
        }, 
        
        setAllModuleInfo: function(infoMap) {
            /// <summary>Sets the module info for all modules. Should only be called once.</summary>
            /// <param name="infoMap" type="Object.Array.&lt;string&gt;">An object that contains a mapping
            ///    from module id (String) to list of required module ids (Array).</param>
        }, 
        
        setAllModuleInfoString: function(opt_info, opt_loadingModuleIds) {
            /// <summary>Sets the module info for all modules. Should only be called once. Also
            /// marks modules that are currently being loaded.</summary>
            /// <param name="opt_info" type="string=">A string representation of the module dependency
            ///      graph, in the form: module1:dep1,dep2/module2:dep1,dep2 etc.
            ///     Where depX is the base-36 encoded position of the dep in the module list.</param>
            /// <param name="opt_loadingModuleIds" type="Array.string=">A list of moduleIds that
            ///     are currently being loaded.</param>
        }, 
        
        getModuleInfo: function(id) {
            /// <summary>Gets a module info object by id.</summary>
            /// <param name="id" type="string">A module identifier.</param>
            /// <returns type="goog.module.ModuleInfo">The module info.</returns>
        }, 
        
        setModuleUris: function(moduleUriMap) {
            /// <summary>Sets the module uris.</summary>
            /// <param name="moduleUriMap" type="Object">The map of id/uris pairs for each module.</param>
        }, 
        
        getLoader: function() {
            /// <summary>Gets the application-specific module loader.</summary>
            /// <returns type="goog.module.AbstractModuleLoader">An object that has a
            ///     loadModules(ids, moduleInfoMap, opt_successFn, opt_errFn,
            ///         opt_timeoutFn, opt_forceReload) method.</returns>
        }, 
        
        setLoader: function(loader) {
            /// <summary>Sets the application-specific module loader.</summary>
            /// <param name="loader" type="goog.module.AbstractModuleLoader">An object that has a
            ///     loadModules(ids, moduleInfoMap, opt_successFn, opt_errFn,
            ///         opt_timeoutFn, opt_forceReload) method.</param>
        }, 
        
        getModuleContext: function() {
            /// <summary>Gets the module context to use to initialize the module.</summary>
            /// <returns type="Object">The context.</returns>
        }, 
        
        setModuleContext: function(context) {
            /// <summary>Sets the module context to use to initialize the module.</summary>
            /// <param name="context" type="Object">The context.</param>
        }, 
        
        isActive: function() {
            /// <summary>Determines if the ModuleManager is active</summary>
            /// <returns type="boolean">TRUE iff the ModuleManager is active (i.e., not idle).</returns>
        }, 
        
        isUserActive: function() {
            /// <summary>Determines if the ModuleManager is user active</summary>
            /// <returns type="boolean">TRUE iff the ModuleManager is user active (i.e., not idle).</returns>
        }, 
        
        preloadModule: function(id, opt_timeout) {
            /// <summary>Preloads a module after a short delay.</summary>
            /// <param name="id" type="string">The id of the module to preload.</param>
            /// <param name="opt_timeout" type="number=">The number of ms to wait before adding the
            ///     module id to the loading queue (defaults to 0 ms). Note that the module
            ///     will be loaded asynchronously regardless of the value of this parameter.</param>
            /// <returns type="goog.async.Deferred">A deferred object.</returns>
        }, 
        
        prefetchModule: function(id) {
            /// <summary>Prefetches a JavaScript module and its dependencies, which means that the
            /// module will be downloaded, but not evaluated. To complete the module load,
            /// the caller should also call load or execOnLoad after prefetching the module.</summary>
            /// <param name="id" type="string">The id of the module to prefetch.</param>
        }, 
        
        setLoaded: function(id) {
            /// <summary>Records that a module was loaded. Also initiates loading the next module if
            /// any module requests are queued. This method is called by code that is
            /// generated and appended to each dynamic module&apos;s code at compilation time.</summary>
            /// <param name="id" type="string">A module id.</param>
        }, 
        
        isModuleLoading: function(id) {
            /// <summary>Gets whether a module is currently loading or in the queue, waiting to be
            /// loaded.</summary>
            /// <param name="id" type="string">A module id.</param>
            /// <returns type="boolean">TRUE iff the module is loading.</returns>
        }, 
        
        execOnLoad: function(moduleId, fn, opt_handler, opt_noLoad, opt_userInitiated, opt_preferSynchronous) {
            /// <summary>Requests that a function be called once a particular module is loaded.
            /// Client code can use this method to safely call into modules that may not yet
            /// be loaded. For consistency, this method always calls the function
            /// asynchronously -- even if the module is already loaded. Initiates loading of
            /// the module if necessary, unless opt_noLoad is true.</summary>
            /// <param name="moduleId" type="string">A module id.</param>
            /// <param name="fn" type="Function">Function to execute when the module has loaded.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
            /// <param name="opt_noLoad" type="boolean=">TRUE iff not to initiate loading of the module.</param>
            /// <param name="opt_userInitiated" type="boolean=">TRUE iff the loading of the module was
            ///     user initiated.</param>
            /// <param name="opt_preferSynchronous" type="boolean=">TRUE iff the function should be
            ///     executed synchronously if the module has already been loaded.</param>
            /// <returns type="goog.module.ModuleLoadCallback">A callback wrapper that exposes
            ///     an abort and execute method.</returns>
        }, 
        
        load: function(moduleId, opt_userInitiated) {
            /// <summary>Loads a module, returning a goog.async.Deferred for keeping track of the
            /// result.</summary>
            /// <param name="moduleId" type="string">A module id.</param>
            /// <param name="opt_userInitiated" type="boolean=">If the load is a result of a user action.</param>
            /// <returns type="goog.async.Deferred">A deferred object.</returns>
        }, 
        
        loadMultiple: function(moduleIds, opt_userInitiated) {
            /// <summary>Loads a list of modules, returning a goog.async.Deferred for keeping track of
            /// the result.</summary>
            /// <param name="moduleIds" type="Array.string">A list of module ids.</param>
            /// <param name="opt_userInitiated" type="boolean=">If the load is a result of a user action.</param>
            /// <returns type="Object.!goog.async.Deferred">A mapping from id (String) to
            ///     deferred objects that will callback or errback when the load for that
            ///     id is finished.</returns>
        }, 
        
        beforeLoadModuleCode: function(id) {
            /// <summary>Method called just before a module code is loaded.</summary>
            /// <param name="id" type="string">Identifier of the module.</param>
        }, 
        
        afterLoadModuleCode: function(id) {
            /// <summary>Method called just after module code is loaded</summary>
            /// <param name="id" type="string">Identifier of the module.</param>
        }, 
        
        registerInitializationCallback: function(fn, opt_handler) {
            /// <summary>Register an initialization callback for the currently loading module. This
            /// should only be called by script that is executed during the evaluation of
            /// a module&apos;s javascript. This is almost equivalent to calling the function
            /// inline, but ensures that all the code from the currently loading module
            /// has been loaded. This makes it cleaner and more robust than calling the
            /// function inline.
            /// 
            /// If this function is called from the base module (the one that contains
            /// the module manager code), the callback is held until #setAllModuleInfo
            /// is called, or until #setModuleContext is called, whichever happens first.</summary>
            /// <param name="fn" type="Function">A callback function that takes a single argument
            ///    which is the module context.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
        }, 
        
        registerLateInitializationCallback: function(fn, opt_handler) {
            /// <summary>Register a late initialization callback for the currently loading module.
            /// Callbacks registered via this function are executed similar to
            /// {@see registerInitializationCallback}, but they are fired after all
            /// initialization callbacks are called.</summary>
            /// <param name="fn" type="Function">A callback function that takes a single argument
            ///    which is the module context.</param>
            /// <param name="opt_handler" type="Object=">Optional handler under whose scope to execute
            ///     the callback.</param>
        }, 
        
        setModuleConstructor: function(fn) {
            /// <summary>Sets the constructor to use for the module object for the currently
            /// loading module. The constructor should derive from {@see
            /// goog.module.BaseModule}.</summary>
            /// <param name="fn" type="Function">The constructor function.</param>
        }, 
        
        registerCallback: function(types, fn) {
            /// <summary>The function to call if the module manager is in error.</summary>
            /// <param name="types" type="goog.module.ModuleManager.CallbackType|Array.goog.module.ModuleManager.CallbackType">The callback type.</param>
            /// <param name="fn" type="Function">The function to register as a callback.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.module.ModuleManager";
})(this);
