
/* vsdoc for goog.net.BrowserChannel */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.BrowserChannel = function(opt_clientVersion){
        /// <summary></summary>
        /// <param name="opt_clientVersion" type="string=">An application-specific version number
        ///        that is sent to the server when connected.</param>
        /// <field name="LATEST_CHANNEL_VERSION" type="number">The latest protocol version that this class supports. We request this version
        /// from the server when opening the connection. Should match
        /// com.google.net.browserchannel.BrowserChannel.LATEST_CHANNEL_VERSION.</field>
        /// <field name="State" type="">Enum type for the browser channel state machine.</field>
        /// <field name="FORWARD_CHANNEL_RETRY_TIMEOUT" type="number">The timeout in milliseconds for a forward channel request.</field>
        /// <field name="BACK_CHANNEL_MAX_RETRIES" type="number">Maximum number of attempts to connect to the server for back channel
        /// requests.</field>
        /// <field name="RTT_ESTIMATE" type="number">A number in MS of how long we guess the maxmium amount of time a round trip
        /// to the server should take. In the future this could be substituted with a
        /// real measurement of the RTT.</field>
        /// <field name="INACTIVE_CHANNEL_RETRY_FACTOR" type="number">When retrying for an inactive channel, we will multiply the total delay by
        /// this number.</field>
        /// <field name="Error" type="">Enum type for identifying a BrowserChannel error.</field>
        /// <field name="Event" type="Object">Events fired by BrowserChannel and associated objects</field>
        /// <field name="ServerReachability" type="">Types of events which reveal information about the reachability of the
        /// server.</field>
        /// <field name="Stat" type="">Enum that identifies events for statistics that are interesting to track.
        /// TODO(user) - Change name not to use Event or use EventTarget</field>
        /// <field name="MAGIC_RESPONSE_COOKIE" type="string">The normal response for forward channel requests.
        /// Used only before version 8 of the protocol.</field>
        /// <field name="OUTSTANDING_DATA_BACKCHANNEL_RETRY_CUTOFF" type="number">A guess at a cutoff at which to no longer assume the backchannel is dead
        /// when we are slow to receive data. Number in bytes.
        /// 
        /// Assumption: The worst bandwidth we work on is 50 kilobits/sec
        /// 50kbits/sec * (1 byte / 8 bits) * 6 sec dead backchannel timeout</field>
        /// <field name="LogSaver" type="">A LogSaver that can be used to accumulate all the debug logs for
        /// BrowserChannels so they can be sent to the server when a problem is
        /// detected.</field>
        /// <returns type="goog.net.BrowserChannel"/>
    };

    var $x = window.goog.net.BrowserChannel;
    $x.prototype = {
                
        getChannelDebug: function() {
            /// <summary>Returns the browserchannel logger.</summary>
            /// <returns type="goog.net.ChannelDebug">The channel debug object.</returns>
        }, 
        
        setChannelDebug: function(channelDebug) {
            /// <summary>Set the browserchannel logger.
            /// TODO(user): Add interface for channel loggers or remove this function.</summary>
            /// <param name="channelDebug" type="goog.net.ChannelDebug">The channel debug object.</param>
        }, 
        
        setStartThreadExecutionHook: function(startHook) {
            /// <summary>Allows the application to set an execution hooks for when BrowserChannel
            /// starts processing requests. This is useful to track timing or logging
            /// special information. The function takes no parameters and return void.</summary>
            /// <param name="startHook" type="Function">The function for the start hook.</param>
        }, 
        
        setEndThreadExecutionHook: function(endHook) {
            /// <summary>Allows the application to set an execution hooks for when BrowserChannel
            /// stops processing requests. This is useful to track timing or logging
            /// special information. The function takes no parameters and return void.</summary>
            /// <param name="endHook" type="Function">The function for the end hook.</param>
        }, 
        
        createChannelRequest: function(channel, channelDebug, opt_sessionId, opt_requestId, opt_retryId) {
            /// <summary>Instantiates a ChannelRequest with the given parameters. Overidden in tests.</summary>
            /// <param name="channel" type="goog.net.BrowserChannel|goog.net.BrowserTestChannel">The BrowserChannel that owns this request.</param>
            /// <param name="channelDebug" type="goog.net.ChannelDebug">A ChannelDebug to use for
            ///     logging.</param>
            /// <param name="opt_sessionId" type="string=">The session id for the channel.</param>
            /// <param name="opt_requestId" type="string|number=">The request id for this request.</param>
            /// <param name="opt_retryId" type="number=">The retry id for this request.</param>
            /// <returns type="goog.net.ChannelRequest">The created channel request.</returns>
        }, 
        
        connect: function(testPath, channelPath, opt_extraParams, opt_oldSessionId, opt_oldArrayId) {
            /// <summary>Starts the channel. This initiates connections to the server.</summary>
            /// <param name="testPath" type="string">The path for the test connection.</param>
            /// <param name="channelPath" type="string">The path for the channel connection.</param>
            /// <param name="opt_extraParams" type="Object=">Extra parameter keys and values to add to
            ///     the requests.</param>
            /// <param name="opt_oldSessionId" type="string=">Session ID from a previous session.</param>
            /// <param name="opt_oldArrayId" type="number=">The last array ID from a previous session.</param>
        }, 
        
        disconnect: function() {
            /// <summary>Disconnects and closes the channel.</summary>
        }, 
        
        getSessionId: function() {
            /// <summary>Returns the session id of the channel. Only available after the
            /// channel has been opened.</summary>
            /// <returns type="string">Session ID.</returns>
        }, 
        
        getExtraHeaders: function() {
            /// <summary>Returns the extra HTTP headers to add to all the requests sent to the server.</summary>
            /// <returns type="Object">The HTTP headers, or null.</returns>
        }, 
        
        setExtraHeaders: function(extraHeaders) {
            /// <summary>Sets extra HTTP headers to add to all the requests sent to the server.</summary>
            /// <param name="extraHeaders" type="Object">The HTTP headers, or null.</param>
        }, 
        
        setReadyStateChangeThrottle: function(throttle) {
            /// <summary>Sets the throttle for handling onreadystatechange events for the request.</summary>
            /// <param name="throttle" type="number">The throttle in ms.  A value of zero indicates
            ///     no throttle.</param>
        }, 
        
        setSupportsCrossDomainXhrs: function(supportCrossDomain) {
            /// <summary>Sets whether cross origin requests are supported for the browser channel.
            /// 
            /// Setting this allows the creation of requests to secondary domains and
            /// sends XHRs with the CORS withCredentials bit set to true.
            /// 
            /// In order for cross-origin requests to work, the server will also need to set
            /// CORS response headers as per:
            /// https://developer.mozilla.org/en-US/docs/HTTP_access_control
            /// 
            /// See {@link goog.net.XhrIo#setWithCredentials}.</summary>
            /// <param name="supportCrossDomain" type="boolean">Whether cross domain XHRs are supported.</param>
        }, 
        
        getHandler: function() {
            /// <summary>Returns the handler used for channel callback events.</summary>
            /// <returns type="goog.net.BrowserChannel.Handler">The handler.</returns>
        }, 
        
        setHandler: function(handler) {
            /// <summary>Sets the handler used for channel callback events.</summary>
            /// <param name="handler" type="goog.net.BrowserChannel.Handler">The handler to set.</param>
        }, 
        
        getAllowHostPrefix: function() {
            /// <summary>Returns whether the channel allows the use of a subdomain. There may be
            /// cases where this isn&apos;t allowed.</summary>
            /// <returns type="boolean">Whether a host prefix is allowed.</returns>
        }, 
        
        setAllowHostPrefix: function(allowHostPrefix) {
            /// <summary>Sets whether the channel allows the use of a subdomain. There may be cases
            /// where this isn&apos;t allowed, for example, logging in with troutboard where
            /// using a subdomain causes Apache to force the user to authenticate twice.</summary>
            /// <param name="allowHostPrefix" type="boolean">Whether a host prefix is allowed.</param>
        }, 
        
        isBuffered: function() {
            /// <summary>Returns whether the channel is buffered or not. This state is valid for
            /// querying only after the test connection has completed. This may be
            /// queried in the goog.net.BrowserChannel.okToMakeRequest() callback.
            /// A channel may be buffered if the test connection determines that
            /// a chunked response could not be sent down within a suitable time.</summary>
            /// <returns type="boolean">Whether the channel is buffered.</returns>
        }, 
        
        getAllowChunkedMode: function() {
            /// <summary>Returns whether chunked mode is allowed. In certain debugging situations,
            /// it&apos;s useful for the application to have a way to disable chunked mode for a
            /// user.</summary>
            /// <returns type="boolean">Whether chunked mode is allowed.</returns>
        }, 
        
        setAllowChunkedMode: function(allowChunkedMode) {
            /// <summary>Sets whether chunked mode is allowed. In certain debugging situations, it&apos;s
            /// useful for the application to have a way to disable chunked mode for a user.</summary>
            /// <param name="allowChunkedMode" type="boolean">Whether chunked mode is allowed.</param>
        }, 
        
        sendMap: function(map, opt_context) {
            /// <summary>Sends a request to the server. The format of the request is a Map data
            /// structure of key/value pairs. These maps are then encoded in a format
            /// suitable for the wire and then reconstituted as a Map data structure that
            /// the server can process.</summary>
            /// <param name="map" type="Object|goog.structs.Map">The map to send.</param>
            /// <param name="opt_context" type="?Object=">The context associated with the map.</param>
        }, 
        
        setFailFast: function(failFast) {
            /// <summary>When set to true, this changes the behavior of the forward channel so it
            /// will not retry requests; it will fail after one network failure, and if
            /// there was already one network failure, the request will fail immediately.</summary>
            /// <param name="failFast" type="boolean">Whether or not to fail fast.</param>
        }, 
        
        getForwardChannelMaxRetries: function() {
            /// <summary></summary>
            /// <returns type="number">The max number of forward-channel retries, which will be 0
            /// in fail-fast mode.</returns>
        }, 
        
        setForwardChannelMaxRetries: function(retries) {
            /// <summary>Sets the maximum number of attempts to connect to the server for forward
            /// channel requests.</summary>
            /// <param name="retries" type="number">The maximum number of attempts.</param>
        }, 
        
        setForwardChannelRequestTimeout: function(timeoutMs) {
            /// <summary>Sets the timeout for a forward channel request.</summary>
            /// <param name="timeoutMs" type="number">The timeout in milliseconds.</param>
        }, 
        
        getBackChannelMaxRetries: function() {
            /// <summary></summary>
            /// <returns type="number">The max number of back-channel retries, which is a constant.</returns>
        }, 
        
        isClosed: function() {
            /// <summary>Returns whether the channel is closed</summary>
            /// <returns type="boolean">true if the channel is closed.</returns>
        }, 
        
        getState: function() {
            /// <summary>Returns the browser channel state.</summary>
            /// <returns type="goog.net.BrowserChannel.State">The current state of the browser
            /// channel.</returns>
        }, 
        
        getLastStatusCode: function() {
            /// <summary>Return the last status code received for a request.</summary>
            /// <returns type="number">The last status code received for a request.</returns>
        }, 
        
        getLastArrayId: function() {
            /// <summary></summary>
            /// <returns type="number">The last array id received.</returns>
        }, 
        
        hasOutstandingRequests: function() {
            /// <summary>Returns whether there are outstanding requests servicing the channel.</summary>
            /// <returns type="boolean">true if there are outstanding requests.</returns>
        }, 
        
        setParser: function(parser) {
            /// <summary>Sets a new parser for the response payload. A custom parser may be set to
            /// avoid using eval(), for example. By default, the parser uses
            /// {@code goog.json.unsafeParse}.</summary>
            /// <param name="parser" type="!goog.string.Parser">Parser.</param>
        }, 
        
        testConnectionFinished: function(testChannel, useChunked) {
            /// <summary>Callback from BrowserTestChannel for when the channel is finished.</summary>
            /// <param name="testChannel" type="goog.net.BrowserTestChannel">The BrowserTestChannel.</param>
            /// <param name="useChunked" type="boolean">Whether we can chunk responses.</param>
        }, 
        
        testConnectionFailure: function(testChannel, errorCode) {
            /// <summary>Callback from BrowserTestChannel for when the channel has an error.</summary>
            /// <param name="testChannel" type="goog.net.BrowserTestChannel">The BrowserTestChannel.</param>
            /// <param name="errorCode" type="goog.net.ChannelRequest.Error">The error code of the
            ///        failure.</param>
        }, 
        
        testConnectionBlocked: function(testChannel) {
            /// <summary>Callback from BrowserTestChannel for when the channel is blocked.</summary>
            /// <param name="testChannel" type="goog.net.BrowserTestChannel">The BrowserTestChannel.</param>
        }, 
        
        onRequestData: function(request, responseText) {
            /// <summary>Callback from ChannelRequest for when new data is received</summary>
            /// <param name="request" type="goog.net.ChannelRequest">The request object.</param>
            /// <param name="responseText" type="string">The text of the response.</param>
        }, 
        
        correctHostPrefix: function(serverHostPrefix) {
            /// <summary>Decides which host prefix should be used, if any.  If there is a handler,
            /// allows the handler to validate a host prefix provided by the server, and
            /// optionally override it.</summary>
            /// <param name="serverHostPrefix" type="?string">The host prefix provided by the server.</param>
            /// <returns type="?string">The host prefix to actually use, if any. Will return null
            ///     if the use of host prefixes was disabled via setAllowHostPrefix().</returns>
        }, 
        
        onRequestComplete: function(request) {
            /// <summary>Callback from ChannelRequest that indicates a request has completed.</summary>
            /// <param name="request" type="goog.net.ChannelRequest">The request object.</param>
        }, 
        
        setRetryDelay: function(baseDelayMs, delaySeedMs) {
            /// <summary></summary>
            /// <param name="baseDelayMs" type="number">The base part of the retry delay, in ms.</param>
            /// <param name="delaySeedMs" type="number">A random delay between 0 and this is added to
            ///     the base part.</param>
        }, 
        
        getForwardChannelUri: function(path) {
            /// <summary>Gets the Uri used for the connection that sends data to the server.</summary>
            /// <param name="path" type="string">The path on the host.</param>
            /// <returns type="goog.Uri">The forward channel URI.</returns>
        }, 
        
        getBackChannelUri: function(hostPrefix, path) {
            /// <summary>Gets the Uri used for the connection that receives data from the server.</summary>
            /// <param name="hostPrefix" type="?string">The host prefix.</param>
            /// <param name="path" type="string">The path on the host.</param>
            /// <returns type="goog.Uri">The back channel URI.</returns>
        }, 
        
        createDataUri: function(hostPrefix, path, opt_overridePort) {
            /// <summary>Creates a data Uri applying logic for secondary hostprefix, port
            /// overrides, and versioning.</summary>
            /// <param name="hostPrefix" type="?string">The host prefix.</param>
            /// <param name="path" type="string">The path on the host (may be absolute or relative).</param>
            /// <param name="opt_overridePort" type="number=">Optional override port.</param>
            /// <returns type="goog.Uri">The data URI.</returns>
        }, 
        
        createXhrIo: function(hostPrefix) {
            /// <summary>Called when BC needs to create an XhrIo object.  Override in a subclass if
            /// you need to customize the behavior, for example to enable the creation of
            /// XHR&apos;s capable of calling a secondary domain. Will also allow calling
            /// a secondary domain if withCredentials (CORS) is enabled.</summary>
            /// <param name="hostPrefix" type="?string">The host prefix, if we need an XhrIo object
            ///     capable of calling a secondary domain.</param>
            /// <returns type="!goog.net.XhrIo">A new XhrIo object.</returns>
        }, 
        
        isActive: function() {
            /// <summary>Gets whether this channel is currently active. This is used to determine the
            /// length of time to wait before retrying. This call delegates to the handler.</summary>
            /// <returns type="boolean">Whether the channel is currently active.</returns>
        }, 
        
        setTimeout: function(fn, ms) {
            /// <summary>Wrapper around SafeTimeout which calls the start and end execution hooks
            /// with a try...finally block.</summary>
            /// <param name="fn" type="Function">The callback function.</param>
            /// <param name="ms" type="number">The time in MS for the timer.</param>
            /// <returns type="number">The ID of the timer.</returns>
        }, 
        
        onStartExecution: function() {
            /// <summary>Helper function to call the start hook</summary>
        }, 
        
        onEndExecution: function() {
            /// <summary>Helper function to call the end hook</summary>
        }, 
        
        getStatEventTarget: function() {
            /// <summary>Returns the singleton event target for stat events.</summary>
            /// <returns type="goog.events.EventTarget">The event target for stat events.</returns>
        }, 
        
        notifyServerReachabilityEvent: function(reachabilityType) {
            /// <summary>Notify the channel that a particular fine grained network event has occurred.
            /// Should be considered package-private.</summary>
            /// <param name="reachabilityType" type="goog.net.BrowserChannel.ServerReachability">The
            ///     reachability event type.</param>
        }, 
        
        notifyStatEvent: function(stat) {
            /// <summary>Helper function to call the stat event callback.</summary>
            /// <param name="stat" type="goog.net.BrowserChannel.Stat">The stat.</param>
        }, 
        
        notifyTimingEvent: function(size, rtt, retries) {
            /// <summary>Helper function to notify listeners about POST request performance.</summary>
            /// <param name="size" type="number">Number of characters in the POST data.</param>
            /// <param name="rtt" type="number">The amount of time from POST start to response.</param>
            /// <param name="retries" type="number">The number of times the POST had to be retried.</param>
        }, 
        
        shouldUseSecondaryDomains: function() {
            /// <summary>Determines whether to use a secondary domain when the server gives us
            /// a host prefix. This allows us to work around browser per-domain
            /// connection limits.
            /// 
            /// Currently, we  use secondary domains when using Trident&apos;s ActiveXObject,
            /// because it supports cross-domain requests out of the box.  Note that in IE10
            /// we no longer use ActiveX since it&apos;s not supported in Metro mode and IE10
            /// supports XHR streaming.
            /// 
            /// If you need to use secondary domains on other browsers and IE10,
            /// you have two choices:
            ///     1) If you only care about browsers that support CORS
            ///        (https://developer.mozilla.org/en-US/docs/HTTP_access_control), you
            ///        can use {@link #setSupportsCrossDomainXhrs} and set the appropriate
            ///        CORS response headers on the server.
            ///     2) Or, override this method in a subclass, and make sure that those
            ///        browsers use some messaging mechanism that works cross-domain (e.g
            ///        iframes and window.postMessage).</summary>
            /// <returns type="boolean">Whether to use secondary domains.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.BrowserChannel";
})(this);
