
/* vsdoc for goog.net.BrowserChannel.Handler */

(function (window) {
    window.goog.net.BrowserChannel = window.goog.net.BrowserChannel || {};

    window.goog.net.BrowserChannel.Handler = function(){
        /// <summary></summary>
        /// <field name="channelHandleMultipleArrays" type="Function">Callback handler for when a batch of response arrays is received from the
        /// server.</field>
        /// <returns type="goog.net.BrowserChannel.Handler"/>
    };

    var $x = window.goog.net.BrowserChannel.Handler;
    $x.prototype = {
                
        okToMakeRequest: function(browserChannel) {
            /// <summary>Whether it&apos;s okay to make a request to the server. A handler can return
            /// false if the channel should fail. For example, if the user has logged out,
            /// the handler may want all requests to fail immediately.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <returns type="goog.net.BrowserChannel.Error">An error code. The code should
            /// return goog.net.BrowserChannel.Error.OK to indicate it&apos;s okay. Any other
            /// error code will cause a failure.</returns>
        }, 
        
        channelOpened: function(browserChannel) {
            /// <summary>Indicates the BrowserChannel has successfully negotiated with the server
            /// and can now send and receive data.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
        }, 
        
        channelHandleArray: function(browserChannel, array) {
            /// <summary>New input is available for the application to process.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <param name="array" type="Array">The data array.</param>
        }, 
        
        channelSuccess: function(browserChannel, deliveredMaps) {
            /// <summary>Indicates maps were successfully sent on the BrowserChannel.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <param name="deliveredMaps" type="Array.goog.net.BrowserChannel.QueuedMap">The
            ///     array of maps that have been delivered to the server. This is a direct
            ///     reference to the internal BrowserChannel array, so a copy should be made
            ///     if the caller desires a reference to the data.</param>
        }, 
        
        channelError: function(browserChannel, error) {
            /// <summary>Indicates an error occurred on the BrowserChannel.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <param name="error" type="goog.net.BrowserChannel.Error">The error code.</param>
        }, 
        
        channelClosed: function(browserChannel, opt_pendingMaps, opt_undeliveredMaps) {
            /// <summary>Indicates the BrowserChannel is closed. Also notifies about which maps,
            /// if any, that may not have been delivered to the server.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <param name="opt_pendingMaps" type="Array.goog.net.BrowserChannel.QueuedMap=">The
            ///     array of pending maps, which may or may not have been delivered to the
            ///     server.</param>
            /// <param name="opt_undeliveredMaps" type="Array.goog.net.BrowserChannel.QueuedMap=">The array of undelivered maps, which have definitely not been delivered
            ///     to the server.</param>
        }, 
        
        getAdditionalParams: function(browserChannel) {
            /// <summary>Gets any parameters that should be added at the time another connection is
            /// made to the server.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <returns type="Object">Extra parameter keys and values to add to the
            ///                  requests.</returns>
        }, 
        
        getNetworkTestImageUri: function(browserChannel) {
            /// <summary>Gets the URI of an image that can be used to test network connectivity.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <returns type="goog.Uri?">A custom URI to load for the network test.</returns>
        }, 
        
        isActive: function(browserChannel) {
            /// <summary>Gets whether this channel is currently active. This is used to determine the
            /// length of time to wait before retrying.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <returns type="boolean">Whether the channel is currently active.</returns>
        }, 
        
        badMapError: function(browserChannel, map) {
            /// <summary>Called by the channel if enumeration of the map throws an exception.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <param name="map" type="Object">The map that can&apos;t be enumerated.</param>
        }, 
        
        correctHostPrefix: function(serverHostPrefix) {
            /// <summary>Allows the handler to override a host prefix provided by the server.  Will
            /// be called whenever the channel has received such a prefix and is considering
            /// its use.</summary>
            /// <param name="serverHostPrefix" type="?string">The host prefix provided by the server.</param>
            /// <returns type="?string">The host prefix the client should use.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.BrowserChannel.Handler";
})(this);
