
/* vsdoc for goog.net.BrowserTestChannel */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.BrowserTestChannel = function(channel, channelDebug){
        /// <summary></summary>
        /// <param name="channel" type="goog.net.BrowserChannel">The BrowserChannel that owns this
        ///     test channel.</param>
        /// <param name="channelDebug" type="goog.net.ChannelDebug">A ChannelDebug to use for
        ///     logging.</param>
        /// <returns type="goog.net.BrowserTestChannel"/>
    };

    var $x = window.goog.net.BrowserTestChannel;
    $x.prototype = {
                
        setExtraHeaders: function(extraHeaders) {
            /// <summary>Sets extra HTTP headers to add to all the requests sent to the server.</summary>
            /// <param name="extraHeaders" type="Object">The HTTP headers.</param>
        }, 
        
        setParser: function(parser) {
            /// <summary>Sets a new parser for the response payload. A custom parser may be set to
            /// avoid using eval(), for example.
            /// By default, the parser uses {@code goog.json.unsafeParse}.</summary>
            /// <param name="parser" type="!goog.string.Parser">Parser.</param>
        }, 
        
        connect: function(path) {
            /// <summary>Starts the test channel. This initiates connections to the server.</summary>
            /// <param name="path" type="string">The relative uri for the test connection.</param>
        }, 
        
        createXhrIo: function(hostPrefix) {
            /// <summary>Factory method for XhrIo objects.</summary>
            /// <param name="hostPrefix" type="?string">The host prefix, if we need an XhrIo object
            ///     capable of calling a secondary domain.</param>
            /// <returns type="!goog.net.XhrIo">New XhrIo object.</returns>
        }, 
        
        abort: function() {
            /// <summary>Aborts the test channel.</summary>
        }, 
        
        isClosed: function() {
            /// <summary>Returns whether the test channel is closed. The ChannelRequest object expects
            /// this method to be implemented on its handler.</summary>
            /// <returns type="boolean">Whether the channel is closed.</returns>
        }, 
        
        onRequestData: function(req, responseText) {
            /// <summary>Callback from ChannelRequest for when new data is received</summary>
            /// <param name="req" type="goog.net.ChannelRequest">The request object.</param>
            /// <param name="responseText" type="string">The text of the response.</param>
        }, 
        
        onRequestComplete: function(req) {
            /// <summary>Callback from ChannelRequest that indicates a request has completed.</summary>
            /// <param name="req" type="goog.net.ChannelRequest">The request object.</param>
        }, 
        
        getLastStatusCode: function() {
            /// <summary>Returns the last status code received for a request.</summary>
            /// <returns type="number">The last status code received for a request.</returns>
        }, 
        
        shouldUseSecondaryDomains: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether we should be using secondary domains when the
            ///     server instructs us to do so.</returns>
        }, 
        
        isActive: function(browserChannel) {
            /// <summary>Gets whether this channel is currently active. This is used to determine the
            /// length of time to wait before retrying.</summary>
            /// <param name="browserChannel" type="goog.net.BrowserChannel">The browser channel.</param>
            /// <returns type="boolean">Whether the channel is currently active.</returns>
        }, 
        
        notifyServerReachabilityEvent: function(reachabilityType) {
            /// <summary>Notifies the channel of a fine grained network event.</summary>
            /// <param name="reachabilityType" type="goog.net.BrowserChannel.ServerReachability">The
            ///     reachability event type.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.BrowserTestChannel";
})(this);
