
/* vsdoc for goog.net.ChannelDebug */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.ChannelDebug = function(){
        /// <summary></summary>
        /// <returns type="goog.net.ChannelDebug"/>
    };

    var $x = window.goog.net.ChannelDebug;
    $x.prototype = {
                
        getLogger: function() {
            /// <summary>Gets the logger used by this ChannelDebug.</summary>
            /// <returns type="goog.debug.Logger">The logger used by this ChannelDebug.</returns>
        }, 
        
        browserOfflineResponse: function(url) {
            /// <summary>Logs that the browser went offline during the lifetime of a request.</summary>
            /// <param name="url" type="goog.Uri">The URL being requested.</param>
        }, 
        
        xmlHttpChannelRequest: function(verb, uri, id, attempt, postData) {
            /// <summary>Logs an XmlHttp request..</summary>
            /// <param name="verb" type="string">The request type (GET/POST).</param>
            /// <param name="uri" type="goog.Uri">The request destination.</param>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="attempt" type="number">Which attempt # the request was.</param>
            /// <param name="postData" type="?string">The data posted in the request.</param>
        }, 
        
        xmlHttpChannelResponseMetaData: function(verb, uri, id, attempt, readyState, statusCode) {
            /// <summary>Logs the meta data received from an XmlHttp request.</summary>
            /// <param name="verb" type="string">The request type (GET/POST).</param>
            /// <param name="uri" type="goog.Uri">The request destination.</param>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="attempt" type="number">Which attempt # the request was.</param>
            /// <param name="readyState" type="goog.net.XmlHttp.ReadyState">The ready state.</param>
            /// <param name="statusCode" type="number">The HTTP status code.</param>
        }, 
        
        xmlHttpChannelResponseText: function(id, responseText, opt_desc) {
            /// <summary>Logs the response data received from an XmlHttp request.</summary>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="responseText" type="?string">The response text.</param>
            /// <param name="opt_desc" type="?string=">Optional request description.</param>
        }, 
        
        tridentChannelRequest: function(verb, uri, id, attempt) {
            /// <summary>Logs a Trident ActiveX request.</summary>
            /// <param name="verb" type="string">The request type (GET/POST).</param>
            /// <param name="uri" type="goog.Uri">The request destination.</param>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="attempt" type="number">Which attempt # the request was.</param>
        }, 
        
        tridentChannelResponseText: function(id, responseText) {
            /// <summary>Logs the response text received from a Trident ActiveX request.</summary>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="responseText" type="string">The response text.</param>
        }, 
        
        tridentChannelResponseDone: function(id, successful) {
            /// <summary>Logs the done response received from a Trident ActiveX request.</summary>
            /// <param name="id" type="string|number|undefined">The request id.</param>
            /// <param name="successful" type="boolean">Whether the request was successful.</param>
        }, 
        
        timeoutResponse: function(uri) {
            /// <summary>Logs a request timeout.</summary>
            /// <param name="uri" type="goog.Uri">The uri that timed out.</param>
        }, 
        
        debug: function(text) {
            /// <summary>Logs a debug message.</summary>
            /// <param name="text" type="string">The message.</param>
        }, 
        
        dumpException: function(e, opt_msg) {
            /// <summary>Logs an exception</summary>
            /// <param name="e" type="Error">The error or error event.</param>
            /// <param name="opt_msg" type="string=">The optional message, defaults to &apos;Exception&apos;.</param>
        }, 
        
        info: function(text) {
            /// <summary>Logs an info message.</summary>
            /// <param name="text" type="string">The message.</param>
        }, 
        
        warning: function(text) {
            /// <summary>Logs a warning message.</summary>
            /// <param name="text" type="string">The message.</param>
        }, 
        
        severe: function(text) {
            /// <summary>Logs a severe message.</summary>
            /// <param name="text" type="string">The message.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.ChannelDebug";
})(this);
