
/* vsdoc for goog.net.ChannelRequest */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.ChannelRequest = function(channel, channelDebug, opt_sessionId, opt_requestId, opt_retryId){
        /// <summary></summary>
        /// <param name="channel" type="goog.net.BrowserChannel|goog.net.BrowserTestChannel">The BrowserChannel that owns this request.</param>
        /// <param name="channelDebug" type="goog.net.ChannelDebug">A ChannelDebug to use for
        ///     logging.</param>
        /// <param name="opt_sessionId" type="string=">The session id for the channel.</param>
        /// <param name="opt_requestId" type="string|number=">The request id for this request.</param>
        /// <param name="opt_retryId" type="number=">The retry id for this request.</param>
        /// <field name="TIMEOUT_MS" type="number">Default timeout in MS for a request. The server must return data within this
        /// time limit for the request to not timeout.</field>
        /// <field name="POLLING_INTERVAL_MS" type="number">How often to poll (in MS) for changes to responseText in browsers that don&apos;t
        /// fire onreadystatechange during incremental loading of responseText.</field>
        /// <field name="Error" type="">Enum type for identifying a ChannelRequest error.</field>
        /// <returns type="goog.net.ChannelRequest"/>
    };

    var $x = window.goog.net.ChannelRequest;
    $x.prototype = {
                
        errorStringFromCode: function(errorCode, statusCode) {
            /// <summary>Returns a useful error string for debugging based on the specified error
            /// code.</summary>
            /// <param name="errorCode" type="goog.net.ChannelRequest.Error">The error code.</param>
            /// <param name="statusCode" type="number">The HTTP status code.</param>
            /// <returns type="string">The error string for the given code combination.</returns>
        }, 
        
        supportsXhrStreaming: function() {
            /// <summary>Returns whether XHR streaming is supported on this browser.
            /// 
            /// If XHR streaming is not supported, we will try to use an ActiveXObject
            /// to create a Forever IFrame.</summary>
            /// <returns type="boolean">Whether XHR streaming is supported.</returns>
        }, 
        
        setExtraHeaders: function(extraHeaders) {
            /// <summary>Sets extra HTTP headers to add to all the requests sent to the server.</summary>
            /// <param name="extraHeaders" type="Object">The HTTP headers.</param>
        }, 
        
        setTimeout: function(timeout) {
            /// <summary>Sets the timeout for a request</summary>
            /// <param name="timeout" type="number">The timeout in MS for when we fail the request.</param>
        }, 
        
        setReadyStateChangeThrottle: function(throttle) {
            /// <summary>Sets the throttle for handling onreadystatechange events for the request.</summary>
            /// <param name="throttle" type="number">The throttle in ms.  A value of zero indicates
            ///     no throttle.</param>
        }, 
        
        xmlHttpPost: function(uri, postData, decodeChunks) {
            /// <summary>Uses XMLHTTP to send an HTTP POST to the server.</summary>
            /// <param name="uri" type="goog.Uri">The uri of the request.</param>
            /// <param name="postData" type="string">The data for the post body.</param>
            /// <param name="decodeChunks" type="boolean">Whether to the result is expected to be
            ///     encoded for chunking and thus requires decoding.</param>
        }, 
        
        xmlHttpGet: function(uri, decodeChunks, hostPrefix, opt_noClose) {
            /// <summary>Uses XMLHTTP to send an HTTP GET to the server.</summary>
            /// <param name="uri" type="goog.Uri">The uri of the request.</param>
            /// <param name="decodeChunks" type="boolean">Whether to the result is expected to be
            ///     encoded for chunking and thus requires decoding.</param>
            /// <param name="hostPrefix" type="?string">The host prefix, if we might be using a
            ///     secondary domain.  Note that it should also be in the URL, adding this
            ///     won&apos;t cause it to be added to the URL.</param>
            /// <param name="opt_noClose" type="boolean=">Whether to request that the tcp/ip connection
            ///     should be closed.</param>
        }, 
        
        tridentGet: function(uri, usingSecondaryDomain) {
            /// <summary>Uses the Trident htmlfile ActiveX control to send a GET request in IE. This
            /// is the innovation discovered that lets us get intermediate results in
            /// Internet Explorer.  Thanks to http://go/kev</summary>
            /// <param name="uri" type="goog.Uri">The uri to request from.</param>
            /// <param name="usingSecondaryDomain" type="boolean">Whether to use a secondary domain.</param>
        }, 
        
        sendUsingImgTag: function(uri) {
            /// <summary>Uses an IMG tag to send an HTTP get to the server. This is only currently
            /// used to terminate the connection, as an IMG tag is the most reliable way to
            /// send something to the server while the page is getting torn down.</summary>
            /// <param name="uri" type="goog.Uri">The uri to send a request to.</param>
        }, 
        
        cancel: function() {
            /// <summary>Cancels the request no matter what the underlying transport is.</summary>
        }, 
        
        getSuccess: function() {
            /// <summary>Indicates whether the request was successful. Only valid after the handler
            /// is called to indicate completion of the request.</summary>
            /// <returns type="boolean">True if the request succeeded.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>If the request was not successful, returns the reason.</summary>
            /// <returns type="?goog.net.ChannelRequest.Error">The last error.</returns>
        }, 
        
        getLastStatusCode: function() {
            /// <summary>Returns the status code of the last request.</summary>
            /// <returns type="number">The status code of the last request.</returns>
        }, 
        
        getSessionId: function() {
            /// <summary>Returns the session id for this channel.</summary>
            /// <returns type="string|undefined">The session ID.</returns>
        }, 
        
        getRequestId: function() {
            /// <summary>Returns the request id for this request. Each request has a unique request
            /// id and the request IDs are a sequential increasing count.</summary>
            /// <returns type="string|number|undefined">The request ID.</returns>
        }, 
        
        getPostData: function() {
            /// <summary>Returns the data for a post, if this request is a post.</summary>
            /// <returns type="?string">The POST data provided by the request initiator.</returns>
        }, 
        
        getRequestStartTime: function() {
            /// <summary>Returns the time that the request started, if it has started.</summary>
            /// <returns type="?number">The time the request started, as returned by goog.now().</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.ChannelRequest";
})(this);
