
/* vsdoc for goog.net.Cookies */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.Cookies = function(context){
        /// <summary></summary>
        /// <param name="context" type="Document">The context document to get/set cookies on.</param>
        /// <field name="MAX_COOKIE_LENGTH" type="number">Static constant for the size of cookies. Per the spec, there&apos;s a 4K limit
        /// to the size of a cookie. To make sure users can&apos;t break this limit, we
        /// should truncate long cookies at 3950 bytes, to be extra careful with dumb
        /// browsers/proxies that interpret 4K as 4000 rather than 4096.</field>
        /// <returns type="goog.net.Cookies"/>
    };

    var $x = window.goog.net.Cookies;
    $x.prototype = {
                
        isEnabled: function() {
            /// <summary>Returns true if cookies are enabled.</summary>
            /// <returns type="boolean">True if cookies are enabled.</returns>
        }, 
        
        isValidName: function(name) {
            /// <summary>We do not allow &apos;=&apos;, &apos;;&apos;, or white space in the name.
            /// 
            /// NOTE: The following are allowed by this method, but should be avoided for
            /// cookies handled by the server.
            /// - any name starting with &apos;$&apos;
            /// - &apos;Comment&apos;
            /// - &apos;Domain&apos;
            /// - &apos;Expires&apos;
            /// - &apos;Max-Age&apos;
            /// - &apos;Path&apos;
            /// - &apos;Secure&apos;
            /// - &apos;Version&apos;</summary>
            /// <param name="name" type="string">Cookie name.</param>
            /// <returns type="boolean">Whether name is valid.</returns>
        }, 
        
        isValidValue: function(value) {
            /// <summary>We do not allow &apos;;&apos; or line break in the value.
            /// 
            /// Spec does not mention any illegal characters, but in practice semi-colons
            /// break parsing and line breaks truncate the name.</summary>
            /// <param name="value" type="string">Cookie value.</param>
            /// <returns type="boolean">Whether value is valid.</returns>
        }, 
        
        set: function(name, value, opt_maxAge, opt_path, opt_domain, opt_secure) {
            /// <summary>Sets a cookie.  The max_age can be -1 to set a session cookie. To remove and
            /// expire cookies, use remove() instead.
            /// 
            /// Neither the {@code name} nor the {@code value} are encoded in any way. It is
            /// up to the callers of {@code get} and {@code set} (as well as all the other
            /// methods) to handle any possible encoding and decoding.</summary>
            /// <param name="name" type="string">The cookie name.</param>
            /// <param name="value" type="string">The cookie value.</param>
            /// <param name="opt_maxAge" type="number=">The max age in seconds (from now). Use -1 to
            ///     set a session cookie. If not provided, the default is -1
            ///     (i.e. set a session cookie).</param>
            /// <param name="opt_path" type="?string=">The path of the cookie. If not present then this
            ///     uses the full request path.</param>
            /// <param name="opt_domain" type="?string=">The domain of the cookie, or null to not
            ///     specify a domain attribute (browser will use the full request host name).
            ///     If not provided, the default is null (i.e. let browser use full request
            ///     host name).</param>
            /// <param name="opt_secure" type="boolean=">Whether the cookie should only be sent over
            ///     a secure channel.</param>
        }, 
        
        get: function(name, opt_default) {
            /// <summary>Returns the value for the first cookie with the given name.</summary>
            /// <param name="name" type="string">The name of the cookie to get.</param>
            /// <param name="opt_default" type="string=">If not found this is returned instead.</param>
            /// <returns type="string|undefined">The value of the cookie. If no cookie is set this
            ///     returns opt_default or undefined if opt_default is not provided.</returns>
        }, 
        
        remove: function(name, opt_path, opt_domain) {
            /// <summary>Removes and expires a cookie.</summary>
            /// <param name="name" type="string">The cookie name.</param>
            /// <param name="opt_path" type="string=">The path of the cookie, or null to expire a cookie
            ///     set at the full request path. If not provided, the default is &apos;/&apos;
            ///     (i.e. path=/).</param>
            /// <param name="opt_domain" type="string=">The domain of the cookie, or null to expire a
            ///     cookie set at the full request host name. If not provided, the default is
            ///     null (i.e. cookie at full request host name).</param>
            /// <returns type="boolean">Whether the cookie existed before it was removed.</returns>
        }, 
        
        getKeys: function() {
            /// <summary>Gets the names for all the cookies.</summary>
            /// <returns type="Array.string">An array with the names of the cookies.</returns>
        }, 
        
        getValues: function() {
            /// <summary>Gets the values for all the cookies.</summary>
            /// <returns type="Array.string">An array with the values of the cookies.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether there are any cookies for this document.</returns>
        }, 
        
        getCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of cookies for this document.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary>Returns whether there is a cookie with the given name.</summary>
            /// <param name="key" type="string">The name of the cookie to test for.</param>
            /// <returns type="boolean">Whether there is a cookie by that name.</returns>
        }, 
        
        containsValue: function(value) {
            /// <summary>Returns whether there is a cookie with the given value. (This is an O(n)
            /// operation.)</summary>
            /// <param name="value" type="string">The value to check for.</param>
            /// <returns type="boolean">Whether there is a cookie with that value.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all cookies for this document.  Note that this will only remove
            /// cookies from the current path and domain.  If there are cookies set using a
            /// subpath and/or another domain these will still be there.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.Cookies";
})(this);
