
/* vsdoc for goog.net.CrossDomainRpc */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.CrossDomainRpc = function(){
        /// <summary></summary>
        /// <field name="HEADER" type="string">Header prefix.</field>
        /// <field name="PARAM" type="string">Parameter prefix.</field>
        /// <field name="PARAM_ECHO" type="string">Parameter to echo prefix.</field>
        /// <field name="PARAM_ECHO_REQUEST_ID" type="string">Parameter to echo: request id</field>
        /// <field name="PARAM_ECHO_DUMMY_URI" type="string">Parameter to echo: dummy resource URI</field>
        /// <returns type="goog.net.CrossDomainRpc"/>
    };

    var $x = window.goog.net.CrossDomainRpc;
    $x.prototype = {
                
        setDummyResourceUri: function(dummyResourceUri) {
            /// <summary>Sets the URI for a dummy resource on caller&apos;s domain.  This function is
            /// used for specifying a particular resource to use rather than relying on
            /// auto detection.</summary>
            /// <param name="dummyResourceUri" type="string">URI to dummy resource on the same domain
            ///    of caller&apos;s page.</param>
        }, 
        
        setUseFallBackDummyResource: function(useFallBack) {
            /// <summary>Sets whether a fallback dummy resource (&quot;/robots.txt&quot; on Firefox and Safari
            /// and current page on IE) should be used when a suitable dummy resource is
            /// not available.</summary>
            /// <param name="useFallBack" type="boolean">Whether to use fallback or not.</param>
        }, 
        
        send: function(uri, opt_continuation, opt_method, opt_params, opt_headers) {
            /// <summary>Sends a request across domain.</summary>
            /// <param name="uri" type="string">Uri to make request to.</param>
            /// <param name="opt_continuation" type="Function=">Continuation function to be called
            ///     when request is completed.  Takes one argument of an event object
            ///     whose target has the following properties: &quot;status&quot; is the HTTP
            ///     response status code, &quot;responseText&quot; is the response text,
            ///     and &quot;headers&quot; is an object with all response headers.  The event
            ///     target&apos;s getResponseJson() method returns a JavaScript object evaluated
            ///     from the JSON response or undefined if response is not JSON.</param>
            /// <param name="opt_method" type="string=">Method of request. Default is POST.</param>
            /// <param name="opt_params" type="Object=">. Each property is turned into a
            ///     request parameter.</param>
            /// <param name="opt_headers" type="Object=">Map of headers of the request.</param>
        }, 
        
        setDebugMode: function(flag) {
            /// <summary>Sets debug mode to true or false.  When debug mode is on, response iframes
            /// are visible and left behind after their use is finished.</summary>
            /// <param name="flag" type="boolean">Flag to indicate intention to turn debug model on
            ///     (true) or off (false).</param>
        }, 
        
        sendRequest: function(uri, opt_method, opt_params, opt_headers) {
            /// <summary>Sends a request across domain.</summary>
            /// <param name="uri" type="string">Uri to make request to.</param>
            /// <param name="opt_method" type="string=">Method of request. Default is POST.</param>
            /// <param name="opt_params" type="Object=">. Each property is turned into a
            ///     request parameter.</param>
            /// <param name="opt_headers" type="Object=">Map of headers of the request.</param>
        }, 
        
        getResponseJson: function() {
            /// <summary>If response is JSON, evaluates it to a JavaScript object and
            /// returns it; otherwise returns undefined.</summary>
            /// <returns type="Object|undefined">JavaScript object if response is in JSON
            ///     or undefined.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the request completed with a success.</returns>
        }, 
        
        reset: function() {
            /// <summary>Removes request iframe used.</summary>
        }, 
        
        sendResponse: function(data, isDataJson, echo, status, headers) {
            /// <summary>Makes response available for grandparent (requester)&apos;s receiveResponse
            /// call to pick up by creating a series of iframes pointed to the dummy URI
            /// with a payload (value after either ? or #) carrying a chunk of response
            /// data and a response info iframe that tells the grandparent (requester) the
            /// readiness of response.</summary>
            /// <param name="data" type="string">Response data (string or JSON string).</param>
            /// <param name="isDataJson" type="boolean">true if data is a JSON string; false if just a
            ///     string.</param>
            /// <param name="echo" type="Object">to echo back
            ///     &quot;xdpe:request-id&quot;: Server that produces the response needs to
            ///     copy it here to support multiple current XD requests on the same page.
            ///     &quot;xdpe:dummy-uri&quot;: URI to a dummy resource that response
            ///     iframes point to to gain the domain of the client.  This can be an
            ///     image (IE) or a CSS file (FF) found on the requester&apos;s page.
            ///     Server should copy value from request parameter &quot;xdpe:dummy-uri&quot;.</param>
            /// <param name="status" type="number">HTTP response status code.</param>
            /// <param name="headers" type="string">Response headers in JSON format.</param>
        }, 
        
        getResponseHeader: function(name) {
            /// <summary>Gets a response header.</summary>
            /// <param name="name" type="string">Name of response header.</param>
            /// <returns type="string|undefined">Value of response header; undefined if not found.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.CrossDomainRpc";
})(this);
