
/* vsdoc for goog.net.FileDownloader */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.FileDownloader = function(dir, opt_pool){
        /// <summary></summary>
        /// <param name="dir" type="!goog.fs.DirectoryEntry">The directory in which the downloaded
        ///     files are stored. This directory should be solely managed by
        ///     FileDownloader.</param>
        /// <param name="opt_pool" type="goog.net.XhrIoPool=">The pool of XhrIo objects to use for
        ///     downloading files.</param>
        /// <returns type="goog.net.FileDownloader"/>
    };

    var $x = window.goog.net.FileDownloader;
    $x.prototype = {
                
        download: function(url) {
            /// <summary>Download a remote file and save its contents to the filesystem. A given file
            /// is uniquely identified by its URL string; this means that the relative and
            /// absolute URLs for a single file are considered different for the purposes of
            /// the FileDownloader.
            /// 
            /// Returns a Deferred that will contain the downloaded blob. If there&apos;s an error
            /// while downloading the URL, this Deferred will be passed the
            /// {@link goog.net.FileDownloader.Error} object as an errback.
            /// 
            /// If a download is already in progress for the given URL, this will return the
            /// deferred blob for that download. If the URL has already been downloaded, this
            /// will fail once it tries to save the downloaded blob.
            /// 
            /// When a download is in progress, all Deferreds returned for that download will
            /// be branches of a single parent. If all such branches are cancelled, or if one
            /// is cancelled with opt_deepCancel set, then the download will be cancelled as
            /// well.</summary>
            /// <param name="url" type="string">The URL of the file to download.</param>
            /// <returns type="!goog.async.Deferred">The deferred result blob.</returns>
        }, 
        
        waitForDownload: function(url) {
            /// <summary>Return a Deferred that will fire once no download is active for a given URL.
            /// If there&apos;s no download active for that URL when this is called, the deferred
            /// will fire immediately; otherwise, it will fire once the download is complete,
            /// whether or not it succeeds.</summary>
            /// <param name="url" type="string">The URL of the download to wait for.</param>
            /// <returns type="!goog.async.Deferred">The Deferred that will fire when the download
            ///     is complete.</returns>
        }, 
        
        isDownloading: function(url) {
            /// <summary>Returns whether or not there is an active download for a given URL.</summary>
            /// <param name="url" type="string">The URL of the download to check.</param>
            /// <returns type="boolean">Whether or not there is an active download for the URL.</returns>
        }, 
        
        getDownloadedBlob: function(url) {
            /// <summary>Load a downloaded blob from the filesystem. Will fire a deferred error if the
            /// given URL has not yet been downloaded.</summary>
            /// <param name="url" type="string">The URL of the blob to load.</param>
            /// <returns type="!goog.async.Deferred">The deferred Blob object. The callback will be
            ///     passed the blob. If a file API error occurs while loading the blob, that
            ///     error will be passed to the errback.</returns>
        }, 
        
        getLocalUrl: function(url) {
            /// <summary>Get the local filesystem: URL for a downloaded file. This is different from
            /// the blob: URL that&apos;s available from getDownloadedBlob(). If the end user
            /// accesses the filesystem: URL, the resulting file&apos;s name will be determined by
            /// the download filename as opposed to an arbitrary GUID. In addition, the
            /// filesystem: URL is connected to a filesystem location, so if the download is
            /// removed then that URL will become invalid.
            /// 
            /// Warning: in Chrome 12, some filesystem: URLs are opened inline. This means
            /// that e.g. HTML pages given to the user via filesystem: URLs will be opened
            /// and processed by the browser.</summary>
            /// <param name="url" type="string">The URL of the file to get the URL of.</param>
            /// <returns type="!goog.async.Deferred">The deferred filesystem: URL. The callback
            ///     will be passed the URL. If a file API error occurs while loading the
            ///     blob, that error will be passed to the errback.</returns>
        }, 
        
        isDownloaded: function(url) {
            /// <summary>Return (deferred) whether or not a URL has been downloaded. Will fire a
            /// deferred error if something goes wrong when determining this.</summary>
            /// <param name="url" type="string">The URL to check.</param>
            /// <returns type="!goog.async.Deferred">The deferred boolean. The callback will be
            ///     passed the boolean. If a file API error occurs while checking the
            ///     existence of the downloaded URL, that error will be passed to the
            ///     errback.</returns>
        }, 
        
        remove: function(url) {
            /// <summary>Remove a URL from the FileDownloader.
            /// 
            /// This returns a Deferred. If the removal is completed successfully, its
            /// callback will be called without any value. If the removal fails, its errback
            /// will be called with the {@link goog.fs.Error}.</summary>
            /// <param name="url" type="string">The URL to remove.</param>
            /// <returns type="!goog.async.Deferred">The deferred used for registering callbacks on
            ///     success or on error.</returns>
        }, 
        
        setBlob: function(url, blob, opt_name) {
            /// <summary>Save a blob for a given URL. This works just as through the blob were
            /// downloaded form that URL, except you specify the blob and no HTTP request is
            /// made.
            /// 
            /// If the URL is currently being downloaded, it&apos;s indeterminate whether the blob
            /// being set or the blob being downloaded will end up in the filesystem.
            /// Whichever one doesn&apos;t get saved will have an error. To ensure that one or the
            /// other takes precedence, use {@link #waitForDownload} to allow the download to
            /// complete before setting the blob.</summary>
            /// <param name="url" type="string">The URL at which to set the blob.</param>
            /// <param name="blob" type="!Blob">The blob to set.</param>
            /// <param name="opt_name" type="string=">The name of the file. If this isn&apos;t given, it&apos;s
            ///     determined from the URL.</param>
            /// <returns type="!goog.async.Deferred">The deferred used for registering callbacks on
            ///     success or on error. This can be cancelled just like a {@link #download}
            ///     Deferred. The objects passed to the errback will be
            ///     {@link goog.net.FileDownloader.Error}s.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.FileDownloader";
})(this);
