
/* vsdoc for goog.net.IframeIo */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.IframeIo = function(){
        /// <summary></summary>
        /// <field name="FRAME_NAME_PREFIX" type="string">Prefix for frame names</field>
        /// <field name="INNER_FRAME_SUFFIX" type="string">Suffix that is added to inner frames used for sending requests in non-IE
        /// browsers</field>
        /// <field name="IFRAME_DISPOSE_DELAY_MS" type="number">The number of milliseconds after a request is completed to dispose the
        /// iframes.  This can be done lazily so we wait long enough for any processing
        /// that occurred as a result of the response to finish.</field>
        /// <field name="errorHandled_" type=""></field>
        /// <returns type="goog.net.IframeIo"/>
    };

    var $x = window.goog.net.IframeIo;
    $x.prototype = {
                
        send: function(uri, opt_callback, opt_method, opt_noCache, opt_data) {
            /// <summary>Static send that creates a short lived instance of IframeIo to send the
            /// request.</summary>
            /// <param name="uri" type="goog.Uri|string">Uri of the request, it is up the caller to
            ///     manage query string params.</param>
            /// <param name="opt_callback" type="Function=">Event handler for when request is completed.</param>
            /// <param name="opt_method" type="string=">Default is GET, POST uses a form to submit the
            ///     request.</param>
            /// <param name="opt_noCache" type="boolean=">Append a timestamp to the request to avoid
            ///     caching.</param>
            /// <param name="opt_data" type="Object|goog.structs.Map=">Map of key-value pairs that
            ///     will be posted to the server via the iframe&apos;s form.</param>
        }, 
        
        getIframeByName: function(fname) {
            /// <summary>Find an iframe by name (assumes the context is goog.global since that is
            /// where IframeIo&apos;s iframes are kept).</summary>
            /// <param name="fname" type="string">The name to find.</param>
            /// <returns type="HTMLIFrameElement">The iframe element with that name.</returns>
        }, 
        
        getInstanceByName: function(fname) {
            /// <summary>Find an instance of the IframeIo object by name.</summary>
            /// <param name="fname" type="string">The name to find.</param>
            /// <returns type="goog.net.IframeIo">The instance of IframeIo.</returns>
        }, 
        
        handleIncrementalData: function(win, data) {
            /// <summary>Handles incremental data and routes it to the correct iframeIo instance.
            /// The HTML page requested by the IframeIo instance should contain script blocks
            /// that call an externed reference to this method.</summary>
            /// <param name="win" type="Window">The window object.</param>
            /// <param name="data" type="Object">The data object.</param>
        }, 
        
        send: function(uri, opt_method, opt_noCache, opt_data) {
            /// <summary>Sends a request via an iframe.
            /// 
            /// A HTML form is used and submitted to the iframe, this simplifies the
            /// difference between GET and POST requests. The iframe needs to be created and
            /// destroyed for each request otherwise the request will contribute to the
            /// history stack.
            /// 
            /// sendFromForm does some clever trickery (thanks jlim) in non-IE browsers to
            /// stop a history entry being added for POST requests.</summary>
            /// <param name="uri" type="goog.Uri|string">Uri of the request.</param>
            /// <param name="opt_method" type="string=">Default is GET, POST uses a form to submit the
            ///     request.</param>
            /// <param name="opt_noCache" type="boolean=">Append a timestamp to the request to avoid
            ///     caching.</param>
            /// <param name="opt_data" type="Object|goog.structs.Map=">Map of key-value pairs.</param>
        }, 
        
        sendFromForm: function(form, opt_uri, opt_noCache) {
            /// <summary>Sends the data stored in an existing form to the server. The HTTP method
            /// should be specified on the form, the action can also be specified but can
            /// be overridden by the optional URI param.
            /// 
            /// This can be used in conjunction will a file-upload input to upload a file in
            /// the background without affecting history.
            /// 
            /// Example form:
            /// &lt;pre&gt;
            ///   &amp;lt;form action=&quot;/server/&quot; enctype=&quot;multipart/form-data&quot; method=&quot;POST&quot;&amp;gt;
            ///     &amp;lt;input name=&quot;userfile&quot; type=&quot;file&quot;&amp;gt;
            ///   &amp;lt;/form&amp;gt;
            /// &lt;/pre&gt;</summary>
            /// <param name="form" type="HTMLFormElement">Form element used to send the request to the
            ///     server.</param>
            /// <param name="opt_uri" type="string=">Uri to set for the destination of the request, by
            ///     default the uri will come from the form.</param>
            /// <param name="opt_noCache" type="boolean=">Append a timestamp to the request to avoid
            ///     caching.</param>
        }, 
        
        abort: function(opt_failureCode) {
            /// <summary>Abort the current Iframe request</summary>
            /// <param name="opt_failureCode" type="goog.net.ErrorCode=">Optional error code to use -
            ///     defaults to ABORT.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        isComplete: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if transfer is complete.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if transfer was successful.</returns>
        }, 
        
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if a transfer is in progress.</returns>
        }, 
        
        getResponseText: function() {
            /// <summary>Returns the last response text (i.e. the text content of the iframe).
            /// Assumes plain text!</summary>
            /// <returns type="?string">Result from the server.</returns>
        }, 
        
        getResponseHtml: function() {
            /// <summary>Returns the last response html (i.e. the innerHtml of the iframe).</summary>
            /// <returns type="?string">Result from the server.</returns>
        }, 
        
        getResponseJson: function() {
            /// <summary>Parses the content as JSON. This is a safe parse and may throw an error
            /// if the response is malformed.
            /// Use goog.json.unsafeparse(this.getResponseText()) if you are sure of the
            /// state of the returned content.</summary>
            /// <returns type="Object">The parsed content.</returns>
        }, 
        
        getResponseXml: function() {
            /// <summary>Returns the document object from the last request.  Not truely XML, but
            /// used to mirror the XhrIo interface.</summary>
            /// <returns type="HTMLDocument">The document object from the last request.</returns>
        }, 
        
        getLastUri: function() {
            /// <summary>Get the uri of the last request.</summary>
            /// <returns type="goog.Uri">Uri of last request.</returns>
        }, 
        
        getLastErrorCode: function() {
            /// <summary>Gets the last error code.</summary>
            /// <returns type="goog.net.ErrorCode">Last error code.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>Gets the last error message.</summary>
            /// <returns type="string">Last error message.</returns>
        }, 
        
        getLastCustomError: function() {
            /// <summary>Gets the last custom error.</summary>
            /// <returns type="Object">Last custom error.</returns>
        }, 
        
        setErrorChecker: function(fn) {
            /// <summary>Sets the callback function used to check if a loaded IFrame is in an error
            /// state.</summary>
            /// <param name="fn" type="Function">Callback that expects a document object as it&apos;s single
            ///     argument.</param>
        }, 
        
        getErrorChecker: function() {
            /// <summary>Gets the callback function used to check if a loaded IFrame is in an error
            /// state.</summary>
            /// <returns type="Function">A callback that expects a document object as it&apos;s single
            ///     argument.</returns>
        }, 
        
        getTimeoutInterval: function() {
            /// <summary>Returns the number of milliseconds after which an incomplete request will be
            /// aborted, or 0 if no timeout is set.</summary>
            /// <returns type="number">Timeout interval in milliseconds.</returns>
        }, 
        
        setTimeoutInterval: function(ms) {
            /// <summary>Sets the number of milliseconds after which an incomplete request will be
            /// aborted and a {@link goog.net.EventType.TIMEOUT} event raised; 0 means no
            /// timeout is set.</summary>
            /// <param name="ms" type="number">Timeout interval in milliseconds; 0 means none.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.IframeIo";
})(this);
