
/* vsdoc for goog.net.Jsonp */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.Jsonp = function(uri, opt_callbackParamName){
        /// <summary></summary>
        /// <param name="uri" type="goog.Uri|string">The Uri of the server side code that receives
        ///     data posted through this channel (e.g.,
        ///     &quot;http://maps.google.com/maps/geo&quot;).</param>
        /// <param name="opt_callbackParamName" type="string=">The parameter name that is used to
        ///     specify the callback. Defaults to &quot;callback&quot;.</param>
        /// <field name="CALLBACKS" type="">The name of the property of goog.global under which the callback is
        /// stored.</field>
        /// <returns type="goog.net.Jsonp"/>
    };

    var $x = window.goog.net.Jsonp;
    $x.prototype = {
                
        setRequestTimeout: function(timeout) {
            /// <summary>Sets the length of time, in milliseconds, this channel is prepared
            /// to wait for for a request to complete. If the call is not competed
            /// within the set time span, it is assumed to have failed. To wait
            /// indefinitely for a request to complete set the timout to a negative
            /// number.</summary>
            /// <param name="timeout" type="number">The length of time before calls are
            /// interrupted.</param>
        }, 
        
        getRequestTimeout: function() {
            /// <summary>Returns the current timeout value, in milliseconds.</summary>
            /// <returns type="number">The timeout value.</returns>
        }, 
        
        send: function(opt_payload, opt_replyCallback, opt_errorCallback, opt_callbackParamValue) {
            /// <summary>Sends the given payload to the URL specified at the construction
            /// time. The reply is delivered to the given replyCallback. If the
            /// errorCallback is specified and the reply does not arrive within the
            /// timeout period set on this channel, the errorCallback is invoked
            /// with the original payload.
            /// 
            /// If no reply callback is specified, then the response is expected to
            /// consist of calls to globally registered functions. No &amp;callback=
            /// URL parameter will be sent in the request, and the script element
            /// will be cleaned up after the timeout.</summary>
            /// <param name="opt_payload" type="Object=">Name-value pairs.  If given, these will be
            ///     added as parameters to the supplied URI as GET parameters to the
            ///     given server URI.</param>
            /// <param name="opt_replyCallback" type="Function=">A function expecting one
            ///     argument, called when the reply arrives, with the response data.</param>
            /// <param name="opt_errorCallback" type="Function=">A function expecting one
            ///     argument, called on timeout, with the payload (if given), otherwise
            ///     null.</param>
            /// <param name="opt_callbackParamValue" type="string=">Value to be used as the
            ///     parameter value for the callback parameter (callbackParamName).
            ///     To be used when the value needs to be fixed by the client for a
            ///     particular request, to make use of the cached responses for the request.
            ///     NOTE: If multiple requests are made with the same
            ///     opt_callbackParamValue, only the last call will work whenever the
            ///     response comes back.</param>
            /// <returns type="Object">A request descriptor that may be used to cancel this
            ///     transmission, or null, if the message may not be cancelled.</returns>
        }, 
        
        cancel: function(request) {
            /// <summary>Cancels a given request. The request must be exactly the object returned by
            /// the send method.</summary>
            /// <param name="request" type="Object">The request object returned by the send method.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.Jsonp";
})(this);
