
/* vsdoc for goog.net.MockIFrameIo */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.MockIFrameIo = function(testQueue){
        /// <summary></summary>
        /// <param name="testQueue" type="goog.testing.TestQueue">Test queue for inserting test
        ///     events.</param>
        /// <returns type="goog.net.MockIFrameIo"/>
    };

    var $x = window.goog.net.MockIFrameIo;
    $x.prototype = {
                
        send: function(uri, opt_method, opt_noCache, opt_data) {
            /// <summary>Simulates the iframe send.</summary>
            /// <param name="uri" type="goog.Uri|string">Uri of the request.</param>
            /// <param name="opt_method" type="string=">Default is GET, POST uses a form to submit the
            ///     request.</param>
            /// <param name="opt_noCache" type="boolean=">Append a timestamp to the request to avoid
            ///     caching.</param>
            /// <param name="opt_data" type="Object|goog.structs.Map=">Map of key-value pairs.</param>
        }, 
        
        sendFromForm: function(form, opt_uri, opt_noCache) {
            /// <summary>Simulates the iframe send from a form.</summary>
            /// <param name="form" type="Element">Form element used to send the request to the server.</param>
            /// <param name="opt_uri" type="string=">Uri to set for the destination of the request, by
            ///     default the uri will come from the form.</param>
            /// <param name="opt_noCache" type="boolean=">Append a timestamp to the request to avoid
            ///     caching.</param>
        }, 
        
        abort: function(opt_failureCode) {
            /// <summary>Simulates aborting the current Iframe request.</summary>
            /// <param name="opt_failureCode" type="goog.net.ErrorCode=">Optional error code to use -
            ///     defaults to ABORT.</param>
        }, 
        
        simulateIncrementalData: function(data) {
            /// <summary>Simulates receive of incremental data.</summary>
            /// <param name="data" type="Object">Data.</param>
        }, 
        
        simulateDone: function(errorCode) {
            /// <summary>Simulates the iframe is done.</summary>
            /// <param name="errorCode" type="goog.net.ErrorCode">The error code for any error that
            ///     should be simulated.</param>
        }, 
        
        simulateReady: function() {
            /// <summary>Simulates the IFrame is ready for the next request.</summary>
        }, 
        
        isComplete: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if transfer is complete.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if transfer was successful.</returns>
        }, 
        
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if a transfer is in progress.</returns>
        }, 
        
        getResponseText: function() {
            /// <summary>Returns the last response text (i.e. the text content of the iframe).
            /// Assumes plain text!</summary>
            /// <returns type="string">Result from the server.</returns>
        }, 
        
        getResponseJson: function() {
            /// <summary>Parses the content as JSON. This is a safe parse and may throw an error
            /// if the response is malformed.</summary>
            /// <returns type="Object">The parsed content.</returns>
        }, 
        
        getLastUri: function() {
            /// <summary>Get the uri of the last request.</summary>
            /// <returns type="goog.Uri">Uri of last request.</returns>
        }, 
        
        getLastErrorCode: function() {
            /// <summary>Gets the last error code.</summary>
            /// <returns type="goog.net.ErrorCode">Last error code.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>Gets the last error message.</summary>
            /// <returns type="string">Last error message.</returns>
        }, 
        
        getLastCustomError: function() {
            /// <summary>Gets the last custom error.</summary>
            /// <returns type="Object">Last custom error.</returns>
        }, 
        
        setErrorChecker: function(fn) {
            /// <summary>Sets the callback function used to check if a loaded IFrame is in an error
            /// state.</summary>
            /// <param name="fn" type="Function">Callback that expects a document object as it&apos;s single
            ///     argument.</param>
        }, 
        
        getErrorChecker: function() {
            /// <summary>Gets the callback function used to check if a loaded IFrame is in an error
            /// state.</summary>
            /// <returns type="Function">A callback that expects a document object as it&apos;s single
            ///     argument.</returns>
        }, 
        
        getTimeoutInterval: function() {
            /// <summary>Returns the number of milliseconds after which an incomplete request will be
            /// aborted, or 0 if no timeout is set.</summary>
            /// <returns type="number">Timeout interval in milliseconds.</returns>
        }, 
        
        setTimeoutInterval: function(ms) {
            /// <summary>Sets the number of milliseconds after which an incomplete request will be
            /// aborted and a {@link goog.net.EventType.TIMEOUT} event raised; 0 means no
            /// timeout is set.</summary>
            /// <param name="ms" type="number">Timeout interval in milliseconds; 0 means none.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.MockIFrameIo";
})(this);
