
/* vsdoc for goog.net.XhrIo */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.XhrIo = function(opt_xmlHttpFactory){
        /// <summary></summary>
        /// <param name="opt_xmlHttpFactory" type="goog.net.XmlHttpFactory=">Factory to use when
        ///     creating XMLHttpRequest objects.</param>
        /// <field name="headers" type="goog.structs.Map">Map of default headers to add to every request, use:
        /// XhrIo.headers.set(name, value)</field>
        /// <field name="ResponseType" type="">Response types that may be requested for XMLHttpRequests.</field>
        /// <field name="CONTENT_TYPE_HEADER" type="string">The Content-Type HTTP header name</field>
        /// <field name="HTTP_SCHEME_PATTERN" type="!RegExp">The pattern matching the &apos;http&apos; and &apos;https&apos; URI schemes</field>
        /// <field name="FORM_CONTENT_TYPE" type="string">The Content-Type HTTP header value for a url-encoded form</field>
        /// <field name="onReadyStateChangeEntryPoint_" type=""></field>
        /// <returns type="goog.net.XhrIo"/>
    };

    var $x = window.goog.net.XhrIo;
    $x.prototype = {
                
        send: function(url, opt_callback, opt_method, opt_content, opt_headers, opt_timeoutInterval, opt_withCredentials) {
            /// <summary>Static send that creates a short lived instance of XhrIo to send the
            /// request.</summary>
            /// <param name="url" type="string|goog.Uri">Uri to make request to.</param>
            /// <param name="opt_callback" type="Function=">Callback function for when request is
            ///     complete.</param>
            /// <param name="opt_method" type="string=">Send method, default: GET.</param>
            /// <param name="opt_content" type="string|FormData|GearsBlob=">Post data. This can be a Gears blob if the underlying HTTP request object
            ///     is a Gears HTTP request.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
            /// <param name="opt_timeoutInterval" type="number=">Number of milliseconds after which an
            ///     incomplete request will be aborted; 0 means no timeout is set.</param>
            /// <param name="opt_withCredentials" type="boolean=">Whether to send credentials with the
            ///     request. Default to false. See {@link goog.net.XhrIo#setWithCredentials}.</param>
        }, 
        
        cleanup: function() {
            /// <summary>Disposes all non-disposed instances of goog.net.XhrIo created by
            /// {@link goog.net.XhrIo.send}.
            /// {@link goog.net.XhrIo.send} cleans up the goog.net.XhrIo instance
            /// it creates when the request completes or fails.  However, if
            /// the request never completes, then the goog.net.XhrIo is not disposed.
            /// This can occur if the window is unloaded before the request completes.
            /// We could have {@link goog.net.XhrIo.send} return the goog.net.XhrIo
            /// it creates and make the client of {@link goog.net.XhrIo.send} be
            /// responsible for disposing it in this case.  However, this makes things
            /// significantly more complicated for the client, and the whole point
            /// of {@link goog.net.XhrIo.send} is that it&apos;s simple and easy to use.
            /// Clients of {@link goog.net.XhrIo.send} should call
            /// {@link goog.net.XhrIo.cleanup} when doing final
            /// cleanup on window unload.</summary>
        }, 
        
        protectEntryPoints: function(errorHandler) {
            /// <summary>Installs exception protection for all entry point introduced by
            /// goog.net.XhrIo instances which are not protected by
            /// {@link goog.debug.ErrorHandler#protectWindowSetTimeout},
            /// {@link goog.debug.ErrorHandler#protectWindowSetInterval}, or
            /// {@link goog.events.protectBrowserEventEntryPoint}.</summary>
            /// <param name="errorHandler" type="goog.debug.ErrorHandler">Error handler with which to
            ///     protect the entry point(s).</param>
        }, 
        
        getTimeoutInterval: function() {
            /// <summary>Returns the number of milliseconds after which an incomplete request will be
            /// aborted, or 0 if no timeout is set.</summary>
            /// <returns type="number">Timeout interval in milliseconds.</returns>
        }, 
        
        setTimeoutInterval: function(ms) {
            /// <summary>Sets the number of milliseconds after which an incomplete request will be
            /// aborted and a {@link goog.net.EventType.TIMEOUT} event raised; 0 means no
            /// timeout is set.</summary>
            /// <param name="ms" type="number">Timeout interval in milliseconds; 0 means none.</param>
        }, 
        
        setResponseType: function(type) {
            /// <summary>Sets the desired type for the response. At time of writing, this is only
            /// supported in very recent versions of WebKit (10.0.612.1 dev and later).
            /// 
            /// If this is used, the response may only be accessed via {@link #getResponse}.</summary>
            /// <param name="type" type="goog.net.XhrIo.ResponseType">The desired type for the response.</param>
        }, 
        
        getResponseType: function() {
            /// <summary>Gets the desired type for the response.</summary>
            /// <returns type="goog.net.XhrIo.ResponseType">The desired type for the response.</returns>
        }, 
        
        setWithCredentials: function(withCredentials) {
            /// <summary>Sets whether a &quot;credentialed&quot; request that is aware of cookie and
            /// authentication information should be made. This option is only supported by
            /// browsers that support HTTP Access Control. As of this writing, this option
            /// is not supported in IE.</summary>
            /// <param name="withCredentials" type="boolean">Whether this should be a &quot;credentialed&quot;
            ///     request.</param>
        }, 
        
        getWithCredentials: function() {
            /// <summary>Gets whether a &quot;credentialed&quot; request is to be sent.</summary>
            /// <returns type="boolean">The desired type for the response.</returns>
        }, 
        
        send: function(url, opt_method, opt_content, opt_headers) {
            /// <summary>Instance send that actually uses XMLHttpRequest to make a server call.</summary>
            /// <param name="url" type="string|goog.Uri">Uri to make request to.</param>
            /// <param name="opt_method" type="string=">Send method, default: GET.</param>
            /// <param name="opt_content" type="string|FormData|GearsBlob=">Post data. This can be a Gears blob if the underlying HTTP request object
            ///     is a Gears HTTP request.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
        }, 
        
        createXhr: function() {
            /// <summary>Creates a new XHR object.</summary>
            /// <returns type="XMLHttpRequest|GearsHttpRequest">The newly created XHR object.</returns>
        }, 
        
        abort: function(opt_failureCode) {
            /// <summary>Abort the current XMLHttpRequest</summary>
            /// <param name="opt_failureCode" type="goog.net.ErrorCode=">Optional error code to use -
            ///     defaults to ABORT.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary>Nullifies all callbacks to reduce risks of leaks.</summary>
        }, 
        
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether there is an active request.</returns>
        }, 
        
        isComplete: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the request has completed.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the request completed with a success.</returns>
        }, 
        
        getReadyState: function() {
            /// <summary>Get the readystate from the Xhr object
            /// Will only return correct result when called from the context of a callback</summary>
            /// <returns type="goog.net.XmlHttp.ReadyState">goog.net.XmlHttp.ReadyState.*.</returns>
        }, 
        
        getStatus: function() {
            /// <summary>Get the status from the Xhr object
            /// Will only return correct result when called from the context of a callback</summary>
            /// <returns type="number">Http status.</returns>
        }, 
        
        getStatusText: function() {
            /// <summary>Get the status text from the Xhr object
            /// Will only return correct result when called from the context of a callback</summary>
            /// <returns type="string">Status text.</returns>
        }, 
        
        getLastUri: function() {
            /// <summary>Get the last Uri that was requested</summary>
            /// <returns type="string">Last Uri.</returns>
        }, 
        
        getResponseText: function() {
            /// <summary>Get the response text from the Xhr object
            /// Will only return correct result when called from the context of a callback.</summary>
            /// <returns type="string">Result from the server, or &apos;&apos; if no result available.</returns>
        }, 
        
        getResponseXml: function() {
            /// <summary>Get the response XML from the Xhr object
            /// Will only return correct result when called from the context of a callback.</summary>
            /// <returns type="Document">The DOM Document representing the XML file, or null
            /// if no result available.</returns>
        }, 
        
        getResponseJson: function(opt_xssiPrefix) {
            /// <summary>Get the response and evaluates it as JSON from the Xhr object
            /// Will only return correct result when called from the context of a callback</summary>
            /// <param name="opt_xssiPrefix" type="string=">Optional XSSI prefix string to use for
            ///     stripping of the response before parsing. This needs to be set only if
            ///     your backend server prepends the same prefix string to the JSON response.</param>
            /// <returns type="Object|undefined">JavaScript object.</returns>
        }, 
        
        getResponse: function() {
            /// <summary>Get the response as the type specificed by {@link #setResponseType}. At time
            /// of writing, this is only directly supported in very recent versions of WebKit
            /// (10.0.612.1 dev and later). If the field is not supported directly, we will
            /// try to emulate it.
            /// 
            /// Emulating the response means following the rules laid out at
            /// http://www.w3.org/TR/XMLHttpRequest/#the-response-attribute
            /// 
            /// On browsers with no support for this (Chrome < 10, Firefox < 4, etc), only
            /// response types of DEFAULT or TEXT may be used, and the response returned will
            /// be the text response.
            /// 
            /// On browsers with Mozilla&apos;s draft support for array buffers (Firefox 4, 5),
            /// only response types of DEFAULT, TEXT, and ARRAY_BUFFER may be used, and the
            /// response returned will be either the text response or the Mozilla
            /// implementation of the array buffer response.
            /// 
            /// On browsers will full support, any valid response type supported by the
            /// browser may be used, and the response provided by the browser will be
            /// returned.</summary>
            /// <returns type="*">The response.</returns>
        }, 
        
        getResponseHeader: function(key) {
            /// <summary>Get the value of the response-header with the given name from the Xhr object
            /// Will only return correct result when called from the context of a callback
            /// and the request has completed</summary>
            /// <param name="key" type="string">The name of the response-header to retrieve.</param>
            /// <returns type="string|undefined">The value of the response-header named key.</returns>
        }, 
        
        getAllResponseHeaders: function() {
            /// <summary>Gets the text of all the headers in the response.
            /// Will only return correct result when called from the context of a callback
            /// and the request has completed.</summary>
            /// <returns type="string">The value of the response headers or empty string.</returns>
        }, 
        
        getLastErrorCode: function() {
            /// <summary>Get the last error message</summary>
            /// <returns type="goog.net.ErrorCode">Last error code.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>Get the last error message</summary>
            /// <returns type="string">Last error message.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.XhrIo";
})(this);
