
/* vsdoc for goog.net.XhrManager */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.XhrManager = function(opt_maxRetries, opt_headers, opt_minCount, opt_maxCount, opt_timeoutInterval){
        /// <summary></summary>
        /// <param name="opt_maxRetries" type="number=">Max. number of retries (Default: 1).</param>
        /// <param name="opt_headers" type="goog.structs.Map=">Map of default headers to add to every
        ///     request.</param>
        /// <param name="opt_minCount" type="number=">Min. number of objects (Default: 1).</param>
        /// <param name="opt_maxCount" type="number=">Max. number of objects (Default: 10).</param>
        /// <param name="opt_timeoutInterval" type="number=">Timeout (in ms) before aborting an
        ///     attempt (Default: 0ms).</param>
        /// <returns type="goog.net.XhrManager"/>
    };

    var $x = window.goog.net.XhrManager;
    $x.prototype = {
                
        setTimeoutInterval: function(ms) {
            /// <summary>Sets the number of milliseconds after which an incomplete request will be
            /// aborted. Zero means no timeout is set.</summary>
            /// <param name="ms" type="number">Timeout interval in milliseconds; 0 means none.</param>
        }, 
        
        getOutstandingCount: function() {
            /// <summary>Returns the number of requests either in flight, or waiting to be sent.
            /// The count will include the current request if used within a COMPLETE event
            /// handler or callback.</summary>
            /// <returns type="number">The number of requests in flight or pending send.</returns>
        }, 
        
        getOutstandingRequestIds: function() {
            /// <summary>Returns an array of request ids that are either in flight, or waiting to
            /// be sent. The id of the current request will be included if used within a
            /// COMPLETE event handler or callback.</summary>
            /// <returns type="!Array.string">Request ids in flight or pending send.</returns>
        }, 
        
        send: function(id, url, opt_method, opt_content, opt_headers, opt_priority, opt_callback, opt_maxRetries, opt_responseType) {
            /// <summary>Registers the given request to be sent. Throws an error if a request
            /// already exists with the given ID.
            /// NOTE: It is not sent immediately. It is queued and will be sent when an
            /// XhrIo object becomes available, taking into account the request&apos;s
            /// priority.</summary>
            /// <param name="id" type="string">The id of the request.</param>
            /// <param name="url" type="string">Uri to make the request too.</param>
            /// <param name="opt_method" type="string=">Send method, default: GET.</param>
            /// <param name="opt_content" type="string=">Post data.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
            /// <param name="opt_priority" type="*=">The priority of the request. A smaller value means a
            ///     higher priority.</param>
            /// <param name="opt_callback" type="Function=">Callback function for when request is
            ///     complete. The only param is the event object from the COMPLETE event.</param>
            /// <param name="opt_maxRetries" type="number=">The maximum number of times the request
            ///     should be retried.</param>
            /// <param name="opt_responseType" type="goog.net.XhrIo.ResponseType=">The response type of
            ///     this request; defaults to goog.net.XhrIo.ResponseType.DEFAULT.</param>
            /// <returns type="goog.net.XhrManager.Request">The queued request object.</returns>
        }, 
        
        abort: function(id, opt_force) {
            /// <summary>Aborts the request associated with id.</summary>
            /// <param name="id" type="string">The id of the request to abort.</param>
            /// <param name="opt_force" type="boolean=">If true, remove the id now so it can be reused.
            ///     No events are fired and the callback is not called when forced.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.XhrManager";
})(this);
