
/* vsdoc for goog.net.XhrManager.Request */

(function (window) {
    window.goog.net.XhrManager = window.goog.net.XhrManager || {};

    window.goog.net.XhrManager.Request = function(url, xhrEventCallback, opt_method, opt_content, opt_headers, opt_callback, opt_maxRetries, opt_responseType){
        /// <summary></summary>
        /// <param name="url" type="string">Uri to make the request too.</param>
        /// <param name="xhrEventCallback" type="Function">Callback attached to the events of the
        ///     XhrIo object of the request.</param>
        /// <param name="opt_method" type="string=">Send method, default: GET.</param>
        /// <param name="opt_content" type="string=">Post data.</param>
        /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
        ///     request.</param>
        /// <param name="opt_callback" type="Function=">Callback function for when request is
        ///     complete. NOTE: Only 1 callback supported across all events.</param>
        /// <param name="opt_maxRetries" type="number=">The maximum number of times the request
        ///     should be retried (Default: 1).</param>
        /// <param name="opt_responseType" type="goog.net.XhrIo.ResponseType=">The response type of
        ///     this request; defaults to goog.net.XhrIo.ResponseType.DEFAULT.</param>
        /// <field name="xhrIo" type="goog.net.XhrIo">The XhrIo instance handling this request. Set in handleAvailableXhr.</field>
        /// <returns type="goog.net.XhrManager.Request"/>
    };

    var $x = window.goog.net.XhrManager.Request;
    $x.prototype = {
                
        getUrl: function() {
            /// <summary>Gets the uri.</summary>
            /// <returns type="string">The uri to make the request to.</returns>
        }, 
        
        getMethod: function() {
            /// <summary>Gets the send method.</summary>
            /// <returns type="string">The send method.</returns>
        }, 
        
        getContent: function() {
            /// <summary>Gets the post data.</summary>
            /// <returns type="string|undefined">The post data.</returns>
        }, 
        
        getHeaders: function() {
            /// <summary>Gets the map of headers.</summary>
            /// <returns type="Object|goog.structs.Map">The map of headers.</returns>
        }, 
        
        getMaxRetries: function() {
            /// <summary>Gets the maximum number of times the request should be retried.</summary>
            /// <returns type="number">The maximum number of times the request should be retried.</returns>
        }, 
        
        getAttemptCount: function() {
            /// <summary>Gets the number of attempts so far.</summary>
            /// <returns type="number">The number of attempts so far.</returns>
        }, 
        
        increaseAttemptCount: function() {
            /// <summary>Increases the number of attempts so far.</summary>
        }, 
        
        hasReachedMaxRetries: function() {
            /// <summary>Returns whether the request has reached the maximum number of retries.</summary>
            /// <returns type="boolean">Whether the request has reached the maximum number of
            ///     retries.</returns>
        }, 
        
        setCompleted: function(complete) {
            /// <summary>Sets the completed status.</summary>
            /// <param name="complete" type="boolean">The completed status.</param>
        }, 
        
        getCompleted: function() {
            /// <summary>Gets the completed status.</summary>
            /// <returns type="boolean">The completed status.</returns>
        }, 
        
        setAborted: function(aborted) {
            /// <summary>Sets the aborted status.</summary>
            /// <param name="aborted" type="boolean">True if the request was aborted, otherwise False.</param>
        }, 
        
        getAborted: function() {
            /// <summary>Gets the aborted status.</summary>
            /// <returns type="boolean">True if request was aborted, otherwise False.</returns>
        }, 
        
        getXhrEventCallback: function() {
            /// <summary>Gets the callback attached to the events of the XhrIo object.</summary>
            /// <returns type="Function|undefined">The callback attached to the events of the
            ///     XhrIo object.</returns>
        }, 
        
        getCompleteCallback: function() {
            /// <summary>Gets the callback for when the request is complete.</summary>
            /// <returns type="Function|undefined">The callback for when the request is complete.</returns>
        }, 
        
        getResponseType: function() {
            /// <summary>Gets the response type that will be set on this request&apos;s XhrIo when it&apos;s
            /// available.</summary>
            /// <returns type="!goog.net.XhrIo.ResponseType">The response type to be set
            ///     when an XhrIo becomes available to this request.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.XhrManager.Request";
})(this);
