
/* vsdoc for goog.net.jsloader */

(function (window) {
    window.goog.net = window.goog.net || {};

    window.goog.net.jsloader = {
        /// <summary></summary>
        /// <field name="DEFAULT_TIMEOUT" type="number">The default length of time, in milliseconds, we are prepared to wait for a
        /// load request to complete.</field>
        /// <field name="ErrorCode" type="">Possible error codes for jsloader.</field>
        /// <returns type="goog.net.jsloader"/>
                
        loadMany: function(uris, opt_options) {
            /// <summary>Loads and evaluates the JavaScript files at the specified URIs, guaranteeing
            /// the order of script loads.
            /// 
            /// Because we have to load the scripts in serial (load script 1, exec script 1,
            /// load script 2, exec script 2, and so on), this will be slower than doing
            /// the network fetches in parallel.
            /// 
            /// If you need to load a large number of scripts but dependency order doesn&apos;t
            /// matter, you should just call goog.net.jsloader.load N times.
            /// 
            /// If you need to load a large number of scripts on the same domain,
            /// you may want to use goog.module.ModuleLoader.</summary>
            /// <param name="uris" type="Array.string">The URIs to load.</param>
            /// <param name="opt_options" type="goog.net.jsloader.Options=">Optional parameters. See
            ///     goog.net.jsloader.options documentation for details.</param>
        }, 
        
        load: function(uri, opt_options) {
            /// <summary>Loads and evaluates a JavaScript file.
            /// When the script loads, a user callback is called.
            /// It is the client&apos;s responsibility to verify that the script ran successfully.</summary>
            /// <param name="uri" type="string">The URI of the JavaScript.</param>
            /// <param name="opt_options" type="goog.net.jsloader.Options=">Optional parameters. See
            ///     goog.net.jsloader.Options documentation for details.</param>
            /// <returns type="!goog.async.Deferred">The deferred result, that may be used to add
            ///     callbacks and/or cancel the transmission.
            ///     The error callback will be called with a single goog.net.jsloader.Error
            ///     parameter.</returns>
        }, 
        
        loadAndVerify: function(uri, verificationObjName, options) {
            /// <summary>Loads a JavaScript file and verifies it was evaluated successfully, using a
            /// verification object.
            /// The verification object is set by the loaded JavaScript at the end of the
            /// script.
            /// We verify this object was set and return its value in the success callback.
            /// If the object is not defined we trigger an error callback.</summary>
            /// <param name="uri" type="string">The URI of the JavaScript.</param>
            /// <param name="verificationObjName" type="string">The name of the verification object that
            ///     the loaded script should set.</param>
            /// <param name="options" type="goog.net.jsloader.Options">Optional parameters. See
            ///     goog.net.jsloader.Options documentation for details.</param>
            /// <returns type="!goog.async.Deferred">The deferred result, that may be used to add
            ///     callbacks and/or cancel the transmission.
            ///     The success callback will be called with a single parameter containing
            ///     the value of the verification object.
            ///     The error callback will be called with a single goog.net.jsloader.Error
            ///     parameter.</returns>
        }
        
    };

    var $x = window.goog.net.jsloader;
    $x.__namespace = "true";
    $x.__typeName = "goog.net.jsloader";
})(this);
