
/* vsdoc for goog.net.xpc.CrossPageChannel */

(function (window) {
    window.goog.net.xpc = window.goog.net.xpc || {};

    window.goog.net.xpc.CrossPageChannel = function(cfg, opt_domHelper){
        /// <summary></summary>
        /// <param name="cfg" type="Object">Channel configuration object.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The optional dom helper to
        ///     use for looking up elements in the dom.</param>
        /// <field name="name" type="string">The name of the channel.</field>
        /// <returns type="goog.net.xpc.CrossPageChannel"/>
    };

    var $x = window.goog.net.xpc.CrossPageChannel;
    $x.prototype = {
                
        isConnected: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the channel is connected.</returns>
        }, 
        
        getConfig: function() {
            /// <summary>Returns the configuration object for this channel.
            /// Package private. Do not call from outside goog.net.xpc.</summary>
            /// <returns type="Object">The configuration object for this channel.</returns>
        }, 
        
        getIframeElement: function() {
            /// <summary>Returns a reference to the iframe-element.
            /// Package private. Do not call from outside goog.net.xpc.</summary>
            /// <returns type="Object">A reference to the iframe-element.</returns>
        }, 
        
        setPeerWindowObject: function(peerWindowObject) {
            /// <summary>Sets the window object the foreign document resides in.</summary>
            /// <param name="peerWindowObject" type="Object">The window object of the peer.</param>
        }, 
        
        getPeerWindowObject: function() {
            /// <summary>Returns the window object the foreign document resides in.
            /// Package private. Do not call from outside goog.net.xpc.</summary>
            /// <returns type="Object">The window object of the peer.</returns>
        }, 
        
        isPeerAvailable: function() {
            /// <summary>Determines whether the peer window is available (e.g. not closed).
            /// Package private. Do not call from outside goog.net.xpc.</summary>
            /// <returns type="boolean">Whether the peer window is available.</returns>
        }, 
        
        getTransportType: function() {
            /// <summary>Returns the transport type in use for this channel.</summary>
            /// <returns type="number">Transport-type identifier.</returns>
        }, 
        
        getTransportName: function() {
            /// <summary>Returns the tranport name in use for this channel.</summary>
            /// <returns type="string">The transport name.</returns>
        }, 
        
        getPeerConfiguration: function() {
            /// <summary></summary>
            /// <returns type="Object">Configuration-object to be used by the peer to
            ///     initialize the channel.</returns>
        }, 
        
        createPeerIframe: function(parentElm, opt_configureIframeCb, opt_addCfgParam) {
            /// <summary>Creates the iframe containing the peer page in a specified parent element.
            /// This method does not connect the channel, connect() still has to be called
            /// separately.</summary>
            /// <param name="parentElm" type="!Element">The container element the iframe is appended to.</param>
            /// <param name="opt_configureIframeCb" type="Function=">If present, this function gets
            ///     called with the iframe element as parameter to allow setting properties
            ///     on it before it gets added to the DOM. If absent, the iframe&apos;s width and
            ///     height are set to &apos;100%&apos;.</param>
            /// <param name="opt_addCfgParam" type="boolean=">Whether to add the peer configuration as
            ///     URL parameter (default: true).</param>
            /// <returns type="!HTMLIFrameElement">The iframe element.</returns>
        }, 
        
        getPeerUri: function(opt_addCfgParam) {
            /// <summary>Returns the peer URI, with an optional URL parameter for configuring the peer
            /// window.</summary>
            /// <param name="opt_addCfgParam" type="boolean=">Whether to add the peer configuration as
            ///     URL parameter (default: true).</param>
            /// <returns type="!goog.Uri">The peer URI.</returns>
        }, 
        
        connect: function(opt_connectCb) {
            /// <summary>Initiates connecting the channel. When this method is called, all the
            /// information needed to connect the channel has to be available.</summary>
            /// <param name="opt_connectCb" type="Function=">The function to be called when the
            /// channel has been connected and is ready to be used.</param>
        }, 
        
        close: function() {
            /// <summary>Closes the channel.</summary>
        }, 
        
        notifyConnected: function(opt_delay) {
            /// <summary>Package-private.
            /// Called by the transport when the channel is connected.</summary>
            /// <param name="opt_delay" type="number=">Delay this number of milliseconds before calling
            ///     the connection callback. Usage is discouraged, but can be used to paper
            ///     over timing vulnerabilities when there is no alternative.</param>
        }, 
        
        notifyTransportError: function() {
            /// <summary>Called by the transport in case of an unrecoverable failure.
            /// Package private. Do not call from outside goog.net.xpc.</summary>
        }, 
        
        send: function(serviceName, payload) {
            /// <summary></summary>
            /// <param name="serviceName" type=""></param>
            /// <param name="payload" type=""></param>
        }, 
        
        xpcDeliver: function(serviceName, payload, opt_origin) {
            /// <summary>Delivers messages to the appropriate service-handler. Named xpcDeliver to
            /// avoid name conflict with {@code deliver} function in superclass
            /// goog.messaging.AbstractChannel.
            /// 
            /// Package private. Do not call from outside goog.net.xpc.</summary>
            /// <param name="serviceName" type="string">The name of the port.</param>
            /// <param name="payload" type="string">The payload.</param>
            /// <param name="opt_origin" type="string=">An optional origin for the message, where the
            ///     underlying transport makes that available.  If this is specified, and
            ///     the PEER_HOSTNAME parameter was provided, they must match or the message
            ///     will be rejected.</param>
        }, 
        
        getRole: function() {
            /// <summary>Returns the role of this channel (either inner or outer).</summary>
            /// <returns type="number">The role of this channel.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.net.xpc.CrossPageChannel";
})(this);
