
/* vsdoc for goog.object */

(function (window) {
    window.goog = window.goog || {};

    window.goog.object = {
        /// <summary></summary>
        /// <returns type="goog.object"/>
                
        forEach: function(obj, f, opt_obj) {
            /// <summary>Calls a function for each element in an object/map/hash.</summary>
            /// <param name="obj" type="Object">The object over which to iterate.</param>
            /// <param name="f" type="Function">The function to call for every element. This function
            ///     takes 3 arguments (the element, the index and the object)
            ///     and the return value is irrelevant.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object within f.</param>
        }, 
        
        filter: function(obj, f, opt_obj) {
            /// <summary>Calls a function for each element in an object/map/hash. If that call returns
            /// true, adds the element to a new object.</summary>
            /// <param name="obj" type="Object">The object over which to iterate.</param>
            /// <param name="f" type="Function">The function to call for every element. This
            ///     function takes 3 arguments (the element, the index and the object)
            ///     and should return a boolean. If the return value is true the
            ///     element is added to the result object. If it is false the
            ///     element is not included.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object within f.</param>
            /// <returns type="!Object">a new object in which only elements that passed the test
            ///     are present.</returns>
        }, 
        
        map: function(obj, f, opt_obj) {
            /// <summary>For every element in an object/map/hash calls a function and inserts the
            /// result into a new object.</summary>
            /// <param name="obj" type="Object">The object over which to iterate.</param>
            /// <param name="f" type="Function">The function to call for every element. This function
            ///     takes 3 arguments (the element, the index and the object)
            ///     and should return something. The result will be inserted
            ///     into a new object.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object within f.</param>
            /// <returns type="!Object">a new object with the results from f.</returns>
        }, 
        
        some: function(obj, f, opt_obj) {
            /// <summary>Calls a function for each element in an object/map/hash. If any
            /// call returns true, returns true (without checking the rest). If
            /// all calls return false, returns false.</summary>
            /// <param name="obj" type="Object">The object to check.</param>
            /// <param name="f" type="Function">The function to call for every element. This function
            ///     takes 3 arguments (the element, the index and the object) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object within f.</param>
            /// <returns type="boolean">true if any element passes the test.</returns>
        }, 
        
        every: function(obj, f, opt_obj) {
            /// <summary>Calls a function for each element in an object/map/hash. If
            /// all calls return true, returns true. If any call returns false, returns
            /// false at this point and does not continue to check the remaining elements.</summary>
            /// <param name="obj" type="Object">The object to check.</param>
            /// <param name="f" type="Function">The function to call for every element. This function
            ///     takes 3 arguments (the element, the index and the object) and should
            ///     return a boolean.</param>
            /// <param name="opt_obj" type="Object=">This is used as the &apos;this&apos; object within f.</param>
            /// <returns type="boolean">false if any element fails the test.</returns>
        }, 
        
        getCount: function(obj) {
            /// <summary>Returns the number of key-value pairs in the object map.</summary>
            /// <param name="obj" type="Object">The object for which to get the number of key-value
            ///     pairs.</param>
            /// <returns type="number">The number of key-value pairs in the object map.</returns>
        }, 
        
        getAnyKey: function(obj) {
            /// <summary>Returns one key from the object map, if any exists.
            /// For map literals the returned key will be the first one in most of the
            /// browsers (a know exception is Konqueror).</summary>
            /// <param name="obj" type="Object">The object to pick a key from.</param>
            /// <returns type="string|undefined">The key or undefined if the object is empty.</returns>
        }, 
        
        getAnyValue: function(obj) {
            /// <summary>Returns one value from the object map, if any exists.
            /// For map literals the returned value will be the first one in most of the
            /// browsers (a know exception is Konqueror).</summary>
            /// <param name="obj" type="Object">The object to pick a value from.</param>
            /// <returns type="*">The value or undefined if the object is empty.</returns>
        }, 
        
        contains: function(obj, val) {
            /// <summary>Whether the object/hash/map contains the given object as a value.
            /// An alias for goog.object.containsValue(obj, val).</summary>
            /// <param name="obj" type="Object">The object in which to look for val.</param>
            /// <param name="val" type="*">The object for which to check.</param>
            /// <returns type="boolean">true if val is present.</returns>
        }, 
        
        getValues: function(obj) {
            /// <summary>Returns the values of the object/map/hash.</summary>
            /// <param name="obj" type="Object">The object from which to get the values.</param>
            /// <returns type="!Array">The values in the object/map/hash.</returns>
        }, 
        
        getKeys: function(obj) {
            /// <summary>Returns the keys of the object/map/hash.</summary>
            /// <param name="obj" type="Object">The object from which to get the keys.</param>
            /// <returns type="!Array.string">Array of property keys.</returns>
        }, 
        
        getValueByKeys: function(obj, var_args) {
            /// <summary>Get a value from an object multiple levels deep.  This is useful for
            /// pulling values from deeply nested objects, such as JSON responses.
            /// Example usage: getValueByKeys(jsonObj, &apos;foo&apos;, &apos;entries&apos;, 3)</summary>
            /// <param name="obj" type="!Object">An object to get the value from.  Can be array-like.</param>
            /// <param name="var_args" type="...(string|number|!Array.number|string)">A number of keys
            ///     (as strings, or nubmers, for array-like objects).  Can also be
            ///     specified as a single array of keys.</param>
            /// <returns type="*">The resulting value.  If, at any point, the value for a key
            ///     is undefined, returns undefined.</returns>
        }, 
        
        containsKey: function(obj, key) {
            /// <summary>Whether the object/map/hash contains the given key.</summary>
            /// <param name="obj" type="Object">The object in which to look for key.</param>
            /// <param name="key" type="*">The key for which to check.</param>
            /// <returns type="boolean">true If the map contains the key.</returns>
        }, 
        
        containsValue: function(obj, val) {
            /// <summary>Whether the object/map/hash contains the given value. This is O(n).</summary>
            /// <param name="obj" type="Object">The object in which to look for val.</param>
            /// <param name="val" type="*">The value for which to check.</param>
            /// <returns type="boolean">true If the map contains the value.</returns>
        }, 
        
        findKey: function(obj, f, opt_this) {
            /// <summary>Searches an object for an element that satisfies the given condition and
            /// returns its key.</summary>
            /// <param name="obj" type="Object">The object to search in.</param>
            /// <param name="f" type="function(*|string|Object): boolean">The function to call for
            ///     every element. Takes 3 arguments (the value, the key and the object) and
            ///     should return a boolean.</param>
            /// <param name="opt_this" type="Object=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="string|undefined">The key of an element for which the function
            ///     returns true or undefined if no such element is found.</returns>
        }, 
        
        findValue: function(obj, f, opt_this) {
            /// <summary>Searches an object for an element that satisfies the given condition and
            /// returns its value.</summary>
            /// <param name="obj" type="Object">The object to search in.</param>
            /// <param name="f" type="function(*|string|Object): boolean">The function to call for
            ///     every element. Takes 3 arguments (the value, the key and the object) and
            ///     should return a boolean.</param>
            /// <param name="opt_this" type="Object=">An optional &quot;this&quot; context for the function.</param>
            /// <returns type="*">The value of an element for which the function returns true or
            ///     undefined if no such element is found.</returns>
        }, 
        
        isEmpty: function(obj) {
            /// <summary>Whether the object/map/hash is empty.</summary>
            /// <param name="obj" type="Object">The object to test.</param>
            /// <returns type="boolean">true if obj is empty.</returns>
        }, 
        
        clear: function(obj) {
            /// <summary>Removes all key value pairs from the object/map/hash.</summary>
            /// <param name="obj" type="Object">The object to clear.</param>
        }, 
        
        remove: function(obj, key) {
            /// <summary>Removes a key-value pair based on the key.</summary>
            /// <param name="obj" type="Object">The object from which to remove the key.</param>
            /// <param name="key" type="*">The key to remove.</param>
            /// <returns type="boolean">Whether an element was removed.</returns>
        }, 
        
        add: function(obj, key, val) {
            /// <summary>Adds a key-value pair to the object. Throws an exception if the key is
            /// already in use. Use set if you want to change an existing pair.</summary>
            /// <param name="obj" type="Object">The object to which to add the key-value pair.</param>
            /// <param name="key" type="string">The key to add.</param>
            /// <param name="val" type="*">The value to add.</param>
        }, 
        
        get: function(obj, key, opt_val) {
            /// <summary>Returns the value for the given key.</summary>
            /// <param name="obj" type="Object">The object from which to get the value.</param>
            /// <param name="key" type="string">The key for which to get the value.</param>
            /// <param name="opt_val" type="*=">The value to return if no item is found for the given
            ///     key (default is undefined).</param>
            /// <returns type="*">The value for the given key.</returns>
        }, 
        
        set: function(obj, key, value) {
            /// <summary>Adds a key-value pair to the object/map/hash.</summary>
            /// <param name="obj" type="Object">The object to which to add the key-value pair.</param>
            /// <param name="key" type="string">The key to add.</param>
            /// <param name="value" type="*">The value to add.</param>
        }, 
        
        setIfUndefined: function(obj, key, value) {
            /// <summary>Adds a key-value pair to the object/map/hash if it doesn&apos;t exist yet.</summary>
            /// <param name="obj" type="Object">The object to which to add the key-value pair.</param>
            /// <param name="key" type="string">The key to add.</param>
            /// <param name="value" type="*">The value to add if the key wasn&apos;t present.</param>
            /// <returns type="*">The value of the entry at the end of the function.</returns>
        }, 
        
        clone: function(obj) {
            /// <summary>Does a flat clone of the object.</summary>
            /// <param name="obj" type="Object">Object to clone.</param>
            /// <returns type="!Object">Clone of the input object.</returns>
        }, 
        
        unsafeClone: function(obj) {
            /// <summary>Clones a value. The input may be an Object, Array, or basic type. Objects and
            /// arrays will be cloned recursively.
            /// 
            /// WARNINGS:
            /// &lt;code&gt;goog.object.unsafeClone&lt;/code&gt; does not detect reference loops. Objects
            /// that refer to themselves will cause infinite recursion.
            /// 
            /// &lt;code&gt;goog.object.unsafeClone&lt;/code&gt; is unaware of unique identifiers, and
            /// copies UIDs created by &lt;code&gt;getUid&lt;/code&gt; into cloned results.</summary>
            /// <param name="obj" type="*">The value to clone.</param>
            /// <returns type="*">A clone of the input value.</returns>
        }, 
        
        transpose: function(obj) {
            /// <summary>Returns a new object in which all the keys and values are interchanged
            /// (keys become values and values become keys). If multiple keys map to the
            /// same value, the chosen transposed value is implementation-dependent.</summary>
            /// <param name="obj" type="Object">The object to transpose.</param>
            /// <returns type="!Object">The transposed object.</returns>
        }, 
        
        extend: function(target, var_args) {
            /// <summary>Extends an object with another object.
            /// This operates &apos;in-place&apos;; it does not create a new Object.
            /// 
            /// Example:
            /// var o = {};
            /// goog.object.extend(o, {a: 0, b: 1});
            /// o; // {a: 0, b: 1}
            /// goog.object.extend(o, {c: 2});
            /// o; // {a: 0, b: 1, c: 2}</summary>
            /// <param name="target" type="Object">The object to modify.</param>
            /// <param name="var_args" type="...Object">The objects from which values will be copied.</param>
        }, 
        
        create: function(var_args) {
            /// <summary>Creates a new object built from the key-value pairs provided as arguments.</summary>
            /// <param name="var_args" type="...*">If only one argument is provided and it is an array
            ///     then this is used as the arguments,  otherwise even arguments are used as
            ///     the property names and odd arguments are used as the property values.</param>
            /// <returns type="!Object">The new object.</returns>
        }, 
        
        createSet: function(var_args) {
            /// <summary>Creates a new object where the property names come from the arguments but
            /// the value is always set to true</summary>
            /// <param name="var_args" type="...*">If only one argument is provided and it is an array
            ///     then this is used as the arguments,  otherwise the arguments are used
            ///     as the property names.</param>
            /// <returns type="!Object">The new object.</returns>
        }, 
        
        createImmutableView: function(obj) {
            /// <summary>Creates an immutable view of the underlying object, if the browser
            /// supports immutable objects.
            /// 
            /// In default mode, writes to this view will fail silently. In strict mode,
            /// they will throw an error.</summary>
            /// <param name="obj" type="!Object">An object.</param>
            /// <returns type="!Object">An immutable view of that object, or the original object
            ///     if this browser does not support immutables.</returns>
        }, 
        
        isImmutableView: function(obj) {
            /// <summary></summary>
            /// <param name="obj" type="!Object">An object.</param>
            /// <returns type="boolean">Whether this is an immutable view of the object.</returns>
        }
        
    };

    var $x = window.goog.object;
    $x.__namespace = "true";
    $x.__typeName = "goog.object";
})(this);
