
/* vsdoc for goog.positioning */

(function (window) {
    window.goog = window.goog || {};

    window.goog.positioning = {
        /// <summary></summary>
        /// <field name="clientPositionTest" type=""></field>
        /// <field name="Corner" type="">Enum for representing an element corner for positioning the popup.
        /// 
        /// The START constants map to LEFT if element directionality is left
        /// to right and RIGHT if the directionality is right to left.
        /// Likewise END maps to RIGHT or LEFT depending on the directionality.</field>
        /// <field name="CornerBit" type="">Enum for bits in the {@see goog.positioning.Corner) bitmap.</field>
        /// <field name="Overflow" type="">Enum for representing position handling in cases where the element would be
        /// positioned outside the viewport.</field>
        /// <field name="OverflowStatus" type="">Enum for representing the outcome of a positioning call.</field>
        /// <returns type="goog.positioning"/>
                
        positionAtAnchor: function(anchorElement, anchorElementCorner, movableElement, movableElementCorner, opt_offset, opt_margin, opt_overflow, opt_preferredSize, opt_viewport) {
            /// <summary>Positions a movable element relative to an anchor element. The caller
            /// specifies the corners that should touch. This functions then moves the
            /// movable element accordingly.</summary>
            /// <param name="anchorElement" type="Element">The element that is the anchor for where
            ///    the movable element should position itself.</param>
            /// <param name="anchorElementCorner" type="goog.positioning.Corner">The corner of the
            ///     anchorElement for positioning the movable element.</param>
            /// <param name="movableElement" type="Element">The element to move.</param>
            /// <param name="movableElementCorner" type="goog.positioning.Corner">The corner of the
            ///     movableElement that that should be positioned adjacent to the anchor
            ///     element.</param>
            /// <param name="opt_offset" type="goog.math.Coordinate=">An offset specified in pixels.
            ///    After the normal positioning algorithm is applied, the offset is then
            ///    applied. Positive coordinates move the popup closer to the center of the
            ///    anchor element. Negative coordinates move the popup away from the center
            ///    of the anchor element.</param>
            /// <param name="opt_margin" type="goog.math.Box=">A margin specified in pixels.
            ///    After the normal positioning algorithm is applied and any offset, the
            ///    margin is then applied. Positive coordinates move the popup away from the
            ///    spot it was positioned towards its center. Negative coordinates move it
            ///    towards the spot it was positioned away from its center.</param>
            /// <param name="opt_overflow" type="?number=">Overflow handling mode. Defaults to IGNORE if
            ///     not specified. Bitmap, {@see goog.positioning.Overflow}.</param>
            /// <param name="opt_preferredSize" type="goog.math.Size=">The preferred size of the
            ///     movableElement.</param>
            /// <param name="opt_viewport" type="goog.math.Box=">Box object describing the dimensions of
            ///     the viewport. If not provided, a default one will be calculated by the
            ///     position of the anchorElement and its moveable parent element.</param>
            /// <returns type="goog.positioning.OverflowStatus">Status bitmap,
            ///     {@see goog.positioning.OverflowStatus}.</returns>
        }, 
        
        getOffsetParentPageOffset: function(movableElement) {
            /// <summary>Calculates the page offset of the given element&apos;s
            /// offsetParent. This value can be used to translate any x- and
            /// y-offset relative to the page to an offset relative to the
            /// offsetParent, which can then be used directly with as position
            /// coordinate for {@code positionWithCoordinate}.</summary>
            /// <param name="movableElement" type="!Element">The element to calculate.</param>
            /// <returns type="!goog.math.Coordinate">The page offset, may be (0, 0).</returns>
        }, 
        
        positionAtCoordinate: function(absolutePos, movableElement, movableElementCorner, opt_margin, opt_viewport, opt_overflow, opt_preferredSize) {
            /// <summary>Positions the specified corner of the movable element at the
            /// specified coordinate.</summary>
            /// <param name="absolutePos" type="goog.math.Coordinate">The coordinate to position the
            ///     element at.</param>
            /// <param name="movableElement" type="Element">The element to be positioned.</param>
            /// <param name="movableElementCorner" type="goog.positioning.Corner">The corner of the
            ///     movableElement that that should be positioned.</param>
            /// <param name="opt_margin" type="goog.math.Box=">A margin specified in pixels.
            ///    After the normal positioning algorithm is applied and any offset, the
            ///    margin is then applied. Positive coordinates move the popup away from the
            ///    spot it was positioned towards its center. Negative coordinates move it
            ///    towards the spot it was positioned away from its center.</param>
            /// <param name="opt_viewport" type="goog.math.Box=">Box object describing the dimensions of
            ///     the viewport. Required if opt_overflow is specified.</param>
            /// <param name="opt_overflow" type="?number=">Overflow handling mode. Defaults to IGNORE if
            ///     not specified, {@see goog.positioning.Overflow}.</param>
            /// <param name="opt_preferredSize" type="goog.math.Size=">The preferred size of the
            ///     movableElement. Defaults to the current size.</param>
            /// <returns type="goog.positioning.OverflowStatus">Status bitmap.</returns>
        }, 
        
        getEffectiveCorner: function(element, corner) {
            /// <summary>Returns an absolute corner (top/bottom left/right) given an absolute
            /// or relative (top/bottom start/end) corner and the direction of an element.
            /// Absolute corners remain unchanged.</summary>
            /// <param name="element" type="Element">DOM element to test for RTL direction.</param>
            /// <param name="corner" type="goog.positioning.Corner">The popup corner used for
            ///     positioning.</param>
            /// <returns type="goog.positioning.Corner">Effective corner.</returns>
        }, 
        
        flipCornerHorizontal: function(corner) {
            /// <summary>Returns the corner opposite the given one horizontally.</summary>
            /// <param name="corner" type="goog.positioning.Corner">The popup corner used to flip.</param>
            /// <returns type="goog.positioning.Corner">The opposite corner horizontally.</returns>
        }, 
        
        flipCornerVertical: function(corner) {
            /// <summary>Returns the corner opposite the given one vertically.</summary>
            /// <param name="corner" type="goog.positioning.Corner">The popup corner used to flip.</param>
            /// <returns type="goog.positioning.Corner">The opposite corner vertically.</returns>
        }, 
        
        flipCorner: function(corner) {
            /// <summary>Returns the corner opposite the given one horizontally and vertically.</summary>
            /// <param name="corner" type="goog.positioning.Corner">The popup corner used to flip.</param>
            /// <returns type="goog.positioning.Corner">The opposite corner horizontally and
            ///     vertically.</returns>
        }
        
    };

    var $x = window.goog.positioning;
    $x.__namespace = "true";
    $x.__typeName = "goog.positioning";
})(this);
