
/* vsdoc for goog.proto2.Message */

(function (window) {
    window.goog.proto2 = window.goog.proto2 || {};

    window.goog.proto2.Message = function(){
        /// <summary></summary>
        /// <field name="FieldType" type="">An enumeration defining the possible field types.
        /// Should be a mirror of that defined in descriptor.h.
        /// 
        /// TODO(user): Remove this alias.  The code generator generates code that
        /// references this enum, so it needs to exist until the code generator is
        /// changed.  The enum was moved to from Message to FieldDescriptor to avoid a
        /// dependency cycle.
        /// 
        /// Use goog.proto2.FieldDescriptor.FieldType instead.</field>
        /// <returns type="goog.proto2.Message"/>
    };

    var $x = window.goog.proto2.Message;
    $x.prototype = {
                
        initializeForLazyDeserializer: function(deserializer, data) {
            /// <summary>Initializes the message with a lazy deserializer and its associated data.
            /// This method should be called by internal methods ONLY.</summary>
            /// <param name="deserializer" type="goog.proto2.LazyDeserializer">The lazy deserializer to
            ///   use to decode the data on the fly.</param>
            /// <param name="data" type="*">The data to decode/deserialize.</param>
        }, 
        
        setUnknown: function(tag, value) {
            /// <summary>Sets the value of an unknown field, by tag.</summary>
            /// <param name="tag" type="number">The tag of an unknown field (must be >= 1).</param>
            /// <param name="value" type="*">The value for that unknown field.</param>
        }, 
        
        forEachUnknown: function(callback, opt_scope) {
            /// <summary>Iterates over all the unknown fields in the message.</summary>
            /// <param name="callback" type="function(number|*)">A callback method
            ///     which gets invoked for each unknown field.</param>
            /// <param name="opt_scope" type="Object=">The scope under which to execute the callback.
            ///     If not given, the current message will be used.</param>
        }, 
        
        getDescriptor: function() {
            /// <summary>Returns the descriptor which describes the current message.
            /// 
            /// This only works if we assume people never subclass protobufs.</summary>
            /// <returns type="!goog.proto2.Descriptor">The descriptor.</returns>
        }, 
        
        has: function(field) {
            /// <summary>Returns whether there is a value stored at the field specified by the
            /// given field descriptor.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to check
            ///     if there is a value.</param>
            /// <returns type="boolean">True if a value was found.</returns>
        }, 
        
        arrayOf: function(field) {
            /// <summary>Returns the array of values found for the given repeated field.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to
            ///     return the values.</param>
            /// <returns type="!Array">The values found.</returns>
        }, 
        
        countOf: function(field) {
            /// <summary>Returns the number of values stored in the given field.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to count
            ///     the number of values.</param>
            /// <returns type="number">The count of the values in the given field.</returns>
        }, 
        
        get: function(field, opt_index) {
            /// <summary>Returns the value stored at the field specified by the
            /// given field descriptor.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to get the
            ///     value.</param>
            /// <param name="opt_index" type="number=">If the field is repeated, the index to use when
            ///     looking up the value.</param>
            /// <returns type="*">The value found or null if none.</returns>
        }, 
        
        getOrDefault: function(field, opt_index) {
            /// <summary>Returns the value stored at the field specified by the
            /// given field descriptor or the default value if none exists.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to get the
            ///     value.</param>
            /// <param name="opt_index" type="number=">If the field is repeated, the index to use when
            ///     looking up the value.</param>
            /// <returns type="*">The value found or the default if none.</returns>
        }, 
        
        set: function(field, value) {
            /// <summary>Stores the given value to the field specified by the
            /// given field descriptor. Note that the field must not be repeated.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field for which to set
            ///     the value.</param>
            /// <param name="value" type="*">The new value for the field.</param>
        }, 
        
        add: function(field, value) {
            /// <summary>Adds the given value to the field specified by the
            /// given field descriptor. Note that the field must be repeated.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field in which to add the
            ///     the value.</param>
            /// <param name="value" type="*">The new value to add to the field.</param>
        }, 
        
        clear: function(field) {
            /// <summary>Clears the field specified.</summary>
            /// <param name="field" type="goog.proto2.FieldDescriptor">The field to clear.</param>
        }, 
        
        equals: function(other) {
            /// <summary>Compares this message with another one ignoring the unknown fields.</summary>
            /// <param name="other" type="*">The other message.</param>
            /// <returns type="boolean">Whether they are equal. Returns false if the {@code other}
            ///     argument is a different type of message or not a message.</returns>
        }, 
        
        copyFrom: function(message) {
            /// <summary>Recursively copies the known fields from the given message to this message.
            /// Removes the fields which are not present in the source message.</summary>
            /// <param name="message" type="!goog.proto2.Message">The source message.</param>
        }, 
        
        mergeFrom: function(message) {
            /// <summary>Merges the given message into this message.
            /// 
            /// Singular fields will be overwritten, except for embedded messages which will
            /// be merged. Repeated fields will be concatenated.</summary>
            /// <param name="message" type="!goog.proto2.Message">The source message.</param>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.proto2.Message">Recursive clone of the message only including
            ///     the known fields.</returns>
        }, 
        
        initDefaults: function(simpleFieldsToo) {
            /// <summary>Fills in the protocol buffer with default values. Any fields that are
            /// already set will not be overridden.</summary>
            /// <param name="simpleFieldsToo" type="boolean">If true, all fields will be initialized;
            ///     if false, only the nested messages and groups.</param>
        }, 
        
        has$Value: function(tag) {
            /// <summary>Returns the whether or not the field indicated by the given tag
            /// has a value.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the has{Field} methods.</summary>
            /// <param name="tag" type="number">The tag.</param>
            /// <returns type="boolean">Whether the message has a value for the field.</returns>
        }, 
        
        get$Value: function(tag, opt_index) {
            /// <summary>Gets the value at the field indicated by the given tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the get{Field} methods.</summary>
            /// <param name="tag" type="number">The field&apos;s tag index.</param>
            /// <param name="opt_index" type="number=">If the field is a repeated field, the index
            ///     at which to get the value.</param>
            /// <returns type="*">The value found or null for none.</returns>
        }, 
        
        get$ValueOrDefault: function(tag, opt_index) {
            /// <summary>Gets the value at the field indicated by the given tag or the default value
            /// if none.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the get{Field} methods.</summary>
            /// <param name="tag" type="number">The field&apos;s tag index.</param>
            /// <param name="opt_index" type="number=">If the field is a repeated field, the index
            ///     at which to get the value.</param>
            /// <returns type="*">The value found or the default value if none set.</returns>
        }, 
        
        array$Values: function(tag) {
            /// <summary>Gets the values at the field indicated by the given tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the {field}Array methods.</summary>
            /// <param name="tag" type="number">The field&apos;s tag index.</param>
            /// <returns type="!Array">The values found. If none, returns an empty array.</returns>
        }, 
        
        count$Values: function(tag) {
            /// <summary>Returns the number of values stored in the field by the given tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the {field}Count methods.</summary>
            /// <param name="tag" type="number">The tag.</param>
            /// <returns type="number">The number of values.</returns>
        }, 
        
        set$Value: function(tag, value) {
            /// <summary>Sets the value of the *non-repeating* field indicated by the given tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the set{Field} methods.</summary>
            /// <param name="tag" type="number">The field&apos;s tag index.</param>
            /// <param name="value" type="*">The field&apos;s value.</param>
        }, 
        
        add$Value: function(tag, value) {
            /// <summary>Adds the value to the *repeating* field indicated by the given tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the add{Field} methods.</summary>
            /// <param name="tag" type="number">The field&apos;s tag index.</param>
            /// <param name="value" type="*">The value to add.</param>
        }, 
        
        clear$Field: function(tag) {
            /// <summary>Clears the field specified by tag.
            /// 
            /// GENERATED CODE USE ONLY. Basis of the clear{Field} methods.</summary>
            /// <param name="tag" type="number">The tag of the field to clear.</param>
        }, 
        
        create$Descriptor: function(messageType, metadataObj) {
            /// <summary>Creates the metadata descriptor representing the definition of this message.
            /// 
            /// GENERATED CODE USE ONLY. Called when constructing message classes.</summary>
            /// <param name="messageType" type="function(new:goog.proto2.Message)">Constructor for the
            ///     message type to which this metadata applies.</param>
            /// <param name="metadataObj" type="Object">The object containing the metadata.</param>
            /// <returns type="!goog.proto2.Descriptor">The new descriptor.</returns>
        }, 
        
        set$Metadata: function(messageType, metadataObj) {
            /// <summary>Sets the metadata that represents the definition of this message.
            /// 
            /// GENERATED CODE USE ONLY. Called when constructing message classes.</summary>
            /// <param name="messageType" type="!Function">Constructor for the
            ///     message type to which this metadata applies.</param>
            /// <param name="metadataObj" type="Object">The object containing the metadata.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.proto2.Message";
})(this);
