
/* vsdoc for goog.pubsub.PubSub */

(function (window) {
    window.goog.pubsub = window.goog.pubsub || {};

    window.goog.pubsub.PubSub = function(){
        /// <summary></summary>
        /// <returns type="goog.pubsub.PubSub"/>
    };

    var $x = window.goog.pubsub.PubSub;
    $x.prototype = {
                
        subscribe: function(topic, fn, opt_context) {
            /// <summary>Subscribes a function to a topic.  The function is invoked as a method on
            /// the given {@code opt_context} object, or in the global scope if no context
            /// is specified.  Subscribing the same function to the same topic multiple
            /// times will result in multiple function invocations while publishing.
            /// Returns a subscription key that can be used to unsubscribe the function from
            /// the topic via {@link #unsubscribeByKey}.</summary>
            /// <param name="topic" type="string">Topic to subscribe to.</param>
            /// <param name="fn" type="Function">Function to be invoked when a message is published to
            ///     the given topic.</param>
            /// <param name="opt_context" type="Object=">Object in whose context the function is to be
            ///     called (the global scope if none).</param>
            /// <returns type="number">Subscription key.</returns>
        }, 
        
        subscribeOnce: function(topic, fn, opt_context) {
            /// <summary>Subscribes a single-use function to a topic.  The function is invoked as a
            /// method on the given {@code opt_context} object, or in the global scope if
            /// no context is specified, and is then unsubscribed.  Returns a subscription
            /// key that can be used to unsubscribe the function from the topic via
            /// {@link #unsubscribeByKey}.</summary>
            /// <param name="topic" type="string">Topic to subscribe to.</param>
            /// <param name="fn" type="Function">Function to be invoked once and then unsubscribed when
            ///     a message is published to the given topic.</param>
            /// <param name="opt_context" type="Object=">Object in whose context the function is to be
            ///     called (the global scope if none).</param>
            /// <returns type="number">Subscription key.</returns>
        }, 
        
        unsubscribe: function(topic, fn, opt_context) {
            /// <summary>Unsubscribes a function from a topic.  Only deletes the first match found.
            /// Returns a Boolean indicating whether a subscription was removed.</summary>
            /// <param name="topic" type="string">Topic to unsubscribe from.</param>
            /// <param name="fn" type="Function">Function to unsubscribe.</param>
            /// <param name="opt_context" type="Object=">Object in whose context the function was to be
            ///     called (the global scope if none).</param>
            /// <returns type="boolean">Whether a matching subscription was removed.</returns>
        }, 
        
        unsubscribeByKey: function(key) {
            /// <summary>Removes a subscription based on the key returned by {@link #subscribe}.
            /// No-op if no matching subscription is found.  Returns a Boolean indicating
            /// whether a subscription was removed.</summary>
            /// <param name="key" type="number">Subscription key.</param>
            /// <returns type="boolean">Whether a matching subscription was removed.</returns>
        }, 
        
        publish: function(topic, var_args) {
            /// <summary>Publishes a message to a topic.  Calls functions subscribed to the topic in
            /// the order in which they were added, passing all arguments along.  If any of
            /// the functions throws an uncaught error, publishing is aborted.</summary>
            /// <param name="topic" type="string">Topic to publish to.</param>
            /// <param name="var_args" type="...*">Arguments that are applied to each subscription
            ///     function.</param>
            /// <returns type="boolean">Whether any subscriptions were called.</returns>
        }, 
        
        clear: function(opt_topic) {
            /// <summary>Clears the subscription list for a topic, or all topics if unspecified.</summary>
            /// <param name="opt_topic" type="string=">Topic to clear (all topics if unspecified).</param>
        }, 
        
        getCount: function(opt_topic) {
            /// <summary>Returns the number of subscriptions to the given topic (or all topics if
            /// unspecified).</summary>
            /// <param name="opt_topic" type="string=">The topic (all topics if unspecified).</param>
            /// <returns type="number">Number of subscriptions to the topic.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.pubsub.PubSub";
})(this);
