
/* vsdoc for goog.spell.SpellCheck */

(function (window) {
    window.goog.spell = window.goog.spell || {};

    window.goog.spell.SpellCheck = function(opt_lookupFunction, opt_language){
        /// <summary></summary>
        /// <param name="opt_lookupFunction" type="Function=">Function to use for word lookup. Must
        ///     accept an array of words, an object reference and a callback function as
        ///     parameters. It must also call the callback function (as a method on the
        ///     object), once ready, with an array containing the original words, their
        ///     spelling status and optionally an array of suggestions.</param>
        /// <param name="opt_language" type="string=">Content language.</param>
        /// <field name="EventType" type="">Constants for event names</field>
        /// <field name="WordStatus" type="">Codes representing the status of an individual word.</field>
        /// <field name="CacheIndex" type="">Fields for word array in cache.</field>
        /// <field name="WORD_BOUNDARY_CHARS" type="string">Regular expression for identifying word boundaries.</field>
        /// <field name="WORD_BOUNDARY_REGEX" type="RegExp">Regular expression for identifying word boundaries.</field>
        /// <field name="SPLIT_REGEX" type="RegExp">Regular expression for splitting a string into individual words and blocks of
        /// separators. Matches zero or one word followed by zero or more separators.</field>
        /// <returns type="goog.spell.SpellCheck"/>
    };

    var $x = window.goog.spell.SpellCheck;
    $x.prototype = {
                
        setLookupFunction: function(f) {
            /// <summary>Sets the lookup function.</summary>
            /// <param name="f" type="Function">Function to use for word lookup. Must accept an array of
            ///     words, an object reference and a callback function as parameters.
            ///     It must also call the callback function (as a method on the object),
            ///     once ready, with an array containing the original words, their
            ///     spelling status and optionally an array of suggestions.</param>
        }, 
        
        setLanguage: function(opt_language) {
            /// <summary>Sets language.</summary>
            /// <param name="opt_language" type="string=">Content language.</param>
        }, 
        
        getLanguage: function() {
            /// <summary>Returns language.</summary>
            /// <returns type="string">Content language.</returns>
        }, 
        
        checkBlock: function(text) {
            /// <summary>Checks spelling for a block of text.</summary>
            /// <param name="text" type="string">Block of text to spell check.</param>
        }, 
        
        checkWord: function(word) {
            /// <summary>Checks spelling for a single word. Returns the status of the supplied word,
            /// or UNKNOWN if it&apos;s not cached. If it&apos;s not cached the word is added to a
            /// queue and checked with the verification implementation with a short delay.</summary>
            /// <param name="word" type="string">Word to check spelling of.</param>
            /// <returns type="goog.spell.SpellCheck.WordStatus">The status of the supplied word,
            ///     or UNKNOWN if it&apos;s not cached.</returns>
        }, 
        
        processPending: function() {
            /// <summary>Processes pending words unless a lookup operation has already been queued or
            /// is in progress.</summary>
        }, 
        
        setWordStatus: function(word, status, opt_suggestions) {
            /// <summary>Sets a words spelling status.</summary>
            /// <param name="word" type="string">Word to set status for.</param>
            /// <param name="status" type="goog.spell.SpellCheck.WordStatus">Status of word.</param>
            /// <param name="opt_suggestions" type="Array.string=">Suggestions.
            /// 
            /// Example:
            /// obj.setWordStatus(&apos;word&apos;, VALID);
            /// obj.setWordStatus(&apos;wrod&apos;, INVALID, [&apos;word&apos;, &apos;wood&apos;, &apos;rod&apos;]);.</param>
        }, 
        
        getSuggestions: function(word) {
            /// <summary>Returns suggestions for the given word.</summary>
            /// <param name="word" type="string">Word to get suggestions for.</param>
            /// <returns type="Array.string">An array of suggestions for the given word.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.spell.SpellCheck";
})(this);
