
/* vsdoc for goog.storage.ExpiringStorage */

(function (window) {
    window.goog.storage = window.goog.storage || {};

    window.goog.storage.ExpiringStorage = function(mechanism){
        /// <summary></summary>
        /// <param name="mechanism" type="!goog.storage.mechanism.Mechanism">The underlying
        ///     storage mechanism.</param>
        /// <field name="EXPIRATION_TIME_KEY" type="string">Metadata key under which the expiration time is stored.</field>
        /// <field name="CREATION_TIME_KEY" type="string">Metadata key under which the creation time is stored.</field>
        /// <returns type="goog.storage.ExpiringStorage"/>
    };

    var $x = window.goog.storage.ExpiringStorage;
    $x.prototype = {
                
        getCreationTime: function(wrapper) {
            /// <summary>Returns the wrapper creation time.</summary>
            /// <param name="wrapper" type="!Object">The wrapper.</param>
            /// <returns type="number|undefined">Wrapper creation time.</returns>
        }, 
        
        getExpirationTime: function(wrapper) {
            /// <summary>Returns the wrapper expiration time.</summary>
            /// <param name="wrapper" type="!Object">The wrapper.</param>
            /// <returns type="number|undefined">Wrapper expiration time.</returns>
        }, 
        
        isExpired: function(wrapper) {
            /// <summary>Checks if the data item has expired.</summary>
            /// <param name="wrapper" type="!Object">The wrapper.</param>
            /// <returns type="boolean">True if the item has expired.</returns>
        }, 
        
        set: function(key, value, opt_expiration) {
            /// <summary>Set an item in the storage.</summary>
            /// <param name="key" type="string">The key to set.</param>
            /// <param name="value" type="*">The value to serialize to a string and save.</param>
            /// <param name="opt_expiration" type="number=">The number of miliseconds since epoch
            ///     (as in goog.now()) when the value is to expire. If the expiration
            ///     time is not provided, the value will persist as long as possible.</param>
        }, 
        
        getWrapper: function(key, opt_expired) {
            /// <summary>Get an item wrapper (the item and its metadata) from the storage.</summary>
            /// <param name="key" type="string">The key to get.</param>
            /// <param name="opt_expired" type="boolean=">If true, return expired wrappers as well.</param>
            /// <returns type="(!Object|undefined)">The wrapper, or undefined if not found.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.storage.ExpiringStorage";
})(this);
