
/* vsdoc for goog.storage.mechanism.mechanismfactory */

(function (window) {
    window.goog.storage.mechanism = window.goog.storage.mechanism || {};

    window.goog.storage.mechanism.mechanismfactory = {
        /// <summary></summary>
        /// <field name="USER_DATA_SHARED_KEY" type="string">The key to shared userData storage.</field>
        /// <returns type="goog.storage.mechanism.mechanismfactory"/>
                
        create: function(opt_namespace) {
            /// <summary>Returns the best local storage mechanism, or null if unavailable.
            /// Local storage means that the database is placed on user&apos;s computer.
            /// The key-value database is normally shared between all the code paths
            /// that request it, so using an optional namespace is recommended. This
            /// provides separation and makes key collisions unlikely.</summary>
            /// <param name="opt_namespace" type="string=">Restricts the visibility to given namespace.</param>
            /// <returns type="goog.storage.mechanism.IterableMechanism">Created mechanism or null.</returns>
        }, 
        
        createHTML5LocalStorage: function(opt_namespace) {
            /// <summary>Returns an HTML5 local storage mechanism, or null if unavailable.
            /// Since the HTML5 local storage does not support namespaces natively,
            /// and the key-value database is shared between all the code paths
            /// that request it, it is recommended that an optional namespace is
            /// used to provide key separation employing a prefix.</summary>
            /// <param name="opt_namespace" type="string=">Restricts the visibility to given namespace.</param>
            /// <returns type="goog.storage.mechanism.IterableMechanism">Created mechanism or null.</returns>
        }, 
        
        createHTML5SessionStorage: function(opt_namespace) {
            /// <summary>Returns an HTML5 session storage mechanism, or null if unavailable.
            /// Since the HTML5 session storage does not support namespaces natively,
            /// and the key-value database is shared between all the code paths
            /// that request it, it is recommended that an optional namespace is
            /// used to provide key separation employing a prefix.</summary>
            /// <param name="opt_namespace" type="string=">Restricts the visibility to given namespace.</param>
            /// <returns type="goog.storage.mechanism.IterableMechanism">Created mechanism or null.</returns>
        }, 
        
        createIEUserData: function(opt_namespace) {
            /// <summary>Returns an IE userData local storage mechanism, or null if unavailable.
            /// Using an optional namespace is recommended to provide separation and
            /// avoid key collisions.</summary>
            /// <param name="opt_namespace" type="string=">Restricts the visibility to given namespace.</param>
            /// <returns type="goog.storage.mechanism.IterableMechanism">Created mechanism or null.</returns>
        }
        
    };

    var $x = window.goog.storage.mechanism.mechanismfactory;
    $x.__namespace = "true";
    $x.__typeName = "goog.storage.mechanism.mechanismfactory";
})(this);
