
/* vsdoc for goog.string */

(function (window) {
    window.goog = window.goog || {};

    window.goog.string = {
        /// <summary></summary>
        /// <field name="linkify" type=""></field>
        /// <field name="path" type=""></field>
        /// <field name="Unicode" type="">Common Unicode string characters.</field>
        /// <returns type="goog.string"/>
                
        Parser: function() {
            /// <summary>An interface for parsing strings into objects.</summary>
        }, 
        
        startsWith: function(str, prefix) {
            /// <summary>Fast prefix-checker.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <param name="prefix" type="string">A string to look for at the start of {@code str}.</param>
            /// <returns type="boolean">True if {@code str} begins with {@code prefix}.</returns>
        }, 
        
        endsWith: function(str, suffix) {
            /// <summary>Fast suffix-checker.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <param name="suffix" type="string">A string to look for at the end of {@code str}.</param>
            /// <returns type="boolean">True if {@code str} ends with {@code suffix}.</returns>
        }, 
        
        caseInsensitiveStartsWith: function(str, prefix) {
            /// <summary>Case-insensitive prefix-checker.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <param name="prefix" type="string">A string to look for at the end of {@code str}.</param>
            /// <returns type="boolean">True if {@code str} begins with {@code prefix} (ignoring
            ///     case).</returns>
        }, 
        
        caseInsensitiveEndsWith: function(str, suffix) {
            /// <summary>Case-insensitive suffix-checker.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <param name="suffix" type="string">A string to look for at the end of {@code str}.</param>
            /// <returns type="boolean">True if {@code str} ends with {@code suffix} (ignoring
            ///     case).</returns>
        }, 
        
        subs: function(str, var_args) {
            /// <summary>Does simple python-style string substitution.
            /// subs(&quot;foo%s hot%s&quot;, &quot;bar&quot;, &quot;dog&quot;) becomes &quot;foobar hotdog&quot;.</summary>
            /// <param name="str" type="string">The string containing the pattern.</param>
            /// <param name="var_args" type="...*">The items to substitute into the pattern.</param>
            /// <returns type="string">A copy of {@code str} in which each occurrence of
            ///     {@code %s} has been replaced an argument from {@code var_args}.</returns>
        }, 
        
        collapseWhitespace: function(str) {
            /// <summary>Converts multiple whitespace chars (spaces, non-breaking-spaces, new lines
            /// and tabs) to a single space, and strips leading and trailing whitespace.</summary>
            /// <param name="str" type="string">Input string.</param>
            /// <returns type="string">A copy of {@code str} with collapsed whitespace.</returns>
        }, 
        
        isEmpty: function(str) {
            /// <summary>Checks if a string is empty or contains only whitespaces.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <returns type="boolean">True if {@code str} is empty or whitespace only.</returns>
        }, 
        
        isEmptySafe: function(str) {
            /// <summary>Checks if a string is null, undefined, empty or contains only whitespaces.</summary>
            /// <param name="str" type="*">The string to check.</param>
            /// <returns type="boolean">True if{@code str} is null, undefined, empty, or
            ///     whitespace only.</returns>
        }, 
        
        isBreakingWhitespace: function(str) {
            /// <summary>Checks if a string is all breaking whitespace.</summary>
            /// <param name="str" type="string">The string to check.</param>
            /// <returns type="boolean">Whether the string is all breaking whitespace.</returns>
        }, 
        
        isAlpha: function(str) {
            /// <summary>Checks if a string contains all letters.</summary>
            /// <param name="str" type="string">string to check.</param>
            /// <returns type="boolean">True if {@code str} consists entirely of letters.</returns>
        }, 
        
        isNumeric: function(str) {
            /// <summary>Checks if a string contains only numbers.</summary>
            /// <param name="str" type="*">string to check. If not a string, it will be
            ///     casted to one.</param>
            /// <returns type="boolean">True if {@code str} is numeric.</returns>
        }, 
        
        isAlphaNumeric: function(str) {
            /// <summary>Checks if a string contains only numbers or letters.</summary>
            /// <param name="str" type="string">string to check.</param>
            /// <returns type="boolean">True if {@code str} is alphanumeric.</returns>
        }, 
        
        isSpace: function(ch) {
            /// <summary>Checks if a character is a space character.</summary>
            /// <param name="ch" type="string">Character to check.</param>
            /// <returns type="boolean">True if {code ch} is a space.</returns>
        }, 
        
        isUnicodeChar: function(ch) {
            /// <summary>Checks if a character is a valid unicode character.</summary>
            /// <param name="ch" type="string">Character to check.</param>
            /// <returns type="boolean">True if {code ch} is a valid unicode character.</returns>
        }, 
        
        stripNewlines: function(str) {
            /// <summary>Takes a string and replaces newlines with a space. Multiple lines are
            /// replaced with a single space.</summary>
            /// <param name="str" type="string">The string from which to strip newlines.</param>
            /// <returns type="string">A copy of {@code str} stripped of newlines.</returns>
        }, 
        
        canonicalizeNewlines: function(str) {
            /// <summary>Replaces Windows and Mac new lines with unix style: \r or \r\n with \n.</summary>
            /// <param name="str" type="string">The string to in which to canonicalize newlines.</param>
            /// <returns type="string">{@code str} A copy of {@code} with canonicalized newlines.</returns>
        }, 
        
        normalizeWhitespace: function(str) {
            /// <summary>Normalizes whitespace in a string, replacing all whitespace chars with
            /// a space.</summary>
            /// <param name="str" type="string">The string in which to normalize whitespace.</param>
            /// <returns type="string">A copy of {@code str} with all whitespace normalized.</returns>
        }, 
        
        normalizeSpaces: function(str) {
            /// <summary>Normalizes spaces in a string, replacing all consecutive spaces and tabs
            /// with a single space. Replaces non-breaking space with a space.</summary>
            /// <param name="str" type="string">The string in which to normalize spaces.</param>
            /// <returns type="string">A copy of {@code str} with all consecutive spaces and tabs
            ///    replaced with a single space.</returns>
        }, 
        
        collapseBreakingSpaces: function(str) {
            /// <summary>Removes the breaking spaces from the left and right of the string and
            /// collapses the sequences of breaking spaces in the middle into single spaces.
            /// The original and the result strings render the same way in HTML.</summary>
            /// <param name="str" type="string">A string in which to collapse spaces.</param>
            /// <returns type="string">Copy of the string with normalized breaking spaces.</returns>
        }, 
        
        trim: function(str) {
            /// <summary>Trims white spaces to the left and right of a string.</summary>
            /// <param name="str" type="string">The string to trim.</param>
            /// <returns type="string">A trimmed copy of {@code str}.</returns>
        }, 
        
        trimLeft: function(str) {
            /// <summary>Trims whitespaces at the left end of a string.</summary>
            /// <param name="str" type="string">The string to left trim.</param>
            /// <returns type="string">A trimmed copy of {@code str}.</returns>
        }, 
        
        trimRight: function(str) {
            /// <summary>Trims whitespaces at the right end of a string.</summary>
            /// <param name="str" type="string">The string to right trim.</param>
            /// <returns type="string">A trimmed copy of {@code str}.</returns>
        }, 
        
        caseInsensitiveCompare: function(str1, str2) {
            /// <summary>A string comparator that ignores case.
            /// -1 = str1 less than str2
            ///  0 = str1 equals str2
            ///  1 = str1 greater than str2</summary>
            /// <param name="str1" type="string">The string to compare.</param>
            /// <param name="str2" type="string">The string to compare {@code str1} to.</param>
            /// <returns type="number">The comparator result, as described above.</returns>
        }, 
        
        numerateCompare: function(str1, str2) {
            /// <summary>String comparison function that handles numbers in a way humans might expect.
            /// Using this function, the string &quot;File 2.jpg&quot; sorts before &quot;File 10.jpg&quot;. The
            /// comparison is mostly case-insensitive, though strings that are identical
            /// except for case are sorted with the upper-case strings before lower-case.
            /// 
            /// This comparison function is significantly slower (about 500x) than either
            /// the default or the case-insensitive compare. It should not be used in
            /// time-critical code, but should be fast enough to sort several hundred short
            /// strings (like filenames) with a reasonable delay.</summary>
            /// <param name="str1" type="string">The string to compare in a numerically sensitive way.</param>
            /// <param name="str2" type="string">The string to compare {@code str1} to.</param>
            /// <returns type="number">less than 0 if str1 &lt; str2, 0 if str1 == str2, greater than
            ///     0 if str1 &gt; str2.</returns>
        }, 
        
        urlEncode: function(str) {
            /// <summary>URL-encodes a string</summary>
            /// <param name="str" type="*">The string to url-encode.</param>
            /// <returns type="string">An encoded copy of {@code str} that is safe for urls.
            ///     Note that &apos;#&apos;, &apos;:&apos;, and other characters used to delimit portions
            ///     of URLs *will* be encoded.</returns>
        }, 
        
        urlDecode: function(str) {
            /// <summary>URL-decodes the string. We need to specially handle &apos;+&apos;s because
            /// the javascript library doesn&apos;t convert them to spaces.</summary>
            /// <param name="str" type="string">The string to url decode.</param>
            /// <returns type="string">The decoded {@code str}.</returns>
        }, 
        
        newLineToBr: function(str, opt_xml) {
            /// <summary>Converts \n to <br>s or <br />s.</summary>
            /// <param name="str" type="string">The string in which to convert newlines.</param>
            /// <param name="opt_xml" type="boolean=">Whether to use XML compatible tags.</param>
            /// <returns type="string">A copy of {@code str} with converted newlines.</returns>
        }, 
        
        htmlEscape: function(str, opt_isLikelyToContainHtmlChars) {
            /// <summary>Escape double quote &apos;&quot;&apos; characters in addition to &apos;&amp;&apos;, &apos;&lt;&apos;, and &apos;&gt;&apos; so that a
            /// string can be included in an HTML tag attribute value within double quotes.
            /// 
            /// It should be noted that > doesn&apos;t need to be escaped for the HTML or XML to
            /// be valid, but it has been decided to escape it for consistency with other
            /// implementations.
            /// 
            /// NOTE(user):
            /// HtmlEscape is often called during the generation of large blocks of HTML.
            /// Using statics for the regular expressions and strings is an optimization
            /// that can more than half the amount of time IE spends in this function for
            /// large apps, since strings and regexes both contribute to GC allocations.
            /// 
            /// Testing for the presence of a character before escaping increases the number
            /// of function calls, but actually provides a speed increase for the average
            /// case -- since the average case often doesn&apos;t require the escaping of all 4
            /// characters and indexOf() is much cheaper than replace().
            /// The worst case does suffer slightly from the additional calls, therefore the
            /// opt_isLikelyToContainHtmlChars option has been included for situations
            /// where all 4 HTML entities are very likely to be present and need escaping.
            /// 
            /// Some benchmarks (times tended to fluctuate +-0.05ms):
            ///                                     FireFox                     IE6
            /// (no chars / average (mix of cases) / all 4 chars)
            /// no checks                     0.13 / 0.22 / 0.22         0.23 / 0.53 / 0.80
            /// indexOf                       0.08 / 0.17 / 0.26         0.22 / 0.54 / 0.84
            /// indexOf + re test             0.07 / 0.17 / 0.28         0.19 / 0.50 / 0.85
            /// 
            /// An additional advantage of checking if replace actually needs to be called
            /// is a reduction in the number of object allocations, so as the size of the
            /// application grows the difference between the various methods would increase.</summary>
            /// <param name="str" type="string">string to be escaped.</param>
            /// <param name="opt_isLikelyToContainHtmlChars" type="boolean=">Don&apos;t perform a check to see
            ///     if the character needs replacing - use this option if you expect each of
            ///     the characters to appear often. Leave false if you expect few html
            ///     characters to occur in your strings, such as if you are escaping HTML.</param>
            /// <returns type="string">An escaped copy of {@code str}.</returns>
        }, 
        
        unescapeEntities: function(str) {
            /// <summary>Unescapes an HTML string.</summary>
            /// <param name="str" type="string">The string to unescape.</param>
            /// <returns type="string">An unescaped copy of {@code str}.</returns>
        }, 
        
        whitespaceEscape: function(str, opt_xml) {
            /// <summary>Do escaping of whitespace to preserve spatial formatting. We use character
            /// entity #160 to make it safer for xml.</summary>
            /// <param name="str" type="string">The string in which to escape whitespace.</param>
            /// <param name="opt_xml" type="boolean=">Whether to use XML compatible tags.</param>
            /// <returns type="string">An escaped copy of {@code str}.</returns>
        }, 
        
        stripQuotes: function(str, quoteChars) {
            /// <summary>Strip quote characters around a string.  The second argument is a string of
            /// characters to treat as quotes.  This can be a single character or a string of
            /// multiple character and in that case each of those are treated as possible
            /// quote characters. For example:
            /// 
            /// &lt;pre&gt;
            /// goog.string.stripQuotes(&apos;&quot;abc&quot;&apos;, &apos;&quot;`&apos;) --> &apos;abc&apos;
            /// goog.string.stripQuotes(&apos;`abc`&apos;, &apos;&quot;`&apos;) --> &apos;abc&apos;
            /// &lt;/pre&gt;</summary>
            /// <param name="str" type="string">The string to strip.</param>
            /// <param name="quoteChars" type="string">The quote characters to strip.</param>
            /// <returns type="string">A copy of {@code str} without the quotes.</returns>
        }, 
        
        truncate: function(str, chars, opt_protectEscapedCharacters) {
            /// <summary>Truncates a string to a certain length and adds &apos;...&apos; if necessary.  The
            /// length also accounts for the ellipsis, so a maximum length of 10 and a string
            /// &apos;Hello World!&apos; produces &apos;Hello W...&apos;.</summary>
            /// <param name="str" type="string">The string to truncate.</param>
            /// <param name="chars" type="number">Max number of characters.</param>
            /// <param name="opt_protectEscapedCharacters" type="boolean=">Whether to protect escaped
            ///     characters from being cut off in the middle.</param>
            /// <returns type="string">The truncated {@code str} string.</returns>
        }, 
        
        truncateMiddle: function(str, chars, opt_protectEscapedCharacters, opt_trailingChars) {
            /// <summary>Truncate a string in the middle, adding &quot;...&quot; if necessary,
            /// and favoring the beginning of the string.</summary>
            /// <param name="str" type="string">The string to truncate the middle of.</param>
            /// <param name="chars" type="number">Max number of characters.</param>
            /// <param name="opt_protectEscapedCharacters" type="boolean=">Whether to protect escaped
            ///     characters from being cutoff in the middle.</param>
            /// <param name="opt_trailingChars" type="number=">Optional number of trailing characters to
            ///     leave at the end of the string, instead of truncating as close to the
            ///     middle as possible.</param>
            /// <returns type="string">A truncated copy of {@code str}.</returns>
        }, 
        
        quote: function(s) {
            /// <summary>Encloses a string in double quotes and escapes characters so that the
            /// string is a valid JS string.</summary>
            /// <param name="s" type="string">The string to quote.</param>
            /// <returns type="string">A copy of {@code s} surrounded by double quotes.</returns>
        }, 
        
        escapeString: function(str) {
            /// <summary>Takes a string and returns the escaped string for that character.</summary>
            /// <param name="str" type="string">The string to escape.</param>
            /// <returns type="string">An escaped string representing {@code str}.</returns>
        }, 
        
        escapeChar: function(c) {
            /// <summary>Takes a character and returns the escaped string for that character. For
            /// example escapeChar(String.fromCharCode(15)) -> &quot;\\x0E&quot;.</summary>
            /// <param name="c" type="string">The character to escape.</param>
            /// <returns type="string">An escaped string representing {@code c}.</returns>
        }, 
        
        toMap: function(s) {
            /// <summary>Takes a string and creates a map (Object) in which the keys are the
            /// characters in the string. The value for the key is set to true. You can
            /// then use goog.object.map or goog.array.map to change the values.</summary>
            /// <param name="s" type="string">The string to build the map from.</param>
            /// <returns type="Object">The map of characters used.</returns>
        }, 
        
        contains: function(s, ss) {
            /// <summary>Checks whether a string contains a given substring.</summary>
            /// <param name="s" type="string">The string to test.</param>
            /// <param name="ss" type="string">The substring to test for.</param>
            /// <returns type="boolean">True if {@code s} contains {@code ss}.</returns>
        }, 
        
        countOf: function(s, ss) {
            /// <summary>Returns the non-overlapping occurrences of ss in s.
            /// If either s or ss evalutes to false, then returns zero.</summary>
            /// <param name="s" type="string">The string to look in.</param>
            /// <param name="ss" type="string">The string to look for.</param>
            /// <returns type="number">Number of occurrences of ss in s.</returns>
        }, 
        
        removeAt: function(s, index, stringLength) {
            /// <summary>Removes a substring of a specified length at a specific
            /// index in a string.</summary>
            /// <param name="s" type="string">The base string from which to remove.</param>
            /// <param name="index" type="number">The index at which to remove the substring.</param>
            /// <param name="stringLength" type="number">The length of the substring to remove.</param>
            /// <returns type="string">A copy of {@code s} with the substring removed or the full
            ///     string if nothing is removed or the input is invalid.</returns>
        }, 
        
        remove: function(s, ss) {
            /// <summary>Removes the first occurrence of a substring from a string.</summary>
            /// <param name="s" type="string">The base string from which to remove.</param>
            /// <param name="ss" type="string">The string to remove.</param>
            /// <returns type="string">A copy of {@code s} with {@code ss} removed or the full
            ///      string if nothing is removed.</returns>
        }, 
        
        removeAll: function(s, ss) {
            /// <summary>Removes all occurrences of a substring from a string.</summary>
            /// <param name="s" type="string">The base string from which to remove.</param>
            /// <param name="ss" type="string">The string to remove.</param>
            /// <returns type="string">A copy of {@code s} with {@code ss} removed or the full
            ///      string if nothing is removed.</returns>
        }, 
        
        regExpEscape: function(s) {
            /// <summary>Escapes characters in the string that are not safe to use in a RegExp.</summary>
            /// <param name="s" type="*">The string to escape. If not a string, it will be casted
            ///     to one.</param>
            /// <returns type="string">A RegExp safe, escaped copy of {@code s}.</returns>
        }, 
        
        repeat: function(string, length) {
            /// <summary>Repeats a string n times.</summary>
            /// <param name="string" type="string">The string to repeat.</param>
            /// <param name="length" type="number">The number of times to repeat.</param>
            /// <returns type="string">A string containing {@code length} repetitions of
            ///     {@code string}.</returns>
        }, 
        
        padNumber: function(num, length, opt_precision) {
            /// <summary>Pads number to given length and optionally rounds it to a given precision.
            /// For example:
            /// &lt;pre&gt;padNumber(1.25, 2, 3) -> &apos;01.250&apos;
            /// padNumber(1.25, 2) -> &apos;01.25&apos;
            /// padNumber(1.25, 2, 1) -> &apos;01.3&apos;
            /// padNumber(1.25, 0) -> &apos;1.25&apos;&lt;/pre&gt;</summary>
            /// <param name="num" type="number">The number to pad.</param>
            /// <param name="length" type="number">The desired length.</param>
            /// <param name="opt_precision" type="number=">The desired precision.</param>
            /// <returns type="string">{@code num} as a string with the given options.</returns>
        }, 
        
        makeSafe: function(obj) {
            /// <summary>Returns a string representation of the given object, with
            /// null and undefined being returned as the empty string.</summary>
            /// <param name="obj" type="*">The object to convert.</param>
            /// <returns type="string">A string representation of the {@code obj}.</returns>
        }, 
        
        buildString: function(var_args) {
            /// <summary>Concatenates string expressions. This is useful
            /// since some browsers are very inefficient when it comes to using plus to
            /// concat strings. Be careful when using null and undefined here since
            /// these will not be included in the result. If you need to represent these
            /// be sure to cast the argument to a String first.
            /// For example:
            /// &lt;pre&gt;buildString(&apos;a&apos;, &apos;b&apos;, &apos;c&apos;, &apos;d&apos;) -> &apos;abcd&apos;
            /// buildString(null, undefined) -> &apos;&apos;
            /// &lt;/pre&gt;</summary>
            /// <param name="var_args" type="...*">A list of strings to concatenate. If not a string,
            ///     it will be casted to one.</param>
            /// <returns type="string">The concatenation of {@code var_args}.</returns>
        }, 
        
        getRandomString: function() {
            /// <summary>Returns a string with at least 64-bits of randomness.
            /// 
            /// Doesn&apos;t trust Javascript&apos;s random function entirely. Uses a combination of
            /// random and current timestamp, and then encodes the string in base-36 to
            /// make it shorter.</summary>
            /// <returns type="string">A random string, e.g. sn1s7vb4gcic.</returns>
        }, 
        
        compareVersions: function(version1, version2) {
            /// <summary>Compares two version numbers.</summary>
            /// <param name="version1" type="string|number">Version of first item.</param>
            /// <param name="version2" type="string|number">Version of second item.</param>
            /// <returns type="number">1 if {@code version1} is higher.
            ///                   0 if arguments are equal.
            ///                  -1 if {@code version2} is higher.</returns>
        }, 
        
        hashCode: function(str) {
            /// <summary>String hash function similar to java.lang.String.hashCode().
            /// The hash code for a string is computed as
            /// s[0] * 31 ^ (n - 1) + s[1] * 31 ^ (n - 2) + ... + s[n - 1],
            /// where s[i] is the ith character of the string and n is the length of
            /// the string. We mod the result to make it between 0 (inclusive) and 2^32
            /// (exclusive).</summary>
            /// <param name="str" type="string">A string.</param>
            /// <returns type="number">Hash value for {@code str}, between 0 (inclusive) and 2^32
            ///  (exclusive). The empty string returns 0.</returns>
        }, 
        
        createUniqueString: function() {
            /// <summary>Generates and returns a string which is unique in the current document.
            /// This is useful, for example, to create unique IDs for DOM elements.</summary>
            /// <returns type="string">A unique id.</returns>
        }, 
        
        toNumber: function(str) {
            /// <summary>Converts the supplied string to a number, which may be Ininity or NaN.
            /// This function strips whitespace: (toNumber(&apos; 123&apos;) === 123)
            /// This function accepts scientific notation: (toNumber(&apos;1e1&apos;) === 10)
            /// 
            /// This is better than Javascript&apos;s built-in conversions because, sadly:
            ///     (Number(&apos; &apos;) === 0) and (parseFloat(&apos;123a&apos;) === 123)</summary>
            /// <param name="str" type="string">The string to convert.</param>
            /// <returns type="number">The number the supplied string represents, or NaN.</returns>
        }, 
        
        toCamelCase: function(str) {
            /// <summary>Converts a string from selector-case to camelCase (e.g. from
            /// &quot;multi-part-string&quot; to &quot;multiPartString&quot;), useful for converting
            /// CSS selectors and HTML dataset keys to their equivalent JS properties.</summary>
            /// <param name="str" type="string">The string in selector-case form.</param>
            /// <returns type="string">The string in camelCase form.</returns>
        }, 
        
        toSelectorCase: function(str) {
            /// <summary>Converts a string from camelCase to selector-case (e.g. from
            /// &quot;multiPartString&quot; to &quot;multi-part-string&quot;), useful for converting JS
            /// style and dataset properties to equivalent CSS selectors and HTML keys.</summary>
            /// <param name="str" type="string">The string in camelCase form.</param>
            /// <returns type="string">The string in selector-case form.</returns>
        }, 
        
        toTitleCase: function(str, opt_delimiters) {
            /// <summary>Converts a string into TitleCase. First character of the string is always
            /// capitalized in addition to the first letter of every subsequent word.
            /// Words are delimited by one or more whitespaces by default. Custom delimiters
            /// can optionally be specified to replace the default, which doesn&apos;t preserve
            /// whitespace delimiters and instead must be explicitly included if needed.
            /// 
            /// Default delimiter => &quot; &quot;:
            ///    goog.string.toTitleCase(&apos;oneTwoThree&apos;)    => &apos;OneTwoThree&apos;
            ///    goog.string.toTitleCase(&apos;one two three&apos;)  => &apos;One Two Three&apos;
            ///    goog.string.toTitleCase(&apos;  one   two   &apos;) => &apos;  One   Two   &apos;
            ///    goog.string.toTitleCase(&apos;one_two_three&apos;)  => &apos;One_two_three&apos;
            ///    goog.string.toTitleCase(&apos;one-two-three&apos;)  => &apos;One-two-three&apos;
            /// 
            /// Custom delimiter => &quot;_-.&quot;:
            ///    goog.string.toTitleCase(&apos;oneTwoThree&apos;, &apos;_-.&apos;)       => &apos;OneTwoThree&apos;
            ///    goog.string.toTitleCase(&apos;one two three&apos;, &apos;_-.&apos;)     => &apos;One two three&apos;
            ///    goog.string.toTitleCase(&apos;  one   two   &apos;, &apos;_-.&apos;)    => &apos;  one   two   &apos;
            ///    goog.string.toTitleCase(&apos;one_two_three&apos;, &apos;_-.&apos;)     => &apos;One_Two_Three&apos;
            ///    goog.string.toTitleCase(&apos;one-two-three&apos;, &apos;_-.&apos;)     => &apos;One-Two-Three&apos;
            ///    goog.string.toTitleCase(&apos;one...two...three&apos;, &apos;_-.&apos;) => &apos;One...Two...Three&apos;
            ///    goog.string.toTitleCase(&apos;one. two. three&apos;, &apos;_-.&apos;)   => &apos;One. two. three&apos;
            ///    goog.string.toTitleCase(&apos;one-two.three&apos;, &apos;_-.&apos;)     => &apos;One-Two.Three&apos;</summary>
            /// <param name="str" type="string">String value in camelCase form.</param>
            /// <param name="opt_delimiters" type="string=">Custom delimiter character set used to
            ///      distinguish words in the string value. Each character represents a
            ///      single delimiter. When provided, default whitespace delimiter is
            ///      overridden and must be explicitly included if needed.</param>
            /// <returns type="string">String value in TitleCase form.</returns>
        }, 
        
        parseInt: function(value) {
            /// <summary>Parse a string in decimal or hexidecimal (&apos;0xFFFF&apos;) form.
            /// 
            /// To parse a particular radix, please use parseInt(string, radix) directly. See
            /// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/parseInt
            /// 
            /// This is a wrapper for the built-in parseInt function that will only parse
            /// numbers as base 10 or base 16.  Some JS implementations assume strings
            /// starting with &quot;0&quot; are intended to be octal. ES3 allowed but discouraged
            /// this behavior. ES5 forbids it.  This function emulates the ES5 behavior.
            /// 
            /// For more information, see Mozilla JS Reference: http://goo.gl/8RiFj</summary>
            /// <param name="value" type="string|number|null|undefined">The value to be parsed.</param>
            /// <returns type="number">The number, parsed. If the string failed to parse, this
            ///     will be NaN.</returns>
        }, 
        
        format: function(formatString, var_args) {
            /// <summary>Performs sprintf-like conversion, ie. puts the values in a template.
            /// DO NOT use it instead of built-in conversions in simple cases such as
            /// &apos;Cost: %.2f&apos; as it would introduce unneccessary latency oposed to
            /// &apos;Cost: &apos; + cost.toFixed(2).</summary>
            /// <param name="formatString" type="string">Template string containing % specifiers.</param>
            /// <param name="var_args" type="...string|number">Values formatString is to be filled with.</param>
            /// <returns type="string">Formatted string.</returns>
        }, 
        
        Stringifier: function() {
            /// <summary>An interface for serializing objects into strings.</summary>
        }
        
    };

    var $x = window.goog.string;
    $x.__namespace = "true";
    $x.__typeName = "goog.string";
})(this);
