
/* vsdoc for goog.structs */

(function (window) {
    window.goog = window.goog || {};

    window.goog.structs = {
        /// <summary></summary>
        /// <returns type="goog.structs"/>
                
        Collection: function() {
            /// <summary>An interface for a collection of values.</summary>
        }, 
        
        getCount: function(col) {
            /// <summary>Returns the number of values in the collection-like object.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <returns type="number">The number of values in the collection-like object.</returns>
        }, 
        
        getValues: function(col) {
            /// <summary>Returns the values of the collection-like object.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <returns type="!Array">The values in the collection-like object.</returns>
        }, 
        
        getKeys: function(col) {
            /// <summary>Returns the keys of the collection. Some collections have no notion of
            /// keys/indexes and this function will return undefined in those cases.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <returns type="!Array|undefined">The keys in the collection.</returns>
        }, 
        
        contains: function(col, val) {
            /// <summary>Whether the collection contains the given value. This is O(n) and uses
            /// equals (==) to test the existence.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <param name="val" type="*">The value to check for.</param>
            /// <returns type="boolean">True if the map contains the value.</returns>
        }, 
        
        isEmpty: function(col) {
            /// <summary>Whether the collection is empty.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <returns type="boolean">True if empty.</returns>
        }, 
        
        clear: function(col) {
            /// <summary>Removes all the elements from the collection.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
        }, 
        
        forEach: function(col, f, opt_obj) {
            /// <summary>Calls a function for each value in a collection. The function takes
            /// three arguments; the value, the key and the collection.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function takes
            ///     3 arguments (the value, the key or undefined if the collection has no
            ///     notion of keys, and the collection) and the return value is irrelevant.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
        }, 
        
        filter: function(col, f, opt_obj) {
            /// <summary>Calls a function for every value in the collection. When a call returns true,
            /// adds the value to a new collection (Array is returned by default).</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function takes
            ///     3 arguments (the value, the key or undefined if the collection has no
            ///     notion of keys, and the collection) and should return a Boolean. If the
            ///     return value is true the value is added to the result collection. If it
            ///     is false the value is not included.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
            /// <returns type="!Object|!Array">A new collection where the passed values are
            ///     present. If col is a key-less collection an array is returned.  If col
            ///     has keys and values a plain old JS object is returned.</returns>
        }, 
        
        map: function(col, f, opt_obj) {
            /// <summary>Calls a function for every value in the collection and adds the result into a
            /// new collection (defaults to creating a new Array).</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function
            ///     takes 3 arguments (the value, the key or undefined if the collection has
            ///     no notion of keys, and the collection) and should return something. The
            ///     result will be used as the value in the new collection.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
            /// <returns type="!Object|!Array">A new collection with the new values.  If col is a
            ///     key-less collection an array is returned.  If col has keys and values a
            ///     plain old JS object is returned.</returns>
        }, 
        
        some: function(col, f, opt_obj) {
            /// <summary>Calls f for each value in a collection. If any call returns true this returns
            /// true (without checking the rest). If all returns false this returns false.</summary>
            /// <param name="col" type="Object|Array|string">The collection-like object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function takes
            ///     3 arguments (the value, the key or undefined if the collection has no
            ///     notion of keys, and the collection) and should return a Boolean.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
            /// <returns type="boolean">True if any value passes the test.</returns>
        }, 
        
        every: function(col, f, opt_obj) {
            /// <summary>Calls f for each value in a collection. If all calls return true this return
            /// true this returns true. If any returns false this returns false at this point
            ///  and does not continue to check the remaining values.</summary>
            /// <param name="col" type="Object">The collection-like object.</param>
            /// <param name="f" type="Function">The function to call for every value. This function takes
            ///     3 arguments (the value, the key or undefined if the collection has no
            ///     notion of keys, and the collection) and should return a Boolean.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
            /// <returns type="boolean">True if all key-value pairs pass the test.</returns>
        }
        
    };

    var $x = window.goog.structs;
    $x.__namespace = "true";
    $x.__typeName = "goog.structs";
})(this);
