
/* vsdoc for goog.structs.AvlTree */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.AvlTree = function(opt_comparator){
        /// <summary></summary>
        /// <param name="opt_comparator" type="Function=">Function used to order the tree&apos;s nodes.</param>
        /// <returns type="goog.structs.AvlTree"/>
    };

    var $x = window.goog.structs.AvlTree;
    $x.prototype = {
                
        add: function(value) {
            /// <summary>Inserts a node into the tree with the specified value if the tree does
            /// not already contain a node with the specified value. If the value is
            /// inserted, the tree is balanced to enforce the AVL-Tree height property.</summary>
            /// <param name="value" type="*">Value to insert into the tree.</param>
            /// <returns type="boolean">Whether value was inserted into the tree.</returns>
        }, 
        
        remove: function(value) {
            /// <summary>Removes a node from the tree with the specified value if the tree contains a
            /// node with this value. If a node is removed the tree is balanced to enforce
            /// the AVL-Tree height property. The value of the removed node is returned.</summary>
            /// <param name="value" type="*">Value to find and remove from the tree.</param>
            /// <returns type="*">The value of the removed node or null if the value was not in
            ///     the tree.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all nodes from the tree.</summary>
        }, 
        
        contains: function(value) {
            /// <summary>Returns true if the tree contains a node with the specified value, false
            /// otherwise.</summary>
            /// <param name="value" type="*">Value to find in the tree.</param>
            /// <returns type="boolean">Whether the tree contains a node with the specified value.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Returns the number of values stored in the tree.</summary>
            /// <returns type="number">The number of values stored in the tree.</returns>
        }, 
        
        getMinimum: function() {
            /// <summary>Returns the value u, such that u is contained in the tree and u < v, for all
            /// values v in the tree where v != u.</summary>
            /// <returns type="*">The minimum value contained in the tree.</returns>
        }, 
        
        getMaximum: function() {
            /// <summary>Returns the value u, such that u is contained in the tree and u > v, for all
            /// values v in the tree where v != u.</summary>
            /// <returns type="*">The maximum value contained in the tree.</returns>
        }, 
        
        getHeight: function() {
            /// <summary>Returns the height of the tree (the maximum depth). This height should
            /// always be <= 1.4405*(Math.log(n+2)/Math.log(2))-1.3277, where n is the
            /// number of nodes in the tree.</summary>
            /// <returns type="number">The height of the tree.</returns>
        }, 
        
        getValues: function() {
            /// <summary>Inserts the values stored in the tree into a new Array and returns the Array.</summary>
            /// <returns type="Array">An array containing all of the trees values in sorted order.</returns>
        }, 
        
        inOrderTraverse: function(func, opt_startValue) {
            /// <summary>Performs an in-order traversal of the tree and calls {@code func} with each
            /// traversed node, optionally starting from the smallest node with a value >= to
            /// the specified start value. The traversal ends after traversing the tree&apos;s
            /// maximum node or when {@code func} returns a value that evaluates to true.</summary>
            /// <param name="func" type="Function">Function to call on each traversed node.</param>
            /// <param name="opt_startValue" type="Object=">If specified, traversal will begin on the
            ///    node with the smallest value >= opt_startValue.</param>
        }, 
        
        reverseOrderTraverse: function(func, opt_startValue) {
            /// <summary>Performs a reverse-order traversal of the tree and calls {@code func} with
            /// each traversed node, optionally starting from the largest node with a value
            /// <= to the specified start value. The traversal ends after traversing the
            /// tree&apos;s minimum node or when func returns a value that evaluates to true.</summary>
            /// <param name="func" type="Function">Function to call on each traversed node.</param>
            /// <param name="opt_startValue" type="Object=">If specified, traversal will begin on the
            ///    node with the largest value <= opt_startValue.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.AvlTree";
})(this);
