
/* vsdoc for goog.structs.LinkedMap */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.LinkedMap = function(opt_maxCount, opt_cache){
        /// <summary></summary>
        /// <param name="opt_maxCount" type="number=">The maximum number of objects to store in the
        ///     LinkedMap. If unspecified or 0, there is no maximum.</param>
        /// <param name="opt_cache" type="boolean=">When set, the LinkedMap stores items in order
        ///     from most recently used to least recently used, instead of insertion
        ///     order.</param>
        /// <returns type="goog.structs.LinkedMap"/>
    };

    var $x = window.goog.structs.LinkedMap;
    $x.prototype = {
                
        get: function(key, opt_val) {
            /// <summary>Retrieves the value for a given key. If this is a caching LinkedMap, the
            /// entry will become the most recently used.</summary>
            /// <param name="key" type="string">The key to retrieve the value for.</param>
            /// <param name="opt_val" type="*=">A default value that will be returned if the key is
            ///     not found, defaults to undefined.</param>
            /// <returns type="*">The retrieved value.</returns>
        }, 
        
        peekValue: function(key, opt_val) {
            /// <summary>Retrieves the value for a given key without updating the entry to be the
            /// most recently used.</summary>
            /// <param name="key" type="string">The key to retrieve the value for.</param>
            /// <param name="opt_val" type="*=">A default value that will be returned if the key is
            ///     not found.</param>
            /// <returns type="*">The retrieved value.</returns>
        }, 
        
        set: function(key, value) {
            /// <summary>Sets a value for a given key. If this is a caching LinkedMap, this entry
            /// will become the most recently used.</summary>
            /// <param name="key" type="string">The key to retrieve the value for.</param>
            /// <param name="value" type="*">A default value that will be returned if the key is
            ///     not found.</param>
        }, 
        
        peek: function() {
            /// <summary>Returns the value of the first node without making any modifications.</summary>
            /// <returns type="*">The value of the first node or undefined if the map is empty.</returns>
        }, 
        
        peekLast: function() {
            /// <summary>Returns the value of the last node without making any modifications.</summary>
            /// <returns type="*">The value of the last node or undefined if the map is empty.</returns>
        }, 
        
        shift: function() {
            /// <summary>Removes the first node from the list and returns its value.</summary>
            /// <returns type="*">The value of the popped node, or undefined if the map was empty.</returns>
        }, 
        
        pop: function() {
            /// <summary>Removes the last node from the list and returns its value.</summary>
            /// <returns type="*">The value of the popped node, or undefined if the map was empty.</returns>
        }, 
        
        remove: function(key) {
            /// <summary>Removes a value from the LinkedMap based on its key.</summary>
            /// <param name="key" type="string">The key to remove.</param>
            /// <returns type="boolean">True if the entry was removed, false if the key was not
            ///     found.</returns>
        }, 
        
        removeNode: function(node) {
            /// <summary>Removes a node from the {@code LinkedMap}. It can be overridden to do
            /// further cleanup such as disposing of the node value.</summary>
            /// <param name="node" type="!goog.structs.LinkedMap.Node_">The node to remove.</param>
        }, 
        
        getCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of items currently in the LinkedMap.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the cache is empty, false if it contains any items.</returns>
        }, 
        
        setMaxCount: function(maxCount) {
            /// <summary>Sets the maximum number of entries allowed in this object, truncating any
            /// excess objects if necessary.</summary>
            /// <param name="maxCount" type="number">The new maximum number of entries to allow.</param>
        }, 
        
        getKeys: function() {
            /// <summary></summary>
            /// <returns type="Array.string">The list of the keys in the appropriate order for
            ///     this LinkedMap.</returns>
        }, 
        
        getValues: function() {
            /// <summary></summary>
            /// <returns type="!Array">The list of the values in the appropriate order for
            ///     this LinkedMap.</returns>
        }, 
        
        contains: function(value) {
            /// <summary>Tests whether a provided value is currently in the LinkedMap. This does not
            /// affect item ordering in cache-style LinkedMaps.</summary>
            /// <param name="value" type="Object">The value to check for.</param>
            /// <returns type="boolean">Whether the value is in the LinkedMap.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary>Tests whether a provided key is currently in the LinkedMap. This does not
            /// affect item ordering in cache-style LinkedMaps.</summary>
            /// <param name="key" type="string">The key to check for.</param>
            /// <returns type="boolean">Whether the key is in the LinkedMap.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all entries in this object.</summary>
        }, 
        
        forEach: function(f, opt_obj) {
            /// <summary>Calls a function on each item in the LinkedMap.</summary>
            /// <param name="f" type="Function">The function to call for each item. The function takes
            ///     three arguments: the value, the key, and the LinkedMap.</param>
            /// <param name="opt_obj" type="Object=">The object context to use as &quot;this&quot; for the
            ///     function.</param>
        }, 
        
        map: function(f, opt_obj) {
            /// <summary>Calls a function on each item in the LinkedMap and returns the results of
            /// those calls in an array.</summary>
            /// <param name="f" type="!Function">The function to call for each item. The function takes
            ///     three arguments: the value, the key, and the LinkedMap.</param>
            /// <param name="opt_obj" type="Object=">The object context to use as &quot;this&quot; for the
            ///     function.</param>
            /// <returns type="!Array">The results of the function calls for each item in the
            ///     LinkedMap.</returns>
        }, 
        
        some: function(f, opt_obj) {
            /// <summary>Calls a function on each item in the LinkedMap and returns true if any of
            /// those function calls returns a true-like value.</summary>
            /// <param name="f" type="Function">The function to call for each item. The function takes
            ///     three arguments: the value, the key, and the LinkedMap, and returns a
            ///     boolean.</param>
            /// <param name="opt_obj" type="Object=">The object context to use as &quot;this&quot; for the
            ///     function.</param>
            /// <returns type="boolean">Whether f evaluates to true for at least one item in the
            ///     LinkedMap.</returns>
        }, 
        
        every: function(f, opt_obj) {
            /// <summary>Calls a function on each item in the LinkedMap and returns true only if every
            /// function call returns a true-like value.</summary>
            /// <param name="f" type="Function">The function to call for each item. The function takes
            ///     three arguments: the value, the key, and the Cache, and returns a
            ///     boolean.</param>
            /// <param name="opt_obj" type="Object=">The object context to use as &quot;this&quot; for the
            ///     function.</param>
            /// <returns type="boolean">Whether f evaluates to true for every item in the Cache.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.LinkedMap";
})(this);
