
/* vsdoc for goog.structs.Map */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.Map = function(opt_map, var_args){
        /// <summary></summary>
        /// <param name="opt_map" type="*=">Map or Object to initialize the map with.</param>
        /// <param name="var_args" type="...*">If 2 or more arguments are present then they
        ///     will be used as key-value pairs.</param>
        /// <returns type="goog.structs.Map"/>
    };

    var $x = window.goog.structs.Map;
    $x.prototype = {
                
        getCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of key-value pairs in the map.</returns>
        }, 
        
        getValues: function() {
            /// <summary>Returns the values of the map.</summary>
            /// <returns type="!Array">The values in the map.</returns>
        }, 
        
        getKeys: function() {
            /// <summary>Returns the keys of the map.</summary>
            /// <returns type="!Array.string">Array of string values.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary>Whether the map contains the given key.</summary>
            /// <param name="key" type="*">The key to check for.</param>
            /// <returns type="boolean">Whether the map contains the key.</returns>
        }, 
        
        containsValue: function(val) {
            /// <summary>Whether the map contains the given value. This is O(n).</summary>
            /// <param name="val" type="*">The value to check for.</param>
            /// <returns type="boolean">Whether the map contains the value.</returns>
        }, 
        
        equals: function(otherMap, opt_equalityFn) {
            /// <summary>Whether this map is equal to the argument map.</summary>
            /// <param name="otherMap" type="goog.structs.Map">The map against which to test equality.</param>
            /// <param name="opt_equalityFn" type="function(?|?) : boolean=">Optional equality function
            ///     to test equality of values. If not specified, this will test whether
            ///     the values contained in each map are identical objects.</param>
            /// <returns type="boolean">Whether the maps are equal.</returns>
        }, 
        
        defaultEquals: function(a, b) {
            /// <summary>Default equality test for values.</summary>
            /// <param name="a" type="*">The first value.</param>
            /// <param name="b" type="*">The second value.</param>
            /// <returns type="boolean">Whether a and b reference the same object.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the map is empty.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all key-value pairs from the map.</summary>
        }, 
        
        remove: function(key) {
            /// <summary>Removes a key-value pair based on the key. This is O(logN) amortized due to
            /// updating the keys array whenever the count becomes half the size of the keys
            /// in the keys array.</summary>
            /// <param name="key" type="*">The key to remove.</param>
            /// <returns type="boolean">Whether object was removed.</returns>
        }, 
        
        get: function(key, opt_val) {
            /// <summary>Returns the value for the given key.  If the key is not found and the default
            /// value is not given this will return {@code undefined}.</summary>
            /// <param name="key" type="*">The key to get the value for.</param>
            /// <param name="opt_val" type="*=">The value to return if no item is found for the given
            ///     key, defaults to undefined.</param>
            /// <returns type="*">The value for the given key.</returns>
        }, 
        
        set: function(key, value) {
            /// <summary>Adds a key-value pair to the map.</summary>
            /// <param name="key" type="*">The key.</param>
            /// <param name="value" type="*">The value to add.</param>
            /// <returns type="*">Some subclasses return a value.</returns>
        }, 
        
        addAll: function(map) {
            /// <summary>Adds multiple key-value pairs from another goog.structs.Map or Object.</summary>
            /// <param name="map" type="Object">Object containing the data to add.</param>
        }, 
        
        clone: function() {
            /// <summary>Clones a map and returns a new map.</summary>
            /// <returns type="!goog.structs.Map">A new map with the same key-value pairs.</returns>
        }, 
        
        transpose: function() {
            /// <summary>Returns a new map in which all the keys and values are interchanged
            /// (keys become values and values become keys). If multiple keys map to the
            /// same value, the chosen transposed value is implementation-dependent.
            /// 
            /// It acts very similarly to {goog.object.transpose(Object)}.</summary>
            /// <returns type="!goog.structs.Map">The transposed map.</returns>
        }, 
        
        toObject: function() {
            /// <summary></summary>
            /// <returns type="!Object">Object representation of the map.</returns>
        }, 
        
        getKeyIterator: function() {
            /// <summary>Returns an iterator that iterates over the keys in the map.  Removal of keys
            /// while iterating might have undesired side effects.</summary>
            /// <returns type="!goog.iter.Iterator">An iterator over the keys in the map.</returns>
        }, 
        
        getValueIterator: function() {
            /// <summary>Returns an iterator that iterates over the values in the map.  Removal of
            /// keys while iterating might have undesired side effects.</summary>
            /// <returns type="!goog.iter.Iterator">An iterator over the values in the map.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.Map";
})(this);
