
/* vsdoc for goog.structs.Pool */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.Pool = function(opt_minCount, opt_maxCount){
        /// <summary></summary>
        /// <param name="opt_minCount" type="number=">Min. number of objects (Default: 1).</param>
        /// <param name="opt_maxCount" type="number=">Max. number of objects (Default: 10).</param>
        /// <field name="delay" type="number">The minimum delay between objects being made available, in milliseconds. If
        /// this is 0, no minimum delay is enforced.</field>
        /// <field name="lastAccess" type="number?">The time of the last object being made available, in milliseconds since the
        /// epoch (i.e., the result of Date#toTime). If this is null, no access has
        /// occurred yet.</field>
        /// <returns type="goog.structs.Pool"/>
    };

    var $x = window.goog.structs.Pool;
    $x.prototype = {
                
        setMinimumCount: function(min) {
            /// <summary>Sets the minimum count of the pool.
            /// If min is greater than the max count of the pool, an error is thrown.</summary>
            /// <param name="min" type="number">The minimum count of the pool.</param>
        }, 
        
        setMaximumCount: function(max) {
            /// <summary>Sets the maximum count of the pool.
            /// If max is less than the max count of the pool, an error is thrown.</summary>
            /// <param name="max" type="number">The maximium count of the pool.</param>
        }, 
        
        setDelay: function(delay) {
            /// <summary>Sets the minimum delay between objects being returned by getObject, in
            /// milliseconds. This defaults to zero, meaning that no minimum delay is
            /// enforced and objects may be used as soon as they&apos;re available.</summary>
            /// <param name="delay" type="number">The minimum delay, in milliseconds.</param>
        }, 
        
        getObject: function() {
            /// <summary></summary>
            /// <returns type="Object|undefined">A new object from the pool if there is one
            ///     available, otherwise undefined.</returns>
        }, 
        
        releaseObject: function(obj) {
            /// <summary>Returns an object to the pool of available objects so that it can be reused.</summary>
            /// <param name="obj" type="Object">The object to return to the pool of free objects.</param>
            /// <returns type="boolean">Whether the object was found in the Pool&apos;s set of in-use
            ///     objects (in other words, whether any action was taken).</returns>
        }, 
        
        addFreeObject: function(obj) {
            /// <summary>Adds an object to the collection of objects that are free. If the object can
            /// not be added, then it is disposed.</summary>
            /// <param name="obj" type="Object">The object to add to collection of free objects.</param>
        }, 
        
        adjustForMinMax: function() {
            /// <summary>Adjusts the objects held in the pool to be within the min/max constraints.
            /// 
            /// NOTE: It is possible that the number of objects in the pool will still be
            /// greater than the maximum count of objects allowed. This will be the case
            /// if no more free objects can be disposed of to get below the minimum count
            /// (i.e., all objects are in use).</summary>
        }, 
        
        createObject: function() {
            /// <summary>Should be overriden by sub-classes to return an instance of the object type
            /// that is expected in the pool.</summary>
            /// <returns type="Object">The created object.</returns>
        }, 
        
        disposeObject: function(obj) {
            /// <summary>Should be overriden to dispose of an object. Default implementation is to
            /// remove all its members, which should render it useless. Calls the object&apos;s
            /// {@code dispose()} method, if available.</summary>
            /// <param name="obj" type="Object">The object to dispose.</param>
        }, 
        
        objectCanBeReused: function(obj) {
            /// <summary>Should be overriden to determine whether an object has become unusable and
            /// should not be returned by getObject(). Calls the object&apos;s
            /// {@code canBeReused()}  method, if available.</summary>
            /// <param name="obj" type="Object">The object to test.</param>
            /// <returns type="boolean">Whether the object can be reused.</returns>
        }, 
        
        contains: function(obj) {
            /// <summary>Returns true if the given object is in the pool.</summary>
            /// <param name="obj" type="Object">The object to check the pool for.</param>
            /// <returns type="boolean">Whether the pool contains the object.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Returns the number of objects currently in the pool.</summary>
            /// <returns type="number">Number of objects currently in the pool.</returns>
        }, 
        
        getInUseCount: function() {
            /// <summary>Returns the number of objects currently in use in the pool.</summary>
            /// <returns type="number">Number of objects currently in use in the pool.</returns>
        }, 
        
        getFreeCount: function() {
            /// <summary>Returns the number of objects currently free in the pool.</summary>
            /// <returns type="number">Number of objects currently free in the pool.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary>Determines if the pool contains no objects.</summary>
            /// <returns type="boolean">Whether the pool contains no objects.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the pool and all objects currently held in the pool.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.Pool";
})(this);
