
/* vsdoc for goog.structs.QuadTree */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.QuadTree = function(minX, minY, maxX, maxY){
        /// <summary></summary>
        /// <param name="minX" type="number">Minimum x-value that can be held in tree.</param>
        /// <param name="minY" type="number">Minimum y-value that can be held in tree.</param>
        /// <param name="maxX" type="number">Maximum x-value that can be held in tree.</param>
        /// <param name="maxY" type="number">Maximum y-value that can be held in tree.</param>
        /// <field name="NodeType" type="">Enumeration of node types.</field>
        /// <returns type="goog.structs.QuadTree"/>
    };

    var $x = window.goog.structs.QuadTree;
    $x.prototype = {
                
        getRootNode: function() {
            /// <summary>Returns a reference to the tree&apos;s root node.  Callers shouldn&apos;t modify nodes,
            /// directly.  This is a convenience for visualization and debugging purposes.</summary>
            /// <returns type="goog.structs.QuadTree.Node">The root node.</returns>
        }, 
        
        set: function(x, y, value) {
            /// <summary>Sets the value of an (x, y) point within the quad-tree.</summary>
            /// <param name="x" type="number">The x-coordinate.</param>
            /// <param name="y" type="number">The y-coordinate.</param>
            /// <param name="value" type="*">The value associated with the point.</param>
        }, 
        
        get: function(x, y, opt_default) {
            /// <summary>Gets the value of the point at (x, y) or null if the point is empty.</summary>
            /// <param name="x" type="number">The x-coordinate.</param>
            /// <param name="y" type="number">The y-coordinate.</param>
            /// <param name="opt_default" type="*=">The default value to return if the node doesn&apos;t
            ///     exist.</param>
            /// <returns type="*">The value of the node, the default value if the node
            ///     doesn&apos;t exist, or undefined if the node doesn&apos;t exist and no default
            ///     has been provided.</returns>
        }, 
        
        remove: function(x, y) {
            /// <summary>Removes a point from (x, y) if it exists.</summary>
            /// <param name="x" type="number">The x-coordinate.</param>
            /// <param name="y" type="number">The y-coordinate.</param>
            /// <returns type="*">The value of the node that was removed, or null if the
            ///     node doesn&apos;t exist.</returns>
        }, 
        
        contains: function(x, y) {
            /// <summary>Returns true if the point at (x, y) exists in the tree.</summary>
            /// <param name="x" type="number">The x-coordinate.</param>
            /// <param name="y" type="number">The y-coordinate.</param>
            /// <returns type="boolean">Whether the tree contains a point at (x, y).</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the tree is empty.</returns>
        }, 
        
        getCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of items in the tree.</returns>
        }, 
        
        clear: function() {
            /// <summary>Removes all items from the tree.</summary>
        }, 
        
        getKeys: function() {
            /// <summary>Returns an array containing the coordinates of each point stored in the tree.</summary>
            /// <returns type="Array.goog.math.Coordinate?">Array of coordinates.</returns>
        }, 
        
        getValues: function() {
            /// <summary>Returns an array containing all values stored within the tree.</summary>
            /// <returns type="Array.Object">The values stored within the tree.</returns>
        }, 
        
        clone: function() {
            /// <summary>Clones the quad-tree and returns the new instance.</summary>
            /// <returns type="goog.structs.QuadTree">A clone of the tree.</returns>
        }, 
        
        forEach: function(fn, opt_obj) {
            /// <summary>Traverses the tree and calls a function on each node.</summary>
            /// <param name="fn" type="function(?|goog.math.Coordinate|goog.structs.QuadTree)">The function to call for every value. This function takes 3 arguments
            ///     (the value, the coordinate, and the tree itself) and the return value is
            ///     irrelevant.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@ code fn}.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.QuadTree";
})(this);
