
/* vsdoc for goog.structs.SimplePool */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.SimplePool = function(initialCount, maxCount){
        /// <summary></summary>
        /// <param name="initialCount" type="number">Initial number of objects to populate the
        ///     free pool at construction time.</param>
        /// <param name="maxCount" type="number">Maximum number of objects to keep in the free pool.</param>
        /// <returns type="goog.structs.SimplePool"/>
    };

    var $x = window.goog.structs.SimplePool;
    $x.prototype = {
                
        setCreateObjectFn: function(createObjectFn) {
            /// <summary>Sets the {@code createObject} function which is used for creating a new
            /// object in the pool.</summary>
            /// <param name="createObjectFn" type="Function">Create object function which returns the
            ///     newly createrd object.</param>
        }, 
        
        setDisposeObjectFn: function(disposeObjectFn) {
            /// <summary>Sets the {@code disposeObject} function which is used for disposing of an
            /// object in the pool.</summary>
            /// <param name="disposeObjectFn" type="Function">Dispose object function which takes the
            ///     object to dispose as a parameter.</param>
        }, 
        
        getObject: function() {
            /// <summary>Gets an unused object from the the pool, if there is one available,
            /// otherwise creates a new one.</summary>
            /// <returns type="*">An object from the pool or a new one if necessary.</returns>
        }, 
        
        releaseObject: function(obj) {
            /// <summary>Returns an object to the pool so that it can be reused. If the pool is
            /// already full, the object is disposed instead.</summary>
            /// <param name="obj" type="*">The object to release.</param>
        }, 
        
        createObject: function() {
            /// <summary>Should be overriden by sub-classes to return an instance of the object type
            /// that is expected in the pool.</summary>
            /// <returns type="*">The created object.</returns>
        }, 
        
        disposeObject: function(obj) {
            /// <summary>Should be overriden to dispose of an object. Default implementation is to
            /// remove all of the object&apos;s members, which should render it useless. Calls the
            ///  object&apos;s dispose method, if available.</summary>
            /// <param name="obj" type="*">The object to dispose.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the pool and all objects currently held in the pool.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.SimplePool";
})(this);
