
/* vsdoc for goog.structs.StringSet */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.StringSet = function(opt_elements){
        /// <summary></summary>
        /// <param name="opt_elements" type="!Array=">Elements to add to the set. The non-string
        ///     items will be converted to strings, so 15 and &apos;15&apos; will mean the same.</param>
        /// <returns type="goog.structs.StringSet"/>
    };

    var $x = window.goog.structs.StringSet;
    $x.prototype = {
                
        encode: function(element) {
            /// <summary>The &apos;__proto__&apos; and the &apos;__count__&apos; keys aren&apos;t enumerable in Firefox, and
            /// &apos;toString&apos;, &apos;valueOf&apos;, &apos;constructor&apos;, etc. aren&apos;t enumerable in IE so they
            /// have to be escaped before they are added to the internal object.
            /// NOTE: When a new set is created, 50-80% of the CPU time is spent in encode.</summary>
            /// <param name="element" type="*">The element to escape.</param>
            /// <returns type="*">The escaped element or the element itself if it doesn&apos;t have to
            ///     be escaped.</returns>
        }, 
        
        decode: function(key) {
            /// <summary>Inverse function of {@link #encode}.
            /// NOTE: forEach would be 30% faster in FF if the compiler inlined decode.</summary>
            /// <param name="key" type="string">The escaped element used as the key of the internal
            ///     object.</param>
            /// <returns type="string">The unescaped element.</returns>
        }, 
        
        add: function(element) {
            /// <summary>Adds a single element to the set.</summary>
            /// <param name="element" type="*">The element to add. It will be converted to string.</param>
        }, 
        
        addArray: function(arr) {
            /// <summary>Adds a the elements of an array to this set.</summary>
            /// <param name="arr" type="!Array">The array to add the elements of.</param>
        }, 
        
        addSet: function(stringSet) {
            /// <summary>Adds a the elements of a set to this set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The set to add the elements of.</param>
        }, 
        
        clear: function() {
            /// <summary>Removes all elements of the set.</summary>
        }, 
        
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.structs.StringSet">Clone of the set.</returns>
        }, 
        
        contains: function(element) {
            /// <summary>Tells if the set contains the given element.</summary>
            /// <param name="element" type="*">The element to check.</param>
            /// <returns type="boolean">Whether it is in the set.</returns>
        }, 
        
        containsArray: function(arr) {
            /// <summary>Tells if the set contains all elements of the array.</summary>
            /// <param name="arr" type="!Array">The elements to check.</param>
            /// <returns type="boolean">Whether they are in the set.</returns>
        }, 
        
        equals: function(stringSet) {
            /// <summary>Tells if this set has the same elements as the given set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The other set.</param>
            /// <returns type="boolean">Whether they have the same elements.</returns>
        }, 
        
        forEach: function(f, opt_obj) {
            /// <summary>Calls a function for each element in the set.</summary>
            /// <param name="f" type="function(string|undefined|!goog.structs.StringSet)">The function
            ///     to call for every element. It takes the element, undefined (because sets
            ///     have no notion of keys), and the set.</param>
            /// <param name="opt_obj" type="Object=">The object to be used as the value of &apos;this&apos;
            ///     within {@code f}.</param>
        }, 
        
        getCount: function() {
            /// <summary>Counts the number of elements in the set in linear time.
            /// NOTE: getCount is always called at most once per set instance in google3.
            /// If this usage pattern won&apos;t change, the linear getCount implementation is
            /// better, because
            /// &lt;li&gt;populating a set and getting the number of elements in it takes the same
            /// amount of time as keeping a count_ member up to date and getting its value;
            /// &lt;li&gt;if getCount is not called, adding and removing elements have no overhead.</summary>
            /// <returns type="number">The number of elements in the set.</returns>
        }, 
        
        getDifference: function(stringSet) {
            /// <summary>Calculates the difference of two sets.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The set to subtract from this set.</param>
            /// <returns type="!goog.structs.StringSet">{@code this} minus {@code stringSet}.</returns>
        }, 
        
        getIntersection: function(stringSet) {
            /// <summary>Calculates the intersection of this set with another set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The set to take the intersection
            ///     with.</param>
            /// <returns type="!goog.structs.StringSet">A new set with the common elements.</returns>
        }, 
        
        getSymmetricDifference: function(stringSet) {
            /// <summary>Calculates the symmetric difference of two sets.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The other set.</param>
            /// <returns type="!goog.structs.StringSet">A new set with the elements in exactly one
            ///     of {@code this} and {@code stringSet}.</returns>
        }, 
        
        getUnion: function(stringSet) {
            /// <summary>Calculates the union of this set and another set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The set to take the union with.</param>
            /// <returns type="!goog.structs.StringSet">A new set with the union of elements.</returns>
        }, 
        
        getValues: function() {
            /// <summary></summary>
            /// <returns type="!Array.string">The elements of the set.</returns>
        }, 
        
        isDisjoint: function(stringSet) {
            /// <summary>Tells if this set and the given set are disjoint.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The other set.</param>
            /// <returns type="boolean">True iff they don&apos;t have common elements.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the set is empty.</returns>
        }, 
        
        isSubsetOf: function(stringSet) {
            /// <summary>Tells if this set is the subset of the given set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The other set.</param>
            /// <returns type="boolean">Whether this set if the subset of that.</returns>
        }, 
        
        isSupersetOf: function(stringSet) {
            /// <summary>Tells if this set is the superset of the given set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The other set.</param>
            /// <returns type="boolean">Whether this set if the superset of that.</returns>
        }, 
        
        remove: function(element) {
            /// <summary>Removes a single element from the set.</summary>
            /// <param name="element" type="*">The element to remove.</param>
            /// <returns type="boolean">Whether the element was in the set.</returns>
        }, 
        
        removeArray: function(arr) {
            /// <summary>Removes all elements of the given array from this set.</summary>
            /// <param name="arr" type="!Array">The elements to remove.</param>
        }, 
        
        removeSet: function(stringSet) {
            /// <summary>Removes all elements of the given set from this set.</summary>
            /// <param name="stringSet" type="!goog.structs.StringSet">The set of elements to remove.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.StringSet";
})(this);
