
/* vsdoc for goog.structs.TreeNode */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.TreeNode = function(key, value){
        /// <summary></summary>
        /// <param name="key" type="*">Key.</param>
        /// <param name="value" type="*">Value.</param>
        /// <returns type="goog.structs.TreeNode"/>
    };

    var $x = window.goog.structs.TreeNode;
    $x.prototype = {
                
        clone: function() {
            /// <summary></summary>
            /// <returns type="!goog.structs.TreeNode">Clone of the tree node without its parent
            ///     and child nodes. The key and the value are copied by reference.</returns>
        }, 
        
        deepClone: function() {
            /// <summary></summary>
            /// <returns type="!goog.structs.TreeNode">Clone of the subtree with this node as root.</returns>
        }, 
        
        getParent: function() {
            /// <summary></summary>
            /// <returns type="goog.structs.TreeNode">Parent node or null if it has no parent.</returns>
        }, 
        
        isLeaf: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the node is a leaf node.</returns>
        }, 
        
        isLastChild: function() {
            /// <summary>Tells if the node is the last child of its parent. This method helps how to
            /// connect the tree nodes with lines: L shapes should be used before the last
            /// children and |- shapes before the rest. Schematic tree visualization:
            /// 
            /// &lt;pre&gt;
            /// Node1
            /// |-Node2
            /// | L-Node3
            /// |   |-Node4
            /// |   L-Node5
            /// L-Node6
            /// &lt;/pre&gt;</summary>
            /// <returns type="boolean">Whether the node has parent and is the last child of it.</returns>
        }, 
        
        getChildren: function() {
            /// <summary></summary>
            /// <returns type="!Array.!goog.structs.TreeNode">Immutable child nodes.</returns>
        }, 
        
        getChildAt: function(index) {
            /// <summary>Gets the child node of this node at the given index.</summary>
            /// <param name="index" type="number">Child index.</param>
            /// <returns type="goog.structs.TreeNode">The node at the given index or null if not
            ///     found.</returns>
        }, 
        
        getChildCount: function() {
            /// <summary></summary>
            /// <returns type="number">The number of children.</returns>
        }, 
        
        getDepth: function() {
            /// <summary></summary>
            /// <returns type="number">The number of ancestors of the node.</returns>
        }, 
        
        getAncestors: function() {
            /// <summary></summary>
            /// <returns type="!Array.!goog.structs.TreeNode">All ancestor nodes in bottom-up
            ///     order.</returns>
        }, 
        
        getRoot: function() {
            /// <summary></summary>
            /// <returns type="!goog.structs.TreeNode">The root of the tree structure, i.e. the
            ///     farthest ancestor of the node or the node itself if it has no parents.</returns>
        }, 
        
        getSubtreeKeys: function() {
            /// <summary>Builds a nested array structure from the node keys in this node&apos;s subtree to
            /// facilitate testing tree operations that change the hierarchy.</summary>
            /// <returns type="!Array">The structure of this node&apos;s descendants as nested array
            ///     of node keys. The number of unclosed opening brackets up to a particular
            ///     node is proportional to the indentation of that node in the graphical
            ///     representation of the tree. Example:
            ///     &lt;pre&gt;
            ///       this
            ///       |- child1
            ///       |  L- grandchild
            ///       L- child2
            ///     &lt;/pre&gt;
            ///     is represented as [&apos;child1&apos;, [&apos;grandchild&apos;], &apos;child2&apos;].</returns>
        }, 
        
        contains: function(node) {
            /// <summary>Tells whether this node is the ancestor of the given node.</summary>
            /// <param name="node" type="!goog.structs.TreeNode">A node.</param>
            /// <returns type="boolean">Whether this node is the ancestor of {@code node}.</returns>
        }, 
        
        findCommonAncestor: function(var_args) {
            /// <summary>Finds the deepest common ancestor of the given nodes. The concept of
            /// ancestor is not strict in this case, it includes the node itself.</summary>
            /// <param name="var_args" type="...!goog.structs.TreeNode">The nodes.</param>
            /// <returns type="goog.structs.TreeNode">The common ancestor of the nodes or null if
            ///     they are from different trees.</returns>
        }, 
        
        forEachChild: function(f, opt_this) {
            /// <summary>Traverses all child nodes.</summary>
            /// <param name="f" type="function(!goog.structs.TreeNode|number|!Array.!goog.structs.TreeNode)">Callback function. It takes the
            ///     node, its index and the array of all child nodes as arguments.</param>
            /// <param name="opt_this" type="Object=">The object to be used as the value of {@code this}
            ///     within {@code f}.</param>
        }, 
        
        forEachDescendant: function(f, opt_this) {
            /// <summary>Traverses all child nodes recursively in preorder.</summary>
            /// <param name="f" type="function(!goog.structs.TreeNode)">Callback function. It takes the
            ///     node as argument.</param>
            /// <param name="opt_this" type="Object=">The object to be used as the value of {@code this}
            ///     within {@code f}.</param>
        }, 
        
        traverse: function(f, opt_this) {
            /// <summary>Traverses the subtree with the possibility to skip branches. Starts with
            /// this node, and visits the descendant nodes depth-first, in preorder.</summary>
            /// <param name="f" type="function(!goog.structs.TreeNode): (boolean|undefined)">Callback
            ///     function. It takes the node as argument. The children of this node will
            ///     be visited if the callback returns true or undefined, and will be
            ///     skipped if the callback returns false.</param>
            /// <param name="opt_this" type="Object=">The object to be used as the value of {@code this}
            ///     within {@code f}.</param>
        }, 
        
        setParent: function(parent) {
            /// <summary>Sets the parent node of this node. The callers must ensure that the parent
            /// node and only that has this node among its children.</summary>
            /// <param name="parent" type="goog.structs.TreeNode">The parent to set. If null, the node
            ///     will be detached from the tree.</param>
        }, 
        
        addChild: function(child) {
            /// <summary>Appends a child node to this node.</summary>
            /// <param name="child" type="!goog.structs.TreeNode">Orphan child node.</param>
        }, 
        
        addChildAt: function(child, index) {
            /// <summary>Inserts a child node at the given index.</summary>
            /// <param name="child" type="!goog.structs.TreeNode">Orphan child node.</param>
            /// <param name="index" type="number">The position to insert at.</param>
        }, 
        
        replaceChildAt: function(newChild, index) {
            /// <summary>Replaces a child node at the given index.</summary>
            /// <param name="newChild" type="!goog.structs.TreeNode">Child node to set. It must not have
            ///     parent node.</param>
            /// <param name="index" type="number">Valid index of the old child to replace.</param>
            /// <returns type="!goog.structs.TreeNode">The original child node, detached from its
            ///     parent.</returns>
        }, 
        
        replaceChild: function(newChild, oldChild) {
            /// <summary>Replaces the given child node.</summary>
            /// <param name="newChild" type="!goog.structs.TreeNode">New node to replace
            ///     {@code oldChild}. It must not have parent node.</param>
            /// <param name="oldChild" type="!goog.structs.TreeNode">Existing child node to be replaced.</param>
            /// <returns type="!goog.structs.TreeNode">The replaced child node detached from its
            ///     parent.</returns>
        }, 
        
        removeChildAt: function(index) {
            /// <summary>Removes the child node at the given index.</summary>
            /// <param name="index" type="number">The position to remove from.</param>
            /// <returns type="goog.structs.TreeNode">The removed node if any.</returns>
        }, 
        
        removeChild: function(child) {
            /// <summary>Removes the given child node of this node.</summary>
            /// <param name="child" type="goog.structs.TreeNode">The node to remove.</param>
            /// <returns type="goog.structs.TreeNode">The removed node if any.</returns>
        }, 
        
        removeChildren: function() {
            /// <summary>Removes all child nodes of this node.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.TreeNode";
})(this);
