
/* vsdoc for goog.structs.Trie */

(function (window) {
    window.goog.structs = window.goog.structs || {};

    window.goog.structs.Trie = function(opt_trie){
        /// <summary></summary>
        /// <param name="opt_trie" type="Object=">Optional goog.structs.Trie or Object to initialize
        ///    trie with.</param>
        /// <returns type="goog.structs.Trie"/>
    };

    var $x = window.goog.structs.Trie;
    $x.prototype = {
                
        set: function(key, value) {
            /// <summary>Sets the given key/value pair in the trie.  O(L), where L is the length
            /// of the key.</summary>
            /// <param name="key" type="string">The key.</param>
            /// <param name="value" type="*">The value.</param>
        }, 
        
        add: function(key, value) {
            /// <summary>Adds the given key/value pair in the trie.  Throw an exception if the key
            /// already exists in the trie.  O(L), where L is the length of the key.</summary>
            /// <param name="key" type="string">The key.</param>
            /// <param name="value" type="*">The value.</param>
        }, 
        
        setAll: function(trie) {
            /// <summary>Adds multiple key/value pairs from another goog.structs.Trie or Object.
            /// O(N) where N is the number of nodes in the trie.</summary>
            /// <param name="trie" type="Object|goog.structs.Trie">Object containing the data to add.</param>
        }, 
        
        get: function(key) {
            /// <summary>Retrieves a value from the trie given a key.  O(L), where L is the length of
            /// the key.</summary>
            /// <param name="key" type="string">The key to retrieve from the trie.</param>
            /// <returns type="*">The value of the key in the trie, or undefined if the trie does
            ///     not contain this key.</returns>
        }, 
        
        getKeyAndPrefixes: function(key, opt_keyStartIndex) {
            /// <summary>Retrieves all values from the trie that correspond to prefixes of the given
            /// input key. O(L), where L is the length of the key.</summary>
            /// <param name="key" type="string">The key to use for lookup. The given key as well as all
            ///     prefixes of the key are retrieved.</param>
            /// <param name="opt_keyStartIndex" type="?number=">Optional position in key to start lookup
            ///     from. Defaults to 0 if not specified.</param>
            /// <returns type="Object">Map of end index of matching prefixes and corresponding
            ///     values. Empty if no match found.</returns>
        }, 
        
        getValues: function() {
            /// <summary>Gets the values of the trie.  Not returned in any reliable order.  O(N) where
            /// N is the number of nodes in the trie.  Calls getValuesInternal_.</summary>
            /// <returns type="Array">The values in the trie.</returns>
        }, 
        
        getKeys: function(opt_prefix) {
            /// <summary>Gets the keys of the trie.  Not returned in any reliable order.  O(N) where
            /// N is the number of nodes in the trie (or prefix subtree).</summary>
            /// <param name="opt_prefix" type="string=">Find only keys with this optional prefix.</param>
            /// <returns type="Array">The keys in the trie.</returns>
        }, 
        
        containsKey: function(key) {
            /// <summary>Checks to see if a certain key is in the trie.  O(L), where L is the length
            /// of the key.</summary>
            /// <param name="key" type="string">A key that may be in the trie.</param>
            /// <returns type="boolean">Whether the trie contains key.</returns>
        }, 
        
        containsValue: function(value) {
            /// <summary>Checks to see if a certain value is in the trie.  Worst case is O(N) where
            /// N is the number of nodes in the trie.</summary>
            /// <param name="value" type="*">A value that may be in the trie.</param>
            /// <returns type="boolean">Whether the trie contains the value.</returns>
        }, 
        
        clear: function() {
            /// <summary>Completely empties a trie of all keys and values.  ~O(1)</summary>
        }, 
        
        remove: function(key) {
            /// <summary>Removes a key from the trie or throws an exception if the key is not in the
            /// trie.  O(L), where L is the length of the key.</summary>
            /// <param name="key" type="string">A key that should be removed from the trie.</param>
            /// <returns type="*">The value whose key was removed.</returns>
        }, 
        
        clone: function() {
            /// <summary>Clones a trie and returns a new trie.  O(N), where N is the number of nodes
            /// in the trie.</summary>
            /// <returns type="goog.structs.Trie">A new goog.structs.Trie with the same key value
            ///     pairs.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Returns the number of key value pairs in the trie.  O(N), where N is the
            /// number of nodes in the trie.
            /// TODO: This could be optimized by storing a weight (count below) in every
            /// node.</summary>
            /// <returns type="number">The number of pairs.</returns>
        }, 
        
        isEmpty: function() {
            /// <summary>Returns true if this trie contains no elements.  ~O(1).</summary>
            /// <returns type="boolean">True iff this trie contains no elements.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.structs.Trie";
})(this);
