
/* vsdoc for goog.style */

(function (window) {
    window.goog = window.goog || {};

    window.goog.style = {
        /// <summary></summary>
        /// <field name="bidi" type=""></field>
        /// <field name="cursor" type=""></field>
        /// <field name="transition" type=""></field>
        /// <returns type="goog.style"/>
                
        setStyle: function(element, style, opt_value) {
            /// <summary>Sets a style value on an element.
            /// 
            /// This function is not indended to patch issues in the browser&apos;s style
            /// handling, but to allow easy programmatic access to setting dash-separated
            /// style properties.  An example is setting a batch of properties from a data
            /// object without overwriting old styles.  When possible, use native APIs:
            /// elem.style.propertyKey = &apos;value&apos; or (if obliterating old styles is fine)
            /// elem.style.cssText = &apos;property1: value1; property2: value2&apos;.</summary>
            /// <param name="element" type="Element">The element to change.</param>
            /// <param name="style" type="string|Object">If a string, a style name. If an object, a hash
            ///     of style names to style values.</param>
            /// <param name="opt_value" type="string|number|boolean=">If style was a string, then this
            ///     should be the value.</param>
        }, 
        
        getStyle: function(element, property) {
            /// <summary>Retrieves an explicitly-set style value of a node. This returns &apos;&apos; if there
            /// isn&apos;t a style attribute on the element or if this style property has not been
            /// explicitly set in script.</summary>
            /// <param name="element" type="Element">Element to get style of.</param>
            /// <param name="property" type="string">Property to get, css-style (if you have a camel-case
            /// property, use element.style[style]).</param>
            /// <returns type="string">Style value.</returns>
        }, 
        
        getComputedStyle: function(element, property) {
            /// <summary>Retrieves a computed style value of a node. It returns empty string if the
            /// value cannot be computed (which will be the case in Internet Explorer) or
            /// &quot;none&quot; if the property requested is an SVG one and it has not been
            /// explicitly set (firefox and webkit).</summary>
            /// <param name="element" type="Element">Element to get style of.</param>
            /// <param name="property" type="string">Property to get (camel-case).</param>
            /// <returns type="string">Style value.</returns>
        }, 
        
        getCascadedStyle: function(element, style) {
            /// <summary>Gets the cascaded style value of a node, or null if the value cannot be
            /// computed (only Internet Explorer can do this).</summary>
            /// <param name="element" type="Element">Element to get style of.</param>
            /// <param name="style" type="string">Property to get (camel-case).</param>
            /// <returns type="string">Style value.</returns>
        }, 
        
        getComputedPosition: function(element) {
            /// <summary>Retrieves the computed value of the position CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the position of.</param>
            /// <returns type="string">Position value.</returns>
        }, 
        
        getBackgroundColor: function(element) {
            /// <summary>Retrieves the computed background color string for a given element. The
            /// string returned is suitable for assigning to another element&apos;s
            /// background-color, but is not guaranteed to be in any particular string
            /// format. Accessing the color in a numeric form may not be possible in all
            /// browsers or with all input.
            /// 
            /// If the background color for the element is defined as a hexadecimal value,
            /// the resulting string can be parsed by goog.color.parse in all supported
            /// browsers.
            /// 
            /// Whether named colors like &quot;red&quot; or &quot;lightblue&quot; get translated into a
            /// format which can be parsed is browser dependent. Calling this function on
            /// transparent elements will return &quot;transparent&quot; in most browsers or
            /// &quot;rgba(0, 0, 0, 0)&quot; in WebKit.</summary>
            /// <param name="element" type="Element">The element to get the background color of.</param>
            /// <returns type="string">The computed string value of the background color.</returns>
        }, 
        
        getComputedOverflowX: function(element) {
            /// <summary>Retrieves the computed value of the overflow-x CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the overflow-x of.</param>
            /// <returns type="string">The computed string value of the overflow-x attribute.</returns>
        }, 
        
        getComputedOverflowY: function(element) {
            /// <summary>Retrieves the computed value of the overflow-y CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the overflow-y of.</param>
            /// <returns type="string">The computed string value of the overflow-y attribute.</returns>
        }, 
        
        getComputedZIndex: function(element) {
            /// <summary>Retrieves the computed value of the z-index CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the z-index of.</param>
            /// <returns type="string|number">The computed value of the z-index attribute.</returns>
        }, 
        
        getComputedTextAlign: function(element) {
            /// <summary>Retrieves the computed value of the text-align CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the text-align of.</param>
            /// <returns type="string">The computed string value of the text-align attribute.</returns>
        }, 
        
        getComputedCursor: function(element) {
            /// <summary>Retrieves the computed value of the cursor CSS attribute.</summary>
            /// <param name="element" type="Element">The element to get the cursor of.</param>
            /// <returns type="string">The computed string value of the cursor attribute.</returns>
        }, 
        
        setPosition: function(el, arg1, opt_arg2) {
            /// <summary>Sets the top/left values of an element.  If no unit is specified in the
            /// argument then it will add px. The second argument is required if the first
            /// argument is a string or number and is ignored if the first argument
            /// is a coordinate.</summary>
            /// <param name="el" type="Element">Element to move.</param>
            /// <param name="arg1" type="string|number|goog.math.Coordinate">Left position or coordinate.</param>
            /// <param name="opt_arg2" type="string|number=">Top position.</param>
        }, 
        
        getPosition: function(element) {
            /// <summary>Gets the offsetLeft and offsetTop properties of an element and returns them
            /// in a Coordinate object</summary>
            /// <param name="element" type="Element">Element.</param>
            /// <returns type="!goog.math.Coordinate">The position.</returns>
        }, 
        
        getClientViewportElement: function(opt_node) {
            /// <summary>Returns the viewport element for a particular document</summary>
            /// <param name="opt_node" type="Node=">DOM node (Document is OK) to get the viewport element
            ///     of.</param>
            /// <returns type="Element">document.documentElement or document.body.</returns>
        }, 
        
        getViewportPageOffset: function(doc) {
            /// <summary>Calculates the viewport coordinates relative to the page/document
            /// containing the node. The viewport may be the browser viewport for
            /// non-iframe document, or the iframe container for iframe&apos;d document.</summary>
            /// <param name="doc" type="!Document">The document to use as the reference point.</param>
            /// <returns type="!goog.math.Coordinate">The page offset of the viewport.</returns>
        }, 
        
        getOffsetParent: function(element) {
            /// <summary>Returns the first parent that could affect the position of a given element.</summary>
            /// <param name="element" type="Element">The element to get the offset parent for.</param>
            /// <returns type="Element">The first offset parent or null if one cannot be found.</returns>
        }, 
        
        getVisibleRectForElement: function(element) {
            /// <summary>Calculates and returns the visible rectangle for a given element. Returns a
            /// box describing the visible portion of the nearest scrollable offset ancestor.
            /// Coordinates are given relative to the document.</summary>
            /// <param name="element" type="Element">Element to get the visible rect for.</param>
            /// <returns type="goog.math.Box">Bounding elementBox describing the visible rect or
            ///     null if scrollable ancestor isn&apos;t inside the visible viewport.</returns>
        }, 
        
        getContainerOffsetToScrollInto: function(element, container, opt_center) {
            /// <summary>Calculate the scroll position of {@code container} with the minimum amount so
            /// that the content and the borders of the given {@code element} become visible.
            /// If the element is bigger than the container, its top left corner will be
            /// aligned as close to the container&apos;s top left corner as possible.</summary>
            /// <param name="element" type="Element">The element to make visible.</param>
            /// <param name="container" type="Element">The container to scroll.</param>
            /// <param name="opt_center" type="boolean=">Whether to center the element in the container.
            ///     Defaults to false.</param>
            /// <returns type="!goog.math.Coordinate">The new scroll position of the container,
            ///     in form of goog.math.Coordinate(scrollLeft, scrollTop).</returns>
        }, 
        
        scrollIntoContainerView: function(element, container, opt_center) {
            /// <summary>Changes the scroll position of {@code container} with the minimum amount so
            /// that the content and the borders of the given {@code element} become visible.
            /// If the element is bigger than the container, its top left corner will be
            /// aligned as close to the container&apos;s top left corner as possible.</summary>
            /// <param name="element" type="Element">The element to make visible.</param>
            /// <param name="container" type="Element">The container to scroll.</param>
            /// <param name="opt_center" type="boolean=">Whether to center the element in the container.
            ///     Defaults to false.</param>
        }, 
        
        getClientLeftTop: function(el) {
            /// <summary>Returns clientLeft (width of the left border and, if the directionality is
            /// right to left, the vertical scrollbar) and clientTop as a coordinate object.</summary>
            /// <param name="el" type="Element">Element to get clientLeft for.</param>
            /// <returns type="!goog.math.Coordinate">Client left and top.</returns>
        }, 
        
        getPageOffset: function(el) {
            /// <summary>Returns a Coordinate object relative to the top-left of the HTML document.
            /// Implemented as a single function to save having to do two recursive loops in
            /// opera and safari just to get both coordinates.  If you just want one value do
            /// use goog.style.getPageOffsetLeft() and goog.style.getPageOffsetTop(), but
            /// note if you call both those methods the tree will be analysed twice.</summary>
            /// <param name="el" type="Element">Element to get the page offset for.</param>
            /// <returns type="!goog.math.Coordinate">The page offset.</returns>
        }, 
        
        getPageOffsetLeft: function(el) {
            /// <summary>Returns the left coordinate of an element relative to the HTML document</summary>
            /// <param name="el" type="Element">Elements.</param>
            /// <returns type="number">The left coordinate.</returns>
        }, 
        
        getPageOffsetTop: function(el) {
            /// <summary>Returns the top coordinate of an element relative to the HTML document</summary>
            /// <param name="el" type="Element">Elements.</param>
            /// <returns type="number">The top coordinate.</returns>
        }, 
        
        getFramedPageOffset: function(el, relativeWin) {
            /// <summary>Returns a Coordinate object relative to the top-left of an HTML document
            /// in an ancestor frame of this element. Used for measuring the position of
            /// an element inside a frame relative to a containing frame.</summary>
            /// <param name="el" type="Element">Element to get the page offset for.</param>
            /// <param name="relativeWin" type="Window">The window to measure relative to. If relativeWin
            ///     is not in the ancestor frame chain of the element, we measure relative to
            ///     the top-most window.</param>
            /// <returns type="!goog.math.Coordinate">The page offset.</returns>
        }, 
        
        translateRectForAnotherFrame: function(rect, origBase, newBase) {
            /// <summary>Translates the specified rect relative to origBase page, for newBase page.
            /// If origBase and newBase are the same, this function does nothing.</summary>
            /// <param name="rect" type="goog.math.Rect">The source rectangle relative to origBase page,
            ///     and it will have the translated result.</param>
            /// <param name="origBase" type="goog.dom.DomHelper">The DomHelper for the input rectangle.</param>
            /// <param name="newBase" type="goog.dom.DomHelper">The DomHelper for the resultant
            ///     coordinate.  This must be a DOM for an ancestor frame of origBase
            ///     or the same as origBase.</param>
        }, 
        
        getRelativePosition: function(a, b) {
            /// <summary>Returns the position of an element relative to another element in the
            /// document.  A relative to B</summary>
            /// <param name="a" type="Element|Event|goog.events.Event">Element or mouse event whose
            ///     position we&apos;re calculating.</param>
            /// <param name="b" type="Element|Event|goog.events.Event">Element or mouse event position
            ///     is relative to.</param>
            /// <returns type="!goog.math.Coordinate">The relative position.</returns>
        }, 
        
        getClientPosition: function(el) {
            /// <summary>Returns the position of the event or the element&apos;s border box relative to
            /// the client viewport.</summary>
            /// <param name="el" type="Element|Event|goog.events.Event">Element or a mouse / touch event.</param>
            /// <returns type="!goog.math.Coordinate">The position.</returns>
        }, 
        
        setPageOffset: function(el, x, opt_y) {
            /// <summary>Moves an element to the given coordinates relative to the client viewport.</summary>
            /// <param name="el" type="Element">Absolutely positioned element to set page offset for.
            ///     It must be in the document.</param>
            /// <param name="x" type="number|goog.math.Coordinate">Left position of the element&apos;s margin
            ///     box or a coordinate object.</param>
            /// <param name="opt_y" type="number=">Top position of the element&apos;s margin box.</param>
        }, 
        
        setSize: function(element, w, opt_h) {
            /// <summary>Sets the width/height values of an element.  If an argument is numeric,
            /// or a goog.math.Size is passed, it is assumed to be pixels and will add
            /// &apos;px&apos; after converting it to an integer in string form. (This just sets the
            /// CSS width and height properties so it might set content-box or border-box
            /// size depending on the box model the browser is using.)</summary>
            /// <param name="element" type="Element">Element to set the size of.</param>
            /// <param name="w" type="string|number|goog.math.Size">Width of the element, or a
            ///     size object.</param>
            /// <param name="opt_h" type="string|number=">Height of the element. Required if w is not a
            ///     size object.</param>
        }, 
        
        setHeight: function(element, height) {
            /// <summary>Set the height of an element.  Sets the element&apos;s style property.</summary>
            /// <param name="element" type="Element">Element to set the height of.</param>
            /// <param name="height" type="string|number">The height value to set.  If a number, &apos;px&apos;
            ///     will be appended, otherwise the value will be applied directly.</param>
        }, 
        
        setWidth: function(element, width) {
            /// <summary>Set the width of an element.  Sets the element&apos;s style property.</summary>
            /// <param name="element" type="Element">Element to set the width of.</param>
            /// <param name="width" type="string|number">The width value to set.  If a number, &apos;px&apos;
            ///     will be appended, otherwise the value will be applied directly.</param>
        }, 
        
        getSize: function(element) {
            /// <summary>Gets the height and width of an element, even if its display is none.
            /// Specifically, this returns the height and width of the border box,
            /// irrespective of the box model in effect.</summary>
            /// <param name="element" type="Element">Element to get size of.</param>
            /// <returns type="!goog.math.Size">Object with width/height properties.</returns>
        }, 
        
        getBounds: function(element) {
            /// <summary>Returns a bounding rectangle for a given element in page space.</summary>
            /// <param name="element" type="Element">Element to get bounds of. Must not be display none.</param>
            /// <returns type="!goog.math.Rect">Bounding rectangle for the element.</returns>
        }, 
        
        toCamelCase: function(selector) {
            /// <summary>Converts a CSS selector in the form style-property to styleProperty.</summary>
            /// <param name="selector" type="*">CSS Selector.</param>
            /// <returns type="string">Camel case selector.</returns>
        }, 
        
        toSelectorCase: function(selector) {
            /// <summary>Converts a CSS selector in the form styleProperty to style-property.</summary>
            /// <param name="selector" type="string">Camel case selector.</param>
            /// <returns type="string">Selector cased.</returns>
        }, 
        
        getOpacity: function(el) {
            /// <summary>Gets the opacity of a node (x-browser). This gets the inline style opacity
            /// of the node, and does not take into account the cascaded or the computed
            /// style for this node.</summary>
            /// <param name="el" type="Element">Element whose opacity has to be found.</param>
            /// <returns type="number|string">Opacity between 0 and 1 or an empty string {@code &apos;&apos;}
            ///     if the opacity is not set.</returns>
        }, 
        
        setOpacity: function(el, alpha) {
            /// <summary>Sets the opacity of a node (x-browser).</summary>
            /// <param name="el" type="Element">Elements whose opacity has to be set.</param>
            /// <param name="alpha" type="number|string">Opacity between 0 and 1 or an empty string
            ///     {@code &apos;&apos;} to clear the opacity.</param>
        }, 
        
        setTransparentBackgroundImage: function(el, src) {
            /// <summary>Sets the background of an element to a transparent image in a browser-
            /// independent manner.
            /// 
            /// This function does not support repeating backgrounds or alternate background
            /// positions to match the behavior of Internet Explorer. It also does not
            /// support sizingMethods other than crop since they cannot be replicated in
            /// browsers other than Internet Explorer.</summary>
            /// <param name="el" type="Element">The element to set background on.</param>
            /// <param name="src" type="string">The image source URL.</param>
        }, 
        
        clearTransparentBackgroundImage: function(el) {
            /// <summary>Clears the background image of an element in a browser independent manner.</summary>
            /// <param name="el" type="Element">The element to clear background image for.</param>
        }, 
        
        showElement: function(el, display) {
            /// <summary>Shows or hides an element from the page. Hiding the element is done by
            /// setting the display property to &quot;none&quot;, removing the element from the
            /// rendering hierarchy so it takes up no space. To show the element, the default
            /// inherited display property is restored (defined either in stylesheets or by
            /// the browser&apos;s default style rules.)
            /// 
            /// Caveat 1: if the inherited display property for the element is set to &quot;none&quot;
            /// by the stylesheets, that is the property that will be restored by a call to
            /// showElement(), effectively toggling the display between &quot;none&quot; and &quot;none&quot;.
            /// 
            /// Caveat 2: if the element display style is set inline (by setting either
            /// element.style.display or a style attribute in the HTML), a call to
            /// showElement will clear that setting and defer to the inherited style in the
            /// stylesheet.</summary>
            /// <param name="el" type="Element">Element to show or hide.</param>
            /// <param name="display" type="*">True to render the element in its default style,
            /// false to disable rendering the element.</param>
        }, 
        
        isElementShown: function(el) {
            /// <summary>Test whether the given element has been shown or hidden via a call to
            /// {@link #showElement}.
            /// 
            /// Note this is strictly a companion method for a call
            /// to {@link #showElement} and the same caveats apply; in particular, this
            /// method does not guarantee that the return value will be consistent with
            /// whether or not the element is actually visible.</summary>
            /// <param name="el" type="Element">The element to test.</param>
            /// <returns type="boolean">Whether the element has been shown.</returns>
        }, 
        
        installStyles: function(stylesString, opt_node) {
            /// <summary>Installs the styles string into the window that contains opt_element.  If
            /// opt_element is null, the main window is used.</summary>
            /// <param name="stylesString" type="string">The style string to install.</param>
            /// <param name="opt_node" type="Node=">Node whose parent document should have the
            ///     styles installed.</param>
            /// <returns type="Element|StyleSheet">The style element created.</returns>
        }, 
        
        uninstallStyles: function(styleSheet) {
            /// <summary>Removes the styles added by {@link #installStyles}.</summary>
            /// <param name="styleSheet" type="Element|StyleSheet">The value returned by
            ///     {@link #installStyles}.</param>
        }, 
        
        setStyles: function(element, stylesString) {
            /// <summary>Sets the content of a style element.  The style element can be any valid
            /// style element.  This element will have its content completely replaced by
            /// the new stylesString.</summary>
            /// <param name="element" type="Element|StyleSheet">A stylesheet element as returned by
            ///     installStyles.</param>
            /// <param name="stylesString" type="string">The new content of the stylesheet.</param>
        }, 
        
        setPreWrap: function(el) {
            /// <summary>Sets &apos;white-space: pre-wrap&apos; for a node (x-browser).
            /// 
            /// There are as many ways of specifying pre-wrap as there are browsers.
            /// 
            /// CSS3/IE8: white-space: pre-wrap;
            /// Mozilla:  white-space: -moz-pre-wrap;
            /// Opera:    white-space: -o-pre-wrap;
            /// IE6/7:    white-space: pre; word-wrap: break-word;</summary>
            /// <param name="el" type="Element">Element to enable pre-wrap for.</param>
        }, 
        
        setInlineBlock: function(el) {
            /// <summary>Sets &apos;display: inline-block&apos; for an element (cross-browser).</summary>
            /// <param name="el" type="Element">Element to which the inline-block display style is to be
            ///    applied.</param>
        }, 
        
        isRightToLeft: function(el) {
            /// <summary>Returns true if the element is using right to left (rtl) direction.</summary>
            /// <param name="el" type="Element">The element to test.</param>
            /// <returns type="boolean">True for right to left, false for left to right.</returns>
        }, 
        
        isUnselectable: function(el) {
            /// <summary>Returns true if the element is set to be unselectable, false otherwise.
            /// Note that on some platforms (e.g. Mozilla), even if an element isn&apos;t set
            /// to be unselectable, it will behave as such if any of its ancestors is
            /// unselectable.</summary>
            /// <param name="el" type="Element">Element to check.</param>
            /// <returns type="boolean">Whether the element is set to be unselectable.</returns>
        }, 
        
        setUnselectable: function(el, unselectable, opt_noRecurse) {
            /// <summary>Makes the element and its descendants selectable or unselectable.  Note
            /// that on some platforms (e.g. Mozilla), even if an element isn&apos;t set to
            /// be unselectable, it will behave as such if any of its ancestors is
            /// unselectable.</summary>
            /// <param name="el" type="Element">The element to alter.</param>
            /// <param name="unselectable" type="boolean">Whether the element and its descendants
            ///     should be made unselectable.</param>
            /// <param name="opt_noRecurse" type="boolean=">Whether to only alter the element&apos;s own
            ///     selectable state, and leave its descendants alone; defaults to false.</param>
        }, 
        
        getBorderBoxSize: function(element) {
            /// <summary>Gets the border box size for an element.</summary>
            /// <param name="element" type="Element">The element to get the size for.</param>
            /// <returns type="!goog.math.Size">The border box size.</returns>
        }, 
        
        setBorderBoxSize: function(element, size) {
            /// <summary>Sets the border box size of an element. This is potentially expensive in IE
            /// if the document is CSS1Compat mode</summary>
            /// <param name="element" type="Element">The element to set the size on.</param>
            /// <param name="size" type="goog.math.Size">The new size.</param>
        }, 
        
        getContentBoxSize: function(element) {
            /// <summary>Gets the content box size for an element.  This is potentially expensive in
            /// all browsers.</summary>
            /// <param name="element" type="Element">The element to get the size for.</param>
            /// <returns type="!goog.math.Size">The content box size.</returns>
        }, 
        
        setContentBoxSize: function(element, size) {
            /// <summary>Sets the content box size of an element. This is potentially expensive in IE
            /// if the document is BackCompat mode.</summary>
            /// <param name="element" type="Element">The element to set the size on.</param>
            /// <param name="size" type="goog.math.Size">The new size.</param>
        }, 
        
        getPaddingBox: function(element) {
            /// <summary>Gets the computed paddings (on all sides) in pixels.</summary>
            /// <param name="element" type="Element">The element to get the padding for.</param>
            /// <returns type="!goog.math.Box">The computed paddings.</returns>
        }, 
        
        getMarginBox: function(element) {
            /// <summary>Gets the computed margins (on all sides) in pixels.</summary>
            /// <param name="element" type="Element">The element to get the margins for.</param>
            /// <returns type="!goog.math.Box">The computed margins.</returns>
        }, 
        
        getBorderBox: function(element) {
            /// <summary>Gets the computed border widths (on all sides) in pixels</summary>
            /// <param name="element" type="Element">The element to get the border widths for.</param>
            /// <returns type="!goog.math.Box">The computed border widths.</returns>
        }, 
        
        getFontFamily: function(el) {
            /// <summary>Returns the font face applied to a given node. Opera and IE should return
            /// the font actually displayed. Firefox returns the author&apos;s most-preferred
            /// font (whether the browser is capable of displaying it or not.)</summary>
            /// <param name="el" type="Element">The element whose font family is returned.</param>
            /// <returns type="string">The font family applied to el.</returns>
        }, 
        
        getLengthUnits: function(value) {
            /// <summary>Returns the units used for a CSS length measurement.</summary>
            /// <param name="value" type="string">A CSS length quantity.</param>
            /// <returns type="?string">The units of measurement.</returns>
        }, 
        
        getFontSize: function(el) {
            /// <summary>Returns the font size, in pixels, of text in an element.</summary>
            /// <param name="el" type="Element">The element whose font size is returned.</param>
            /// <returns type="number">The font size (in pixels).</returns>
        }, 
        
        parseStyleAttribute: function(value) {
            /// <summary>Parses a style attribute value.  Converts CSS property names to camel case.</summary>
            /// <param name="value" type="string">The style attribute value.</param>
            /// <returns type="!Object">Map of CSS properties to string values.</returns>
        }, 
        
        toStyleAttribute: function(obj) {
            /// <summary>Reverse of parseStyleAttribute; that is, takes a style object and returns the
            /// corresponding attribute value.  Converts camel case property names to proper
            /// CSS selector names.</summary>
            /// <param name="obj" type="Object">Map of CSS properties to values.</param>
            /// <returns type="string">The style attribute value.</returns>
        }, 
        
        setFloat: function(el, value) {
            /// <summary>Sets CSS float property on an element.</summary>
            /// <param name="el" type="Element">The element to set float property on.</param>
            /// <param name="value" type="string">The value of float CSS property to set on this element.</param>
        }, 
        
        getFloat: function(el) {
            /// <summary>Gets value of explicitly-set float CSS property on an element.</summary>
            /// <param name="el" type="Element">The element to get float property of.</param>
            /// <returns type="string">The value of explicitly-set float CSS property on this
            ///     element.</returns>
        }, 
        
        getScrollbarWidth: function(opt_className) {
            /// <summary>Returns the scroll bar width (represents the width of both horizontal
            /// and vertical scroll).</summary>
            /// <param name="opt_className" type="string=">An optional class name (or names) to apply
            ///     to the invisible div created to measure the scrollbar. This is necessary
            ///     if some scrollbars are styled differently than others.</param>
            /// <returns type="number">The scroll bar width in px.</returns>
        }, 
        
        getCssTranslation: function(element) {
            /// <summary>Returns the x,y translation component of any CSS transforms applied to the
            /// element, in pixels.</summary>
            /// <param name="element" type="!Element">The element to get the translation of.</param>
            /// <returns type="!goog.math.Coordinate">The CSS translation of the element in px.</returns>
        }
        
    };

    var $x = window.goog.style;
    $x.__namespace = "true";
    $x.__typeName = "goog.style";
})(this);
