
/* vsdoc for goog.style.bidi */

(function (window) {
    window.goog.style = window.goog.style || {};

    window.goog.style.bidi = {
        /// <summary></summary>
        /// <returns type="goog.style.bidi"/>
                
        getScrollLeft: function(element) {
            /// <summary>Returns the normalized scrollLeft position for a scrolled element.</summary>
            /// <param name="element" type="Element">The scrolled element.</param>
            /// <returns type="number">The number of pixels the element is scrolled. 0 indicates
            ///     that the element is not scrolled at all (which, in general, is the
            ///     left-most position in ltr and the right-most position in rtl).</returns>
        }, 
        
        getOffsetStart: function(element) {
            /// <summary>Returns the &quot;offsetStart&quot; of an element, analagous to offsetLeft but
            /// normalized for right-to-left environments and various browser
            /// inconsistencies. This value returned can always be passed to setScrollOffset
            /// to scroll to an element&apos;s left edge in a left-to-right offsetParent or
            /// right edge in a right-to-left offsetParent.
            /// 
            /// For example, here offsetStart is 10px in an LTR environment and 5px in RTL:
            /// 
            /// &lt;pre&gt;
            /// |          xxxxxxxxxx     |
            ///  ^^^^^^^^^^   ^^^^   ^^^^^
            ///     10px      elem    5px
            /// &lt;/pre&gt;
            /// 
            /// If an element is positioned before the start of its offsetParent, the
            /// startOffset may be negative.  This can be used with setScrollOffset to
            /// reliably scroll to an element:
            /// 
            /// &lt;pre&gt;
            /// var scrollOffset = goog.style.bidi.getOffsetStart(element);
            /// goog.style.bidi.setScrollOffset(element.offsetParent, scrollOffset);
            /// &lt;/pre&gt;</summary>
            /// <param name="element" type="Element">The element for which we need to determine the
            ///     offsetStart position.</param>
            /// <returns type="number">The offsetStart for that element.</returns>
        }, 
        
        setScrollOffset: function(element, offsetStart) {
            /// <summary>Sets the element&apos;s scrollLeft attribute so it is correctly scrolled by
            /// offsetStart pixels.  This takes into account whether the element is RTL and
            /// the nuances of different browsers.  To scroll to the &quot;beginning&quot; of an
            /// element use getOffsetStart to obtain the element&apos;s offsetStart value and then
            /// pass the value to setScrollOffset.</summary>
            /// <param name="element" type="Element">The element to set scrollLeft on.</param>
            /// <param name="offsetStart" type="number">The number of pixels to scroll the element.
            ///     If this value is < 0, 0 is used.</param>
        }, 
        
        setPosition: function(elem, left, top, isRtl) {
            /// <summary>Sets the element&apos;s left style attribute in LTR or right style attribute in
            /// RTL.  Also clears the left attribute in RTL and the right attribute in LTR.</summary>
            /// <param name="elem" type="Element">The element to position.</param>
            /// <param name="left" type="number">The left position in LTR; will be set as right in RTL.</param>
            /// <param name="top" type="?number">The top position.  If null only the left/right is set.</param>
            /// <param name="isRtl" type="boolean">Whether we are in RTL mode.</param>
        }
        
    };

    var $x = window.goog.style.bidi;
    $x.__namespace = "true";
    $x.__typeName = "goog.style.bidi";
})(this);
