
/* vsdoc for goog.testing */

(function (window) {
    window.goog = window.goog || {};

    window.goog.testing = {
        /// <summary></summary>
        /// <field name="asserts" type=""></field>
        /// <field name="benchmark" type=""></field>
        /// <field name="dom" type=""></field>
        /// <field name="events" type=""></field>
        /// <field name="fs" type=""></field>
        /// <field name="graphics" type=""></field>
        /// <field name="jsunit" type=""></field>
        /// <field name="mockmatchers" type=""></field>
        /// <field name="proto2" type=""></field>
        /// <field name="singleton" type=""></field>
        /// <field name="stacktrace" type=""></field>
        /// <field name="style" type=""></field>
        /// <returns type="goog.testing"/>
                
        FunctionMock: function(opt_functionName, opt_strictness) {
            /// <summary>Class used to mock a function. Useful for mocking closures and anonymous
            /// callbacks etc. Creates a function object that extends goog.testing.Mock.</summary>
            /// <param name="opt_functionName" type="string=">The optional name of the function to mock.
            ///     Set to &apos;[anonymous mocked function]&apos; if not passed in.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked function.</returns>
        }, 
        
        MethodMock: function(scope, functionName, opt_strictness) {
            /// <summary>Mocks an existing function. Creates a goog.testing.FunctionMock
            /// and registers it in the given scope with the name specified by functionName.</summary>
            /// <param name="scope" type="Object">The scope of the method to be mocked out.</param>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked method.</returns>
        }, 
        
        GlobalFunctionMock: function(functionName, opt_strictness) {
            /// <summary>Mocks a global / top-level function. Creates a goog.testing.MethodMock
            /// in the global scope with the name specified by functionName.</summary>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked global function.</returns>
        }, 
        
        createFunctionMock: function(opt_functionName, opt_strictness) {
            /// <summary>Convenience method for creating a mock for a function.</summary>
            /// <param name="opt_functionName" type="string=">The optional name of the function to mock
            ///     set to &apos;[anonymous mocked function]&apos; if not passed in.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked function.</returns>
        }, 
        
        createMethodMock: function(scope, functionName, opt_strictness) {
            /// <summary>Convenience method for creating a mock for a method.</summary>
            /// <param name="scope" type="Object">The scope of the method to be mocked out.</param>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked global function.</returns>
        }, 
        
        createConstructorMock: function(scope, constructorName, opt_strictness) {
            /// <summary>Convenience method for creating a mock for a constructor. Copies class
            /// members to the mock.
            /// 
            /// &lt;p&gt;When mocking a constructor to return a mocked instance, remember to create
            /// the instance mock before mocking the constructor. If you mock the constructor
            /// first, then the mock framework will be unable to examine the prototype chain
            /// when creating the mock instance.</summary>
            /// <param name="scope" type="Object">The scope of the constructor to be mocked out.</param>
            /// <param name="constructorName" type="string">The name of the constructor we&apos;re going to
            ///     mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked constructor.</returns>
        }, 
        
        createGlobalFunctionMock: function(functionName, opt_strictness) {
            /// <summary>Convenience method for creating a mocks for a global / top-level function.</summary>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked global function.</returns>
        }, 
        
        MockInterface: function() {
            /// <summary></summary>
        }, 
        
        recordFunction: function(opt_f) {
            /// <summary>Wraps the function into another one which calls the inner function and
            /// records its calls. The recorded function will have 3 static methods:
            /// {@code getCallCount}, {@code getCalls} and {@code getLastCall} but won&apos;t
            /// inherit the original function&apos;s prototype and static fields.</summary>
            /// <param name="opt_f" type="!Function=">The function to wrap and record. Defaults to
            ///     {@link goog.nullFunction}.</param>
            /// <returns type="!Function">The wrapped function.</returns>
        }, 
        
        recordConstructor: function(ctor) {
            /// <summary>Same as {@link goog.testing.recordFunction} but the recorded function will
            /// have the same prototype and static fields as the original one. It can be
            /// used with constructors.</summary>
            /// <param name="ctor" type="!Function">The function to wrap and record.</param>
            /// <returns type="!Function">The wrapped function.</returns>
        }
        
    };

    var $x = window.goog.testing;
    $x.__namespace = "true";
    $x.__typeName = "goog.testing";
})(this);
