
/* vsdoc for goog.testing.Mock */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.Mock = function(objectToMock, opt_mockStaticMethods, opt_createProxy){
        /// <summary></summary>
        /// <param name="objectToMock" type="Object|Function">The object that should be mocked, or
        ///    the constructor of an object to mock.</param>
        /// <param name="opt_mockStaticMethods" type="boolean=">An optional argument denoting that
        ///     a mock should be constructed from the static functions of a class.</param>
        /// <param name="opt_createProxy" type="boolean=">An optional argument denoting that
        ///     a proxy for the target mock should be created.</param>
        /// <field name="LOOSE" type="number">Option that may be passed when constructing function, method, and
        /// constructor mocks. Indicates that the expected calls should be accepted in
        /// any order.</field>
        /// <field name="STRICT" type="number">Option that may be passed when constructing function, method, and
        /// constructor mocks. Indicates that the expected calls should be accepted in
        /// the recorded order only.</field>
        /// <field name="$proxy" type="Object">A proxy for the mock.  This can be used for dependency injection in lieu of
        /// the mock if the test requires a strict instanceof check.</field>
        /// <returns type="goog.testing.Mock"/>
    };

    var $x = window.goog.testing.Mock;
    $x.prototype = {
                
        $registerArgumentListVerifier: function(methodName, fn) {
            /// <summary>Registers a verfifier function to use when verifying method argument lists.</summary>
            /// <param name="methodName" type="string">The name of the method for which the verifierFn
            ///     should be used.</param>
            /// <param name="fn" type="Function">Argument list verifier function.  Should take 2 argument
            ///     arrays as arguments, and return true if they are considered equivalent.</param>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $mockMethod: function(name) {
            /// <summary>The function that replaces all methods on the mock object.</summary>
            /// <param name="name" type="string">The name of the method being mocked.</param>
            /// <returns type="*">In record mode, returns the mock object. In replay mode, returns
            ///    whatever the creator of the mock set as the return value.</returns>
        }, 
        
        $recordExpectation: function() {
            /// <summary>Records the currently pending expectation, intended to be overridden by a
            /// subclass.</summary>
        }, 
        
        $recordCall: function(name, args) {
            /// <summary>Records an actual method call, intended to be overridden by a
            /// subclass. The subclass must find the pending expectation and return the
            /// correct value.</summary>
            /// <param name="name" type="string">The name of the method being called.</param>
            /// <param name="args" type="Array">The arguments to the method.</param>
            /// <returns type="*">The return expected by the mock.</returns>
        }, 
        
        $maybeThrow: function(expectation) {
            /// <summary>If the expectation expects to throw, this method will throw.</summary>
            /// <param name="expectation" type="goog.testing.MockExpectation">The expectation.</param>
        }, 
        
        $do: function(expectation, args) {
            /// <summary>If this expectation defines a function to be called,
            /// it will be called and its result will be returned.
            /// Otherwise, if the expectation expects to throw, it will throw.
            /// Otherwise, this method will return defined value.</summary>
            /// <param name="expectation" type="goog.testing.MockExpectation">The expectation.</param>
            /// <param name="args" type="Array">The arguments to the method.</param>
            /// <returns type="*">The return value expected by the mock.</returns>
        }, 
        
        $returns: function(val) {
            /// <summary>Specifies a return value for the currently pending expectation.</summary>
            /// <param name="val" type="*">The return value.</param>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $throws: function(val) {
            /// <summary>Specifies a value for the currently pending expectation to throw.</summary>
            /// <param name="val" type="*">The value to throw.</param>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $does: function(func) {
            /// <summary>Specifies a function to call for currently pending expectation.
            /// Note, that using this method overrides declarations made
            /// using $returns() and $throws() methods.</summary>
            /// <param name="func" type="Function">The function to call.</param>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $atMostOnce: function() {
            /// <summary>Allows the expectation to be called 0 or 1 times.</summary>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $atLeastOnce: function() {
            /// <summary>Allows the expectation to be called any number of times, as long as it&apos;s
            /// called once.</summary>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $anyTimes: function() {
            /// <summary>Allows the expectation to be called any number of times.</summary>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $times: function(times) {
            /// <summary>Specifies the number of times the expectation should be called.</summary>
            /// <param name="times" type="number">The number of times this method will be called.</param>
            /// <returns type="goog.testing.Mock">This mock object.</returns>
        }, 
        
        $replay: function() {
            /// <summary>Switches from recording to replay mode.</summary>
        }, 
        
        $reset: function() {
            /// <summary>Resets the state of this mock object. This clears all pending expectations
            /// without verifying, and puts the mock in recording mode.</summary>
        }, 
        
        $throwException: function(comment, opt_message) {
            /// <summary>Throws an exception and records that an exception was thrown.</summary>
            /// <param name="comment" type="string">A short comment about the exception.</param>
            /// <param name="opt_message" type="?string=">A longer message about the exception.</param>
        }, 
        
        $recordAndThrow: function(ex) {
            /// <summary>Throws an exception and records that an exception was thrown.</summary>
            /// <param name="ex" type="Object">Exception.</param>
        }, 
        
        $verify: function() {
            /// <summary>Verify that all of the expectations were met. Should be overridden by
            /// subclasses.</summary>
        }, 
        
        $verifyCall: function(expectation, name, args) {
            /// <summary>Verifies that a method call matches an expectation.</summary>
            /// <param name="expectation" type="goog.testing.MockExpectation">The expectation to check.</param>
            /// <param name="name" type="string">The name of the called method.</param>
            /// <param name="args" type="Array.*?">The arguments passed to the mock.</param>
            /// <returns type="boolean">Whether the call matches the expectation.</returns>
        }, 
        
        $argumentsAsString: function(args) {
            /// <summary>Render the provided argument array to a string to help
            /// clients with debugging tests.</summary>
            /// <param name="args" type="Array.*?">The arguments passed to the mock.</param>
            /// <returns type="string">Human-readable string.</returns>
        }, 
        
        $throwCallException: function(name, args, opt_expectation) {
            /// <summary>Throw an exception based on an incorrect method call.</summary>
            /// <param name="name" type="string">Name of method called.</param>
            /// <param name="args" type="Array.*?">Arguments passed to the mock.</param>
            /// <param name="opt_expectation" type="goog.testing.MockExpectation=">Expected next call,
            ///     if any.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.Mock";
})(this);
