
/* vsdoc for goog.testing.MockClassRecord */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.MockClassRecord = function(namespace, className, originalClass, proxy){
        /// <summary></summary>
        /// <param name="namespace" type="Object">The namespace in which the mocked class resides.</param>
        /// <param name="className" type="string">The name of the class within the namespace.</param>
        /// <param name="originalClass" type="Function">The original class implementation before it
        ///     was replaced by a proxy.</param>
        /// <param name="proxy" type="Function">The proxy that replaced the original class.</param>
        /// <returns type="goog.testing.MockClassRecord"/>
    };

    var $x = window.goog.testing.MockClassRecord;
    $x.prototype = {
                
        getNamespace: function() {
            /// <summary>A getter for this record&apos;s namespace.</summary>
            /// <returns type="Object">The namespace.</returns>
        }, 
        
        getClassName: function() {
            /// <summary>A getter for this record&apos;s class name.</summary>
            /// <returns type="string">The name of the class referenced by this record.</returns>
        }, 
        
        getOriginalClass: function() {
            /// <summary>A getter for the original class.</summary>
            /// <returns type="Function">The original class implementation before mocking.</returns>
        }, 
        
        getProxy: function() {
            /// <summary>A getter for the proxy being used as a replacement for the original class.</summary>
            /// <returns type="Function">The proxy.</returns>
        }, 
        
        getStaticMock: function() {
            /// <summary>A getter for the static mock.</summary>
            /// <returns type="goog.testing.StrictMock|goog.testing.LooseMock|null">The static
            ///     mock associated with this record.</returns>
        }, 
        
        setStaticMock: function(staticMock) {
            /// <summary>A setter for the static mock.</summary>
            /// <param name="staticMock" type="goog.testing.StrictMock|goog.testing.LooseMock">A mock to
            ///     associate with the static functions for the referenced class.</param>
        }, 
        
        addMockInstance: function(args, mock) {
            /// <summary>Adds a new mock instance mapping.  The mapping connects a set of function
            /// arguments to a specific mock instance.</summary>
            /// <param name="args" type="Array">An array of function arguments.</param>
            /// <param name="mock" type="goog.testing.StrictMock|goog.testing.LooseMock">A mock
            ///     associated with the supplied arguments.</param>
        }, 
        
        findMockInstance: function(args) {
            /// <summary>Finds the mock corresponding to a given argument set.  Throws an error if
            /// there is no appropriate match found.</summary>
            /// <param name="args" type="Array">An array of function arguments.</param>
            /// <returns type="goog.testing.StrictMock|goog.testing.LooseMock|null">The mock
            ///     corresponding to a given argument set.</returns>
        }, 
        
        reset: function() {
            /// <summary>Resets this record by reverting all the mocked classes back to the original
            /// implementation and clearing out the mock instance list.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.MockClassRecord";
})(this);
