
/* vsdoc for goog.testing.MockClock */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.MockClock = function(opt_autoInstall){
        /// <summary></summary>
        /// <param name="opt_autoInstall" type="boolean=">Install the MockClock at construction time.</param>
        /// <field name="REQUEST_ANIMATION_FRAME_TIMEOUT" type="number">Default wait timeout for mocking requestAnimationFrame (in milliseconds).</field>
        /// <returns type="goog.testing.MockClock"/>
    };

    var $x = window.goog.testing.MockClock;
    $x.prototype = {
                
        install: function() {
            /// <summary>Installs the MockClock by overriding the global object&apos;s implementation of
            /// setTimeout, setInterval, clearTimeout and clearInterval.</summary>
        }, 
        
        uninstall: function() {
            /// <summary>Removes the MockClock&apos;s hooks into the global object&apos;s functions and revert
            /// to their original values.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        reset: function() {
            /// <summary>Resets the MockClock, removing all timeouts that are scheduled and resets
            /// the fake timer count.</summary>
        }, 
        
        setTimeoutDelay: function(delay) {
            /// <summary>Sets the amount of time between when a timeout is scheduled to fire and when
            /// it actually fires.</summary>
            /// <param name="delay" type="number">The delay in milliseconds.  May be negative.</param>
        }, 
        
        getTimeoutDelay: function() {
            /// <summary></summary>
            /// <returns type="number">delay The amount of time between when a timeout is
            ///     scheduled to fire and when it actually fires, in milliseconds.  May
            ///     be negative.</returns>
        }, 
        
        tick: function(opt_millis) {
            /// <summary>Increments the MockClock&apos;s time by a given number of milliseconds, running
            /// any functions that are now overdue.</summary>
            /// <param name="opt_millis" type="number=">Number of milliseconds to increment the counter.
            ///     If not specified, clock ticks 1 millisecond.</param>
            /// <returns type="number">Current mock time in milliseconds.</returns>
        }, 
        
        getTimeoutsMade: function() {
            /// <summary></summary>
            /// <returns type="number">The number of timeouts that have been scheduled.</returns>
        }, 
        
        getCurrentTime: function() {
            /// <summary></summary>
            /// <returns type="number">The MockClock&apos;s current time in milliseconds.</returns>
        }, 
        
        isTimeoutSet: function(timeoutKey) {
            /// <summary></summary>
            /// <param name="timeoutKey" type="number">The timeout key.</param>
            /// <returns type="boolean">Whether the timer has been set and not cleared,
            ///     independent of the timeout&apos;s expiration.  In other words, the timeout
            ///     could have passed or could be scheduled for the future.  Either way,
            ///     this function returns true or false depending only on whether the
            ///     provided timeoutKey represents a timeout that has been set and not
            ///     cleared.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.MockClock";
})(this);
