
/* vsdoc for goog.testing.MockControl */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.MockControl = function(){
        /// <summary></summary>
        /// <returns type="goog.testing.MockControl"/>
    };

    var $x = window.goog.testing.MockControl;
    $x.prototype = {
                
        addMock: function(mock) {
            /// <summary>Takes control of this mock.</summary>
            /// <param name="mock" type="goog.testing.MockInterface">Mock to be controlled.</param>
            /// <returns type="goog.testing.MockInterface">The same mock passed in,
            ///     for convenience.</returns>
        }, 
        
        $replayAll: function() {
            /// <summary>Calls replay on each controlled mock.</summary>
        }, 
        
        $resetAll: function() {
            /// <summary>Calls reset on each controlled mock.</summary>
        }, 
        
        $verifyAll: function() {
            /// <summary>Calls verify on each controlled mock.</summary>
        }, 
        
        $tearDown: function() {
            /// <summary>Calls tearDown on each controlled mock, if necesssary.</summary>
        }, 
        
        createStrictMock: function(objectToMock, opt_mockStaticMethods, opt_createProxy) {
            /// <summary>Creates a controlled StrictMock.  Passes its arguments through to the
            /// StrictMock constructor.</summary>
            /// <param name="objectToMock" type="Object">The object to mock.</param>
            /// <param name="opt_mockStaticMethods" type="boolean=">An optional argument denoting that
            ///     a mock should be constructed from the static functions of a class.</param>
            /// <param name="opt_createProxy" type="boolean=">An optional argument denoting that
            ///     a proxy for the target mock should be created.</param>
            /// <returns type="goog.testing.StrictMock">The mock object.</returns>
        }, 
        
        createLooseMock: function(objectToMock, opt_ignoreUnexpectedCalls, opt_mockStaticMethods, opt_createProxy) {
            /// <summary>Creates a controlled LooseMock.  Passes its arguments through to the
            /// LooseMock constructor.</summary>
            /// <param name="objectToMock" type="Object">The object to mock.</param>
            /// <param name="opt_ignoreUnexpectedCalls" type="boolean=">Whether to ignore unexpected
            ///     calls.</param>
            /// <param name="opt_mockStaticMethods" type="boolean=">An optional argument denoting that
            ///     a mock should be constructed from the static functions of a class.</param>
            /// <param name="opt_createProxy" type="boolean=">An optional argument denoting that
            ///     a proxy for the target mock should be created.</param>
            /// <returns type="goog.testing.LooseMock">The mock object.</returns>
        }, 
        
        createFunctionMock: function(opt_functionName, opt_strictness) {
            /// <summary>Creates a controlled FunctionMock.  Passes its arguments through to the
            /// FunctionMock constructor.</summary>
            /// <param name="opt_functionName" type="string=">The optional name of the function to mock
            ///     set to &apos;[anonymous mocked function]&apos; if not passed in.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked function.</returns>
        }, 
        
        createMethodMock: function(scope, functionName, opt_strictness) {
            /// <summary>Creates a controlled MethodMock.  Passes its arguments through to the
            /// MethodMock constructor.</summary>
            /// <param name="scope" type="Object">The scope of the method to be mocked out.</param>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked method.</returns>
        }, 
        
        createConstructorMock: function(scope, constructorName, opt_strictness) {
            /// <summary>Creates a controlled MethodMock for a constructor.  Passes its arguments
            /// through to the MethodMock constructor. See
            /// {@link goog.testing.createConstructorMock} for details.</summary>
            /// <param name="scope" type="Object">The scope of the constructor to be mocked out.</param>
            /// <param name="constructorName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked method.</returns>
        }, 
        
        createGlobalFunctionMock: function(functionName, opt_strictness) {
            /// <summary>Creates a controlled GlobalFunctionMock.  Passes its arguments through to the
            /// GlobalFunctionMock constructor.</summary>
            /// <param name="functionName" type="string">The name of the function we&apos;re going to mock.</param>
            /// <param name="opt_strictness" type="number=">One of goog.testing.Mock.LOOSE or
            ///     goog.testing.Mock.STRICT. The default is STRICT.</param>
            /// <returns type="goog.testing.MockInterface">The mocked function.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.MockControl";
})(this);
