
/* vsdoc for goog.testing.MultiTestRunner */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.MultiTestRunner = function(opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">A DOM helper.</param>
        /// <field name="DEFAULT_TIMEOUT_MS" type="number">Default maximimum amount of time to spend at each stage of the test.</field>
        /// <field name="STATES" type="Array.<string>">Messages corresponding to the numeric states.</field>
        /// <returns type="goog.testing.MultiTestRunner"/>
    };

    var $x = window.goog.testing.MultiTestRunner;
    $x.prototype = {
                
        setName: function(name) {
            /// <summary>Sets the name for the test suite.</summary>
            /// <param name="name" type="string">The suite&apos;s name.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getName: function() {
            /// <summary>Returns the name for the test suite.</summary>
            /// <returns type="string">The name for the test suite.</returns>
        }, 
        
        setBasePath: function(path) {
            /// <summary>Sets the basepath that tests added using addTests are resolved with.</summary>
            /// <param name="path" type="string">The relative basepath.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getBasePath: function() {
            /// <summary>Returns the basepath that tests added using addTests are resolved with.</summary>
            /// <returns type="string">The basepath that tests added using addTests are resolved
            ///     with.</returns>
        }, 
        
        setVerbosePasses: function(verbose) {
            /// <summary>Sets whether the report should contain verbose information for tests that
            /// pass.</summary>
            /// <param name="verbose" type="boolean">Whether report should be verbose.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getVerbosePasses: function() {
            /// <summary>Returns whether the report should contain verbose information for tests that
            /// pass.</summary>
            /// <returns type="boolean">Whether the report should contain verbose information for
            ///     tests that pass.</returns>
        }, 
        
        setHidePasses: function(hide) {
            /// <summary>Sets whether the report should contain passing tests at all, makes
            /// setVerbosePasses obsolete.</summary>
            /// <param name="hide" type="boolean">Whether report should not contain passing tests.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getHidePasses: function() {
            /// <summary>Returns whether the report should contain passing tests at all, makes
            /// setVerbosePasses obsolete.</summary>
            /// <returns type="boolean">Whether the report should contain passing tests at all,
            ///     makes setVerbosePasses obsolete.</returns>
        }, 
        
        setStatsBucketSizes: function(f, t) {
            /// <summary>Sets the bucket sizes for the histograms.</summary>
            /// <param name="f" type="number">Bucket size for num files loaded histogram.</param>
            /// <param name="t" type="number">Bucket size for run time histogram.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        setTimeout: function(timeout) {
            /// <summary>Sets the number of milliseconds to wait for the page to load, initialize and
            /// run the tests.</summary>
            /// <param name="timeout" type="number">Time in milliseconds.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getTimeout: function() {
            /// <summary>Returns the number of milliseconds to wait for the page to load, initialize
            /// and run the tests.</summary>
            /// <returns type="number">The number of milliseconds to wait for the page to load,
            ///     initialize and run the tests.</returns>
        }, 
        
        setPoolSize: function(size) {
            /// <summary>Sets the number of tests that can be run at the same time. This only improves
            /// performance due to the amount of time spent loading the tests.</summary>
            /// <param name="size" type="number">The number of tests to run at a time.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getPoolSize: function() {
            /// <summary>Returns the number of tests that can be run at the same time. This only
            /// improves performance due to the amount of time spent loading the tests.</summary>
            /// <returns type="number">The number of tests that can be run at the same time. This
            ///     only improves performance due to the amount of time spent loading the
            ///     tests.</returns>
        }, 
        
        setFilterFunction: function(filterFn) {
            /// <summary>Sets a filter function. Only test paths that match the filter function
            /// will be executed.</summary>
            /// <param name="filterFn" type="function(string): boolean">Filters test paths.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getFilterFunction: function() {
            /// <summary>Returns a filter function. Only test paths that match the filter function
            /// will be executed.</summary>
            /// <returns type="function(string): boolean">A filter function. Only test paths that
            ///     match the filter function will be executed.</returns>
        }, 
        
        addTests: function(tests) {
            /// <summary>Adds an array of tests to the tests that the test runner should execute.</summary>
            /// <param name="tests" type="Array.string">Adds tests to the test runner.</param>
            /// <returns type="goog.testing.MultiTestRunner">Instance for chaining.</returns>
        }, 
        
        getAllTests: function() {
            /// <summary>Returns the list of all tests added to the runner.</summary>
            /// <returns type="Array.string">The list of all tests added to the runner.</returns>
        }, 
        
        getTestsToRun: function() {
            /// <summary>Returns the list of tests that will be run when start() is called.</summary>
            /// <returns type="Array.string">The list of tests that will be run when start() is
            ///     called.</returns>
        }, 
        
        getTestsThatFailed: function() {
            /// <summary>Returns a list of tests from runner that have been marked as failed.</summary>
            /// <returns type="Array.string">A list of tests from runner that have been marked as
            ///     failed.</returns>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        start: function() {
            /// <summary>Starts executing the tests.</summary>
        }, 
        
        log: function(msg) {
            /// <summary>Logs a message to the log window.</summary>
            /// <param name="msg" type="string">A message to log.</param>
        }, 
        
        processResult: function(frame) {
            /// <summary>Processes a result returned from a TestFrame.  If there are tests remaining
            /// it will trigger the next one to be run, otherwise if there are no tests and
            /// all results have been recieved then it will call finish.</summary>
            /// <param name="frame" type="goog.testing.MultiTestRunner.TestFrame">The frame that just
            ///     finished.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.MultiTestRunner";
})(this);
