
/* vsdoc for goog.testing.PerformanceTimer */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.PerformanceTimer = function(opt_numSamples, opt_timeoutInterval){
        /// <summary></summary>
        /// <param name="opt_numSamples" type="number=">Number of times to run the test function;
        ///     defaults to 10.</param>
        /// <param name="opt_timeoutInterval" type="number=">Number of milliseconds after which the
        ///     test is to be aborted; defaults to 5 seconds (5,000ms).</param>
        /// <returns type="goog.testing.PerformanceTimer"/>
    };

    var $x = window.goog.testing.PerformanceTimer;
    $x.prototype = {
                
        getNumSamples: function() {
            /// <summary></summary>
            /// <returns type="number">The number of times the test function will be run.</returns>
        }, 
        
        setNumSamples: function(numSamples) {
            /// <summary>Sets the number of times the test function will be run.</summary>
            /// <param name="numSamples" type="number">Number of times to run the test function.</param>
        }, 
        
        getTimeoutInterval: function() {
            /// <summary></summary>
            /// <returns type="number">The number of milliseconds after which the test times out.</returns>
        }, 
        
        setTimeoutInterval: function(timeoutInterval) {
            /// <summary>Sets the number of milliseconds after which the test times out.</summary>
            /// <param name="timeoutInterval" type="number">Timeout interval in ms.</param>
        }, 
        
        setDiscardOutliers: function(discard) {
            /// <summary>Sets whether to ignore the smallest and the largest values when computing
            /// stats.</summary>
            /// <param name="discard" type="boolean">Whether to discard outlier values.</param>
        }, 
        
        isDiscardOutliers: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether outlier values are discarded prior to computing
            ///     stats.</returns>
        }, 
        
        run: function(testFn) {
            /// <summary>Executes the test function the required number of times (or until the
            /// test run exceeds the timeout interval, whichever comes first).  Returns
            /// an object containing the following:
            /// &lt;pre&gt;
            ///   {
            ///     &apos;average&apos;: average execution time (ms)
            ///     &apos;count&apos;: number of executions (may be fewer than expected due to timeout)
            ///     &apos;maximum&apos;: longest execution time (ms)
            ///     &apos;minimum&apos;: shortest execution time (ms)
            ///     &apos;standardDeviation&apos;: sample standard deviation (ms)
            ///     &apos;total&apos;: total execution time (ms)
            ///   }
            /// &lt;/pre&gt;</summary>
            /// <param name="testFn" type="Function">Test function whose performance is to
            ///     be measured.</param>
            /// <returns type="Object">Object containing performance stats.</returns>
        }, 
        
        runTask: function(task) {
            /// <summary>Executes the test function of the specified task as described in
            /// {@code run}. In addition, if specified, the set up and tear down functions of
            /// the task are invoked before and after each invocation of the test function.</summary>
            /// <param name="task" type="goog.testing.PerformanceTimer.Task">A task describing the test
            ///     function to invoke.</param>
            /// <returns type="Object">Object containing performance stats.</returns>
        }, 
        
        createResults: function(samples) {
            /// <summary>Creates a performance timer results object by analyzing a given array of
            /// sample timings.</summary>
            /// <param name="samples" type="Array.number">The samples to analyze.</param>
            /// <returns type="Object">Object containing performance stats.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.PerformanceTimer";
})(this);
