
/* vsdoc for goog.testing.TestCase */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.TestCase = function(opt_name){
        /// <summary></summary>
        /// <param name="opt_name" type="string=">The name of the test case, defaults to
        ///     &apos;Untitled Test Case&apos;.</param>
        /// <field name="result_" type="goog.testing.TestCase.Result">Object used to encapsulate the test results.</field>
        /// <field name="Order" type="">The order to run the auto-discovered tests.</field>
        /// <field name="MAX_RUN_TIME" type="number">The maximum amount of time that the test can run before we force it to be
        /// async.  This prevents the test runner from blocking the browser and
        /// potentially hurting the Selenium test harness.</field>
        /// <field name="order" type="string">The order to run the auto-discovered tests in.</field>
        /// <field name="currentTestName" type="?string">TODO(user) replace this with prototype.currentTest.
        /// Name of the current test that is running, or null if none is running.</field>
        /// <field name="IS_IE" type="boolean">Avoid a dependency on goog.userAgent and keep our own reference of whether
        /// the browser is IE.</field>
        /// <field name="started" type="boolean">Whether the test case has ever tried to execute.</field>
        /// <field name="running" type="boolean">Whether the test case is running.</field>
        /// <returns type="goog.testing.TestCase"/>
    };

    var $x = window.goog.testing.TestCase;
    $x.prototype = {
                
        add: function(test) {
            /// <summary>Adds a new test to the test case.</summary>
            /// <param name="test" type="goog.testing.TestCase.Test">The test to add.</param>
        }, 
        
        setTests: function(tests) {
            /// <summary>Sets the tests.</summary>
            /// <param name="tests" type="Array.goog.testing.TestCase.Test">A new test array.</param>
        }, 
        
        getTests: function() {
            /// <summary>Gets the tests.</summary>
            /// <returns type="Array.goog.testing.TestCase.Test">The test array.</returns>
        }, 
        
        getCount: function() {
            /// <summary>Returns the number of tests contained in the test case.</summary>
            /// <returns type="number">The number of tests.</returns>
        }, 
        
        getActuallyRunCount: function() {
            /// <summary>Returns the number of tests actually run in the test case, i.e. subtracting
            /// any which are skipped.</summary>
            /// <returns type="number">The number of un-ignored tests.</returns>
        }, 
        
        next: function() {
            /// <summary>Returns the current test and increments the pointer.</summary>
            /// <returns type="goog.testing.TestCase.Test?">The current test case.</returns>
        }, 
        
        reset: function() {
            /// <summary>Resets the test case pointer, so that next returns the first test.</summary>
        }, 
        
        setCompletedCallback: function(fn) {
            /// <summary>Sets the callback function that should be executed when the tests have
            /// completed.</summary>
            /// <param name="fn" type="Function">The callback function.</param>
        }, 
        
        setTestRunner: function(tr) {
            /// <summary>Sets the test runner that is running this test case.</summary>
            /// <param name="tr" type="goog.testing.TestRunner">The test runner.</param>
        }, 
        
        shouldRunTests: function() {
            /// <summary>Can be overridden in test classes to indicate whether the tests in a case
            /// should be run in that particular situation.  For example, this could be used
            /// to stop tests running in a particular browser, where browser support for
            /// the class under test was absent.</summary>
            /// <returns type="boolean">Whether any of the tests in the case should be run.</returns>
        }, 
        
        execute: function() {
            /// <summary>Executes each of the tests.</summary>
        }, 
        
        finalize: function() {
            /// <summary>Finalizes the test case, called when the tests have finished executing.</summary>
        }, 
        
        saveMessage: function(message) {
            /// <summary>Saves a message to the result set.</summary>
            /// <param name="message" type="string">The message to save.</param>
        }, 
        
        isInsideMultiTestRunner: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the test case is running inside the multi test
            ///     runner.</returns>
        }, 
        
        log: function(val) {
            /// <summary>Logs an object to the console, if available.</summary>
            /// <param name="val" type="*">The value to log. Will be ToString&apos;d.</param>
        }, 
        
        isSuccess: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the test was a success.</returns>
        }, 
        
        getReport: function(opt_verbose) {
            /// <summary>Returns a string detailing the results from the test.</summary>
            /// <param name="opt_verbose" type="boolean=">If true results will include data about all
            ///     tests, not just what failed.</param>
            /// <returns type="string">The results from the test.</returns>
        }, 
        
        getRunTime: function() {
            /// <summary>Returns the amount of time it took for the test to run.</summary>
            /// <returns type="number">The run time, in milliseconds.</returns>
        }, 
        
        getNumFilesLoaded: function() {
            /// <summary>Returns the number of script files that were loaded in order to run the test.</summary>
            /// <returns type="number">The number of script files.</returns>
        }, 
        
        runTests: function() {
            /// <summary>Executes each of the tests.
            /// Overridable by the individual test case.  This allows test cases to defer
            /// when the test is actually started.  If overridden, finalize must be called
            /// by the test to indicate it has finished.</summary>
        }, 
        
        getGlobals: function(opt_prefix) {
            /// <summary>Gets the object with all globals.</summary>
            /// <param name="opt_prefix" type="string=">An optional prefix. If specified, only get things
            ///     under this prefix.</param>
            /// <returns type="Object">An object with all globals starting with the prefix.</returns>
        }, 
        
        getGlobals: function(opt_prefix) {
            /// <summary>Gets the object with all globals.</summary>
            /// <param name="opt_prefix" type="string=">An optional prefix. If specified, only get things
            ///     under this prefix.</param>
            /// <returns type="Object">An object with all globals starting with the prefix.</returns>
        }, 
        
        setUpPage: function() {
            /// <summary>Gets called before any tests are executed.  Can be overridden to set up the
            /// environment for the whole test case.</summary>
        }, 
        
        tearDownPage: function() {
            /// <summary>Gets called after all tests have been executed.  Can be overridden to tear
            /// down the entire test case.</summary>
        }, 
        
        setUp: function() {
            /// <summary>Gets called before every goog.testing.TestCase.Test is been executed. Can be
            /// overridden to add set up functionality to each test.</summary>
        }, 
        
        tearDown: function() {
            /// <summary>Gets called after every goog.testing.TestCase.Test has been executed. Can be
            /// overriden to add tear down functionality to each test.</summary>
        }, 
        
        getAutoDiscoveryPrefix: function() {
            /// <summary></summary>
            /// <returns type="string">The function name prefix used to auto-discover tests.</returns>
        }, 
        
        getBatchTime: function() {
            /// <summary></summary>
            /// <returns type="number">Time since the last batch of tests was started.</returns>
        }, 
        
        setBatchTime: function(batchTime) {
            /// <summary></summary>
            /// <param name="batchTime" type="number">Time since the last batch of tests was started.</param>
        }, 
        
        createTestFromAutoDiscoveredFunction: function(name, ref) {
            /// <summary>Creates a {@code goog.testing.TestCase.Test} from an auto-discovered
            ///     function.</summary>
            /// <param name="name" type="string">The name of the function.</param>
            /// <param name="ref" type="function() : void">The auto-discovered function.</param>
            /// <returns type="goog.testing.TestCase.Test">The newly created test.</returns>
        }, 
        
        autoDiscoverTests: function() {
            /// <summary>Adds any functions defined in the global scope that are prefixed with &quot;test&quot;
            /// to the test case.  Also overrides setUp, tearDown, setUpPage, tearDownPage
            /// and runTests if they are defined.</summary>
        }, 
        
        maybeFailTestEarly: function(testCase) {
            /// <summary>Checks to see if the test should be marked as failed before it is run.
            /// 
            /// If there was an error in setUpPage, we treat that as a failure for all tests
            /// and mark them all as having failed.</summary>
            /// <param name="testCase" type="goog.testing.TestCase.Test">The current test case.</param>
            /// <returns type="boolean">Whether the test was marked as failed.</returns>
        }, 
        
        cycleTests: function() {
            /// <summary>Cycles through the tests, breaking out using a setTimeout if the execution
            /// time has execeeded {@link #MAX_RUN_TIME}.</summary>
        }, 
        
        timeout: function(fn, time) {
            /// <summary>Calls a function after a delay, using the protected timeout.</summary>
            /// <param name="fn" type="Function">The function to call.</param>
            /// <param name="time" type="number">Delay in milliseconds.</param>
            /// <returns type="number">The timeout id.</returns>
        }, 
        
        clearTimeout: function(id) {
            /// <summary>Clears a timeout created by {@code this.timeout()}.</summary>
            /// <param name="id" type="number">A timeout id.</param>
        }, 
        
        now: function() {
            /// <summary></summary>
            /// <returns type="number">The current time in milliseconds, don&apos;t use goog.now as some
            ///     tests override it.</returns>
        }, 
        
        doSuccess: function(test) {
            /// <summary>Handles a test that passed.</summary>
            /// <param name="test" type="goog.testing.TestCase.Test">The test that passed.</param>
        }, 
        
        doError: function(test, opt_e) {
            /// <summary>Handles a test that failed.</summary>
            /// <param name="test" type="goog.testing.TestCase.Test">The test that failed.</param>
            /// <param name="opt_e" type="*=">The exception object associated with the
            ///     failure or a string.</param>
        }, 
        
        logError: function(name, opt_e) {
            /// <summary></summary>
            /// <param name="name" type="string">Failed test name.</param>
            /// <param name="opt_e" type="*=">The exception object associated with the
            ///     failure or a string.</param>
            /// <returns type="goog.testing.TestCase.Error">Error object.</returns>
        }, 
        
        initializeTestRunner: function(testCase) {
            /// <summary>Initializes the given test case with the global test runner &apos;G_testRunner&apos;.</summary>
            /// <param name="testCase" type="goog.testing.TestCase">The test case to install.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.TestCase";
})(this);
