
/* vsdoc for goog.testing.TestRunner */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.TestRunner = function(){
        /// <summary></summary>
        /// <field name="errors" type="Array.<string>">Errors that occurred in the window.</field>
        /// <field name="testCase" type="goog.testing.TestCase?">Reference to the active test case.</field>
        /// <field name="initialized" type="boolean">Whether the test runner has been initialized yet.</field>
        /// <returns type="goog.testing.TestRunner"/>
    };

    var $x = window.goog.testing.TestRunner;
    $x.prototype = {
                
        initialize: function(testCase) {
            /// <summary>Initializes the test runner.</summary>
            /// <param name="testCase" type="goog.testing.TestCase">The test case to initialize with.</param>
        }, 
        
        setStrict: function(strict) {
            /// <summary>By default, the test runner is strict, and fails if it runs an empty
            /// test case.</summary>
            /// <param name="strict" type="boolean">Whether the test runner should fail on an empty
            ///     test case.</param>
        }, 
        
        isStrict: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the test runner should fail on an empty
            ///     test case.</returns>
        }, 
        
        isInitialized: function() {
            /// <summary>Returns true if the test runner is initialized.
            /// Used by Selenium Hooks.</summary>
            /// <returns type="boolean">Whether the test runner is active.</returns>
        }, 
        
        isFinished: function() {
            /// <summary>Returns true if the test runner is finished.
            /// Used by Selenium Hooks.</summary>
            /// <returns type="boolean">Whether the test runner is active.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary>Returns true if the test case didn&apos;t fail.
            /// Used by Selenium Hooks.</summary>
            /// <returns type="boolean">Whether the current test returned successfully.</returns>
        }, 
        
        hasErrors: function() {
            /// <summary>Returns true if the test case runner has errors that were caught outside of
            /// the test case.</summary>
            /// <returns type="boolean">Whether there were JS errors.</returns>
        }, 
        
        logError: function(msg) {
            /// <summary>Logs an error that occurred.  Used in the case of environment setting up
            /// an onerror handler.</summary>
            /// <param name="msg" type="string">Error message.</param>
        }, 
        
        logTestFailure: function(ex) {
            /// <summary>Log failure in current running test.</summary>
            /// <param name="ex" type="Error">Exception.</param>
        }, 
        
        setErrorFilter: function(fn) {
            /// <summary>Sets a function to use as a filter for errors.</summary>
            /// <param name="fn" type="function(string)">Filter function.</param>
        }, 
        
        getReport: function(opt_verbose) {
            /// <summary>Returns a report of the test case that ran.
            /// Used by Selenium Hooks.</summary>
            /// <param name="opt_verbose" type="boolean=">If true results will include data about all
            ///     tests, not just what failed.</param>
            /// <returns type="string">A report summary of the test.</returns>
        }, 
        
        getRunTime: function() {
            /// <summary>Returns the amount of time it took for the test to run.
            /// Used by Selenium Hooks.</summary>
            /// <returns type="number">The run time, in milliseconds.</returns>
        }, 
        
        getNumFilesLoaded: function() {
            /// <summary>Returns the number of script files that were loaded in order to run the test.</summary>
            /// <returns type="number">The number of script files.</returns>
        }, 
        
        execute: function() {
            /// <summary>Executes a test case and prints the results to the window.</summary>
        }, 
        
        writeLog: function(log) {
            /// <summary>Writes a nicely formatted log out to the document.</summary>
            /// <param name="log" type="string">The string to write.</param>
        }, 
        
        log: function(s) {
            /// <summary>Logs a message to the current test case.</summary>
            /// <param name="s" type="string">The text to output to the log.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.TestRunner";
})(this);
