
/* vsdoc for goog.testing.asserts */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.asserts = {
        /// <summary></summary>
        /// <field name="EQUALITY_PREDICATE_CANT_PROCESS" type="?string">The return value of the equality predicate passed to findDifferences below,
        /// in cases where the predicate can&apos;t test the input variables for equality.</field>
        /// <field name="EQUALITY_PREDICATE_VARS_ARE_EQUAL" type="?string">The return value of the equality predicate passed to findDifferences below,
        /// in cases where the input vriables are equal.</field>
        /// <returns type="goog.testing.asserts"/>
                
        callWithoutLogging: function(fn) {
            /// <summary>Runs a function in an environment where test failures are not logged. This is
            /// useful for testing test code, where failures can be a normal part of a test.</summary>
            /// <param name="fn" type="function() : void">Function to run without logging failures.</param>
        }, 
        
        findDifferences: function(expected, actual, opt_equalityPredicate) {
            /// <summary>Determines if two items of any type match, and formulates an error message
            /// if not.</summary>
            /// <param name="expected" type="*">Expected argument to match.</param>
            /// <param name="actual" type="*">Argument as a result of performing the test.</param>
            /// <param name="opt_equalityPredicate" type="(function(string|*|*): ?string)=">An optional
            ///     function that can be used to check equality of variables. It accepts 3
            ///     arguments: type-of-variables, var1, var2 (in that order) and returns an
            ///     error message if the variables are not equal,
            ///     goog.testing.asserts.EQUALITY_PREDICATE_VARS_ARE_EQUAL if the variables
            ///     are equal, or
            ///     goog.testing.asserts.EQUALITY_PREDICATE_CANT_PROCESS if the predicate
            ///     couldn&apos;t check the input variables. The function will be called only if
            ///     the types of var1 and var2 are identical.</param>
            /// <returns type="?string">Null on success, error message on failure.</returns>
        }, 
        
        raiseException: function(comment, opt_message) {
            /// <summary>Raises a JsUnit exception with the given comment.</summary>
            /// <param name="comment" type="string">A summary for the exception.</param>
            /// <param name="opt_message" type="string=">A description of the exception.</param>
        }
        
    };

    var $x = window.goog.testing.asserts;
    $x.__namespace = "true";
    $x.__typeName = "goog.testing.asserts";
})(this);
