
/* vsdoc for goog.testing.async.MockControl */

(function (window) {
    window.goog.testing.async = window.goog.testing.async || {};

    window.goog.testing.async.MockControl = function(mockControl){
        /// <summary></summary>
        /// <param name="mockControl" type="goog.testing.MockControl">The parent MockControl.</param>
        /// <returns type="goog.testing.async.MockControl"/>
    };

    var $x = window.goog.testing.async.MockControl;
    $x.prototype = {
                
        createCallbackMock: function(name, callback, opt_selfObj) {
            /// <summary>Returns a function that will assert that it will be called, and run the given
            /// callback when it is.</summary>
            /// <param name="name" type="string">The name of the callback mock.</param>
            /// <param name="callback" type="function(...[*]) : *">The wrapped callback. This will be
            ///     called when the returned function is called.</param>
            /// <param name="opt_selfObj" type="Object=">The object which this should point to when the
            ///     callback is run.</param>
            /// <returns type="!Function">The mock callback.</returns>
        }, 
        
        asyncAssertEquals: function(message, var_args) {
            /// <summary>Returns a function that will assert that its arguments are equal to the
            /// arguments given to asyncAssertEquals. In addition, the function also asserts
            /// that it will be called.</summary>
            /// <param name="message" type="string">A message to print if the arguments are wrong.</param>
            /// <param name="var_args" type="...*">The arguments to assert.</param>
            /// <returns type="function(...[*]) : void">The mock callback.</returns>
        }, 
        
        assertDeferredError: function(deferred, fn) {
            /// <summary>Asserts that a deferred object will have an error and call its errback
            /// function.</summary>
            /// <param name="deferred" type="goog.async.Deferred">The deferred object.</param>
            /// <param name="fn" type="function() : void">A function wrapping the code in which the error
            ///     will occur.</param>
        }, 
        
        assertDeferredEquals: function(message, expected, actual) {
            /// <summary>Asserts that a deferred object will call its callback with the given value.</summary>
            /// <param name="message" type="string">A message to print if the arguments are wrong.</param>
            /// <param name="expected" type="goog.async.Deferred|*">The expected value. If this is a
            ///     deferred object, then the expected value is the deferred value.</param>
            /// <param name="actual" type="goog.async.Deferred|*">The actual value. If this is a deferred
            ///     object, then the actual value is the deferred value. Either this or
            ///     &apos;expected&apos; must be deferred.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.async.MockControl";
})(this);
