
/* vsdoc for goog.testing.dom */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.dom = {
        /// <summary></summary>
        /// <returns type="goog.testing.dom"/>
                
        assertNodesMatch: function(it, array) {
            /// <summary>Tests if the given iterator over nodes matches the given Array of node
            /// descriptors.  Throws an error if any match fails.</summary>
            /// <param name="it" type="goog.iter.Iterator">An iterator over nodes.</param>
            /// <param name="array" type="Array.Node|number|string">Array of node descriptors to match
            ///     against.  Node descriptors can be any of the following:
            ///         Node: Test if the two nodes are equal.
            ///         number: Test node.nodeType == number.
            ///         string starting with &apos;#&apos;: Match the node&apos;s id with the text
            ///             after &quot;#&quot;.
            ///         other string: Match the text node&apos;s contents.</param>
        }, 
        
        exposeNode: function(node) {
            /// <summary>Exposes a node as a string.</summary>
            /// <param name="node" type="Node">A node.</param>
            /// <returns type="string">A string representation of the node.</returns>
        }, 
        
        exposeRange: function(range) {
            /// <summary>Exposes the nodes of a range wrapper as a string.</summary>
            /// <param name="range" type="goog.dom.AbstractRange">A range.</param>
            /// <returns type="string">A string representation of the range.</returns>
        }, 
        
        assertHtmlContentsMatch: function(htmlPattern, actual, opt_strictAttributes) {
            /// <summary>Assert that the html in {@code actual} is substantially similar to
            /// htmlPattern.  This method tests for the same set of styles, for the same
            /// order of nodes, and the presence of attributes.  Breaking whitespace nodes
            /// are ignored.  Elements can be
            /// annotated with classnames corresponding to keys in goog.userAgent and will be
            /// expected to show up in that user agent and expected not to show up in
            /// others.</summary>
            /// <param name="htmlPattern" type="string">The pattern to match.</param>
            /// <param name="actual" type="!Element">The element to check: its contents are matched
            ///     against the HTML pattern.</param>
            /// <param name="opt_strictAttributes" type="boolean=">If false, attributes that appear in
            ///     htmlPattern must be in actual, but actual can have attributes not
            ///     present in htmlPattern.  If true, htmlPattern and actual must have the
            ///     same set of attributes.  Default is false.</param>
        }, 
        
        assertHtmlMatches: function(htmlPattern, actual) {
            /// <summary>Assert that the html in {@code actual} is substantially similar to
            /// htmlPattern.  This method tests for the same set of styles, and for the same
            /// order of nodes.  Breaking whitespace nodes are ignored.  Elements can be
            /// annotated with classnames corresponding to keys in goog.userAgent and will be
            /// expected to show up in that user agent and expected not to show up in
            /// others.</summary>
            /// <param name="htmlPattern" type="string">The pattern to match.</param>
            /// <param name="actual" type="string">The html to check.</param>
        }, 
        
        findTextNode: function(textOrRegexp, root) {
            /// <summary>Finds the first text node descendant of root with the given content.  Note
            /// that this operates on a text node level, so if text nodes get split this
            /// may not match the user visible text.  Using normalize() may help here.</summary>
            /// <param name="textOrRegexp" type="string|RegExp">The text to find, or a regular
            ///     expression to find a match of.</param>
            /// <param name="root" type="Element">The element to search in.</param>
            /// <returns type="Node">The first text node that matches, or null if none is found.</returns>
        }, 
        
        assertRangeEquals: function(start, startOffset, end, endOffset, range) {
            /// <summary>Assert the end points of a range.
            /// 
            /// Notice that &quot;Are two ranges visually identical?&quot; and &quot;Do two ranges have
            /// the same endpoint?&quot; are independent questions. Two visually identical ranges
            /// may have different endpoints. And two ranges with the same endpoints may
            /// be visually different.</summary>
            /// <param name="start" type="Node">The expected start node.</param>
            /// <param name="startOffset" type="number">The expected start offset.</param>
            /// <param name="end" type="Node">The expected end node.</param>
            /// <param name="endOffset" type="number">The expected end offset.</param>
            /// <param name="range" type="goog.dom.AbstractRange">The actual range.</param>
        }
        
    };

    var $x = window.goog.testing.dom;
    $x.__namespace = "true";
    $x.__typeName = "goog.testing.dom";
})(this);
