
/* vsdoc for goog.testing.editor.TestHelper */

(function (window) {
    window.goog.testing.editor = window.goog.testing.editor || {};

    window.goog.testing.editor.TestHelper = function(root){
        /// <summary></summary>
        /// <param name="root" type="Element">The root editable element.</param>
        /// <returns type="goog.testing.editor.TestHelper"/>
    };

    var $x = window.goog.testing.editor.TestHelper;
    $x.prototype = {
                
        setRoot: function(root) {
            /// <summary>Selects a new root element.</summary>
            /// <param name="root" type="Element">The root editable element.</param>
        }, 
        
        setUpEditableElement: function() {
            /// <summary>Make the root element editable.  Alse saves its HTML to be restored
            /// in tearDown.</summary>
        }, 
        
        tearDownEditableElement: function() {
            /// <summary>Reset the element previously initialized, restoring its HTML and making it
            /// non editable.</summary>
        }, 
        
        assertHtmlMatches: function(htmlPattern) {
            /// <summary>Assert that the html in &apos;root&apos; is substantially similar to htmlPattern.
            /// This method tests for the same set of styles, and for the same order of
            /// nodes.  Breaking whitespace nodes are ignored.  Elements can be annotated
            /// with classnames corresponding to keys in goog.userAgent and will be
            /// expected to show up in that user agent and expected not to show up in
            /// others.</summary>
            /// <param name="htmlPattern" type="string">The pattern to match.</param>
        }, 
        
        findTextNode: function(textOrRegexp) {
            /// <summary>Finds the first text node descendant of root with the given content.</summary>
            /// <param name="textOrRegexp" type="string|RegExp">The text to find, or a regular
            ///     expression to find a match of.</param>
            /// <returns type="Node">The first text node that matches, or null if none is found.</returns>
        }, 
        
        select: function(from, fromOffset, opt_to, opt_toOffset) {
            /// <summary>Select from the given from offset in the given from node to the given
            /// to offset in the optionally given to node. If nodes are passed in, uses them,
            /// otherwise uses findTextNode to find the nodes to select. Selects a caret
            /// if opt_to and opt_toOffset are not given.</summary>
            /// <param name="from" type="Node|string">Node or text of the node to start the selection at.</param>
            /// <param name="fromOffset" type="number">Offset within the above node to start the
            ///     selection at.</param>
            /// <param name="opt_to" type="Node|string=">Node or text of the node to end the selection
            ///     at.</param>
            /// <param name="opt_toOffset" type="number=">Offset within the above node to end the
            ///     selection at.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.editor.TestHelper";
})(this);
