
/* vsdoc for goog.testing.editor.dom */

(function (window) {
    window.goog.testing.editor = window.goog.testing.editor || {};

    window.goog.testing.editor.dom = {
        /// <summary></summary>
        /// <returns type="goog.testing.editor.dom"/>
                
        getPreviousNonEmptyTextNode: function(node, opt_stopAt, opt_skipDescendants) {
            /// <summary>Returns the previous (in document order) node from the given node that is a
            /// non-empty text node, or null if none is found or opt_stopAt is not an
            /// ancestor of node. Note that if the given node has children, the search will
            /// start from the end tag of the node, meaning all its descendants will be
            /// included in the search, unless opt_skipDescendants is true.</summary>
            /// <param name="node" type="Node">Node to start searching from.</param>
            /// <param name="opt_stopAt" type="Node=">Node to stop searching at (search will be
            ///     restricted to this node&apos;s subtree), defaults to the body of the document
            ///     containing node.</param>
            /// <param name="opt_skipDescendants" type="boolean=">Whether to skip searching the given
            ///     node&apos;s descentants.</param>
            /// <returns type="Text">The previous (in document order) node from the given node
            ///     that is a non-empty text node, or null if none is found.</returns>
        }, 
        
        getNextNonEmptyTextNode: function(node, opt_stopAt, opt_skipDescendants) {
            /// <summary>Returns the next (in document order) node from the given node that is a
            /// non-empty text node, or null if none is found or opt_stopAt is not an
            /// ancestor of node. Note that if the given node has children, the search will
            /// start from the start tag of the node, meaning all its descendants will be
            /// included in the search, unless opt_skipDescendants is true.</summary>
            /// <param name="node" type="Node">Node to start searching from.</param>
            /// <param name="opt_stopAt" type="Node=">Node to stop searching at (search will be
            ///     restricted to this node&apos;s subtree), defaults to the body of the document
            ///     containing node.</param>
            /// <param name="opt_skipDescendants" type="boolean=">Whether to skip searching the given
            ///     node&apos;s descentants.</param>
            /// <returns type="Text">The next (in document order) node from the given node that
            ///     is a non-empty text node, or null if none is found or opt_stopAt is not
            ///     an ancestor of node.</returns>
        }, 
        
        assertRangeBetweenText: function(before, after, range, opt_stopAt) {
            /// <summary>Assert that the range is surrounded by the given strings. This is useful
            /// because different browsers can place the range endpoints inside different
            /// nodes even when visually the range looks the same. Also, there may be empty
            /// text nodes in the way (again depending on the browser) making it difficult to
            /// use assertRangeEquals.</summary>
            /// <param name="before" type="string">String that should occur immediately before the start
            ///     point of the range. If this is the empty string, assert will only succeed
            ///     if there is no text before the start point of the range.</param>
            /// <param name="after" type="string">String that should occur immediately after the end
            ///     point of the range. If this is the empty string, assert will only succeed
            ///     if there is no text after the end point of the range.</param>
            /// <param name="range" type="goog.dom.AbstractRange">The range to be tested.</param>
            /// <param name="opt_stopAt" type="Node=">Node to stop searching at (search will be
            ///     restricted to this node&apos;s subtree).</param>
        }
        
    };

    var $x = window.goog.testing.editor.dom;
    $x.__namespace = "true";
    $x.__typeName = "goog.testing.editor.dom";
})(this);
