
/* vsdoc for goog.testing.events */

(function (window) {
    window.goog.testing = window.goog.testing || {};

    window.goog.testing.events = {
        /// <summary></summary>
        /// <returns type="goog.testing.events"/>
                
        fireClickSequence: function(target, opt_button, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a mousedown, mouseup, and then click on the given event target,
            /// with the left mouse button.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_button" type="goog.events.BrowserEvent.MouseButton=">Mouse button;
            ///     defaults to {@code goog.events.BrowserEvent.MouseButton.LEFT}.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }, 
        
        fireDoubleClickSequence: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates the sequence of events fired by the browser when the user double-
            /// clicks the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }, 
        
        fireKeySequence: function(target, keyCode, opt_eventProperties) {
            /// <summary>Simulates a complete keystroke (keydown, keypress, and keyup). Note that
            /// if preventDefault is called on the keydown, the keypress will not fire.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="keyCode" type="number">The keycode of the key pressed.</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }, 
        
        fireNonAsciiKeySequence: function(target, keyCode, keyPressKeyCode, opt_eventProperties) {
            /// <summary>Simulates a complete keystroke (keydown, keypress, and keyup) when typing
            /// a non-ASCII character. Same as fireKeySequence, the keypress will not fire
            /// if preventDefault is called on the keydown.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="keyCode" type="number">The keycode of the keydown and keyup events.</param>
            /// <param name="keyPressKeyCode" type="number">The keycode of the keypress event.</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }, 
        
        fireMouseOverEvent: function(target, relatedTarget, opt_coords) {
            /// <summary>Simulates a mouseover event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="relatedTarget" type="EventTarget">The related target for the event (e.g.,
            ///     the node that the mouse is being moved out of).</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireMouseMoveEvent: function(target, opt_coords) {
            /// <summary>Simulates a mousemove event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireMouseOutEvent: function(target, relatedTarget, opt_coords) {
            /// <summary>Simulates a mouseout event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="relatedTarget" type="EventTarget">The related target for the event (e.g.,
            ///     the node that the mouse is being moved into).</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireMouseDownEvent: function(target, opt_button, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a mousedown event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_button" type="goog.events.BrowserEvent.MouseButton=">Mouse button;
            ///     defaults to {@code goog.events.BrowserEvent.MouseButton.LEFT}.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireMouseUpEvent: function(target, opt_button, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a mouseup event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_button" type="goog.events.BrowserEvent.MouseButton=">Mouse button;
            ///     defaults to {@code goog.events.BrowserEvent.MouseButton.LEFT}.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireClickEvent: function(target, opt_button, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a click event on the given target. IE only supports click with
            /// the left mouse button.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_button" type="goog.events.BrowserEvent.MouseButton=">Mouse button;
            ///     defaults to {@code goog.events.BrowserEvent.MouseButton.LEFT}.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireDoubleClickEvent: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a double-click event on the given target. Always double-clicks
            /// with the left mouse button since no browser supports double-clicking with
            /// any other buttons.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireContextMenuEvent: function(target, opt_coords) {
            /// <summary>Simulates a contextmenu event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireContextMenuSequence: function(target, opt_coords) {
            /// <summary>Simulates a mousedown, contextmenu, and the mouseup on the given event
            /// target, with the right mouse button.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Mouse position. Defaults to event&apos;s
            /// target&apos;s position (if available), otherwise (0, 0).</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }, 
        
        firePopStateEvent: function(target, state) {
            /// <summary>Simulates a popstate event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="state" type="Object">History state object.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireFocusEvent: function(target) {
            /// <summary>Simulate a focus event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <returns type="boolean">The value returned by firing the focus browser event,
            ///     which returns false iff &apos;preventDefault&apos; was invoked.</returns>
        }, 
        
        fireBrowserEvent: function(event) {
            /// <summary>Simulates an event&apos;s capturing and bubbling phases.</summary>
            /// <param name="event" type="Event">A simulated native event. It will be wrapped in a
            ///     normalized BrowserEvent and dispatched to Closure listeners on all
            ///     ancestors of its target (inclusive).</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireTouchStartEvent: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a touchstart event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Touch position. Defaults to event&apos;s
            ///     target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireTouchMoveEvent: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a touchmove event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Touch position. Defaults to event&apos;s
            ///     target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireTouchEndEvent: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a touchend event on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Touch position. Defaults to event&apos;s
            ///     target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the event: false if preventDefault() was
            ///     called on it, true otherwise.</returns>
        }, 
        
        fireTouchSequence: function(target, opt_coords, opt_eventProperties) {
            /// <summary>Simulates a simple touch sequence on the given target.</summary>
            /// <param name="target" type="EventTarget">The target for the event.</param>
            /// <param name="opt_coords" type="goog.math.Coordinate=">Touch position. Defaults to event&apos;s
            ///     target&apos;s position (if available), otherwise (0, 0).</param>
            /// <param name="opt_eventProperties" type="Object=">Event properties to be mixed into the
            ///     BrowserEvent.</param>
            /// <returns type="boolean">The returnValue of the sequence: false if preventDefault()
            ///     was called on any of the events, true otherwise.</returns>
        }
        
    };

    var $x = window.goog.testing.events;
    $x.__namespace = "true";
    $x.__typeName = "goog.testing.events";
})(this);
