
/* vsdoc for goog.testing.net.XhrIo */

(function (window) {
    window.goog.testing.net = window.goog.testing.net || {};

    window.goog.testing.net.XhrIo = function(opt_testQueue){
        /// <summary></summary>
        /// <param name="opt_testQueue" type="goog.testing.TestQueue=">Test queue for inserting test
        ///     events.</param>
        /// <field name="headers" type="goog.structs.Map">Map of default headers to add to every request, use:
        /// XhrIo.headers.set(name, value)</field>
        /// <field name="ResponseType" type="">Alias this enum here to make mocking of goog.net.XhrIo easier.</field>
        /// <returns type="goog.testing.net.XhrIo"/>
    };

    var $x = window.goog.testing.net.XhrIo;
    $x.prototype = {
                
        getSendInstances: function() {
            /// <summary>Returns an Array containing all non-disposed instances of
            /// goog.testing.net.XhrIo created by {@link goog.testing.net.XhrIo.send}.</summary>
            /// <returns type="Array">Array of goog.testing.net.XhrIo instances.</returns>
        }, 
        
        cleanup: function() {
            /// <summary>Disposes all non-disposed instances of goog.testing.net.XhrIo created by
            /// {@link goog.testing.net.XhrIo.send}.</summary>
        }, 
        
        send: function(url, opt_callback, opt_method, opt_content, opt_headers, opt_timeoutInterval) {
            /// <summary>Simulates the static XhrIo send method.</summary>
            /// <param name="url" type="string">Uri to make request to.</param>
            /// <param name="opt_callback" type="Function=">Callback function for when request is
            ///     complete.</param>
            /// <param name="opt_method" type="string=">Send method, default: GET.</param>
            /// <param name="opt_content" type="string=">Post data.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
            /// <param name="opt_timeoutInterval" type="number=">Number of milliseconds after which an
            ///     incomplete request will be aborted; 0 means no timeout is set.</param>
        }, 
        
        getTimeoutInterval: function() {
            /// <summary>Returns the number of milliseconds after which an incomplete request will be
            /// aborted, or 0 if no timeout is set.</summary>
            /// <returns type="number">Timeout interval in milliseconds.</returns>
        }, 
        
        setTimeoutInterval: function(ms) {
            /// <summary>Sets the number of milliseconds after which an incomplete request will be
            /// aborted and a {@link goog.net.EventType.TIMEOUT} event raised; 0 means no
            /// timeout is set.</summary>
            /// <param name="ms" type="number">Timeout interval in milliseconds; 0 means none.</param>
        }, 
        
        simulateTimeout: function() {
            /// <summary>Causes timeout events to be fired.</summary>
        }, 
        
        setResponseType: function(type) {
            /// <summary>Sets the desired type for the response. At time of writing, this is only
            /// supported in very recent versions of WebKit (10.0.612.1 dev and later).
            /// 
            /// If this is used, the response may only be accessed via {@link #getResponse}.</summary>
            /// <param name="type" type="goog.net.XhrIo.ResponseType">The desired type for the response.</param>
        }, 
        
        getResponseType: function() {
            /// <summary>Gets the desired type for the response.</summary>
            /// <returns type="goog.net.XhrIo.ResponseType">The desired type for the response.</returns>
        }, 
        
        setWithCredentials: function(withCredentials) {
            /// <summary>Sets whether a &quot;credentialed&quot; request that is aware of cookie and
            /// authentication information should be made. This option is only supported by
            /// browsers that support HTTP Access Control. As of this writing, this option
            /// is not supported in IE.</summary>
            /// <param name="withCredentials" type="boolean">Whether this should be a &quot;credentialed&quot;
            ///     request.</param>
        }, 
        
        getWithCredentials: function() {
            /// <summary>Gets whether a &quot;credentialed&quot; request is to be sent.</summary>
            /// <returns type="boolean">The desired type for the response.</returns>
        }, 
        
        abort: function(opt_failureCode) {
            /// <summary>Abort the current XMLHttpRequest</summary>
            /// <param name="opt_failureCode" type="goog.net.ErrorCode=">Optional error code to use -
            ///     defaults to ABORT.</param>
        }, 
        
        send: function(url, opt_method, opt_content, opt_headers) {
            /// <summary>Simulates the XhrIo send.</summary>
            /// <param name="url" type="string">Uri to make request too.</param>
            /// <param name="opt_method" type="string=">Send method, default: GET.</param>
            /// <param name="opt_content" type="string=">Post data.</param>
            /// <param name="opt_headers" type="Object|goog.structs.Map=">Map of headers to add to the
            ///     request.</param>
        }, 
        
        createXhr: function() {
            /// <summary>Creates a new XHR object.</summary>
            /// <returns type="XMLHttpRequest|GearsHttpRequest">The newly created XHR object.</returns>
        }, 
        
        simulateReadyStateChange: function(readyState) {
            /// <summary>Simulates changing to the new ready state.</summary>
            /// <param name="readyState" type="number">Ready state to change to.</param>
        }, 
        
        simulatePartialResponse: function(partialResponse, opt_headers) {
            /// <summary>Simulate receiving some bytes but the request not fully completing, and
            /// the XHR entering the &apos;INTERACTIVE&apos; state.</summary>
            /// <param name="partialResponse" type="string">A string to append to the response text.</param>
            /// <param name="opt_headers" type="Object=">Simulated response headers.</param>
        }, 
        
        simulateResponse: function(statusCode, response, opt_headers) {
            /// <summary>Simulates receiving a response.</summary>
            /// <param name="statusCode" type="number">Simulated status code.</param>
            /// <param name="response" type="string|Document|null">Simulated response.</param>
            /// <param name="opt_headers" type="Object=">Simulated response headers.</param>
        }, 
        
        simulateReady: function() {
            /// <summary>Simulates the Xhr is ready for the next request.</summary>
        }, 
        
        isActive: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether there is an active request.</returns>
        }, 
        
        isComplete: function() {
            /// <summary>Has the request completed.</summary>
            /// <returns type="boolean">Whether the request has completed.</returns>
        }, 
        
        isSuccess: function() {
            /// <summary>Has the request compeleted with a success.</summary>
            /// <returns type="boolean">Whether the request compeleted successfully.</returns>
        }, 
        
        getReadyState: function() {
            /// <summary>Returns the readystate.</summary>
            /// <returns type="number">goog.net.XmlHttp.ReadyState.*.</returns>
        }, 
        
        getStatus: function() {
            /// <summary>Get the status from the Xhr object.  Will only return correct result when
            /// called from the context of a callback.</summary>
            /// <returns type="number">Http status.</returns>
        }, 
        
        getStatusText: function() {
            /// <summary>Get the status text from the Xhr object.  Will only return correct result
            /// when called from the context of a callback.</summary>
            /// <returns type="string">Status text.</returns>
        }, 
        
        getLastErrorCode: function() {
            /// <summary>Gets the last error message.</summary>
            /// <returns type="goog.net.ErrorCode">Last error code.</returns>
        }, 
        
        getLastError: function() {
            /// <summary>Gets the last error message.</summary>
            /// <returns type="string">Last error message.</returns>
        }, 
        
        getLastUri: function() {
            /// <summary>Gets the last URI that was requested.</summary>
            /// <returns type="string">Last URI.</returns>
        }, 
        
        getLastMethod: function() {
            /// <summary>Gets the last HTTP method that was requested.</summary>
            /// <returns type="string|undefined">Last HTTP method used by send.</returns>
        }, 
        
        getLastContent: function() {
            /// <summary>Gets the last POST content that was requested.</summary>
            /// <returns type="string|undefined">Last POST content or undefined if last request was
            ///      a GET.</returns>
        }, 
        
        getLastRequestHeaders: function() {
            /// <summary>Gets the headers of the last request.</summary>
            /// <returns type="Object|goog.structs.Map|undefined">Last headers manually set in send
            ///      call or undefined if no additional headers were specified.</returns>
        }, 
        
        getResponseText: function() {
            /// <summary>Gets the response text from the Xhr object.  Will only return correct result
            /// when called from the context of a callback.</summary>
            /// <returns type="string">Result from the server.</returns>
        }, 
        
        getResponseJson: function(opt_xssiPrefix) {
            /// <summary>Gets the response and evaluates it as JSON from the Xhr object.  Will only
            /// return correct result when called from the context of a callback.</summary>
            /// <param name="opt_xssiPrefix" type="string=">Optional XSSI prefix string to use for
            ///     stripping of the response before parsing. This needs to be set only if
            ///     your backend server prepends the same prefix string to the JSON response.</param>
            /// <returns type="Object">JavaScript object.</returns>
        }, 
        
        getResponseXml: function() {
            /// <summary>Gets the response XML from the Xhr object.  Will only return correct result
            /// when called from the context of a callback.</summary>
            /// <returns type="Document">Result from the server if it was XML.</returns>
        }, 
        
        getResponse: function() {
            /// <summary>Get the response as the type specificed by {@link #setResponseType}. At time
            /// of writing, this is only supported in very recent versions of WebKit
            /// (10.0.612.1 dev and later).</summary>
            /// <returns type="*">The response.</returns>
        }, 
        
        getResponseHeader: function(key) {
            /// <summary>Get the value of the response-header with the given name from the Xhr object
            /// Will only return correct result when called from the context of a callback
            /// and the request has completed</summary>
            /// <param name="key" type="string">The name of the response-header to retrieve.</param>
            /// <returns type="string|undefined">The value of the response-header named key.</returns>
        }, 
        
        getAllResponseHeaders: function() {
            /// <summary>Gets the text of all the headers in the response.
            /// Will only return correct result when called from the context of a callback
            /// and the request has completed</summary>
            /// <returns type="string">The string containing all the response headers.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.testing.net.XhrIo";
})(this);
