
/* vsdoc for goog.tweak */

(function (window) {
    window.goog = window.goog || {};

    window.goog.tweak = {
        /// <summary></summary>
        /// <field name="testhelpers" type=""></field>
        /// <field name="ConfigParams" type=""></field>
        /// <returns type="goog.tweak"/>
                
        getRegistry: function() {
            /// <summary>Returns/creates the registry singleton.</summary>
            /// <returns type="!goog.tweak.Registry">The tweak registry.</returns>
        }, 
        
        beginBooleanGroup: function(id, description, opt_configParams) {
            /// <summary>Creates and registers a group of BooleanSettings that are all set by a
            /// single query parameter. A call to goog.tweak.endBooleanGroup() must be used
            /// to close this group. Only goog.tweak.registerBoolean() calls are allowed with
            /// the beginBooleanGroup()/endBooleanGroup().</summary>
            /// <param name="id" type="string">The unique ID for the setting.</param>
            /// <param name="description" type="string">A description of what the setting does.</param>
            /// <param name="opt_configParams" type="goog.tweak.ConfigParams=">Extra configuration
            ///     parameters.</param>
        }, 
        
        endBooleanGroup: function() {
            /// <summary>Stops adding boolean entries to the active boolean group.</summary>
        }, 
        
        registerBoolean: function(id, description, opt_defaultValue, opt_configParams) {
            /// <summary>Creates and registers a BooleanSetting.</summary>
            /// <param name="id" type="string">The unique ID for the setting.</param>
            /// <param name="description" type="string">A description of what the setting does.</param>
            /// <param name="opt_defaultValue" type="boolean=">The default value for the setting.</param>
            /// <param name="opt_configParams" type="goog.tweak.ConfigParams=">Extra configuration
            ///     parameters.</param>
        }, 
        
        registerString: function(id, description, opt_defaultValue, opt_configParams) {
            /// <summary>Creates and registers a StringSetting.</summary>
            /// <param name="id" type="string">The unique ID for the setting.</param>
            /// <param name="description" type="string">A description of what the setting does.</param>
            /// <param name="opt_defaultValue" type="string=">The default value for the setting.</param>
            /// <param name="opt_configParams" type="goog.tweak.ConfigParams=">Extra configuration
            ///     parameters.</param>
        }, 
        
        registerNumber: function(id, description, opt_defaultValue, opt_configParams) {
            /// <summary>Creates and registers a NumericSetting.</summary>
            /// <param name="id" type="string">The unique ID for the setting.</param>
            /// <param name="description" type="string">A description of what the setting does.</param>
            /// <param name="opt_defaultValue" type="number=">The default value for the setting.</param>
            /// <param name="opt_configParams" type="goog.tweak.ConfigParams=">Extra configuration
            ///     parameters.</param>
        }, 
        
        registerButton: function(id, description, callback, opt_label) {
            /// <summary>Creates and registers a ButtonAction.</summary>
            /// <param name="id" type="string">The unique ID for the setting.</param>
            /// <param name="description" type="string">A description of what the action does.</param>
            /// <param name="callback" type="!Function">Function to call when the button is clicked.</param>
            /// <param name="opt_label" type="string=">The button text (instead of the ID).</param>
        }, 
        
        overrideDefaultValue: function(id, value) {
            /// <summary>Sets a default value to use for the given tweak instead of the one passed
            /// to the register* function. This function must be called before the tweak is
            /// registered.</summary>
            /// <param name="id" type="string">The unique string that identifies the entry.</param>
            /// <param name="value" type="string|number|boolean">The new default value for the tweak.</param>
        }, 
        
        getBoolean: function(id) {
            /// <summary>Returns the value of the boolean setting with the given ID.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="boolean">The value of the tweak.</returns>
        }, 
        
        getString: function(id) {
            /// <summary>Returns the value of the string setting with the given ID,</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="string">The value of the tweak.</returns>
        }, 
        
        getNumber: function(id) {
            /// <summary>Returns the value of the numeric setting with the given ID.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="number">The value of the tweak.</returns>
        }
        
    };

    var $x = window.goog.tweak;
    $x.__namespace = "true";
    $x.__typeName = "goog.tweak";
})(this);
