
/* vsdoc for goog.tweak.BaseSetting */

(function (window) {
    window.goog.tweak = window.goog.tweak || {};

    window.goog.tweak.BaseSetting = function(id, description){
        /// <summary></summary>
        /// <param name="id" type="string">The ID for the setting.</param>
        /// <param name="description" type="string">A description of what the setting does.</param>
        /// <field name="logger" type="!goog.debug.Logger">The logger for this class.</field>
        /// <field name="initialize" type="">Sets the value of the entry based on the value of the query parameter. Once
        /// this is called, configuration settings (associated query parameter, token,
        /// etc) may not be changed.</field>
        /// <field name="getNewValueEncoded" type="?string">Returns the value to be used in the query parameter for this tweak.</field>
        /// <returns type="goog.tweak.BaseSetting"/>
    };

    var $x = window.goog.tweak.BaseSetting;
    $x.prototype = {
                
        assertNotInitialized: function(funcName) {
            /// <summary>Asserts that this tweak has not been initialized yet.</summary>
            /// <param name="funcName" type="string">Function name to use in the assertion message.</param>
        }, 
        
        isInitializing: function() {
            /// <summary>Returns whether the setting is currently being initialized.</summary>
            /// <returns type="boolean">Whether the setting is currently being initialized.</returns>
        }, 
        
        setInitialQueryParamValue: function(value) {
            /// <summary>Sets the initial query parameter value for this setting. May not be called
            /// after the setting has been initialized.</summary>
            /// <param name="value" type="string">The inital query parameter value for this setting.</param>
        }, 
        
        getParamName: function() {
            /// <summary>Returns the name of the query parameter used for this setting.</summary>
            /// <returns type="?string">The param name. Null if no query parameter is directly
            ///     associated with the setting.</returns>
        }, 
        
        setParamName: function(value) {
            /// <summary>Sets the name of the query parameter used for this setting. If null is
            /// passed the the setting will not appear in the top-level query string.</summary>
            /// <param name="value" type="?string">The new value.</param>
        }, 
        
        ensureInitialized: function() {
            /// <summary>Applies the default value or query param value if this is the first time
            /// that the function has been called.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.tweak.BaseSetting";
})(this);
