
/* vsdoc for goog.tweak.Registry */

(function (window) {
    window.goog.tweak = window.goog.tweak || {};

    window.goog.tweak.Registry = function(queryParams, compilerOverrides){
        /// <summary></summary>
        /// <param name="queryParams" type="string">Value of window.location.search.</param>
        /// <param name="compilerOverrides" type="!Object.string|number|boolean">Default value
        ///     overrides set by the compiler.</param>
        /// <returns type="goog.tweak.Registry"/>
    };

    var $x = window.goog.tweak.Registry;
    $x.prototype = {
                
        parseQueryParams: function(queryParams) {
            /// <summary>Simple parser for query params. Makes all keys lower-case.</summary>
            /// <param name="queryParams" type="string">The part of the url between the ? and the #.</param>
            /// <returns type="!Object.string">map of key->value.</returns>
        }, 
        
        register: function(entry) {
            /// <summary>Registers the given tweak setting/action.</summary>
            /// <param name="entry" type="goog.tweak.BaseEntry">The entry.</param>
        }, 
        
        addOnRegisterListener: function(func) {
            /// <summary>Adds a callback to be called whenever a new tweak is added.</summary>
            /// <param name="func" type="!Function">The callback.</param>
        }, 
        
        hasEntry: function(id) {
            /// <summary></summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="boolean">Whether a tweak with the given ID is registered.</returns>
        }, 
        
        getEntry: function(id) {
            /// <summary>Returns the BaseEntry with the given ID. Asserts if it does not exists.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="!goog.tweak.BaseEntry">The entry.</returns>
        }, 
        
        getBooleanSetting: function(id) {
            /// <summary>Returns the boolean setting with the given ID. Asserts if the ID does not
            /// refer to a registered entry or if it refers to one of the wrong type.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="!goog.tweak.BooleanSetting">The entry.</returns>
        }, 
        
        getStringSetting: function(id) {
            /// <summary>Returns the string setting with the given ID. Asserts if the ID does not
            /// refer to a registered entry or if it refers to one of the wrong type.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="!goog.tweak.StringSetting">The entry.</returns>
        }, 
        
        getNumericSetting: function(id) {
            /// <summary>Returns the numeric setting with the given ID. Asserts if the ID does not
            /// refer to a registered entry or if it refers to one of the wrong type.</summary>
            /// <param name="id" type="string">The unique string that identifies this entry.</param>
            /// <returns type="!goog.tweak.NumericSetting">The entry.</returns>
        }, 
        
        extractEntries: function(excludeChildEntries, excludeNonSettings) {
            /// <summary>Creates and returns an array of all BaseSetting objects with an associted
            /// query parameter.</summary>
            /// <param name="excludeChildEntries" type="boolean">Exclude BooleanInGroupSettings.</param>
            /// <param name="excludeNonSettings" type="boolean">Exclude entries that are not subclasses
            ///     of BaseSetting.</param>
            /// <returns type="!Array.!goog.tweak.BaseSetting">The settings.</returns>
        }, 
        
        makeUrlQuery: function(opt_existingSearchStr) {
            /// <summary>Returns the query part of the URL that will apply all set tweaks.</summary>
            /// <param name="opt_existingSearchStr" type="string=">The part of the url between the ? and
            ///     the #. Uses window.location.search if not given.</param>
            /// <returns type="string">The query string.</returns>
        }, 
        
        overrideDefaultValue: function(id, value) {
            /// <summary>Sets a default value to use for the given tweak instead of the one passed
            /// to the register* function. This function must be called before the tweak is
            /// registered.</summary>
            /// <param name="id" type="string">The unique string that identifies the entry.</param>
            /// <param name="value" type="string|number|boolean">The replacement value to be used as the
            ///     default value for the setting.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.tweak.Registry";
})(this);
