
/* vsdoc for goog.ui.AbstractSpellChecker */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.AbstractSpellChecker = function(handler, opt_domHelper){
        /// <summary></summary>
        /// <param name="handler" type="goog.spell.SpellCheck">Instance of the SpellCheckHandler
        ///     support object to use. A single instance can be shared by multiple editor
        ///     components.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="handler_" type="goog.spell.SpellCheck">Handler to use for caching and lookups.</field>
        /// <field name="suggestionsMenuClassName" type="string">Class name for suggestions menu.</field>
        /// <field name="markCorrected" type="boolean">Whether corrected words should be highlighted.</field>
        /// <field name="getElementProperties" type="Object">Returns desired element properties for the specified status.
        /// Should be overridden by implementation.</field>
        /// <field name="Direction" type="">Constants for representing the direction while navigating.</field>
        /// <field name="AsyncResult" type="">Constants for the result of asynchronous processing.</field>
        /// <returns type="goog.ui.AbstractSpellChecker"/>
    };

    var $x = window.goog.ui.AbstractSpellChecker;
    $x.prototype = {
                
        getHandler: function() {
            /// <summary></summary>
            /// <returns type="goog.spell.SpellCheck">The handler used for caching and lookups.</returns>
        }, 
        
        setHandler: function(handler) {
            /// <summary>Sets the handler used for caching and lookups.</summary>
            /// <param name="handler" type="goog.spell.SpellCheck">The handler used for caching and
            ///     lookups.</param>
        }, 
        
        getMenu: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.PopupMenu|undefined">The suggestions menu.</returns>
        }, 
        
        getMenuEdit: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.MenuItem|undefined">The menu item for edit word option.</returns>
        }, 
        
        getNextId: function() {
            /// <summary></summary>
            /// <returns type="number">The next unique instance ID for a misspelled word.</returns>
        }, 
        
        setExcludeMarker: function(marker) {
            /// <summary>Sets the marker for the excluded text.
            /// 
            /// {@see goog.ui.AbstractSpellChecker.prototype.excludeMarker}</summary>
            /// <param name="marker" type="Array.string|string|RegExp|null">A RegExp for plain text
            ///        or class names for the rich text spell checker for the elements to
            ///        exclude from checking.</param>
        }, 
        
        check: function() {
            /// <summary>Checks spelling for all text.
            /// Should be overridden by implementation.</summary>
        }, 
        
        resume: function() {
            /// <summary>Hides correction UI.
            /// Should be overridden by implementation.</summary>
        }, 
        
        isVisible: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the correction ui is visible.</returns>
        }, 
        
        clearWordElements: function() {
            /// <summary>Clears the word to element references map used by replace/ignore.</summary>
        }, 
        
        ignoreWord: function(word) {
            /// <summary>Ignores spelling of word.</summary>
            /// <param name="word" type="string">Word to add.</param>
        }, 
        
        replaceWord: function(el, old, word) {
            /// <summary>Replaces word.</summary>
            /// <param name="el" type="Element">An element wrapping the word that should be replaced.</param>
            /// <param name="old" type="string">Word that was replaced.</param>
            /// <param name="word" type="string">Word to replace with.</param>
        }, 
        
        showSuggestionsMenu: function(el, opt_pos) {
            /// <summary>Displays suggestions menu.</summary>
            /// <param name="el" type="Element">Element to display menu for.</param>
            /// <param name="opt_pos" type="goog.events.BrowserEvent|goog.math.Coordinate=">Position to
            ///     display menu at relative to the viewport (in client coordinates), or a
            ///     mouse event.</param>
        }, 
        
        initSuggestionsMenu: function() {
            /// <summary>Initializes suggestions menu. Populates menu with separator and ignore option
            /// that are always valid. Suggestions are later added above the separator.</summary>
        }, 
        
        onCorrectionAction: function(event) {
            /// <summary>Handles correction menu actions.</summary>
            /// <param name="event" type="goog.events.Event">Action event.</param>
        }, 
        
        removeMarkup: function(el) {
            /// <summary>Removes spell-checker markup and restore the node to text.</summary>
            /// <param name="el" type="Element">Word element. MUST have a text node child.</param>
        }, 
        
        updateElement: function(el, word, status) {
            /// <summary>Updates element based on word status. Either converts it to a text node, or
            /// merges it with the previous or next text node if the status of the world is
            /// VALID, in which case the element itself is eliminated.</summary>
            /// <param name="el" type="Element">Word element.</param>
            /// <param name="word" type="string">Word to update status for.</param>
            /// <param name="status" type="goog.spell.SpellCheck.WordStatus">Status of word.</param>
        }, 
        
        makeElementId: function(opt_id) {
            /// <summary>Generates unique Ids for spell checker elements.</summary>
            /// <param name="opt_id" type="number=">Id to suffix with.</param>
            /// <returns type="string">Unique element id.</returns>
        }, 
        
        getElementById: function(id) {
            /// <summary>Returns the span element that matches the given number id.</summary>
            /// <param name="id" type="number">Number id to make the element id.</param>
            /// <returns type="Element">The matching span element or null if no span matches.</returns>
        }, 
        
        createWordElement_: function(word, status) {
            /// <summary>Creates an element for a specified word and stores a reference to it.</summary>
            /// <param name="word" type="string">Word to create element for.</param>
            /// <param name="status" type="goog.spell.SpellCheck.WordStatus">Status of word.</param>
            /// <returns type="HTMLSpanElement">The created element.</returns>
        }, 
        
        registerWordElement_: function(word, el) {
            /// <summary>Stores a reference to word element.</summary>
            /// <param name="word" type="string">The word to store.</param>
            /// <param name="el" type="HTMLSpanElement">The element associated with it.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        populateDictionary: function(text, words) {
            /// <summary>Precharges local dictionary cache. This is optional, but greatly reduces
            /// amount of subsequent churn in the DOM tree because most of the words become
            /// known from the very beginning.</summary>
            /// <param name="text" type="string">Text to process.</param>
            /// <param name="words" type="number">Max number of words to scan.</param>
            /// <returns type="number">number of words actually scanned.</returns>
        }, 
        
        processWord: function(node, text, status) {
            /// <summary>Processes word.
            /// Should be overridden by implementation.</summary>
            /// <param name="node" type="Node">Node containing word.</param>
            /// <param name="text" type="string">Word to process.</param>
            /// <param name="status" type="goog.spell.SpellCheck.WordStatus">Status of the word.</param>
        }, 
        
        processRange: function(node, text) {
            /// <summary>Processes range of text that checks out (contains no unrecognized words).
            /// Should be overridden by implementation. May contain words and separators.</summary>
            /// <param name="node" type="Node">Node containing text range.</param>
            /// <param name="text" type="string">text to process.</param>
        }, 
        
        initializeAsyncMode: function() {
            /// <summary>Starts asynchronous processing mode.</summary>
        }, 
        
        finishAsyncProcessing: function() {
            /// <summary>Finalizes asynchronous processing mode. Should be called after there is no
            /// more text to process and processTextAsync and/or continueAsyncProcessing
            /// returned FINISHED.</summary>
        }, 
        
        blockReadyEvents: function() {
            /// <summary>Blocks processing of spell checker READY events. This is used in dictionary
            /// recharge and async mode so that completion is not signaled prematurely.</summary>
        }, 
        
        unblockReadyEvents: function() {
            /// <summary>Unblocks processing of spell checker READY events. This is used in
            /// dictionary recharge and async mode so that completion is not signaled
            /// prematurely.</summary>
        }, 
        
        processTextAsync: function(node, text) {
            /// <summary>Splits text into individual words and blocks of separators. Calls virtual
            /// processWord_ and processRange_ methods.</summary>
            /// <param name="node" type="Node">Node containing text.</param>
            /// <param name="text" type="string">Text to process.</param>
            /// <returns type="goog.ui.AbstractSpellChecker.AsyncResult">operation result.</returns>
        }, 
        
        continueAsyncProcessing: function() {
            /// <summary>Continues processing started by processTextAsync. Calls virtual
            /// processWord_ and processRange_ methods.</summary>
            /// <returns type="goog.ui.AbstractSpellChecker.AsyncResult">operation result.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.AbstractSpellChecker";
})(this);
