
/* vsdoc for goog.ui.Button */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Button = function(content, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="content" type="goog.ui.ControlContent">Text caption or existing DOM
        ///     structure to display as the button&apos;s caption.</param>
        /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Renderer used to render or
        ///     decorate the button; defaults to {@link goog.ui.NativeButtonRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM hepler, used for
        ///     document interaction.</param>
        /// <field name="Side" type="">Constants for button sides, see {@link goog.ui.Button.prototype.setCollapsed}
        /// for details. Aliased from goog.ui.ButtonSide to support legacy users without
        /// creating a circular dependency in {@link goog.ui.ButtonRenderer}.</field>
        /// <returns type="goog.ui.Button"/>
    };

    var $x = window.goog.ui.Button;
    $x.prototype = {
                
        getValue: function() {
            /// <summary>Returns the value associated with the button.</summary>
            /// <returns type="*">Button value (undefined if none).</returns>
        }, 
        
        setValue: function(value) {
            /// <summary>Sets the value associated with the button, and updates its DOM.</summary>
            /// <param name="value" type="*">New button value.</param>
        }, 
        
        setValueInternal: function(value) {
            /// <summary>Sets the value associated with the button.  Unlike {@link #setValue},
            /// doesn&apos;t update the button&apos;s DOM.  Considered protected; to be called only
            /// by renderer code during element decoration.</summary>
            /// <param name="value" type="*">New button value.</param>
        }, 
        
        getTooltip: function() {
            /// <summary>Returns the tooltip for the button.</summary>
            /// <returns type="string|undefined">Tooltip text (undefined if none).</returns>
        }, 
        
        setTooltip: function(tooltip) {
            /// <summary>Sets the tooltip for the button, and updates its DOM.</summary>
            /// <param name="tooltip" type="string">New tooltip text.</param>
        }, 
        
        setTooltipInternal: function(tooltip) {
            /// <summary>Sets the tooltip for the button.  Unlike {@link #setTooltip}, doesn&apos;t update
            /// the button&apos;s DOM.  Considered protected; to be called only by renderer code
            /// during element decoration.</summary>
            /// <param name="tooltip" type="string">New tooltip text.</param>
        }, 
        
        setCollapsed: function(sides) {
            /// <summary>Collapses the border on one or both sides of the button, allowing it to be
            /// combined with the adjancent button(s), forming a single UI componenet with
            /// multiple targets.</summary>
            /// <param name="sides" type="number">Bitmap of one or more {@link goog.ui.ButtonSide}s for
            ///     which borders should be collapsed.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        handleKeyEventInternal: function(e) {
            /// <summary>Attempts to handle a keyboard event; returns true if the event was handled,
            /// false otherwise.  If the button is enabled and the Enter/Space key was
            /// pressed, handles the event by dispatching an {@code ACTION} event,
            /// and returns true. Overrides {@link goog.ui.Control#handleKeyEventInternal}.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">Whether the key event was handled.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Button";
})(this);
