
/* vsdoc for goog.ui.ColorMenuButton */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.ColorMenuButton = function(content, opt_menu, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="content" type="goog.ui.ControlContent">Text caption or existing DOM
        ///     structure to display as the button&apos;s caption.</param>
        /// <param name="opt_menu" type="goog.ui.Menu=">Menu to render under the button when clicked;
        ///     should contain at least one {@link goog.ui.ColorPalette} if present.</param>
        /// <param name="opt_renderer" type="goog.ui.MenuButtonRenderer=">Button renderer;
        ///     defaults to {@link goog.ui.ColorMenuButtonRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM hepler, used for
        ///     document interaction.</param>
        /// <field name="PALETTES" type="!Object">Default color palettes.</field>
        /// <field name="NO_COLOR" type="string">Value for the &quot;no color&quot; menu item object in the color menu (if present).
        /// The {@link goog.ui.ColorMenuButton#handleMenuAction} method interprets
        /// ACTION events dispatched by an item with this value as meaning &quot;clear the
        /// selected color.&quot;</field>
        /// <returns type="goog.ui.ColorMenuButton"/>
    };

    var $x = window.goog.ui.ColorMenuButton;
    $x.prototype = {
                
        newColorMenu: function(opt_extraItems, opt_domHelper) {
            /// <summary>Factory method that creates and returns a new {@link goog.ui.Menu} instance
            /// containing default color palettes.</summary>
            /// <param name="opt_extraItems" type="Array.goog.ui.Control=">Optional extra menu items to
            ///     add before the color palettes.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM hepler, used for
            ///     document interaction.</param>
            /// <returns type="goog.ui.Menu">Color menu.</returns>
        }, 
        
        getSelectedColor: function() {
            /// <summary>Returns the currently selected color (null if none).</summary>
            /// <returns type="?string">The selected color.</returns>
        }, 
        
        setSelectedColor: function(color) {
            /// <summary>Sets the selected color, or clears the selected color if the argument is
            /// null or not any of the available color choices.</summary>
            /// <param name="color" type="?string">New color.</param>
        }, 
        
        setValue: function(value) {
            /// <summary>Sets the value associated with the color menu button.  Overrides
            /// {@link goog.ui.Button#setValue} by interpreting the value as a color
            /// spec string.</summary>
            /// <param name="value" type="*">New button value; should be a color spec string.</param>
        }, 
        
        handleMenuAction: function(e) {
            /// <summary>Handles {@link goog.ui.Component.EventType.ACTION} events dispatched by
            /// the menu item clicked by the user.  Updates the button, calls the superclass
            /// implementation to hide the menu, stops the propagation of the event, and
            /// dispatches an ACTION event on behalf of the button itself.  Overrides
            /// {@link goog.ui.MenuButton#handleMenuAction}.</summary>
            /// <param name="e" type="goog.events.Event">Action event to handle.</param>
        }, 
        
        setOpen: function(open, opt_e) {
            /// <summary>Opens or closes the menu.  Overrides {@link goog.ui.MenuButton#setOpen} by
            /// generating a default color menu on the fly if needed.</summary>
            /// <param name="open" type="boolean">Whether to open or close the menu.</param>
            /// <param name="opt_e" type="goog.events.Event=">Mousedown event that caused the menu to
            ///     be opened.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ColorMenuButton";
})(this);
