
/* vsdoc for goog.ui.ColorPicker */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.ColorPicker = function(opt_domHelper, opt_colorPalette){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <param name="opt_colorPalette" type="goog.ui.ColorPalette=">Optional color palette to
        ///     use for this color picker.</param>
        /// <field name="DEFAULT_NUM_COLS" type="number">Default number of columns in the color palette. May be overridden by calling
        /// setSize.</field>
        /// <field name="EventType" type="">Constants for event names.</field>
        /// <field name="SIMPLE_GRID_COLORS" type="Array.<string>">Array of colors for a 7-cell wide simple-grid color picker.</field>
        /// <returns type="goog.ui.ColorPicker"/>
    };

    var $x = window.goog.ui.ColorPicker;
    $x.prototype = {
                
        getColors: function() {
            /// <summary>Gets the array of colors displayed by the color picker.
            /// Modifying this array will lead to unexpected behavior.</summary>
            /// <returns type="Array.string?">The colors displayed by this widget.</returns>
        }, 
        
        setColors: function(colors) {
            /// <summary>Sets the array of colors to be displayed by the color picker.</summary>
            /// <param name="colors" type="Array.string">The array of colors to be added.</param>
        }, 
        
        addColors: function(colors) {
            /// <summary>Sets the array of colors to be displayed by the color picker.</summary>
            /// <param name="colors" type="Array.string">The array of colors to be added.</param>
        }, 
        
        setSize: function(size) {
            /// <summary>Sets the size of the palette.  Will throw an error after the picker has been
            /// rendered.</summary>
            /// <param name="size" type="goog.math.Size|number">The size of the grid.</param>
        }, 
        
        getSize: function() {
            /// <summary>Gets the number of columns displayed.</summary>
            /// <returns type="goog.math.Size?">The size of the grid.</returns>
        }, 
        
        setColumnCount: function(n) {
            /// <summary>Sets the number of columns.  Will throw an error after the picker has been
            /// rendered.</summary>
            /// <param name="n" type="number">The number of columns.</param>
        }, 
        
        getSelectedIndex: function() {
            /// <summary></summary>
            /// <returns type="number">The index of the color selected.</returns>
        }, 
        
        setSelectedIndex: function(ind) {
            /// <summary>Sets which color is selected. A value that is out-of-range means that no
            /// color is selected.</summary>
            /// <param name="ind" type="number">The index in this.colors_ of the selected color.</param>
        }, 
        
        getSelectedColor: function() {
            /// <summary>Gets the color that is currently selected in this color picker.</summary>
            /// <returns type="?string">The hex string of the color selected, or null if no
            ///     color is selected.</returns>
        }, 
        
        setSelectedColor: function(color) {
            /// <summary>Sets which color is selected.  Noop if the color palette hasn&apos;t been created
            /// yet.</summary>
            /// <param name="color" type="string">The selected color.</param>
        }, 
        
        isFocusable: function() {
            /// <summary>Returns true if the component is focusable, false otherwise.  The default
            /// is true.  Focusable components always have a tab index and allocate a key
            /// handler to handle keyboard events while focused.</summary>
            /// <returns type="boolean">True iff the component is focusable.</returns>
        }, 
        
        setFocusable: function(focusable) {
            /// <summary>Sets whether the component is focusable.  The default is true.
            /// Focusable components always have a tab index and allocate a key handler to
            /// handle keyboard events while focused.</summary>
            /// <param name="focusable" type="boolean">True iff the component is focusable.</param>
        }, 
        
        canDecorate: function(element) {
            /// <summary>ColorPickers cannot be used to decorate pre-existing html, since the
            /// structure they build is fairly complicated.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Returns always false.</returns>
        }, 
        
        enterDocument: function() {
            /// <summary>Renders the color picker inside the provided element. This will override the
            /// current content of the element.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        focus: function() {
            /// <summary>Sets the focus to the color picker&apos;s palette.</summary>
        }, 
        
        createSimpleColorGrid: function(opt_domHelper) {
            /// <summary>Returns an unrendered instance of the color picker.  The colors and layout
            /// are a simple color grid, the same as the old Gmail color picker.</summary>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
            /// <returns type="goog.ui.ColorPicker">The unrendered instance.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ColorPicker";
})(this);
