
/* vsdoc for goog.ui.Component */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Component = function(opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="EventType" type="">Common events fired by components so that event propagation is useful.  Not
        /// all components are expected to dispatch or listen for all event types.
        /// Events dispatched before a state transition should be cancelable to prevent
        /// the corresponding state change.</field>
        /// <field name="Error" type="">Errors thrown by the component.</field>
        /// <field name="State" type="">Common component states.  Components may have distinct appearance depending
        /// on what state(s) apply to them.  Not all components are expected to support
        /// all states.</field>
        /// <returns type="goog.ui.Component"/>
    };

    var $x = window.goog.ui.Component;
    $x.prototype = {
                
        getStateTransitionEvent: function(state, isEntering) {
            /// <summary>Static helper method; returns the type of event components are expected to
            /// dispatch when transitioning to or from the given state.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to/from which the component
            ///     is transitioning.</param>
            /// <param name="isEntering" type="boolean">Whether the component is entering or leaving the
            ///     state.</param>
            /// <returns type="goog.ui.Component.EventType">Event type to dispatch.</returns>
        }, 
        
        setDefaultRightToLeft: function(rightToLeft) {
            /// <summary>Set the default right-to-left value. This causes all component&apos;s created from
            /// this point foward to have the given value. This is useful for cases where
            /// a given page is always in one directionality, avoiding unnecessary
            /// right to left determinations.</summary>
            /// <param name="rightToLeft" type="?boolean">Whether the components should be rendered
            ///     right-to-left. Null iff components should determine their directionality.</param>
        }, 
        
        getId: function() {
            /// <summary>Gets the unique ID for the instance of this component.  If the instance
            /// doesn&apos;t already have an ID, generates one on the fly.</summary>
            /// <returns type="string">Unique component ID.</returns>
        }, 
        
        setId: function(id) {
            /// <summary>Assigns an ID to this component instance.  It is the caller&apos;s responsibility
            /// to guarantee that the ID is unique.  If the component is a child of a parent
            /// component, then the parent component&apos;s child index is updated to reflect the
            /// new ID; this may throw an error if the parent already has a child with an ID
            /// that conflicts with the new ID.</summary>
            /// <param name="id" type="string">Unique component ID.</param>
        }, 
        
        getElement: function() {
            /// <summary>Gets the component&apos;s element.</summary>
            /// <returns type="Element">The element for the component.</returns>
        }, 
        
        setElementInternal: function(element) {
            /// <summary>Sets the component&apos;s root element to the given element.  Considered
            /// protected and final.
            /// 
            /// This should generally only be called during createDom. Setting the element
            /// does not actually change which element is rendered, only the element that is
            /// associated with this UI component.</summary>
            /// <param name="element" type="Element">Root element for the component.</param>
        }, 
        
        getElementsByClass: function(className) {
            /// <summary>Returns an array of all the elements in this component&apos;s DOM with the
            /// provided className.</summary>
            /// <param name="className" type="string">The name of the class to look for.</param>
            /// <returns type="!goog.array.ArrayLike">The items found with the class name provided.</returns>
        }, 
        
        getElementByClass: function(className) {
            /// <summary>Returns the first element in this component&apos;s DOM with the provided
            /// className.</summary>
            /// <param name="className" type="string">The name of the class to look for.</param>
            /// <returns type="Element">The first item with the class name provided.</returns>
        }, 
        
        getHandler: function() {
            /// <summary>Returns the event handler for this component, lazily created the first time
            /// this method is called.</summary>
            /// <returns type="!goog.events.EventHandler">Event handler for this component.</returns>
        }, 
        
        setParent: function(parent) {
            /// <summary>Sets the parent of this component to use for event bubbling.  Throws an error
            /// if the component already has a parent or if an attempt is made to add a
            /// component to itself as a child.  Callers must use {@code removeChild | @code removeChildAt} to remove components from their containers before
            /// calling this method.</summary>
            /// <param name="parent" type="goog.ui.Component">The parent component.</param>
        }, 
        
        getParent: function() {
            /// <summary>Returns the component&apos;s parent, if any.</summary>
            /// <returns type="goog.ui.Component?">The parent component.</returns>
        }, 
        
        setParentEventTarget: function(parent) {
            /// <summary>Overrides {@link goog.events.EventTarget#setParentEventTarget} to throw an
            /// error if the parent component is set, and the argument is not the parent.</summary>
            /// <param name="parent" type=""></param>
        }, 
        
        getDomHelper: function() {
            /// <summary>Returns the dom helper that is being used on this component.</summary>
            /// <returns type="!goog.dom.DomHelper">The dom helper used on this component.</returns>
        }, 
        
        isInDocument: function() {
            /// <summary>Determines whether the component has been added to the document.</summary>
            /// <returns type="boolean">TRUE if rendered. Otherwise, FALSE.</returns>
        }, 
        
        createDom: function() {
            /// <summary>Creates the initial DOM representation for the component.  The default
            /// implementation is to set this.element_ = div.</summary>
        }, 
        
        render: function(opt_parentElement) {
            /// <summary>Renders the component.  If a parent element is supplied, the component&apos;s
            /// element will be appended to it.  If there is no optional parent element and
            /// the element doesn&apos;t have a parentNode then it will be appended to the
            /// document body.
            /// 
            /// If this component has a parent component, and the parent component is
            /// not in the document already, then this will not call {@code enterDocument}
            /// on this component.
            /// 
            /// Throws an Error if the component is already rendered.</summary>
            /// <param name="opt_parentElement" type="Element=">Optional parent element to render the
            ///    component into.</param>
        }, 
        
        renderBefore: function(sibling) {
            /// <summary>Renders the component before another element. The other element should be in
            /// the document already.
            /// 
            /// Throws an Error if the component is already rendered.</summary>
            /// <param name="sibling" type="Node">Node to render the component before.</param>
        }, 
        
        decorate: function(element) {
            /// <summary>Decorates the element for the UI component.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Determines if a given element can be decorated by this type of component.
            /// This method should be overridden by inheriting objects.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">True if the element can be decorated, false otherwise.</returns>
        }, 
        
        wasDecorated: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the component was decorated.</returns>
        }, 
        
        decorateInternal: function(element) {
            /// <summary>Actually decorates the element. Should be overridden by inheriting objects.
            /// This method can assume there are checks to ensure the component has not
            /// already been rendered have occurred and that enter document will be called
            /// afterwards. This method is considered protected.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        enterDocument: function() {
            /// <summary>Called when the component&apos;s element is known to be in the document. Anything
            /// using document.getElementById etc. should be done at this stage.
            /// 
            /// If the component contains child components, this call is propagated to its
            /// children.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary>Called by dispose to clean up the elements and listeners created by a
            /// component, or by a parent component/application who has removed the
            /// component from the document but wants to reuse it later.
            /// 
            /// If the component contains child components, this call is propagated to its
            /// children.
            /// 
            /// It should be possible for the component to be rendered again once this method
            /// has been called.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the component.  Calls {@code exitDocument}, which is expected to
            /// remove event handlers and clean up the component.  Propagates the call to
            /// the component&apos;s children, if any. Removes the component&apos;s DOM from the
            /// document unless it was decorated.</summary>
        }, 
        
        makeId: function(idFragment) {
            /// <summary>Helper function for subclasses that gets a unique id for a given fragment,
            /// this can be used by components to generate unique string ids for DOM
            /// elements.</summary>
            /// <param name="idFragment" type="string">A partial id.</param>
            /// <returns type="string">Unique element id.</returns>
        }, 
        
        makeIds: function(object) {
            /// <summary>Makes a collection of ids.  This is a convenience method for makeId.  The
            /// object&apos;s values are the id fragments and the new values are the generated
            /// ids.  The key will remain the same.</summary>
            /// <param name="object" type="Object">The object that will be used to create the ids.</param>
            /// <returns type="Object">An object of id keys to generated ids.</returns>
        }, 
        
        getModel: function() {
            /// <summary>Returns the model associated with the UI component.</summary>
            /// <returns type="*">The model.</returns>
        }, 
        
        setModel: function(obj) {
            /// <summary>Sets the model associated with the UI component.</summary>
            /// <param name="obj" type="*">The model.</param>
        }, 
        
        getFragmentFromId: function(id) {
            /// <summary>Helper function for returning the fragment portion of an id generated using
            /// makeId().</summary>
            /// <param name="id" type="string">Id generated with makeId().</param>
            /// <returns type="string">Fragment.</returns>
        }, 
        
        getElementByFragment: function(idFragment) {
            /// <summary>Helper function for returning an element in the document with a unique id
            /// generated using makeId().</summary>
            /// <param name="idFragment" type="string">The partial id.</param>
            /// <returns type="Element">The element with the unique id, or null if it cannot be
            ///     found.</returns>
        }, 
        
        addChild: function(child, opt_render) {
            /// <summary>Adds the specified component as the last child of this component.  See
            /// {@link goog.ui.Component#addChildAt} for detailed semantics.</summary>
            /// <param name="child" type="goog.ui.Component">The new child component.</param>
            /// <param name="opt_render" type="boolean=">If true, the child component will be rendered
            ///    into the parent.</param>
        }, 
        
        addChildAt: function(child, index, opt_render) {
            /// <summary>Adds the specified component as a child of this component at the given
            /// 0-based index.
            /// 
            /// Both {@code addChild} and {@code addChildAt} assume the following contract
            /// between parent and child components:
            ///  &lt;ul&gt;
            ///    &lt;li&gt;the child component&apos;s element must be a descendant of the parent
            ///        component&apos;s element, and
            ///    &lt;li&gt;the DOM state of the child component must be consistent with the DOM
            ///        state of the parent component (see {@code isInDocument}) in the
            ///        steady state -- the exception is to addChildAt(child, i, false) and
            ///        then immediately decorate/render the child.
            ///  &lt;/ul&gt;
            /// 
            /// In particular, {@code parent.addChild(child)} will throw an error if the
            /// child component is already in the document, but the parent isn&apos;t.
            /// 
            /// Clients of this API may call {@code addChild} and {@code addChildAt} with
            /// {@code opt_render} set to true.  If {@code opt_render} is true, calling these
            /// methods will automatically render the child component&apos;s element into the
            /// parent component&apos;s element.  However, {@code parent.addChild(child, true)}
            /// will throw an error if:
            ///  &lt;ul&gt;
            ///    &lt;li&gt;the parent component has no DOM (i.e. {@code parent.getElement()} is
            ///        null), or
            ///    &lt;li&gt;the child component is already in the document, regardless of the
            ///        parent&apos;s DOM state.
            ///  &lt;/ul&gt;
            /// 
            /// If {@code opt_render} is true and the parent component is not already
            /// in the document, {@code enterDocument} will not be called on this component
            /// at this point.
            /// 
            /// Finally, this method also throws an error if the new child already has a
            /// different parent, or the given index is out of bounds.</summary>
            /// <param name="child" type="goog.ui.Component">The new child component.</param>
            /// <param name="index" type="number">0-based index at which the new child component is to be
            ///    added; must be between 0 and the current child count (inclusive).</param>
            /// <param name="opt_render" type="boolean=">If true, the child component will be rendered
            ///    into the parent.</param>
            /// <returns type="void">Nada.</returns>
        }, 
        
        getContentElement: function() {
            /// <summary>Returns the DOM element into which child components are to be rendered,
            /// or null if the component itself hasn&apos;t been rendered yet.  This default
            /// implementation returns the component&apos;s root element.  Subclasses with
            /// complex DOM structures must override this method.</summary>
            /// <returns type="Element">Element to contain child elements (null if none).</returns>
        }, 
        
        isRightToLeft: function() {
            /// <summary>Returns true if the component is rendered right-to-left, false otherwise.
            /// The first time this function is invoked, the right-to-left rendering property
            /// is set if it has not been already.</summary>
            /// <returns type="boolean">Whether the control is rendered right-to-left.</returns>
        }, 
        
        setRightToLeft: function(rightToLeft) {
            /// <summary>Set is right-to-left. This function should be used if the component needs
            /// to know the rendering direction during dom creation (i.e. before
            /// {@link #enterDocument} is called and is right-to-left is set).</summary>
            /// <param name="rightToLeft" type="boolean">Whether the component is rendered
            ///     right-to-left.</param>
        }, 
        
        hasChildren: function() {
            /// <summary>Returns true if the component has children.</summary>
            /// <returns type="boolean">True if the component has children.</returns>
        }, 
        
        getChildCount: function() {
            /// <summary>Returns the number of children of this component.</summary>
            /// <returns type="number">The number of children.</returns>
        }, 
        
        getChildIds: function() {
            /// <summary>Returns an array containing the IDs of the children of this component, or an
            /// empty array if the component has no children.</summary>
            /// <returns type="Array.string">Child component IDs.</returns>
        }, 
        
        getChild: function(id) {
            /// <summary>Returns the child with the given ID, or null if no such child exists.</summary>
            /// <param name="id" type="string">Child component ID.</param>
            /// <returns type="goog.ui.Component?">The child with the given ID; null if none.</returns>
        }, 
        
        getChildAt: function(index) {
            /// <summary>Returns the child at the given index, or null if the index is out of bounds.</summary>
            /// <param name="index" type="number">0-based index.</param>
            /// <returns type="goog.ui.Component?">The child at the given index; null if none.</returns>
        }, 
        
        forEachChild: function(f, opt_obj) {
            /// <summary>Calls the given function on each of this component&apos;s children in order.  If
            /// {@code opt_obj} is provided, it will be used as the &apos;this&apos; object in the
            /// function when called.  The function should take two arguments:  the child
            /// component and its 0-based index.  The return value is ignored.</summary>
            /// <param name="f" type="Function">The function to call for every child component; should
            ///    take 2 arguments (the child and its index).</param>
            /// <param name="opt_obj" type="Object=">Used as the &apos;this&apos; object in f when called.</param>
        }, 
        
        indexOfChild: function(child) {
            /// <summary>Returns the 0-based index of the given child component, or -1 if no such
            /// child is found.</summary>
            /// <param name="child" type="goog.ui.Component?">The child component.</param>
            /// <returns type="number">0-based index of the child component; -1 if not found.</returns>
        }, 
        
        removeChild: function(child, opt_unrender) {
            /// <summary>Removes the given child from this component, and returns it.  Throws an error
            /// if the argument is invalid or if the specified child isn&apos;t found in the
            /// parent component.  The argument can either be a string (interpreted as the
            /// ID of the child component to remove) or the child component itself.
            /// 
            /// If {@code opt_unrender} is true, calls {@link goog.ui.component#exitDocument}
            /// on the removed child, and subsequently detaches the child&apos;s DOM from the
            /// document.  Otherwise it is the caller&apos;s responsibility to clean up the child
            /// component&apos;s DOM.</summary>
            /// <param name="child" type="string|goog.ui.Component|null">The ID of the child to remove,
            ///    or the child component itself.</param>
            /// <param name="opt_unrender" type="boolean=">If true, calls {@code exitDocument} on the
            ///    removed child component, and detaches its DOM from the document.</param>
            /// <returns type="goog.ui.Component">The removed component, if any.</returns>
        }, 
        
        removeChildAt: function(index, opt_unrender) {
            /// <summary>Removes the child at the given index from this component, and returns it.
            /// Throws an error if the argument is out of bounds, or if the specified child
            /// isn&apos;t found in the parent.  See {@link goog.ui.Component#removeChild} for
            /// detailed semantics.</summary>
            /// <param name="index" type="number">0-based index of the child to remove.</param>
            /// <param name="opt_unrender" type="boolean=">If true, calls {@code exitDocument} on the
            ///    removed child component, and detaches its DOM from the document.</param>
            /// <returns type="goog.ui.Component">The removed component, if any.</returns>
        }, 
        
        removeChildren: function(opt_unrender) {
            /// <summary>Removes every child component attached to this one and returns them.</summary>
            /// <param name="opt_unrender" type="boolean=">If true, calls {@link #exitDocument} on the
            ///    removed child components, and detaches their DOM from the document.</param>
            /// <returns type="!Array.goog.ui.Component">The removed components if any.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Component";
})(this);
