
/* vsdoc for goog.ui.Container */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Container = function(opt_orientation, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_orientation" type="?goog.ui.Container.Orientation=">Container
        ///     orientation; defaults to {@code VERTICAL}.</param>
        /// <param name="opt_renderer" type="goog.ui.ContainerRenderer=">Renderer used to render or
        ///     decorate the container; defaults to {@link goog.ui.ContainerRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for document
        ///     interaction.</param>
        /// <field name="EventType" type="">Container-specific events.</field>
        /// <field name="Orientation" type="">Container orientation constants.</field>
        /// <returns type="goog.ui.Container"/>
    };

    var $x = window.goog.ui.Container;
    $x.prototype = {
                
        getKeyEventTarget: function() {
            /// <summary>Returns the DOM element on which the container is listening for keyboard
            /// events (null if none).</summary>
            /// <returns type="Element">Element on which the container is listening for key
            ///     events.</returns>
        }, 
        
        setKeyEventTarget: function(element) {
            /// <summary>Attaches an element on which to listen for key events.</summary>
            /// <param name="element" type="Element|undefined">The element to attach, or null/undefined
            ///     to attach to the default element.</param>
        }, 
        
        getKeyHandler: function() {
            /// <summary>Returns the keyboard event handler for this container, lazily created the
            /// first time this method is called.  The keyboard event handler listens for
            /// keyboard events on the container&apos;s key event target, as determined by its
            /// renderer.</summary>
            /// <returns type="goog.events.KeyHandler">Keyboard event handler for this container.</returns>
        }, 
        
        getRenderer: function() {
            /// <summary>Returns the renderer used by this container to render itself or to decorate
            /// an existing element.</summary>
            /// <returns type="goog.ui.ContainerRenderer">Renderer used by the container.</returns>
        }, 
        
        setRenderer: function(renderer) {
            /// <summary>Registers the given renderer with the container.  Changing renderers after
            /// the container has already been rendered or decorated is an error.</summary>
            /// <param name="renderer" type="goog.ui.ContainerRenderer">Renderer used by the container.</param>
        }, 
        
        createDom: function() {
            /// <summary>Creates the container&apos;s DOM.</summary>
        }, 
        
        getContentElement: function() {
            /// <summary>Returns the DOM element into which child components are to be rendered,
            /// or null if the container itself hasn&apos;t been rendered yet.  Overrides
            /// {@link goog.ui.Component#getContentElement} by delegating to the renderer.</summary>
            /// <returns type="Element">Element to contain child elements (null if none).</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Returns true if the given element can be decorated by this container.
            /// Overrides {@link goog.ui.Component#canDecorate}.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">True iff the element can be decorated.</returns>
        }, 
        
        decorateInternal: function(element) {
            /// <summary>Decorates the given element with this container. Overrides {@link
            /// goog.ui.Component#decorateInternal}.  Considered protected.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        enterDocument: function() {
            /// <summary>Configures the container after its DOM has been rendered, and sets up event
            /// handling.  Overrides {@link goog.ui.Component#enterDocument}.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary>Cleans up the container before its DOM is removed from the document, and
            /// removes event handlers.  Overrides {@link goog.ui.Component#exitDocument}.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        handleEnterItem: function(e) {
            /// <summary>Handles ENTER events raised by child controls when they are navigated to.</summary>
            /// <param name="e" type="goog.events.Event">ENTER event to handle.</param>
            /// <returns type="boolean">Whether to prevent handleMouseOver from handling
            ///    the event.</returns>
        }, 
        
        handleHighlightItem: function(e) {
            /// <summary>Handles HIGHLIGHT events dispatched by items in the container when
            /// they are highlighted.</summary>
            /// <param name="e" type="goog.events.Event">Highlight event to handle.</param>
        }, 
        
        handleUnHighlightItem: function(e) {
            /// <summary>Handles UNHIGHLIGHT events dispatched by items in the container when
            /// they are unhighlighted.</summary>
            /// <param name="e" type="goog.events.Event">Unhighlight event to handle.</param>
        }, 
        
        handleOpenItem: function(e) {
            /// <summary>Handles OPEN events dispatched by items in the container when they are
            /// opened.</summary>
            /// <param name="e" type="goog.events.Event">Open event to handle.</param>
        }, 
        
        handleCloseItem: function(e) {
            /// <summary>Handles CLOSE events dispatched by items in the container when they are
            /// closed.</summary>
            /// <param name="e" type="goog.events.Event">Close event to handle.</param>
        }, 
        
        handleMouseDown: function(e) {
            /// <summary>Handles mousedown events over the container.  The default implementation
            /// sets the &quot;mouse button pressed&quot; flag and, if the container is focusable,
            /// grabs keyboard focus.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mousedown event to handle.</param>
        }, 
        
        handleDocumentMouseUp: function(e) {
            /// <summary>Handles mouseup events over the document.  The default implementation
            /// clears the &quot;mouse button pressed&quot; flag.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouseup event to handle.</param>
        }, 
        
        handleChildMouseEvents: function(e) {
            /// <summary>Handles mouse events originating from nodes belonging to the controls hosted
            /// in the container.  Locates the child control based on the DOM node that
            /// dispatched the event, and forwards the event to the control for handling.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        getOwnerControl: function(node) {
            /// <summary>Returns the child control that owns the given DOM node, or null if no such
            /// control is found.</summary>
            /// <param name="node" type="Node">DOM node whose owner is to be returned.</param>
            /// <returns type="goog.ui.Control?">Control hosted in the container to which the node
            ///     belongs (if found).</returns>
        }, 
        
        handleFocus: function(e) {
            /// <summary>Handles focus events raised when the container&apos;s key event target receives
            /// keyboard focus.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Focus event to handle.</param>
        }, 
        
        handleBlur: function(e) {
            /// <summary>Handles blur events raised when the container&apos;s key event target loses
            /// keyboard focus.  The default implementation clears the highlight index.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Blur event to handle.</param>
        }, 
        
        handleKeyEvent: function(e) {
            /// <summary>Attempts to handle a keyboard event, if the control is enabled, by calling
            /// {@link handleKeyEventInternal}.  Considered protected; should only be used
            /// within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">Whether the key event was handled.</returns>
        }, 
        
        handleKeyEventInternal: function(e) {
            /// <summary>Attempts to handle a keyboard event; returns true if the event was handled,
            /// false otherwise.  If the container is enabled, and a child is highlighted,
            /// calls the child control&apos;s {@code handleKeyEvent} method to give the control
            /// a chance to handle the event first.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">Whether the event was handled by the container (or one of
            ///     its children).</returns>
        }, 
        
        addChild: function(child, opt_render) {
            /// <summary>Adds the specified control as the last child of this container.  See
            /// {@link goog.ui.Container#addChildAt} for detailed semantics.</summary>
            /// <param name="child" type="goog.ui.Component">The new child control.</param>
            /// <param name="opt_render" type="boolean=">Whether the new child should be rendered
            ///     immediately after being added (defaults to false).</param>
        }, 
        
        addChildAt: function(control, index, opt_render) {
            /// <summary>Adds the control as a child of this container at the given 0-based index.
            /// Overrides {@link goog.ui.Component#addChildAt} by also updating the
            /// container&apos;s highlight index.  Since {@link goog.ui.Component#addChild} uses
            /// {@link #addChildAt} internally, we only need to override this method.</summary>
            /// <param name="control" type="goog.ui.Component">New child.</param>
            /// <param name="index" type="number">Index at which the new child is to be added.</param>
            /// <param name="opt_render" type="boolean=">Whether the new child should be rendered
            ///     immediately after being added (defaults to false).</param>
        }, 
        
        removeChild: function(control, opt_unrender) {
            /// <summary>Removes a child control.  Overrides {@link goog.ui.Component#removeChild} by
            /// updating the highlight index.  Since {@link goog.ui.Component#removeChildAt}
            /// uses {@link #removeChild} internally, we only need to override this method.</summary>
            /// <param name="control" type="string|goog.ui.Component">The ID of the child to remove, or
            ///     the control itself.</param>
            /// <param name="opt_unrender" type="boolean=">Whether to call {@code exitDocument} on the
            ///     removed control, and detach its DOM from the document (defaults to
            ///     false).</param>
            /// <returns type="goog.ui.Control">The removed control, if any.</returns>
        }, 
        
        getOrientation: function() {
            /// <summary>Returns the container&apos;s orientation.</summary>
            /// <returns type="?goog.ui.Container.Orientation">Container orientation.</returns>
        }, 
        
        setOrientation: function(orientation) {
            /// <summary>Sets the container&apos;s orientation.</summary>
            /// <param name="orientation" type="goog.ui.Container.Orientation">Container orientation.</param>
        }, 
        
        isVisible: function() {
            /// <summary>Returns true if the container&apos;s visibility is set to visible, false if
            /// it is set to hidden.  A container that is set to hidden is guaranteed
            /// to be hidden from the user, but the reverse isn&apos;t necessarily true.
            /// A container may be set to visible but can otherwise be obscured by another
            /// element, rendered off-screen, or hidden using direct CSS manipulation.</summary>
            /// <returns type="boolean">Whether the container is set to be visible.</returns>
        }, 
        
        setVisible: function(visible, opt_force) {
            /// <summary>Shows or hides the container.  Does nothing if the container already has
            /// the requested visibility.  Otherwise, dispatches a SHOW or HIDE event as
            /// appropriate, giving listeners a chance to prevent the visibility change.</summary>
            /// <param name="visible" type="boolean">Whether to show or hide the container.</param>
            /// <param name="opt_force" type="boolean=">If true, doesn&apos;t check whether the container
            ///     already has the requested visibility, and doesn&apos;t dispatch any events.</param>
            /// <returns type="boolean">Whether the visibility was changed.</returns>
        }, 
        
        isEnabled: function() {
            /// <summary>Returns true if the container is enabled, false otherwise.</summary>
            /// <returns type="boolean">Whether the container is enabled.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Enables/disables the container based on the {@code enable} argument.
            /// Dispatches an {@code ENABLED | @code DISABLED} event prior to changing
            /// the container&apos;s state, which may be caught and canceled to prevent the
            /// container from changing state.  Also enables/disables child controls.</summary>
            /// <param name="enable" type="boolean">Whether to enable or disable the container.</param>
        }, 
        
        isFocusable: function() {
            /// <summary>Returns true if the container is focusable, false otherwise.  The default
            /// is true.  Focusable containers always have a tab index and allocate a key
            /// handler to handle keyboard events while focused.</summary>
            /// <returns type="boolean">Whether the component is focusable.</returns>
        }, 
        
        setFocusable: function(focusable) {
            /// <summary>Sets whether the container is focusable.  The default is true.  Focusable
            /// containers always have a tab index and allocate a key handler to handle
            /// keyboard events while focused.</summary>
            /// <param name="focusable" type="boolean">Whether the component is to be focusable.</param>
        }, 
        
        isFocusableChildrenAllowed: function() {
            /// <summary>Returns true if the container allows children to be focusable, false
            /// otherwise.  Only effective if the container is not focusable.</summary>
            /// <returns type="boolean">Whether children should be focusable.</returns>
        }, 
        
        setFocusableChildrenAllowed: function(focusable) {
            /// <summary>Sets whether the container allows children to be focusable, false
            /// otherwise.  Only effective if the container is not focusable.</summary>
            /// <param name="focusable" type="boolean">Whether the children should be focusable.</param>
        }, 
        
        isOpenFollowsHighlight: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether highlighting a child component should also open it.</returns>
        }, 
        
        setOpenFollowsHighlight: function(follow) {
            /// <summary>Sets whether highlighting a child component should also open it.</summary>
            /// <param name="follow" type="boolean">Whether highlighting a child component also opens it.</param>
        }, 
        
        getHighlightedIndex: function() {
            /// <summary>Returns the index of the currently highlighted item (-1 if none).</summary>
            /// <returns type="number">Index of the currently highlighted item.</returns>
        }, 
        
        setHighlightedIndex: function(index) {
            /// <summary>Highlights the item at the given 0-based index (if any).  If another item
            /// was previously highlighted, it is un-highlighted.</summary>
            /// <param name="index" type="number">Index of item to highlight (-1 removes the current
            ///     highlight).</param>
        }, 
        
        setHighlighted: function(item) {
            /// <summary>Highlights the given item if it exists and is a child of the container;
            /// otherwise un-highlights the currently highlighted item.</summary>
            /// <param name="item" type="goog.ui.Control">Item to highlight.</param>
        }, 
        
        getHighlighted: function() {
            /// <summary>Returns the currently highlighted item (if any).</summary>
            /// <returns type="goog.ui.Control?">Highlighted item (null if none).</returns>
        }, 
        
        highlightFirst: function() {
            /// <summary>Highlights the first highlightable item in the container</summary>
        }, 
        
        highlightLast: function() {
            /// <summary>Highlights the last highlightable item in the container.</summary>
        }, 
        
        highlightNext: function() {
            /// <summary>Highlights the next highlightable item (or the first if nothing is currently
            /// highlighted).</summary>
        }, 
        
        highlightPrevious: function() {
            /// <summary>Highlights the previous highlightable item (or the last if nothing is
            /// currently highlighted).</summary>
        }, 
        
        highlightHelper: function(fn, startIndex) {
            /// <summary>Helper function that manages the details of moving the highlight among
            /// child controls in response to keyboard events.</summary>
            /// <param name="fn" type="function(number|number) : number">Function that accepts the
            ///     current and maximum indices, and returns the next index to check.</param>
            /// <param name="startIndex" type="number">Start index.</param>
            /// <returns type="boolean">Whether the highlight has changed.</returns>
        }, 
        
        canHighlightItem: function(item) {
            /// <summary>Returns whether the given item can be highlighted.</summary>
            /// <param name="item" type="goog.ui.Control">The item to check.</param>
            /// <returns type="boolean">Whether the item can be highlighted.</returns>
        }, 
        
        setHighlightedIndexFromKeyEvent: function(index) {
            /// <summary>Helper method that sets the highlighted index to the given index in response
            /// to a keyboard event.  The base class implementation simply calls the
            /// {@link #setHighlightedIndex} method, but subclasses can override this
            /// behavior as needed.</summary>
            /// <param name="index" type="number">Index of item to highlight.</param>
        }, 
        
        getOpenItem: function() {
            /// <summary>Returns the currently open (expanded) control in the container (null if
            /// none).</summary>
            /// <returns type="goog.ui.Control?">The currently open control.</returns>
        }, 
        
        isMouseButtonPressed: function() {
            /// <summary>Returns true if the mouse button is pressed, false otherwise.</summary>
            /// <returns type="boolean">Whether the mouse button is pressed.</returns>
        }, 
        
        setMouseButtonPressed: function(pressed) {
            /// <summary>Sets or clears the &quot;mouse button pressed&quot; flag.</summary>
            /// <param name="pressed" type="boolean">Whether the mouse button is presed.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Container";
})(this);
