
/* vsdoc for goog.ui.ContainerRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.ContainerRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of containers rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.ContainerRenderer"/>
    };

    var $x = window.goog.ui.ContainerRenderer;
    $x.prototype = {
                
        getCustomRenderer: function(ctor, cssClassName) {
            /// <summary>Constructs a new renderer and sets the CSS class that the renderer will use
            /// as the base CSS class to apply to all elements rendered by that renderer.
            /// An example to use this function using a menu is:
            /// 
            /// &lt;pre&gt;
            /// var myCustomRenderer = goog.ui.ContainerRenderer.getCustomRenderer(
            ///     goog.ui.MenuRenderer, &apos;my-special-menu&apos;);
            /// var newMenu = new goog.ui.Menu(opt_domHelper, myCustomRenderer);
            /// &lt;/pre&gt;
            /// 
            /// Your styles for the menu can now be:
            /// &lt;pre&gt;
            /// .my-special-menu { }
            /// &lt;/pre&gt;
            /// 
            /// &lt;em&gt;instead&lt;/em&gt; of
            /// &lt;pre&gt;
            /// .CSS_MY_SPECIAL_MENU .goog-menu { }
            /// &lt;/pre&gt;
            /// 
            /// You would want to use this functionality when you want an instance of a
            /// component to have specific styles different than the other components of the
            /// same type in your application.  This avoids using descendant selectors to
            /// apply the specific styles to this component.</summary>
            /// <param name="ctor" type="Function">The constructor of the renderer you want to create.</param>
            /// <param name="cssClassName" type="string">The name of the CSS class for this renderer.</param>
            /// <returns type="goog.ui.ContainerRenderer">An instance of the desired renderer with
            ///     its getCssClass() method overridden to return the supplied custom CSS
            ///     class name.</returns>
        }, 
        
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to the container.
            /// See http://wiki/Main/ARIA for more info.</summary>
            /// <returns type="undefined|string">ARIA role.</returns>
        }, 
        
        enableTabIndex: function(element, enable) {
            /// <summary>Enables or disables the tab index of the element.  Only elements with a
            /// valid tab index can receive focus.</summary>
            /// <param name="element" type="Element">Element whose tab index is to be changed.</param>
            /// <param name="enable" type="boolean">Whether to add or remove the element&apos;s tab index.</param>
        }, 
        
        createDom: function(container) {
            /// <summary>Creates and returns the container&apos;s root element.  The default
            /// simply creates a DIV and applies the renderer&apos;s own CSS class name to it.
            /// To be overridden in subclasses.</summary>
            /// <param name="container" type="goog.ui.Container">Container to render.</param>
            /// <returns type="Element">Root element for the container.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary>Returns the DOM element into which child components are to be rendered,
            /// or null if the container hasn&apos;t been rendered yet.</summary>
            /// <param name="element" type="Element">Root element of the container whose content element
            ///     is to be returned.</param>
            /// <returns type="Element">Element to contain child elements (null if none).</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Default implementation of {@code canDecorate}; returns true if the element
            /// is a DIV, false otherwise.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Whether the renderer can decorate the element.</returns>
        }, 
        
        decorate: function(container, element) {
            /// <summary>Default implementation of {@code decorate} for {@link goog.ui.Container}s.
            /// Decorates the element with the container, and attempts to decorate its child
            /// elements.  Returns the decorated element.</summary>
            /// <param name="container" type="goog.ui.Container">Container to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        setStateFromClassName: function(container, className, baseClass) {
            /// <summary>Sets the container&apos;s state based on the given CSS class name, encountered
            /// during decoration.  CSS class names that don&apos;t represent container states
            /// are ignored.  Considered protected; subclasses should override this method
            /// to support more states and CSS class names.</summary>
            /// <param name="container" type="goog.ui.Container">Container to update.</param>
            /// <param name="className" type="string">CSS class name.</param>
            /// <param name="baseClass" type="string">Base class name used as the root of state-specific
            ///     class names (typically the renderer&apos;s own class name).</param>
        }, 
        
        decorateChildren: function(container, element, opt_firstChild) {
            /// <summary>Takes a container and an element that may contain child elements, decorates
            /// the child elements, and adds the corresponding components to the container
            /// as child components.  Any non-element child nodes (e.g. empty text nodes
            /// introduced by line breaks in the HTML source) are removed from the element.</summary>
            /// <param name="container" type="goog.ui.Container">Container whose children are to be
            ///     discovered.</param>
            /// <param name="element" type="Element">Element whose children are to be decorated.</param>
            /// <param name="opt_firstChild" type="Element=">the first child to be decorated.</param>
        }, 
        
        getDecoratorForChild: function(element) {
            /// <summary>Inspects the element, and creates an instance of {@link goog.ui.Control} or
            /// an appropriate subclass best suited to decorate it.  Returns the control (or
            /// null if no suitable class was found).  This default implementation uses the
            /// element&apos;s CSS class to find the appropriate control class to instantiate.
            /// May be overridden in subclasses.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="goog.ui.Control?">A new control suitable to decorate the element
            ///     (null if none).</returns>
        }, 
        
        initializeDom: function(container) {
            /// <summary>Initializes the container&apos;s DOM when the container enters the document.
            /// Called from {@link goog.ui.Container#enterDocument}.</summary>
            /// <param name="container" type="goog.ui.Container">Container whose DOM is to be initialized
            ///     as it enters the document.</param>
        }, 
        
        getKeyEventTarget: function(container) {
            /// <summary>Returns the element within the container&apos;s DOM that should receive keyboard
            /// focus (null if none).  The default implementation returns the container&apos;s
            /// root element.</summary>
            /// <param name="container" type="goog.ui.Container">Container whose key event target is
            ///     to be returned.</param>
            /// <returns type="Element">Key event target (null if none).</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of containers
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }, 
        
        getClassNames: function(container) {
            /// <summary>Returns all CSS class names applicable to the given container, based on its
            /// state.  The array of class names returned includes the renderer&apos;s own CSS
            /// class, followed by a CSS class indicating the container&apos;s orientation,
            /// followed by any state-specific CSS classes.</summary>
            /// <param name="container" type="goog.ui.Container">Container whose CSS classes are to be
            ///     returned.</param>
            /// <returns type="Array.string">Array of CSS class names applicable to the
            ///     container.</returns>
        }, 
        
        getDefaultOrientation: function() {
            /// <summary>Returns the default orientation of containers rendered or decorated by this
            /// renderer.  The base class implementation returns {@code VERTICAL}.</summary>
            /// <returns type="goog.ui.Container.Orientation">Default orientation for containers
            ///     created or decorated by this renderer.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ContainerRenderer";
})(this);
