
/* vsdoc for goog.ui.Control */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Control = function(content, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure
        ///     to display as the content of the component (if any).</param>
        /// <param name="opt_renderer" type="goog.ui.ControlRenderer=">Renderer used to render or
        ///     decorate the component; defaults to {@link goog.ui.ControlRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper, used for
        ///     document interaction.</param>
        /// <field name="registerDecorator" type="">Maps a CSS class name to a function that returns a new instance of
        /// {@link goog.ui.Control} or a subclass thereof, suitable to decorate
        /// an element that has the specified CSS class.  UI components that extend
        /// {@link goog.ui.Control} and want {@link goog.ui.Container}s to be able
        /// to discover and decorate elements using them should register a factory
        /// function via this API.</field>
        /// <field name="getDecorator" type="goog.ui.Control?">Takes an element and returns a new instance of {@link goog.ui.Control}
        /// or a subclass, suitable to decorate it (based on the element&apos;s CSS class).</field>
        /// <field name="decorate" type="goog.ui.Control?">Takes an element, and decorates it with a {@link goog.ui.Control} instance
        /// if a suitable decorator is found.</field>
        /// <field name="handleContextMenu" type="">Handles contextmenu events.</field>
        /// <returns type="goog.ui.Control"/>
    };

    var $x = window.goog.ui.Control;
    $x.prototype = {
                
        isHandleMouseEvents: function() {
            /// <summary>Returns true if the control is configured to handle its own mouse events,
            /// false otherwise.  Controls not hosted in {@link goog.ui.Container}s have
            /// to handle their own mouse events, but controls hosted in containers may
            /// allow their parent to handle mouse events on their behalf.  Considered
            /// protected; should only be used within this package and by subclasses.</summary>
            /// <returns type="boolean">Whether the control handles its own mouse events.</returns>
        }, 
        
        setHandleMouseEvents: function(enable) {
            /// <summary>Enables or disables mouse event handling for the control.  Containers may
            /// use this method to disable mouse event handling in their child controls.
            /// Considered protected; should only be used within this package and by
            /// subclasses.</summary>
            /// <param name="enable" type="boolean">Whether to enable or disable mouse event handling.</param>
        }, 
        
        getKeyEventTarget: function() {
            /// <summary>Returns the DOM element on which the control is listening for keyboard
            /// events (null if none).</summary>
            /// <returns type="Element">Element on which the control is listening for key
            ///     events.</returns>
        }, 
        
        getKeyHandler: function() {
            /// <summary>Returns the keyboard event handler for this component, lazily created the
            /// first time this method is called.  Considered protected; should only be
            /// used within this package and by subclasses.</summary>
            /// <returns type="goog.events.KeyHandler">Keyboard event handler for this component.</returns>
        }, 
        
        getRenderer: function() {
            /// <summary>Returns the renderer used by this component to render itself or to decorate
            /// an existing element.</summary>
            /// <returns type="goog.ui.ControlRenderer|undefined">Renderer used by the component
            ///     (undefined if none).</returns>
        }, 
        
        setRenderer: function(renderer) {
            /// <summary>Registers the given renderer with the component.  Changing renderers after
            /// the component has entered the document is an error.</summary>
            /// <param name="renderer" type="goog.ui.ControlRenderer">Renderer used by the component.</param>
        }, 
        
        getExtraClassNames: function() {
            /// <summary>Returns any additional class name(s) to be applied to the component&apos;s
            /// root element, or null if no extra class names are needed.</summary>
            /// <returns type="Array.string?">Additional class names to be applied to
            ///     the component&apos;s root element (null if none).</returns>
        }, 
        
        addClassName: function(className) {
            /// <summary>Adds the given class name to the list of classes to be applied to the
            /// component&apos;s root element.</summary>
            /// <param name="className" type="string">Additional class name to be applied to the
            ///     component&apos;s root element.</param>
        }, 
        
        removeClassName: function(className) {
            /// <summary>Removes the given class name from the list of classes to be applied to
            /// the component&apos;s root element.</summary>
            /// <param name="className" type="string">Class name to be removed from the component&apos;s root
            ///     element.</param>
        }, 
        
        enableClassName: function(className, enable) {
            /// <summary>Adds or removes the given class name to/from the list of classes to be
            /// applied to the component&apos;s root element.</summary>
            /// <param name="className" type="string">CSS class name to add or remove.</param>
            /// <param name="enable" type="boolean">Whether to add or remove the class name.</param>
        }, 
        
        createDom: function() {
            /// <summary>Creates the control&apos;s DOM.  Overrides {@link goog.ui.Component#createDom} by
            /// delegating DOM manipulation to the control&apos;s renderer.</summary>
        }, 
        
        getPreferredAriaRole: function() {
            /// <summary>Returns the control&apos;s preferred ARIA role. This can be used by a control to
            /// override the role that would be assigned by the renderer.  This is useful in
            /// cases where a different ARIA role is appropriate for a control because of the
            /// context in which it&apos;s used.  E.g., a {@link goog.ui.MenuButton} added to a
            /// {@link goog.ui.Select} should have an ARIA role of LISTBOX and not MENUITEM.</summary>
            /// <returns type="?goog.dom.a11y.Role">This control&apos;s preferred ARIA role or null if
            ///     no preferred ARIA role is set.</returns>
        }, 
        
        setPreferredAriaRole: function(role) {
            /// <summary>Sets the control&apos;s preferred ARIA role. This can be used to override the role
            /// that would be assigned by the renderer.  This is useful in cases where a
            /// different ARIA role is appropriate for a control because of the
            /// context in which it&apos;s used.  E.g., a {@link goog.ui.MenuButton} added to a
            /// {@link goog.ui.Select} should have an ARIA role of LISTBOX and not MENUITEM.</summary>
            /// <param name="role" type="goog.dom.a11y.Role">This control&apos;s preferred ARIA role.</param>
        }, 
        
        getContentElement: function() {
            /// <summary>Returns the DOM element into which child components are to be rendered,
            /// or null if the control itself hasn&apos;t been rendered yet.  Overrides
            /// {@link goog.ui.Component#getContentElement} by delegating to the renderer.</summary>
            /// <returns type="Element">Element to contain child elements (null if none).</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Returns true if the given element can be decorated by this component.
            /// Overrides {@link goog.ui.Component#canDecorate}.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Whether the element can be decorated by this component.</returns>
        }, 
        
        decorateInternal: function(element) {
            /// <summary>Decorates the given element with this component. Overrides {@link
            /// goog.ui.Component#decorateInternal} by delegating DOM manipulation
            /// to the control&apos;s renderer.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        enterDocument: function() {
            /// <summary>Configures the component after its DOM has been rendered, and sets up event
            /// handling.  Overrides {@link goog.ui.Component#enterDocument}.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary>Cleans up the component before its DOM is removed from the document, and
            /// removes event handlers.  Overrides {@link goog.ui.Component#exitDocument}
            /// by making sure that components that are removed from the document aren&apos;t
            /// focusable (i.e. have no tab index).</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getContent: function() {
            /// <summary>Returns the text caption or DOM structure displayed in the component.</summary>
            /// <returns type="goog.ui.ControlContent">Text caption or DOM structure
            ///     comprising the component&apos;s contents.</returns>
        }, 
        
        setContent: function(content) {
            /// <summary>Sets the component&apos;s content to the given text caption, element, or array of
            /// nodes.  (If the argument is an array of nodes, it must be an actual array,
            /// not an array-like object.)</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM
            ///     structure to set as the component&apos;s contents.</param>
        }, 
        
        setContentInternal: function(content) {
            /// <summary>Sets the component&apos;s content to the given text caption, element, or array
            /// of nodes.  Unlike {@link #setContent}, doesn&apos;t modify the component&apos;s DOM.
            /// Called by renderers during element decoration.  Considered protected; should
            /// only be used within this package and by subclasses.</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to set as the component&apos;s contents.</param>
        }, 
        
        getCaption: function() {
            /// <summary></summary>
            /// <returns type="string">Text caption of the control or empty string if none.</returns>
        }, 
        
        setCaption: function(caption) {
            /// <summary>Sets the text caption of the component.</summary>
            /// <param name="caption" type="string">Text caption of the component.</param>
        }, 
        
        setRightToLeft: function(rightToLeft) {
            /// <summary></summary>
            /// <param name="rightToLeft" type=""></param>
        }, 
        
        isAllowTextSelection: function() {
            /// <summary>Returns true if the control allows text selection within its DOM, false
            /// otherwise.  Controls that disallow text selection have the appropriate
            /// unselectable styling applied to their elements.  Note that controls hosted
            /// in containers will report that they allow text selection even if their
            /// container disallows text selection.</summary>
            /// <returns type="boolean">Whether the control allows text selection.</returns>
        }, 
        
        setAllowTextSelection: function(allow) {
            /// <summary>Allows or disallows text selection within the control&apos;s DOM.</summary>
            /// <param name="allow" type="boolean">Whether the control should allow text selection.</param>
        }, 
        
        isVisible: function() {
            /// <summary>Returns true if the component&apos;s visibility is set to visible, false if
            /// it is set to hidden.  A component that is set to hidden is guaranteed
            /// to be hidden from the user, but the reverse isn&apos;t necessarily true.
            /// A component may be set to visible but can otherwise be obscured by another
            /// element, rendered off-screen, or hidden using direct CSS manipulation.</summary>
            /// <returns type="boolean">Whether the component is visible.</returns>
        }, 
        
        setVisible: function(visible, opt_force) {
            /// <summary>Shows or hides the component.  Does nothing if the component already has
            /// the requested visibility.  Otherwise, dispatches a SHOW or HIDE event as
            /// appropriate, giving listeners a chance to prevent the visibility change.
            /// When showing a component that is both enabled and focusable, ensures that
            /// its key target has a tab index.  When hiding a component that is enabled
            /// and focusable, blurs its key target and removes its tab index.</summary>
            /// <param name="visible" type="boolean">Whether to show or hide the component.</param>
            /// <param name="opt_force" type="boolean=">If true, doesn&apos;t check whether the component
            ///     already has the requested visibility, and doesn&apos;t dispatch any events.</param>
            /// <returns type="boolean">Whether the visibility was changed.</returns>
        }, 
        
        isEnabled: function() {
            /// <summary>Returns true if the component is enabled, false otherwise.</summary>
            /// <returns type="boolean">Whether the component is enabled.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Enables or disables the component.  Does nothing if this state transition
            /// is disallowed.  If the component is both visible and focusable, updates its
            /// focused state and tab index as needed.  If the component is being disabled,
            /// ensures that it is also deactivated and un-highlighted first.  Note that the
            /// component&apos;s enabled/disabled state is &quot;locked&quot; as long as it is hosted in a
            /// {@link goog.ui.Container} that is itself disabled; this is to prevent clients
            /// from accidentally re-enabling a control that is in a disabled container.</summary>
            /// <param name="enable" type="boolean">Whether to enable or disable the component.</param>
        }, 
        
        isHighlighted: function() {
            /// <summary>Returns true if the component is currently highlighted, false otherwise.</summary>
            /// <returns type="boolean">Whether the component is highlighted.</returns>
        }, 
        
        setHighlighted: function(highlight) {
            /// <summary>Highlights or unhighlights the component.  Does nothing if this state
            /// transition is disallowed.</summary>
            /// <param name="highlight" type="boolean">Whether to highlight or unhighlight the component.</param>
        }, 
        
        isActive: function() {
            /// <summary>Returns true if the component is active (pressed), false otherwise.</summary>
            /// <returns type="boolean">Whether the component is active.</returns>
        }, 
        
        setActive: function(active) {
            /// <summary>Activates or deactivates the component.  Does nothing if this state
            /// transition is disallowed.</summary>
            /// <param name="active" type="boolean">Whether to activate or deactivate the component.</param>
        }, 
        
        isSelected: function() {
            /// <summary>Returns true if the component is selected, false otherwise.</summary>
            /// <returns type="boolean">Whether the component is selected.</returns>
        }, 
        
        setSelected: function(select) {
            /// <summary>Selects or unselects the component.  Does nothing if this state transition
            /// is disallowed.</summary>
            /// <param name="select" type="boolean">Whether to select or unselect the component.</param>
        }, 
        
        isChecked: function() {
            /// <summary>Returns true if the component is checked, false otherwise.</summary>
            /// <returns type="boolean">Whether the component is checked.</returns>
        }, 
        
        setChecked: function(check) {
            /// <summary>Checks or unchecks the component.  Does nothing if this state transition
            /// is disallowed.</summary>
            /// <param name="check" type="boolean">Whether to check or uncheck the component.</param>
        }, 
        
        isFocused: function() {
            /// <summary>Returns true if the component is styled to indicate that it has keyboard
            /// focus, false otherwise.  Note that {@code isFocused()} returning true
            /// doesn&apos;t guarantee that the component&apos;s key event target has keyborad focus,
            /// only that it is styled as such.</summary>
            /// <returns type="boolean">Whether the component is styled to indicate as having
            ///     keyboard focus.</returns>
        }, 
        
        setFocused: function(focused) {
            /// <summary>Applies or removes styling indicating that the component has keyboard focus.
            /// Note that unlike the other &quot;set&quot; methods, this method is called as a result
            /// of the component&apos;s element having received or lost keyboard focus, not the
            /// other way around, so calling {@code setFocused(true)} doesn&apos;t guarantee that
            /// the component&apos;s key event target has keyboard focus, only that it is styled
            /// as such.</summary>
            /// <param name="focused" type="boolean">Whether to apply or remove styling to indicate that
            ///     the component&apos;s element has keyboard focus.</param>
        }, 
        
        isOpen: function() {
            /// <summary>Returns true if the component is open (expanded), false otherwise.</summary>
            /// <returns type="boolean">Whether the component is open.</returns>
        }, 
        
        setOpen: function(open) {
            /// <summary>Opens (expands) or closes (collapses) the component.  Does nothing if this
            /// state transition is disallowed.</summary>
            /// <param name="open" type="boolean">Whether to open or close the component.</param>
        }, 
        
        getState: function() {
            /// <summary>Returns the component&apos;s state as a bit mask of {@link
            /// goog.ui.Component.State}s.</summary>
            /// <returns type="number">Bit mask representing component state.</returns>
        }, 
        
        hasState: function(state) {
            /// <summary>Returns true if the component is in the specified state, false otherwise.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to check.</param>
            /// <returns type="boolean">Whether the component is in the given state.</returns>
        }, 
        
        setState: function(state, enable) {
            /// <summary>Sets or clears the given state on the component, and updates its styling
            /// accordingly.  Does nothing if the component is already in the correct state
            /// or if it doesn&apos;t support the specified state.  Doesn&apos;t dispatch any state
            /// transition events; use advisedly.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to set or clear.</param>
            /// <param name="enable" type="boolean">Whether to set or clear the state (if supported).</param>
        }, 
        
        setStateInternal: function(state) {
            /// <summary>Sets the component&apos;s state to the state represented by a bit mask of
            /// {@link goog.ui.Component.State}s.  Unlike {@link #setState}, doesn&apos;t
            /// update the component&apos;s styling, and doesn&apos;t reject unsupported states.
            /// Called by renderers during element decoration.  Considered protected;
            /// should only be used within this package and by subclasses.</summary>
            /// <param name="state" type="number">Bit mask representing component state.</param>
        }, 
        
        isSupportedState: function(state) {
            /// <summary>Returns true if the component supports the specified state, false otherwise.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to check.</param>
            /// <returns type="boolean">Whether the component supports the given state.</returns>
        }, 
        
        setSupportedState: function(state, support) {
            /// <summary>Enables or disables support for the given state. Disabling support
            /// for a state while the component is in that state is an error.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to support or de-support.</param>
            /// <param name="support" type="boolean">Whether the component should support the state.</param>
        }, 
        
        isAutoState: function(state) {
            /// <summary>Returns true if the component provides default event handling for the state,
            /// false otherwise.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to check.</param>
            /// <returns type="boolean">Whether the component provides default event handling for
            ///     the state.</returns>
        }, 
        
        setAutoStates: function(states, enable) {
            /// <summary>Enables or disables automatic event handling for the given state(s).</summary>
            /// <param name="states" type="number">Bit mask of {@link goog.ui.Component.State}s for which
            ///     default event handling is to be enabled or disabled.</param>
            /// <param name="enable" type="boolean">Whether the component should provide default event
            ///     handling for the state(s).</param>
        }, 
        
        isDispatchTransitionEvents: function(state) {
            /// <summary>Returns true if the component is set to dispatch transition events for the
            /// given state, false otherwise.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to check.</param>
            /// <returns type="boolean">Whether the component dispatches transition events for
            ///     the state.</returns>
        }, 
        
        setDispatchTransitionEvents: function(states, enable) {
            /// <summary>Enables or disables transition events for the given state(s).  Controls
            /// handle state transitions internally by default, and only dispatch state
            /// transition events if explicitly requested to do so by calling this method.</summary>
            /// <param name="states" type="number">Bit mask of {@link goog.ui.Component.State}s for
            ///     which transition events should be enabled or disabled.</param>
            /// <param name="enable" type="boolean">Whether transition events should be enabled.</param>
        }, 
        
        isTransitionAllowed: function(state, enable) {
            /// <summary>Returns true if the transition into or out of the given state is allowed to
            /// proceed, false otherwise.  A state transition is allowed under the following
            /// conditions:
            /// &lt;ul&gt;
            ///   &lt;li&gt;the component supports the state,
            ///   &lt;li&gt;the component isn&apos;t already in the target state,
            ///   &lt;li&gt;either the component is configured not to dispatch events for this
            ///       state transition, or a transition event was dispatched and wasn&apos;t
            ///       canceled by any event listener, and
            ///   &lt;li&gt;the component hasn&apos;t been disposed of
            /// &lt;/ul&gt;
            /// Considered protected; should only be used within this package and by
            /// subclasses.</summary>
            /// <param name="state" type="goog.ui.Component.State">State to/from which the control is
            ///     transitioning.</param>
            /// <param name="enable" type="boolean">Whether the control is entering or leaving the state.</param>
            /// <returns type="boolean">Whether the state transition is allowed to proceed.</returns>
        }, 
        
        handleMouseOver: function(e) {
            /// <summary>Handles mouseover events.  Dispatches an ENTER event; if the event isn&apos;t
            /// canceled, the component is enabled, and it supports auto-highlighting,
            /// highlights the component.  Considered protected; should only be used
            /// within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        handleMouseOut: function(e) {
            /// <summary>Handles mouseout events.  Dispatches a LEAVE event; if the event isn&apos;t
            /// canceled, and the component supports auto-highlighting, deactivates and
            /// un-highlights the component.  Considered protected; should only be used
            /// within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        handleMouseDown: function(e) {
            /// <summary>Handles mousedown events.  If the component is enabled, highlights and
            /// activates it.  If the component isn&apos;t configured for keyboard access,
            /// prevents it from receiving keyboard focus.  Considered protected; should
            /// only be used within this package andy by subclasses.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        handleMouseUp: function(e) {
            /// <summary>Handles mouseup events.  If the component is enabled, highlights it.  If
            /// the component has previously been activated, performs its associated action
            /// by calling {@link performActionInternal}, then deactivates it.  Considered
            /// protected; should only be used within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        handleDblClick: function(e) {
            /// <summary>Handles dblclick events.  Should only be registered if the user agent is
            /// IE.  If the component is enabled, performs its associated action by calling
            /// {@link performActionInternal}.  This is used to allow more performant
            /// buttons in IE.  In IE, no mousedown event is fired when that mousedown will
            /// trigger a dblclick event.  Because of this, a user clicking quickly will
            /// only cause ACTION events to fire on every other click.  This is a workaround
            /// to generate ACTION events for every click.  Unfortunately, this workaround
            /// won&apos;t ever trigger the ACTIVE state.  This is roughly the same behaviour as
            /// if this were a &apos;button&apos; element with a listener on mouseup.  Considered
            /// protected; should only be used within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        performActionInternal: function(e) {
            /// <summary>Performs the appropriate action when the control is activated by the user.
            /// The default implementation first updates the checked and selected state of
            /// controls that support them, then dispatches an ACTION event.  Considered
            /// protected; should only be used within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.Event">Event that triggered the action.</param>
            /// <returns type="boolean">Whether the action is allowed to proceed.</returns>
        }, 
        
        handleFocus: function(e) {
            /// <summary>Handles focus events on the component&apos;s key event target element.  If the
            /// component is focusable, updates its state and styling to indicate that it
            /// now has keyboard focus.  Considered protected; should only be used within
            /// this package and by subclasses.  <b>Warning:</b> IE dispatches focus and
            /// blur events asynchronously!</summary>
            /// <param name="e" type="goog.events.Event">Focus event to handle.</param>
        }, 
        
        handleBlur: function(e) {
            /// <summary>Handles blur events on the component&apos;s key event target element.  Always
            /// deactivates the component.  In addition, if the component is focusable,
            /// updates its state and styling to indicate that it no longer has keyboard
            /// focus.  Considered protected; should only be used within this package and
            /// by subclasses.  <b>Warning:</b> IE dispatches focus and blur events
            /// asynchronously!</summary>
            /// <param name="e" type="goog.events.Event">Blur event to handle.</param>
        }, 
        
        handleKeyEvent: function(e) {
            /// <summary>Attempts to handle a keyboard event, if the component is enabled and visible,
            /// by calling {@link handleKeyEventInternal}.  Considered protected; should only
            /// be used within this package and by subclasses.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">Whether the key event was handled.</returns>
        }, 
        
        handleKeyEventInternal: function(e) {
            /// <summary>Attempts to handle a keyboard event; returns true if the event was handled,
            /// false otherwise.  Considered protected; should only be used within this
            /// package and by subclasses.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">Whether the key event was handled.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Control";
})(this);
