
/* vsdoc for goog.ui.ControlRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.ControlRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <field name="IE6_CLASS_COMBINATIONS" type="Array.<Array.<string>>">Array of arrays of CSS classes that we want composite classes added and
        /// removed for in IE6 and lower as a workaround for lack of multi-class CSS
        /// selector support.
        /// 
        /// Subclasses that have accompanying CSS requiring this workaround should define
        /// their own static IE6_CLASS_COMBINATIONS constant and override
        /// getIe6ClassCombinations to return it.
        /// 
        /// For example, if your stylesheet uses the selector .button.collapse-left
        /// (and is compiled to .button_collapse-left for the IE6 version of the
        /// stylesheet,) you should include [&apos;button&apos;, &apos;collapse-left&apos;] in this array
        /// and the class button_collapse-left will be applied to the root element
        /// whenever both button and collapse-left are applied individually.
        /// 
        /// Members of each class name combination will be joined with underscores in the
        /// order that they&apos;re defined in the array. You should alphabetize them (for
        /// compatibility with the CSS compiler) unless you are doing something special.</field>
        /// <returns type="goog.ui.ControlRenderer"/>
    };

    var $x = window.goog.ui.ControlRenderer;
    $x.prototype = {
                
        getCustomRenderer: function(ctor, cssClassName) {
            /// <summary>Constructs a new renderer and sets the CSS class that the renderer will use
            /// as the base CSS class to apply to all elements rendered by that renderer.
            /// An example to use this function using a color palette:
            /// 
            /// &lt;pre&gt;
            /// var myCustomRenderer = goog.ui.ControlRenderer.getCustomRenderer(
            ///     goog.ui.PaletteRenderer, &apos;my-special-palette&apos;);
            /// var newColorPalette = new goog.ui.ColorPalette(
            ///     colors, myCustomRenderer, opt_domHelper);
            /// &lt;/pre&gt;
            /// 
            /// Your CSS can look like this now:
            /// &lt;pre&gt;
            /// .my-special-palette { }
            /// .my-special-palette-table { }
            /// .my-special-palette-cell { }
            /// etc.
            /// &lt;/pre&gt;
            /// 
            /// &lt;em&gt;instead&lt;/em&gt; of
            /// &lt;pre&gt;
            /// .CSS_MY_SPECIAL_PALETTE .goog-palette { }
            /// .CSS_MY_SPECIAL_PALETTE .goog-palette-table { }
            /// .CSS_MY_SPECIAL_PALETTE .goog-palette-cell { }
            /// etc.
            /// &lt;/pre&gt;
            /// 
            /// You would want to use this functionality when you want an instance of a
            /// component to have specific styles different than the other components of the
            /// same type in your application.  This avoids using descendant selectors to
            /// apply the specific styles to this component.</summary>
            /// <param name="ctor" type="Function">The constructor of the renderer you are trying to
            ///     create.</param>
            /// <param name="cssClassName" type="string">The name of the CSS class for this renderer.</param>
            /// <returns type="goog.ui.ControlRenderer">An instance of the desired renderer with
            ///     its getCssClass() method overridden to return the supplied custom CSS
            ///     class name.</returns>
        }, 
        
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to the control.
            /// See http://wiki/Main/ARIA for more info.</summary>
            /// <returns type="goog.dom.a11y.Role|undefined">ARIA role.</returns>
        }, 
        
        createDom: function(control) {
            /// <summary>Returns the control&apos;s contents wrapped in a DIV, with the renderer&apos;s own
            /// CSS class and additional state-specific classes applied to it.</summary>
            /// <param name="control" type="goog.ui.Control">Control to render.</param>
            /// <returns type="Element">Root element for the control.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary>Takes the control&apos;s root element and returns the parent element of the
            /// control&apos;s contents.  Since by default controls are rendered as a single
            /// DIV, the default implementation returns the element itself.  Subclasses
            /// with more complex DOM structures must override this method as needed.</summary>
            /// <param name="element" type="Element">Root element of the control whose content element
            ///     is to be returned.</param>
            /// <returns type="Element">The control&apos;s content element.</returns>
        }, 
        
        enableClassName: function(control, className, enable) {
            /// <summary>Updates the control&apos;s DOM by adding or removing the specified class name
            /// to/from its root element. May add additional combined classes as needed in
            /// IE6 and lower. Because of this, subclasses should use this method when
            /// modifying class names on the control&apos;s root element.</summary>
            /// <param name="control" type="goog.ui.Control|Element">Control instance (or root element)
            ///     to be updated.</param>
            /// <param name="className" type="string">CSS class name to add or remove.</param>
            /// <param name="enable" type="boolean">Whether to add or remove the class name.</param>
        }, 
        
        enableExtraClassName: function(control, className, enable) {
            /// <summary>Updates the control&apos;s DOM by adding or removing the specified extra class
            /// name to/from its element.</summary>
            /// <param name="control" type="goog.ui.Control">Control to be updated.</param>
            /// <param name="className" type="string">CSS class name to add or remove.</param>
            /// <param name="enable" type="boolean">Whether to add or remove the class name.</param>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Returns true if this renderer can decorate the element, false otherwise.
            /// The default implementation always returns true.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Whether the renderer can decorate the element.</returns>
        }, 
        
        decorate: function(control, element) {
            /// <summary>Default implementation of {@code decorate} for {@link goog.ui.Control}s.
            /// Initializes the control&apos;s ID, content, and state based on the ID of the
            /// element, its child nodes, and its CSS classes, respectively.  Returns the
            /// element.</summary>
            /// <param name="control" type="goog.ui.Control">Control instance to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        initializeDom: function(control) {
            /// <summary>Initializes the control&apos;s DOM by configuring properties that can only be set
            /// after the DOM has entered the document.  This implementation sets up BiDi
            /// and keyboard focus.  Called from {@link goog.ui.Control#enterDocument}.</summary>
            /// <param name="control" type="goog.ui.Control">Control whose DOM is to be initialized
            ///     as it enters the document.</param>
        }, 
        
        setAriaRole: function(element, opt_preferredRole) {
            /// <summary>Sets the element&apos;s ARIA role.</summary>
            /// <param name="element" type="Element">Element to update.</param>
            /// <param name="opt_preferredRole" type="?goog.dom.a11y.Role=">The preferred ARIA role.</param>
        }, 
        
        setAriaStates: function(control, element) {
            /// <summary>Sets the element&apos;s ARIA states. An element does not need an ARIA role in
            /// order to have an ARIA state. Only states which are initialized to be true
            /// will be set.</summary>
            /// <param name="control" type="!goog.ui.Control">Control whose ARIA state will be updated.</param>
            /// <param name="element" type="!Element">Element whose ARIA state is to be updated.</param>
        }, 
        
        setAllowTextSelection: function(element, allow) {
            /// <summary>Allows or disallows text selection within the control&apos;s DOM.</summary>
            /// <param name="element" type="Element">The control&apos;s root element.</param>
            /// <param name="allow" type="boolean">Whether the element should allow text selection.</param>
        }, 
        
        setRightToLeft: function(element, rightToLeft) {
            /// <summary>Applies special styling to/from the control&apos;s element if it is rendered
            /// right-to-left, and removes it if it is rendered left-to-right.</summary>
            /// <param name="element" type="Element">The control&apos;s root element.</param>
            /// <param name="rightToLeft" type="boolean">Whether the component is rendered
            ///     right-to-left.</param>
        }, 
        
        isFocusable: function(control) {
            /// <summary>Returns true if the control&apos;s key event target supports keyboard focus
            /// (based on its {@code tabIndex} attribute), false otherwise.</summary>
            /// <param name="control" type="goog.ui.Control">Control whose key event target is to be
            ///     checked.</param>
            /// <returns type="boolean">Whether the control&apos;s key event target is focusable.</returns>
        }, 
        
        setFocusable: function(control, focusable) {
            /// <summary>Updates the control&apos;s key event target to make it focusable or non-focusable
            /// via its {@code tabIndex} attribute.  Does nothing if the control doesn&apos;t
            /// support the {@code FOCUSED} state, or if it has no key event target.</summary>
            /// <param name="control" type="goog.ui.Control">Control whose key event target is to be
            ///     updated.</param>
            /// <param name="focusable" type="boolean">Whether to enable keyboard focus support on the
            ///     control&apos;s key event target.</param>
        }, 
        
        setVisible: function(element, visible) {
            /// <summary>Shows or hides the element.</summary>
            /// <param name="element" type="Element">Element to update.</param>
            /// <param name="visible" type="boolean">Whether to show the element.</param>
        }, 
        
        setState: function(control, state, enable) {
            /// <summary>Updates the appearance of the control in response to a state change.</summary>
            /// <param name="control" type="goog.ui.Control">Control instance to update.</param>
            /// <param name="state" type="goog.ui.Component.State">State to enable or disable.</param>
            /// <param name="enable" type="boolean">Whether the control is entering or exiting the state.</param>
        }, 
        
        updateAriaState: function(element, state, enable) {
            /// <summary>Updates the element&apos;s ARIA (accessibility) state.</summary>
            /// <param name="element" type="Element">Element whose ARIA state is to be updated.</param>
            /// <param name="state" type="goog.ui.Component.State">Component state being enabled or
            ///     disabled.</param>
            /// <param name="enable" type="boolean">Whether the state is being enabled or disabled.</param>
        }, 
        
        setContent: function(element, content) {
            /// <summary>Takes a control&apos;s root element, and sets its content to the given text
            /// caption or DOM structure.  The default implementation replaces the children
            /// of the given element.  Renderers that create more complex DOM structures
            /// must override this method accordingly.</summary>
            /// <param name="element" type="Element">The control&apos;s root element.</param>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure to be
            ///     set as the control&apos;s content. The DOM nodes will not be cloned, they
            ///     will only moved under the content element of the control.</param>
        }, 
        
        getKeyEventTarget: function(control) {
            /// <summary>Returns the element within the component&apos;s DOM that should receive keyboard
            /// focus (null if none).  The default implementation returns the control&apos;s root
            /// element.</summary>
            /// <param name="control" type="goog.ui.Control">Control whose key event target is to be
            ///     returned.</param>
            /// <returns type="Element">The key event target.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class name to be applied to the root element of all
            /// components rendered or decorated using this renderer.  The class name
            /// is expected to uniquely identify the renderer class, i.e. no two
            /// renderer classes are expected to share the same CSS class name.</summary>
            /// <returns type="string">Renderer-specific CSS class name.</returns>
        }, 
        
        getIe6ClassCombinations: function() {
            /// <summary>Returns an array of combinations of classes to apply combined class names for
            /// in IE6 and below. See {@link IE6_CLASS_COMBINATIONS} for more detail. This
            /// method doesn&apos;t reference {@link IE6_CLASS_COMBINATIONS} so that it can be
            /// compiled out, but subclasses should return their IE6_CLASS_COMBINATIONS
            /// static constant instead.</summary>
            /// <returns type="Array.Array.&lt;string&gt;">Array of class name combinations.</returns>
        }, 
        
        getStructuralCssClass: function() {
            /// <summary>Returns the name of a DOM structure-specific CSS class to be applied to the
            /// root element of all components rendered or decorated using this renderer.
            /// Unlike the class name returned by {@link #getCssClass}, the structural class
            /// name may be shared among different renderers that generate similar DOM
            /// structures.  The structural class name also serves as the basis of derived
            /// class names used to identify and style structural elements of the control&apos;s
            /// DOM, as well as the basis for state-specific class names.  The default
            /// implementation returns the same class name as {@link #getCssClass}, but
            /// subclasses are expected to override this method as needed.</summary>
            /// <returns type="string">DOM structure-specific CSS class name (same as the renderer-
            ///     specific CSS class name by default).</returns>
        }, 
        
        getClassNames: function(control) {
            /// <summary>Returns all CSS class names applicable to the given control, based on its
            /// state.  The return value is an array of strings containing
            /// &lt;ol&gt;
            ///   &lt;li&gt;the renderer-specific CSS class returned by {@link #getCssClass},
            ///       followed by
            ///   &lt;li&gt;the structural CSS class returned by {@link getStructuralCssClass} (if
            ///       different from the renderer-specific CSS class), followed by
            ///   &lt;li&gt;any state-specific classes returned by {@link #getClassNamesForState},
            ///       followed by
            ///   &lt;li&gt;any extra classes returned by the control&apos;s {@code getExtraClassNames}
            ///       method and
            ///   &lt;li&gt;for IE6 and lower, additional combined classes from
            ///       {@link getAppliedCombinedClassNames_}.
            /// &lt;/ol&gt;
            /// Since all controls have at least one renderer-specific CSS class name, this
            /// method is guaranteed to return an array of at least one element.</summary>
            /// <param name="control" type="goog.ui.Control">Control whose CSS classes are to be
            ///     returned.</param>
            /// <returns type="Array.string">Array of CSS class names applicable to the control.</returns>
        }, 
        
        getClassNamesForState: function(state) {
            /// <summary>Takes a bit mask of {@link goog.ui.Component.State}s, and returns an array
            /// of the appropriate class names representing the given state, suitable to be
            /// applied to the root element of a component rendered using this renderer, or
            /// null if no state-specific classes need to be applied.  This default
            /// implementation uses the renderer&apos;s {@link getClassForState} method to
            /// generate each state-specific class.</summary>
            /// <param name="state" type="number">Bit mask of component states.</param>
            /// <returns type="!Array.string">Array of CSS class names representing the given
            ///     state.</returns>
        }, 
        
        getClassForState: function(state) {
            /// <summary>Takes a single {@link goog.ui.Component.State}, and returns the
            /// corresponding CSS class name (null if none).</summary>
            /// <param name="state" type="goog.ui.Component.State">Component state.</param>
            /// <returns type="string|undefined">CSS class representing the given state (undefined
            ///     if none).</returns>
        }, 
        
        getStateFromClass: function(className) {
            /// <summary>Takes a single CSS class name which may represent a component state, and
            /// returns the corresponding component state (0x00 if none).</summary>
            /// <param name="className" type="string">CSS class name, possibly representing a component
            ///     state.</param>
            /// <returns type="goog.ui.Component.State">state Component state corresponding
            ///     to the given CSS class (0x00 if none).</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ControlRenderer";
})(this);
