
/* vsdoc for goog.ui.CustomButtonRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.CustomButtonRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.CustomButtonRenderer"/>
    };

    var $x = window.goog.ui.CustomButtonRenderer;
    $x.prototype = {
                
        createDom: function(control) {
            /// <summary>Returns the button&apos;s contents wrapped in the following DOM structure:
            ///    &lt;div class=&quot;goog-inline-block goog-custom-button&quot;&gt;
            ///      &lt;div class=&quot;goog-inline-block goog-custom-button-outer-box&quot;&gt;
            ///        &lt;div class=&quot;goog-inline-block goog-custom-button-inner-box&quot;&gt;
            ///          Contents...
            ///        &lt;/div&gt;
            ///      &lt;/div&gt;
            ///    &lt;/div&gt;
            /// Overrides {@link goog.ui.ButtonRenderer#createDom}.</summary>
            /// <param name="control" type="goog.ui.Control">goog.ui.Button to render.</param>
            /// <returns type="Element">Root element for the button.</returns>
        }, 
        
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to custom buttons.</summary>
            /// <returns type="goog.dom.a11y.Role|undefined">ARIA role.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary>Takes the button&apos;s root element and returns the parent element of the
            /// button&apos;s contents.  Overrides the superclass implementation by taking
            /// the nested DIV structure of custom buttons into account.</summary>
            /// <param name="element" type="Element">Root element of the button whose content
            ///     element is to be returned.</param>
            /// <returns type="Element">The button&apos;s content element (if any).</returns>
        }, 
        
        createButton: function(content, dom) {
            /// <summary>Takes a text caption or existing DOM structure, and returns the content
            /// wrapped in a pseudo-rounded-corner box.  Creates the following DOM structure:
            ///  &lt;div class=&quot;goog-inline-block goog-custom-button-outer-box&quot;&gt;
            ///    &lt;div class=&quot;goog-inline-block goog-custom-button-inner-box&quot;&gt;
            ///      Contents...
            ///    &lt;/div&gt;
            ///  &lt;/div&gt;
            /// Used by both {@link #createDom} and {@link #decorate}.  To be overridden
            /// by subclasses.</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure to wrap
            ///     in a box.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Pseudo-rounded-corner box containing the content.</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Returns true if this renderer can decorate the element.  Overrides
            /// {@link goog.ui.ButtonRenderer#canDecorate} by returning true if the
            /// element is a DIV, false otherwise.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Whether the renderer can decorate the element.</returns>
        }, 
        
        hasBoxStructure: function(button, element) {
            /// <summary>Check if the button&apos;s element has a box structure.</summary>
            /// <param name="button" type="goog.ui.Button">Button instance whose structure is being
            ///     checked.</param>
            /// <param name="element" type="Element">Element of the button.</param>
            /// <returns type="boolean">Whether the element has a box structure.</returns>
        }, 
        
        decorate: function(control, element) {
            /// <summary>Takes an existing element and decorates it with the custom button control.
            /// Initializes the control&apos;s ID, content, tooltip, value, and state based
            /// on the ID of the element, its child nodes, and its CSS classes, respectively.
            /// Returns the element.  Overrides {@link goog.ui.ButtonRenderer#decorate}.</summary>
            /// <param name="control" type="goog.ui.Control">Button instance to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.CustomButtonRenderer";
})(this);
