
/* vsdoc for goog.ui.DatePicker */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.DatePicker = function(opt_date, opt_dateTimeSymbols, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_date" type="goog.date.Date|Date=">Date to initialize the date picker
        ///     with, defaults to the current date.</param>
        /// <param name="opt_dateTimeSymbols" type="Object=">Date and time symbols to use.
        ///     Defaults to goog.i18n.DateTimeSymbols if not set.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="Events" type="Object">Constants for event names</field>
        /// <field name="isCreated" type=""></field>
        /// <field name="create" type=""></field>
        /// <returns type="goog.ui.DatePicker"/>
    };

    var $x = window.goog.ui.DatePicker;
    $x.prototype = {
                
        getFirstWeekday: function() {
            /// <summary></summary>
            /// <returns type="number">The first day of week, 0 = Monday, 6 = Sunday.</returns>
        }, 
        
        getWeekdayClass: function(wday) {
            /// <summary>Returns the class name associated with specified weekday.</summary>
            /// <param name="wday" type="number">The week day number to get the class name for.</param>
            /// <returns type="string">The class name associated with specified weekday.</returns>
        }, 
        
        getShowFixedNumWeeks: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether a fixed number of weeks should be showed. If not
            ///     only weeks for the current month will be shown.</returns>
        }, 
        
        getShowOtherMonths: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether a days from the previous and/or next month should
            ///     be shown.</returns>
        }, 
        
        getExtraWeekAtEnd: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether a the extra week(s) added always should be at the
            ///     end. Only applicable if a fixed number of weeks are shown.</returns>
        }, 
        
        getShowWeekNum: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether week numbers should be shown.</returns>
        }, 
        
        getShowWeekdayNames: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether weekday names should be shown.</returns>
        }, 
        
        getAllowNone: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether none is a valid selection.</returns>
        }, 
        
        getShowToday: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the today button should be shown.</returns>
        }, 
        
        getBaseCssClass: function() {
            /// <summary>Returns base CSS class. This getter is used to get base CSS class part.
            /// All CSS class names in component are created as:
            ///   goog.getCssName(this.getBaseCssClass(), &apos;CLASS_NAME&apos;)</summary>
            /// <returns type="string">Base CSS class.</returns>
        }, 
        
        setFirstWeekday: function(wday) {
            /// <summary>Sets the first day of week</summary>
            /// <param name="wday" type="number">Week day, 0 = Monday, 6 = Sunday.</param>
        }, 
        
        setWeekdayClass: function(wday, className) {
            /// <summary>Sets class name associated with specified weekday.</summary>
            /// <param name="wday" type="number">Week day, 0 = Monday, 6 = Sunday.</param>
            /// <param name="className" type="string">Class name.</param>
        }, 
        
        setShowFixedNumWeeks: function(b) {
            /// <summary>Sets whether a fixed number of weeks should be showed. If not only weeks
            /// for the current month will be showed.</summary>
            /// <param name="b" type="boolean">Whether a fixed number of weeks should be showed.</param>
        }, 
        
        setShowOtherMonths: function(b) {
            /// <summary>Sets whether a days from the previous and/or next month should be shown.</summary>
            /// <param name="b" type="boolean">Whether a days from the previous and/or next month should
            ///     be shown.</param>
        }, 
        
        setUseSimpleNavigationMenu: function(b) {
            /// <summary>Sets whether the picker should use a simple navigation menu that only
            /// contains controls for navigating to the next and previous month. The default
            /// navigation menu contains controls for navigating to the next/previous month,
            /// next/previous year, and menus for jumping to specific months and years.</summary>
            /// <param name="b" type="boolean">Whether to use a simple navigation menu.</param>
        }, 
        
        setExtraWeekAtEnd: function(b) {
            /// <summary>Sets whether a the extra week(s) added always should be at the end. Only
            /// applicable if a fixed number of weeks are shown.</summary>
            /// <param name="b" type="boolean">Whether a the extra week(s) added always should be at the
            ///     end.</param>
        }, 
        
        setShowWeekNum: function(b) {
            /// <summary>Sets whether week numbers should be shown.</summary>
            /// <param name="b" type="boolean">Whether week numbers should be shown.</param>
        }, 
        
        setShowWeekdayNames: function(b) {
            /// <summary>Sets whether weekday names should be shown.</summary>
            /// <param name="b" type="boolean">Whether weekday names should be shown.</param>
        }, 
        
        setUseNarrowWeekdayNames: function(b) {
            /// <summary>Sets whether the picker uses narrow weekday names (&apos;M&apos;, &apos;T&apos;, &apos;W&apos;, ...).
            /// 
            /// The default behavior is to use short names (&apos;Mon&apos;, &apos;Tue&apos;, &apos;Wed&apos;, ...).</summary>
            /// <param name="b" type="boolean">Whether to use narrow weekday names.</param>
        }, 
        
        setAllowNone: function(b) {
            /// <summary>Sets whether none is a valid selection.</summary>
            /// <param name="b" type="boolean">Whether none is a valid selection.</param>
        }, 
        
        setShowToday: function(b) {
            /// <summary>Sets whether the today button should be shown.</summary>
            /// <param name="b" type="boolean">Whether the today button should be shown.</param>
        }, 
        
        setDecorator: function(f) {
            /// <summary>Sets the decorator function. The function should have the interface of
            ///   {string} f({goog.date.Date});
            /// and return a String representing a CSS class to decorate the cell
            /// corresponding to the date specified.</summary>
            /// <param name="f" type="Function">The decorator function.</param>
        }, 
        
        previousMonth: function() {
            /// <summary>Changes the active month to the previous one.</summary>
        }, 
        
        nextMonth: function() {
            /// <summary>Changes the active month to the next one.</summary>
        }, 
        
        previousYear: function() {
            /// <summary>Changes the active year to the previous one.</summary>
        }, 
        
        nextYear: function() {
            /// <summary>Changes the active year to the next one.</summary>
        }, 
        
        selectToday: function() {
            /// <summary>Selects the current date.</summary>
        }, 
        
        selectNone: function() {
            /// <summary>Clears the selection.</summary>
        }, 
        
        getActiveMonth: function() {
            /// <summary></summary>
            /// <returns type="goog.date.Date">The active month displayed.</returns>
        }, 
        
        getDate: function() {
            /// <summary></summary>
            /// <returns type="goog.date.Date">The selected date or null if nothing is selected.</returns>
        }, 
        
        setDate: function(date) {
            /// <summary>Sets the selected date.</summary>
            /// <param name="date" type="goog.date.Date|Date">Date to select or null to select nothing.</param>
        }, 
        
        decorateInternal: function(el) {
            /// <summary></summary>
            /// <param name="el" type=""></param>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.DatePicker";
})(this);
