
/* vsdoc for goog.ui.Dialog */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Dialog = function(opt_class, opt_useIframeMask, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_class" type="string=">CSS class name for the dialog element, also used
        ///     as a class name prefix for related elements; defaults to modal-dialog.</param>
        /// <param name="opt_useIframeMask" type="boolean=">Work around windowed controls z-index
        ///     issue by using an iframe instead of a div for bg element.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper; see {@link
        ///     goog.ui.Component} for semantics.</param>
        /// <field name="SELECT_EVENT" type="string">Event type constant for dialog events.
        /// TODO(attila): Change this to goog.ui.Dialog.EventType.SELECT.</field>
        /// <field name="EventType" type="">Events dispatched by dialogs.</field>
        /// <field name="DefaultButtonKeys" type="">The keys used to identify standard buttons in events.</field>
        /// <field name="DefaultButtonCaptions" type="">The default captions for the default buttons.</field>
        /// <returns type="goog.ui.Dialog"/>
    };

    var $x = window.goog.ui.Dialog;
    $x.prototype = {
                
        getCssClass: function() {
            /// <summary></summary>
        }, 
        
        setTitle: function(title) {
            /// <summary>Sets the title.</summary>
            /// <param name="title" type="string">The title text.</param>
        }, 
        
        getTitle: function() {
            /// <summary>Gets the title.</summary>
            /// <returns type="string">The title.</returns>
        }, 
        
        setContent: function(html) {
            /// <summary>Allows arbitrary HTML to be set in the content element.</summary>
            /// <param name="html" type="string">Content HTML.</param>
        }, 
        
        getContent: function() {
            /// <summary>Gets the content HTML of the content element.</summary>
            /// <returns type="string">Content HTML.</returns>
        }, 
        
        getPreferredAriaRole: function() {
            /// <summary>Returns the dialog&apos;s preferred ARIA role. This can be used to override the
            /// default dialog role, e.g. with an ARIA role of ALERTDIALOG for a simple
            /// warning or confirmation dialog.</summary>
            /// <returns type="goog.dom.a11y.Role">This dialog&apos;s preferred ARIA role.</returns>
        }, 
        
        setPreferredAriaRole: function(role) {
            /// <summary>Sets the dialog&apos;s preferred ARIA role. This can be used to override the
            /// default dialog role, e.g. with an ARIA role of ALERTDIALOG for a simple
            /// warning or confirmation dialog.</summary>
            /// <param name="role" type="goog.dom.a11y.Role">This dialog&apos;s preferred ARIA role.</param>
        }, 
        
        getContentElement: function() {
            /// <summary>Returns the content element so that more complicated things can be done with
            /// the content area.  Renders if the DOM is not yet created.  Overrides
            /// {@link goog.ui.Component#getContentElement}.</summary>
            /// <returns type="Element">The content element.</returns>
        }, 
        
        getTitleElement: function() {
            /// <summary>Returns the title element so that more complicated things can be done with
            /// the title.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The title element.</returns>
        }, 
        
        getTitleTextElement: function() {
            /// <summary>Returns the title text element so that more complicated things can be done
            /// with the text of the title.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The title text element.</returns>
        }, 
        
        getTitleCloseElement: function() {
            /// <summary>Returns the title close element so that more complicated things can be done
            /// with the close area of the title.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The close box.</returns>
        }, 
        
        getButtonElement: function() {
            /// <summary>Returns the button element so that more complicated things can be done with
            /// the button area.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The button container element.</returns>
        }, 
        
        getDialogElement: function() {
            /// <summary>Returns the dialog element so that more complicated things can be done with
            /// the dialog box.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The dialog element.</returns>
        }, 
        
        getBackgroundElement: function() {
            /// <summary>Returns the background mask element so that more complicated things can be
            /// done with the background region.  Renders if the DOM is not yet created.</summary>
            /// <returns type="Element">The background mask element.</returns>
        }, 
        
        getBackgroundElementOpacity: function() {
            /// <summary>Gets the opacity of the background mask.</summary>
            /// <returns type="number">Background mask opacity.</returns>
        }, 
        
        setBackgroundElementOpacity: function(opacity) {
            /// <summary>Sets the opacity of the background mask.</summary>
            /// <param name="opacity" type="number">Background mask opacity.</param>
        }, 
        
        setModal: function(modal) {
            /// <summary>Sets the modal property of the dialog. In case the dialog is already
            /// inDocument, renders the modal background elements according to the specified
            /// modal parameter.
            /// 
            /// Note that non-modal dialogs cannot use an iframe mask.</summary>
            /// <param name="modal" type="boolean">Whether the dialog is modal.</param>
        }, 
        
        getModal: function() {
            /// <summary></summary>
            /// <returns type="boolean">modal Whether the dialog is modal.</returns>
        }, 
        
        getClass: function() {
            /// <summary></summary>
            /// <returns type="string">The CSS class name for the dialog element.</returns>
        }, 
        
        setDraggable: function(draggable) {
            /// <summary>Sets whether the dialog can be dragged.</summary>
            /// <param name="draggable" type="boolean">Whether the dialog can be dragged.</param>
        }, 
        
        createDragger: function() {
            /// <summary>Returns a dragger for moving the dialog and adds a class for the move cursor.
            /// Defaults to allow dragging of the title only, but can be overridden if
            /// different drag targets or dragging behavior is desired.</summary>
            /// <returns type="!goog.fx.Dragger">The created dragger instance.</returns>
        }, 
        
        getDraggable: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the dialog is draggable.</returns>
        }, 
        
        setDraggingEnabled_: function(enabled) {
            /// <summary>Enables or disables dragging.</summary>
            /// <param name="enabled" type="boolean">Whether to enable it.</param>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        decorateInternal: function(element) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        setVisible: function(visible) {
            /// <summary>Sets the visibility of the dialog box and moves focus to the
            /// default button. Lazily renders the component if needed. After this
            /// method returns, isVisible() will always return the new state, even
            /// if there is a transition.</summary>
            /// <param name="visible" type="boolean">Whether the dialog should be visible.</param>
        }, 
        
        onShow: function() {
            /// <summary></summary>
        }, 
        
        onHide: function() {
            /// <summary></summary>
        }, 
        
        focus: function() {
            /// <summary>Focuses the dialog contents and the default dialog button if there is one.</summary>
        }, 
        
        getHasTitleCloseButton: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this dialog has a title close button.</returns>
        }, 
        
        setHasTitleCloseButton: function(b) {
            /// <summary>Sets whether the dialog should have a close button in the title bar. There
            /// will always be an element for the title close button, but setting this
            /// parameter to false will cause it to be hidden and have no active listener.</summary>
            /// <param name="b" type="boolean">Whether this dialog should have a title close button.</param>
        }, 
        
        isEscapeToCancel: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the escape key should close this dialog.</returns>
        }, 
        
        setEscapeToCancel: function(b) {
            /// <summary></summary>
            /// <param name="b" type="boolean">Whether the escape key should close this dialog.</param>
        }, 
        
        setDisposeOnHide: function(b) {
            /// <summary>Sets whether the dialog should be disposed when it is hidden.  By default
            /// dialogs are not disposed when they are hidden.</summary>
            /// <param name="b" type="boolean">Whether the dialog should get disposed when it gets
            ///     hidden.</param>
        }, 
        
        getDisposeOnHide: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the dialog should be disposed when it is hidden.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setButtonSet: function(buttons) {
            /// <summary>Sets the button set to use.
            /// Note: Passing in null will cause no button set to be rendered.</summary>
            /// <param name="buttons" type="goog.ui.Dialog.ButtonSet?">The button set to use.</param>
        }, 
        
        getButtonSet: function() {
            /// <summary>Returns the button set being used.</summary>
            /// <returns type="goog.ui.Dialog.ButtonSet?">The button set being used.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Dialog";
})(this);
