
/* vsdoc for goog.ui.Dialog.ButtonSet */

(function (window) {
    window.goog.ui.Dialog = window.goog.ui.Dialog || {};

    window.goog.ui.Dialog.ButtonSet = function(opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper; see {@link
        ///    goog.ui.Component} for semantics.</param>
        /// <field name="DefaultButtons" type="">The standard buttons (keys associated with captions).</field>
        /// <field name="OK" type=""></field>
        /// <field name="OK_CANCEL" type=""></field>
        /// <field name="YES_NO" type=""></field>
        /// <field name="YES_NO_CANCEL" type=""></field>
        /// <field name="CONTINUE_SAVE_CANCEL" type=""></field>
        /// <returns type="goog.ui.Dialog.ButtonSet"/>
    };

    var $x = window.goog.ui.Dialog.ButtonSet;
    $x.prototype = {
                
        set: function(key, caption, opt_isDefault, opt_isCancel) {
            /// <summary>Adds a button to the button set.  Buttons will be displayed in the order they
            /// are added.</summary>
            /// <param name="key" type="*">Key used to identify the button in events.</param>
            /// <param name="caption" type="*">A string caption or a DOM node that can be
            ///     appended to a button element.</param>
            /// <param name="opt_isDefault" type="boolean=">Whether this button is the default button,
            ///     Dialog will dispatch for this button if enter is pressed.</param>
            /// <param name="opt_isCancel" type="boolean=">Whether this button has the same behaviour as
            ///    cancel.  If escape is pressed this button will fire.</param>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The button set, to make it easy to chain
            ///    &quot;set&quot; calls and build new ButtonSets.</returns>
        }, 
        
        addButton: function(button, opt_isDefault, opt_isCancel) {
            /// <summary>Adds a button (an object with a key and caption) to this button set. Buttons
            /// will be displayed in the order they are added.</summary>
            /// <param name="button" type="!{key: string|caption: string}">The button key and caption.</param>
            /// <param name="opt_isDefault" type="boolean=">Whether this button is the default button.
            ///     Dialog will dispatch for this button if enter is pressed.</param>
            /// <param name="opt_isCancel" type="boolean=">Whether this button has the same behavior as
            ///     cancel. If escape is pressed this button will fire.</param>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The button set, to make it easy to chain
            ///     &quot;addButton&quot; calls and build new ButtonSets.</returns>
        }, 
        
        attachToElement: function(el) {
            /// <summary>Attaches the button set to an element, rendering it inside.</summary>
            /// <param name="el" type="Element">Container.</param>
        }, 
        
        render: function() {
            /// <summary>Renders the button set inside its container element.</summary>
        }, 
        
        decorate: function(element) {
            /// <summary>Decorates the given element by adding any {@code button} elements found
            /// among its descendants to the button set.  The first button found is assumed
            /// to be the default and will receive focus when the button set is rendered.
            /// If a button with a name of {@link goog.ui.Dialog.DefaultButtonKeys.CANCEL}
            /// is found, it is assumed to have &quot;Cancel&quot; semantics.
            /// TODO(attila):  ButtonSet should be a goog.ui.Component.  Really.</summary>
            /// <param name="element" type="Element">The element to decorate; should contain buttons.</param>
        }, 
        
        getElement: function() {
            /// <summary>Gets the component&apos;s element.</summary>
            /// <returns type="Element">The element for the component.
            /// TODO(user): Remove after refactoring to goog.ui.Component.</returns>
        }, 
        
        getDomHelper: function() {
            /// <summary>Returns the dom helper that is being used on this component.</summary>
            /// <returns type="!goog.dom.DomHelper">The dom helper used on this component.
            /// TODO(user): Remove after refactoring to goog.ui.Component.</returns>
        }, 
        
        setDefault: function(key) {
            /// <summary>Sets the default button.</summary>
            /// <param name="key" type="?string">The default button.</param>
        }, 
        
        getDefault: function() {
            /// <summary>Returns the default button.</summary>
            /// <returns type="?string">The default button.</returns>
        }, 
        
        setCancel: function(key) {
            /// <summary>Sets the cancel button.</summary>
            /// <param name="key" type="?string">The cancel button.</param>
        }, 
        
        getCancel: function() {
            /// <summary>Returns the cancel button.</summary>
            /// <returns type="?string">The cancel button.</returns>
        }, 
        
        getButton: function(key) {
            /// <summary>Returns the HTML Button element.</summary>
            /// <param name="key" type="string">The button to return.</param>
            /// <returns type="Element">The button, if found else null.</returns>
        }, 
        
        getAllButtons: function() {
            /// <summary>Returns all the HTML Button elements in the button set container.</summary>
            /// <returns type="NodeList">A live NodeList of the buttons.</returns>
        }, 
        
        setButtonEnabled: function(key, enabled) {
            /// <summary>Enables or disables a button in this set by key. If the button is not found,
            /// does nothing.</summary>
            /// <param name="key" type="string">The button to enable or disable.</param>
            /// <param name="enabled" type="boolean">True to enable; false to disable.</param>
        }, 
        
        setAllButtonsEnabled: function(enabled) {
            /// <summary>Enables or disables all of the buttons in this set.</summary>
            /// <param name="enabled" type="boolean">True to enable; false to disable.</param>
        }, 
        
        createOk: function() {
            /// <summary>Creates a new ButtonSet with a single &apos;OK&apos; button, which is also set with
            /// cancel button semantics so that pressing escape will close the dialog.</summary>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The created ButtonSet.</returns>
        }, 
        
        createOkCancel: function() {
            /// <summary>Creates a new ButtonSet with &apos;OK&apos; (default) and &apos;Cancel&apos; buttons.</summary>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The created ButtonSet.</returns>
        }, 
        
        createYesNo: function() {
            /// <summary>Creates a new ButtonSet with &apos;Yes&apos; (default) and &apos;No&apos; buttons.</summary>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The created ButtonSet.</returns>
        }, 
        
        createYesNoCancel: function() {
            /// <summary>Creates a new ButtonSet with &apos;Yes&apos;, &apos;No&apos; (default), and &apos;Cancel&apos; buttons.</summary>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The created ButtonSet.</returns>
        }, 
        
        createContinueSaveCancel: function() {
            /// <summary>Creates a new ButtonSet with &apos;Continue&apos;, &apos;Save&apos;, and &apos;Cancel&apos; (default)
            /// buttons.</summary>
            /// <returns type="!goog.ui.Dialog.ButtonSet">The created ButtonSet.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Dialog.ButtonSet";
})(this);
