
/* vsdoc for goog.ui.DrilldownRow */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.DrilldownRow = function(opt_properties){
        /// <summary></summary>
        /// <param name="opt_properties" type="Object=">This parameter can contain:
        ///   contents:  if present, user data identifying
        ///     the information loaded into the row and its children.
        ///   loaded: initializes the isLoaded property, defaults to true.
        ///   expanded: DrilldownRow expanded or not, default is true.
        ///   html: String of HTML, relevant and required for DrilldownRows to be
        ///     added as children.  Ignored when decorating an existing table row.
        ///   decorator: Function that accepts one DrilldownRow argument, and
        ///     should customize and style the row.  The default is to call
        ///     goog.ui.DrilldownRow.decorator.</param>
        /// <field name="sampleProperties" type="">Example object with properties of the form accepted by the class
        /// constructor.  These are educational and show the compiler that
        /// these properties can be set so it doesn&apos;t emit warnings.</field>
        /// <returns type="goog.ui.DrilldownRow"/>
    };

    var $x = window.goog.ui.DrilldownRow;
    $x.prototype = {
                
        enterDocument: function() {
            /// <summary>The base class method calls its superclass method and this
            /// drilldown&apos;s &apos;decorator&apos; method as defined in the constructor.</summary>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        canDecorate: function(node) {
            /// <summary>A top-level DrilldownRow decorates a TR element.</summary>
            /// <param name="node" type="Element">The element to test for decorability.</param>
            /// <returns type="boolean">true iff the node is a TR.</returns>
        }, 
        
        addChildAt: function(child, index, opt_render) {
            /// <summary>Child drilldowns are rendered when needed.</summary>
            /// <param name="child" type="goog.ui.Component">New DrilldownRow child to be added.</param>
            /// <param name="index" type="number">position to be occupied by the child.</param>
            /// <param name="opt_render" type="boolean=">true to force immediate rendering.</param>
        }, 
        
        removeChild: function(child) {
            /// <summary></summary>
            /// <param name="child" type=""></param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        render: function() {
            /// <summary>Rendering of DrilldownRow&apos;s is on need, do not call this directly
            /// from application code.
            /// 
            /// Rendering a DrilldownRow places it according to its position in its
            /// tree of DrilldownRows.  DrilldownRows cannot be placed any other
            /// way so this method does not use any arguments.  This does not call
            /// the base class method and does not modify any of this
            /// DrilldownRow&apos;s children.</summary>
        }, 
        
        findIndex: function() {
            /// <summary>Finds the numeric index of this child within its parent Component.
            /// Throws an exception if it has no parent.</summary>
            /// <returns type="number">index of this within the children of the parent Component.</returns>
        }, 
        
        isExpanded: function() {
            /// <summary>Returns the expanded state of the DrilldownRow.</summary>
            /// <returns type="boolean">true iff this is expanded.</returns>
        }, 
        
        setExpanded: function(expanded) {
            /// <summary>Sets the expanded state of this DrilldownRow: makes all children
            /// displayable or not displayable corresponding to the expanded state.</summary>
            /// <param name="expanded" type="boolean">whether this should be expanded or not.</param>
        }, 
        
        getDepth: function() {
            /// <summary>Returns this DrilldownRow&apos;s level in the tree.  Top level is 1.</summary>
            /// <returns type="number">depth of this DrilldownRow in its tree of drilldowns.</returns>
        }, 
        
        decorate: function(selfObj) {
            /// <summary>This static function is a default decorator that adds HTML at the
            /// beginning of the first cell to display indentation and an expander
            /// image; sets up a click handler on the toggler; initializes a class
            /// for the row: either goog-drilldown-expanded or
            /// goog-drilldown-collapsed, depending on the initial state of the
            /// DrilldownRow; and sets up a click event handler on the toggler
            /// element.
            /// 
            /// This creates a DIV with class=toggle.  Your application can set up
            /// CSS style rules something like this:
            /// 
            /// tr.goog-drilldown-expanded .toggle {
            ///   background-image: url(&apos;minus.png&apos;);
            /// }
            /// 
            /// tr.goog-drilldown-collapsed .toggle {
            ///   background-image: url(&apos;plus.png&apos;);
            /// }
            /// 
            /// These background images show whether the DrilldownRow is expanded.</summary>
            /// <param name="selfObj" type="goog.ui.DrilldownRow">DrilldownRow to be decorated.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.DrilldownRow";
})(this);
