
/* vsdoc for goog.ui.FlatButtonRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.FlatButtonRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.FlatButtonRenderer"/>
    };

    var $x = window.goog.ui.FlatButtonRenderer;
    $x.prototype = {
                
        createDom: function(button) {
            /// <summary>Returns the control&apos;s contents wrapped in a div element, with
            /// the renderer&apos;s own CSS class and additional state-specific classes applied
            /// to it, and the button&apos;s disabled attribute set or cleared as needed.
            /// Overrides {@link goog.ui.ButtonRenderer#createDom}.</summary>
            /// <param name="button" type="goog.ui.Control">Button to render.</param>
            /// <returns type="Element">Root element for the button.</returns>
        }, 
        
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to flat buttons.</summary>
            /// <returns type="goog.dom.a11y.Role|undefined">ARIA role.</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Returns true if this renderer can decorate the element.  Overrides
            /// {@link goog.ui.ButtonRenderer#canDecorate} by returning true if the
            /// element is a DIV, false otherwise.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="boolean">Whether the renderer can decorate the element.</returns>
        }, 
        
        decorate: function(button, element) {
            /// <summary>Takes an existing element and decorates it with the flat button control.
            /// Initializes the control&apos;s ID, content, tooltip, value, and state based
            /// on the ID of the element, its child nodes, and its CSS classes, respectively.
            /// Returns the element.  Overrides {@link goog.ui.ButtonRenderer#decorate}.</summary>
            /// <param name="button" type="goog.ui.Control">Button instance to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        getValue: function(element) {
            /// <summary>Flat buttons can&apos;t use the value attribute since they are div elements.
            /// Overrides {@link goog.ui.ButtonRenderer#getValue} to prevent trying to
            /// access the element&apos;s value.</summary>
            /// <param name="element" type="Element">The button control&apos;s root element.</param>
            /// <returns type="string">Value not valid for flat buttons.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.FlatButtonRenderer";
})(this);
