
/* vsdoc for goog.ui.Gauge */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Gauge = function(width, height, opt_domHelper){
        /// <summary></summary>
        /// <param name="width" type="number">The width in pixels.</param>
        /// <param name="height" type="number">The height in pixels.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">The DOM helper object for the
        ///     document we want to render in.</param>
        /// <field name="RED" type="">Constant for a background color for a gauge area.</field>
        /// <field name="GREEN" type="">Constant for a background color for a gauge area.</field>
        /// <field name="YELLOW" type="">Constant for a background color for a gauge area.</field>
        /// <field name="FACTOR_RADIUS_FROM_SIZE" type="number">The radius of the entire gauge from the canvas size.</field>
        /// <field name="FACTOR_MAIN_AREA" type="number">The ratio of internal gauge radius from entire radius.
        /// The remaining area is the border around the gauge.</field>
        /// <field name="FACTOR_COLOR_RADIUS" type="number">The ratio of the colored background area for value ranges.
        /// The colored area width is computed as
        /// InternalRadius * (1 - FACTOR_COLOR_RADIUS)</field>
        /// <field name="FACTOR_MAJOR_TICKS" type="number">The ratio of the major ticks length start position, from the radius.
        /// The major ticks length width is computed as
        /// InternalRadius * (1 - FACTOR_MAJOR_TICKS)</field>
        /// <field name="FACTOR_MINOR_TICKS" type="number">The ratio of the minor ticks length start position, from the radius.
        /// The minor ticks length width is computed as
        /// InternalRadius * (1 - FACTOR_MINOR_TICKS)</field>
        /// <field name="FACTOR_NEEDLE_FRONT" type="number">The length of the needle front (value facing) from the internal radius.
        /// The needle front is the part of the needle that points to the value.</field>
        /// <field name="FACTOR_NEEDLE_BACK" type="number">The length of the needle back relative to the internal radius.
        /// The needle back is the part of the needle that points away from the value.</field>
        /// <field name="FACTOR_NEEDLE_WIDTH" type="number">The width of the needle front at the hinge.
        /// This is the width of the curve control point, the actual width is
        /// computed by the curve itself.</field>
        /// <field name="FACTOR_NEEDLE_HINGE" type="number">The width (radius) of the needle hinge from the gauge radius.</field>
        /// <field name="FACTOR_TITLE_FONT_SIZE" type="number">The title font size (height) for titles relative to the internal radius.</field>
        /// <field name="FACTOR_TITLE_OFFSET" type="number">The offset of the title from the center, relative to the internal radius.</field>
        /// <field name="FACTOR_VALUE_FONT_SIZE" type="number">The formatted value font size (height) relative to the internal radius.</field>
        /// <field name="FACTOR_TICK_LABEL_FONT_SIZE" type="number">The title font size (height) for tick labels relative to the internal radius.</field>
        /// <field name="FACTOR_VALUE_OFFSET" type="number">The offset of the formatted value down from the center, relative to the
        /// internal radius.</field>
        /// <field name="TITLE_FONT_NAME" type="string">The font name for title text.</field>
        /// <field name="NEEDLE_MOVE_MAX_STEP" type="number">The maximal size of a step the needle can move (percent from size of range).
        /// If the needle needs to move more, it will be moved in animated steps, to
        /// show a smooth transition between values.</field>
        /// <field name="NEEDLE_MOVE_TIME" type="number">Time in miliseconds for animating a move of the value pointer.</field>
        /// <field name="MAX_EXCEED_POSITION_POSITION" type="number">Tolerance factor for how much values can exceed the range (being too
        /// low or too high). The value is presented as a position (percentage).</field>
        /// <returns type="goog.ui.Gauge"/>
    };

    var $x = window.goog.ui.Gauge;
    $x.prototype = {
                
        getMinimum: function() {
            /// <summary></summary>
            /// <returns type="number">The minimum value of the range.</returns>
        }, 
        
        setMinimum: function(min) {
            /// <summary>Sets the minimum value of the range</summary>
            /// <param name="min" type="number">The minimum value of the range.</param>
        }, 
        
        getMaximum: function() {
            /// <summary></summary>
            /// <returns type="number">The maximum value of the range.</returns>
        }, 
        
        setMaximum: function(max) {
            /// <summary>Sets the maximum number of the range</summary>
            /// <param name="max" type="number">The maximum value of the range.</param>
        }, 
        
        setValue: function(value, opt_formattedValue) {
            /// <summary>Sets the current value range displayed by the gauge.</summary>
            /// <param name="value" type="number">The current value for the gauge. This value
            ///     determines the position of the needle of the gauge.</param>
            /// <param name="opt_formattedValue" type="string=">The string value to show in the gauge.
            ///     If not specified, no string value will be displayed.</param>
        }, 
        
        setTicks: function(majorUnits, minorUnits) {
            /// <summary>Sets the number of major tick sections and minor tick sections.</summary>
            /// <param name="majorUnits" type="number">The number of major tick sections.</param>
            /// <param name="minorUnits" type="number">The number of minor tick sections for each major
            ///     tick section.</param>
        }, 
        
        setMajorTickLabels: function(tickLabels) {
            /// <summary>Sets the labels of the major ticks.</summary>
            /// <param name="tickLabels" type="Array.string">A text label for each major tick value.</param>
        }, 
        
        setTitleTop: function(text) {
            /// <summary>Sets the top title of the gauge.
            /// The top title is displayed above the center.</summary>
            /// <param name="text" type="string">The top title text.</param>
        }, 
        
        setTitleBottom: function(text) {
            /// <summary>Sets the bottom title of the gauge.
            /// The top title is displayed below the center.</summary>
            /// <param name="text" type="string">The bottom title text.</param>
        }, 
        
        setTitleFont: function(font) {
            /// <summary>Sets the font for displaying top and bottom titles.</summary>
            /// <param name="font" type="goog.graphics.Font">The font for titles.</param>
        }, 
        
        setValueFont: function(font) {
            /// <summary>Sets the font for displaying the formatted value.</summary>
            /// <param name="font" type="goog.graphics.Font">The font for displaying the value.</param>
        }, 
        
        setTheme: function(theme) {
            /// <summary>Sets the color theme for drawing the gauge.</summary>
            /// <param name="theme" type="goog.ui.GaugeTheme">The color theme to use.</param>
        }, 
        
        addBackgroundColor: function(fromValue, toValue, color) {
            /// <summary>Set the background color for a range of values on the gauge.</summary>
            /// <param name="fromValue" type="number">The lower (start) value of the colored range.</param>
            /// <param name="toValue" type="number">The higher (end) value of the colored range.</param>
            /// <param name="color" type="string">The color name to paint the range with. For example
            ///     &apos;red&apos;, &apos;#ffcc00&apos; or constants like goog.ui.Gauge.RED.</param>
        }, 
        
        createDom: function() {
            /// <summary>Creates the DOM representation of the graphics area.</summary>
        }, 
        
        redraw: function() {
            /// <summary>Redraws the entire gauge.
            /// Should be called after theme colors have been changed.</summary>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Gauge";
})(this);
