
/* vsdoc for goog.ui.HoverCard */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.HoverCard = function(isAnchor, opt_checkDescendants, opt_domHelper, opt_triggeringDocument){
        /// <summary></summary>
        /// <param name="isAnchor" type="Function|Object">Function that returns true if a given
        ///     element should trigger the hovercard.  Alternatively, it can be a map of
        ///     tag names to the attribute that the tag should have in order to trigger
        ///     the hovercard, e.g., {A: &apos;href&apos;} for all links.  Tag names must be all
        ///     upper case; attribute names are case insensitive.</param>
        /// <param name="opt_checkDescendants" type="boolean=">Use false for a performance gain if
        ///     you are sure that none of your triggering elements have child elements.
        ///     Default is true.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper to use for
        ///     creating and rendering the hovercard element.</param>
        /// <param name="opt_triggeringDocument" type="Document=">Optional document to use in place
        ///     of the one included in the DomHelper for finding triggering elements.
        ///     Defaults to the document included in the DomHelper.</param>
        /// <field name="EventType" type="">Enum for event type fired by HoverCard.</field>
        /// <returns type="goog.ui.HoverCard"/>
    };

    var $x = window.goog.ui.HoverCard;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        triggerForElement: function(anchorElement, opt_pos, opt_data) {
            /// <summary>Triggers the hovercard to show after a delay.</summary>
            /// <param name="anchorElement" type="Element">Element that is triggering the hovercard.</param>
            /// <param name="opt_pos" type="goog.positioning.AbstractPosition=">Position to display
            ///     hovercard.</param>
            /// <param name="opt_data" type="Object=">Data to pass to the onTrigger event.</param>
        }, 
        
        onTrigger: function(triggerEvent) {
            /// <summary>Called when an element triggers the hovercard.  This will return false
            /// if an event handler sets preventDefault to true, which will prevent
            /// the hovercard from being shown.</summary>
            /// <param name="triggerEvent" type="!goog.ui.HoverCard.TriggerEvent">Event object to use
            ///     for trigger event.</param>
            /// <returns type="boolean">Whether hovercard should be shown or cancelled.</returns>
        }, 
        
        cancelTrigger: function() {
            /// <summary>Abort pending hovercard showing, if any.</summary>
        }, 
        
        onCancelTrigger: function() {
            /// <summary>This method gets called when we detect that a trigger event will not lead
            /// to the hovercard being shown.</summary>
        }, 
        
        getAnchorElement: function() {
            /// <summary>Gets the DOM element that triggered the current hovercard.  Note that in
            /// the TRIGGER or CANCEL_TRIGGER events, the current hovercard&apos;s anchor may not
            /// be the one that caused the event, so use the event&apos;s anchor property instead.</summary>
            /// <returns type="Element">Object that caused the currently displayed hovercard (or
            ///     pending hovercard if none is displayed) to be triggered.</returns>
        }, 
        
        onHide_: function() {
            /// <summary>Make sure we detach from temp anchor when we are done displaying hovercard.</summary>
        }, 
        
        handleMouseOver: function(event) {
            /// <summary>This mouse over event is only received if the anchor is already attached.
            /// If it was attached manually, then it may need to be triggered.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse over event.</param>
        }, 
        
        handleMouseOutAndBlur: function(event) {
            /// <summary>If the mouse moves out of the trigger while we&apos;re being triggered, then
            /// cancel it.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Mouse out or blur event.</param>
        }, 
        
        maybeShow: function(el, opt_pos) {
            /// <summary>Called by timer from mouse over handler. If this is called and the hovercard
            /// is not shown for whatever reason, then send a cancel trigger event.</summary>
            /// <param name="el" type="Element">Element to show tooltip for.</param>
            /// <param name="opt_pos" type="goog.positioning.AbstractPosition=">Position to display popup
            ///     at.</param>
        }, 
        
        setMaxSearchSteps: function(maxSearchSteps) {
            /// <summary>Sets the max number of levels to search up the dom if checking descendants.</summary>
            /// <param name="maxSearchSteps" type="number">Maximum number of levels to search up the
            ///     dom if checking descendants.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.HoverCard";
})(this);
