
/* vsdoc for goog.ui.KeyboardShortcutHandler */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.KeyboardShortcutHandler = function(keyTarget){
        /// <summary></summary>
        /// <param name="keyTarget" type="goog.events.EventTarget|EventTarget">Event target that the
        ///     key event listener is attached to, typically the applications root
        ///     container.</param>
        /// <field name="MAX_KEY_SEQUENCE_DELAY" type="number">Maximum allowed delay, in milliseconds, allowed between the first and second
        /// key in a key sequence.</field>
        /// <field name="Modifiers" type="">Bit values for modifier keys.</field>
        /// <field name="EventType" type="">Events.</field>
        /// <returns type="goog.ui.KeyboardShortcutHandler"/>
    };

    var $x = window.goog.ui.KeyboardShortcutHandler;
    $x.prototype = {
                
        getKeyCode: function(name) {
            /// <summary>Static method for getting the key code for a given key.</summary>
            /// <param name="name" type="string">Name of key.</param>
            /// <returns type="number">The key code.</returns>
        }, 
        
        setAlwaysPreventDefault: function(alwaysPreventDefault) {
            /// <summary>Sets whether to always prevent the default action when a shortcut event is
            /// fired. If false, the default action is prevented only if preventDefault is
            /// called on  either of the corresponding SHORTCUT_TRIGGERED or SHORTCUT_PREFIX
            /// events. If true, the default action is prevented whenever a shortcut event
            /// is fired. The default value is true.</summary>
            /// <param name="alwaysPreventDefault" type="boolean">Whether to always call preventDefault.</param>
        }, 
        
        getAlwaysPreventDefault: function() {
            /// <summary>Returns whether the default action will always be prevented when a shortcut
            /// event is fired. The default value is true.</summary>
            /// <returns type="boolean">Whether preventDefault will always be called.</returns>
        }, 
        
        setAlwaysStopPropagation: function(alwaysStopPropagation) {
            /// <summary>Sets whether to always stop propagation for the event when fired. If false,
            /// the propagation is stopped only if stopPropagation is called on either of the
            /// corresponding SHORT_CUT_TRIGGERED or SHORTCUT_PREFIX events. If true, the
            /// event is prevented from propagating beyond its target whenever it is fired.
            /// The default value is false.</summary>
            /// <param name="alwaysStopPropagation" type="boolean">Whether to always call
            ///     stopPropagation.</param>
        }, 
        
        getAlwaysStopPropagation: function() {
            /// <summary>Returns whether the event will always be stopped from propagating beyond its
            /// target when a shortcut event is fired. The default value is false.</summary>
            /// <returns type="boolean">Whether stopPropagation will always be called.</returns>
        }, 
        
        setAllShortcutsAreGlobal: function(allShortcutsGlobal) {
            /// <summary>Sets whether to treat all shortcuts (including modifier shortcuts) as if the
            /// keys had been passed to the setGlobalKeys function.</summary>
            /// <param name="allShortcutsGlobal" type="boolean">Whether to treat all shortcuts as global.</param>
        }, 
        
        getAllShortcutsAreGlobal: function() {
            /// <summary>Returns whether all shortcuts (including modifier shortcuts) are treated as
            /// if the keys had been passed to the setGlobalKeys function.</summary>
            /// <returns type="boolean">Whether all shortcuts are treated as globals.</returns>
        }, 
        
        setModifierShortcutsAreGlobal: function(modifierShortcutsGlobal) {
            /// <summary>Sets whether to treat shortcuts with modifiers as if the keys had been
            /// passed to the setGlobalKeys function.  Ignored if you have called
            /// setAllShortcutsAreGlobal(true).  Applies only to form elements (not
            /// content-editable).</summary>
            /// <param name="modifierShortcutsGlobal" type="boolean">Whether to treat shortcuts with
            ///     modifiers as global.</param>
        }, 
        
        getModifierShortcutsAreGlobal: function() {
            /// <summary>Returns whether shortcuts with modifiers are treated as if the keys had been
            /// passed to the setGlobalKeys function.  Ignored if you have called
            /// setAllShortcutsAreGlobal(true).  Applies only to form elements (not
            /// content-editable).</summary>
            /// <returns type="boolean">Whether shortcuts with modifiers are treated as globals.</returns>
        }, 
        
        registerShortcut: function(identifier, var_args) {
            /// <summary>Registers a keyboard shortcut.</summary>
            /// <param name="identifier" type="string">Identifier for the task performed by the keyboard
            ///                 combination. Multiple shortcuts can be provided for the same
            ///                 task by specifying the same identifier.</param>
            /// <param name="var_args" type="...(number|string|Array.number)">See below.
            /// 
            /// param {number} keyCode Numeric code for key
            /// param {number=} opt_modifiers Bitmap indicating required modifier keys.
            ///                goog.ui.KeyboardShortcutHandler.Modifiers.SHIFT, CONTROL,
            ///                ALT, or META.
            /// 
            /// The last two parameters can be repeated any number of times to create a
            /// shortcut using a sequence of strokes. Instead of varagrs the second parameter
            /// could also be an array where each element would be ragarded as a parameter.
            /// 
            /// A string representation of the shortcut can be supplied instead of the last
            /// two parameters. In that case the method only takes two arguments, the
            /// identifier and the string.
            /// 
            /// Examples:
            ///   g               registerShortcut(str, G_KEYCODE)
            ///   Ctrl+g          registerShortcut(str, G_KEYCODE, CTRL)
            ///   Ctrl+Shift+g    registerShortcut(str, G_KEYCODE, CTRL | SHIFT)
            ///   Ctrl+g a        registerShortcut(str, G_KEYCODE, CTRL, A_KEYCODE)
            ///   Ctrl+g Shift+a  registerShortcut(str, G_KEYCODE, CTRL, A_KEYCODE, SHIFT)
            ///   g a             registerShortcut(str, G_KEYCODE, NONE, A_KEYCODE)
            /// 
            /// Examples using string representation for shortcuts:
            ///   g               registerShortcut(str, &apos;g&apos;)
            ///   Ctrl+g          registerShortcut(str, &apos;ctrl+g&apos;)
            ///   Ctrl+Shift+g    registerShortcut(str, &apos;ctrl+shift+g&apos;)
            ///   Ctrl+g a        registerShortcut(str, &apos;ctrl+g a&apos;)
            ///   Ctrl+g Shift+a  registerShortcut(str, &apos;ctrl+g shift+a&apos;)
            ///   g a             registerShortcut(str, &apos;g a&apos;).</param>
        }, 
        
        unregisterShortcut: function(var_args) {
            /// <summary>Unregisters a keyboard shortcut by keyCode and modifiers or string
            /// representation of sequence.
            /// 
            /// param {number} keyCode Numeric code for key
            /// param {number=} opt_modifiers Bitmap indicating required modifier keys.
            ///                 goog.ui.KeyboardShortcutHandler.Modifiers.SHIFT, CONTROL,
            ///                 ALT, or META.
            /// 
            /// The two parameters can be repeated any number of times to create a shortcut
            /// using a sequence of strokes.
            /// 
            /// A string representation of the shortcut can be supplied instead see
            /// {@link #registerShortcut} for syntax. In that case the method only takes one
            /// argument.</summary>
            /// <param name="var_args" type="...(number|string|Array.number)">String representation, or
            ///     array or list of alternating key codes and modifiers.</param>
        }, 
        
        isShortcutRegistered: function(var_args) {
            /// <summary>Verifies if a particular keyboard shortcut is registered already. It has
            /// the same interface as the unregistering of shortcuts.
            /// 
            /// param {number} keyCode Numeric code for key
            /// param {number=} opt_modifiers Bitmap indicating required modifier keys.
            ///                 goog.ui.KeyboardShortcutHandler.Modifiers.SHIFT, CONTROL,
            ///                 ALT, or META.
            /// 
            /// The two parameters can be repeated any number of times to create a shortcut
            /// using a sequence of strokes.
            /// 
            /// A string representation of the shortcut can be supplied instead see
            /// {@link #registerShortcut} for syntax. In that case the method only takes one
            /// argument.</summary>
            /// <param name="var_args" type="...(number|string|Array.number)">String representation, or
            ///     array or list of alternating key codes and modifiers.</param>
            /// <returns type="boolean">Whether the specified keyboard shortcut is registered.</returns>
        }, 
        
        unregisterAll: function() {
            /// <summary>Unregisters all keyboard shortcuts.</summary>
        }, 
        
        setGlobalKeys: function(keys) {
            /// <summary>Sets the global keys; keys that are safe to always regarded as shortcuts,
            /// even if entered in a textarea or input field.</summary>
            /// <param name="keys" type="Array.number">List of keys.</param>
        }, 
        
        getGlobalKeys: function() {
            /// <summary></summary>
            /// <returns type="Array.number">The global keys, i.e. keys that are safe to always
            ///     regard as shortcuts, even if entered in a textarea or input field.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getEventType: function(identifier) {
            /// <summary>Returns event type for a specific shortcut.</summary>
            /// <param name="identifier" type="string">Identifier for the shortcut task.</param>
            /// <returns type="string">Theh event type.</returns>
        }, 
        
        parseStringShortcut: function(s) {
            /// <summary>Builds stroke array from string representation of shortcut.</summary>
            /// <param name="s" type="string">String representation of shortcut.</param>
            /// <returns type="Array.Object">The stroke array.</returns>
        }, 
        
        initializeKeyListener: function(keyTarget) {
            /// <summary>Adds a key event listener that triggers {@link #handleKeyDown_} when keys
            /// are pressed.</summary>
            /// <param name="keyTarget" type="goog.events.EventTarget|EventTarget">Event target that the
            ///     event listener should be attached to.</param>
        }, 
        
        clearKeyListener: function() {
            /// <summary>Removes the listener that was added by link {@link #initializeKeyListener}.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.KeyboardShortcutHandler";
})(this);
