
/* vsdoc for goog.ui.Menu */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Menu = function(opt_domHelper, opt_renderer){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <param name="opt_renderer" type="goog.ui.MenuRenderer=">Renderer used to render or
        ///     decorate the container; defaults to {@link goog.ui.MenuRenderer}.</param>
        /// <field name="EventType" type="">Event types dispatched by the menu.</field>
        /// <field name="CSS_CLASS" type="string">CSS class for menus.</field>
        /// <returns type="goog.ui.Menu"/>
    };

    var $x = window.goog.ui.Menu;
    $x.prototype = {
                
        getCssClass: function() {
            /// <summary>Returns the CSS class applied to menu elements, also used as the prefix for
            /// derived styles, if any.  Subclasses should override this method as needed.
            /// Considered protected.</summary>
            /// <returns type="string">The CSS class applied to menu elements.</returns>
        }, 
        
        containsElement: function(element) {
            /// <summary>Returns whether the provided element is to be considered inside the menu for
            /// purposes such as dismissing the menu on an event.  This is so submenus can
            /// make use of elements outside their own DOM.</summary>
            /// <param name="element" type="Element">The element to test for.</param>
            /// <returns type="boolean">Whether the provided element is to be considered inside
            ///     the menu.</returns>
        }, 
        
        addItem: function(item) {
            /// <summary>Adds a new menu item at the end of the menu.</summary>
            /// <param name="item" type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator">Menu
            ///     item to add to the menu.</param>
        }, 
        
        addItemAt: function(item, n) {
            /// <summary>Adds a new menu item at a specific index in the menu.</summary>
            /// <param name="item" type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator">Menu
            ///     item to add to the menu.</param>
            /// <param name="n" type="number">Index at which to insert the menu item.</param>
        }, 
        
        removeItem: function(item) {
            /// <summary>Removes an item from the menu and disposes of it.</summary>
            /// <param name="item" type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator">The
            ///     menu item to remove.</param>
        }, 
        
        removeItemAt: function(n) {
            /// <summary>Removes a menu item at a given index in the menu and disposes of it.</summary>
            /// <param name="n" type="number">Index of item.</param>
        }, 
        
        getItemAt: function(n) {
            /// <summary>Returns a reference to the menu item at a given index.</summary>
            /// <param name="n" type="number">Index of menu item.</param>
            /// <returns type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator|null">Reference to the menu item.</returns>
        }, 
        
        getItemCount: function() {
            /// <summary>Returns the number of items in the menu (including separators).</summary>
            /// <returns type="number">The number of items in the menu.</returns>
        }, 
        
        getItems: function() {
            /// <summary>Returns an array containing the menu items contained in the menu.</summary>
            /// <returns type="Array.goog.ui.MenuItem">An array of menu items.</returns>
        }, 
        
        setPosition: function(x, opt_y) {
            /// <summary>Sets the position of the menu relative to the view port.</summary>
            /// <param name="x" type="number|goog.math.Coordinate">Left position or coordinate obj.</param>
            /// <param name="opt_y" type="number=">Top position.</param>
        }, 
        
        getPosition: function() {
            /// <summary>Gets the page offset of the menu, or null if the menu isn&apos;t visible</summary>
            /// <returns type="goog.math.Coordinate?">Object holding the x-y coordinates of the
            ///     menu or null if the menu is not visible.</returns>
        }, 
        
        setAllowAutoFocus: function(allow) {
            /// <summary>Sets whether the menu can automatically move focus to its key event target
            /// when it is set to visible.</summary>
            /// <param name="allow" type="boolean">Whether the menu can automatically move focus to its
            ///     key event target when it is set to visible.</param>
        }, 
        
        getAllowAutoFocus: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the menu can automatically move focus to its key
            ///     event target when it is set to visible.</returns>
        }, 
        
        setAllowHighlightDisabled: function(allow) {
            /// <summary>Sets whether the menu will highlight disabled menu items or skip to the next
            /// active item.</summary>
            /// <param name="allow" type="boolean">Whether the menu will highlight disabled menu items or
            ///     skip to the next active item.</param>
        }, 
        
        getAllowHighlightDisabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the menu will highlight disabled menu items or skip
            ///     to the next active item.</returns>
        }, 
        
        setVisible: function(opt_e, opt_force, opt_e) {
            /// <summary></summary>
            /// <param name="opt_e" type="goog.events.Event=">Mousedown event that caused this menu to
            ///     be made visible (ignored if show is false).</param>
            /// <param name="opt_force" type=""></param>
            /// <param name="opt_e" type=""></param>
        }, 
        
        handleEnterItem: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        highlightNextPrefix: function(charStr) {
            /// <summary>Highlights the next item that begins with the specified string.  If no
            /// (other) item begins with the given string, the selection is unchanged.</summary>
            /// <param name="charStr" type="string">The prefix to match.</param>
            /// <returns type="boolean">Whether a matching prefix was found.</returns>
        }, 
        
        canHighlightItem: function(item) {
            /// <summary></summary>
            /// <param name="item" type=""></param>
        }, 
        
        decorateInternal: function(element) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
        }, 
        
        handleKeyEventInternal: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        decorateContent: function(element) {
            /// <summary>Decorate menu items located in any descendent node which as been explicitly
            /// marked as a &apos;content&apos; node.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Menu";
})(this);
