
/* vsdoc for goog.ui.MenuButton */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.MenuButton = function(content, opt_menu, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="content" type="goog.ui.ControlContent">Text caption or existing DOM
        ///     structure to display as the button&apos;s caption (if any).</param>
        /// <param name="opt_menu" type="goog.ui.Menu=">Menu to render under the button when clicked.</param>
        /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Renderer used to render or
        ///     decorate the menu button; defaults to {@link goog.ui.MenuButtonRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM hepler, used for
        ///     document interaction.</param>
        /// <returns type="goog.ui.MenuButton"/>
    };

    var $x = window.goog.ui.MenuButton;
    $x.prototype = {
                
        enterDocument: function() {
            /// <summary>Sets up event handlers specific to menu buttons.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary>Removes event handlers specific to menu buttons, and ensures that the
            /// attached menu also exits the document.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        handleMouseDown: function(e) {
            /// <summary>Handles mousedown events.  Invokes the superclass implementation to dispatch
            /// an ACTIVATE event and activate the button.  Also toggles the visibility of
            /// the attached menu.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        handleMouseUp: function(e) {
            /// <summary>Handles mouseup events.  Invokes the superclass implementation to dispatch
            /// an ACTION event and deactivate the button.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        performActionInternal: function(e) {
            /// <summary>Performs the appropriate action when the menu button is activated by the
            /// user.  Overrides the superclass implementation by not dispatching an {@code
            /// ACTION} event, because menu buttons exist only to reveal menus, not to
            /// perform actions themselves.  Calls {@link #setActive} to deactivate the
            /// button.</summary>
            /// <param name="e" type="goog.events.Event">Mouse or key event that triggered the action.</param>
            /// <returns type="boolean">Whether the action was allowed to proceed.</returns>
        }, 
        
        handleDocumentMouseDown: function(e) {
            /// <summary>Handles mousedown events over the document.  If the mousedown happens over
            /// an element unrelated to the component, hides the menu.
            /// TODO(attila): Reconcile this with goog.ui.Popup (and handle frames/windows).</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        containsElement: function(element) {
            /// <summary>Returns true if the given element is to be considered part of the component,
            /// even if it isn&apos;t a DOM descendant of the component&apos;s root element.</summary>
            /// <param name="element" type="Element">Element to test (if any).</param>
            /// <returns type="boolean">Whether the element is considered part of the component.</returns>
        }, 
        
        handleKeyEventInternal: function(e) {
            /// <summary></summary>
            /// <param name="e" type=""></param>
        }, 
        
        handleMenuAction: function(e) {
            /// <summary>Handles {@code ACTION} events dispatched by an activated menu item.</summary>
            /// <param name="e" type="goog.events.Event">Action event to handle.</param>
        }, 
        
        handleMenuBlur: function(e) {
            /// <summary>Handles {@code BLUR} events dispatched by the popup menu by closing it.
            /// Only registered if the menu is focusable.</summary>
            /// <param name="e" type="goog.events.Event">Blur event dispatched by a focusable menu.</param>
        }, 
        
        handleBlur: function(e) {
            /// <summary>Handles blur events dispatched by the button&apos;s key event target when it
            /// loses keyboard focus by closing the popup menu (unless it is focusable).
            /// Only registered if the button is focusable.</summary>
            /// <param name="e" type="goog.events.Event">Blur event dispatched by the menu button.</param>
        }, 
        
        getMenu: function() {
            /// <summary>Returns the menu attached to the button.  If no menu is attached, creates a
            /// new empty menu.</summary>
            /// <returns type="goog.ui.Menu">Popup menu attached to the menu button.</returns>
        }, 
        
        setMenu: function(menu) {
            /// <summary>Replaces the menu attached to the button with the argument, and returns the
            /// previous menu (if any).</summary>
            /// <param name="menu" type="goog.ui.Menu?">New menu to be attached to the menu button (null
            ///     to remove the menu).</param>
            /// <returns type="goog.ui.Menu|undefined">Previous menu (undefined if none).</returns>
        }, 
        
        setMenuPosition: function(position) {
            /// <summary>Specify which positioning algorithm to use.
            /// 
            /// This method is preferred over the fine-grained positioning methods like
            /// setPositionElement, setAlignMenuToStart, and setScrollOnOverflow. Calling
            /// this method will override settings by those methods.</summary>
            /// <param name="position" type="goog.positioning.AnchoredPosition">The position of the
            ///     Menu the button. If the position has a null anchor, we will use the
            ///     menubutton element as the anchor.</param>
        }, 
        
        setPositionElement: function(positionElement) {
            /// <summary>Sets an element for anchoring the menu.</summary>
            /// <param name="positionElement" type="Element">New element to use for
            ///     positioning the dropdown menu.  Null to use the default behavior
            ///     of positioning to this menu button.</param>
        }, 
        
        setMenuMargin: function(margin) {
            /// <summary>Sets a margin that will be applied to the menu&apos;s position when it is shown.
            /// If null, no margin will be applied.</summary>
            /// <param name="margin" type="goog.math.Box">Margin to apply.</param>
        }, 
        
        addItem: function(item) {
            /// <summary>Adds a new menu item at the end of the menu.</summary>
            /// <param name="item" type="goog.ui.MenuItem|goog.ui.MenuSeparator|goog.ui.Control">Menu
            ///     item to add to the menu.</param>
        }, 
        
        addItemAt: function(item, index) {
            /// <summary>Adds a new menu item at the specific index in the menu.</summary>
            /// <param name="item" type="goog.ui.MenuItem|goog.ui.MenuSeparator">Menu item to add to the
            ///     menu.</param>
            /// <param name="index" type="number">Index at which to insert the menu item.</param>
        }, 
        
        removeItem: function(item) {
            /// <summary>Removes the item from the menu and disposes of it.</summary>
            /// <param name="item" type="goog.ui.MenuItem|goog.ui.MenuSeparator">The menu item to remove.</param>
        }, 
        
        removeItemAt: function(index) {
            /// <summary>Removes the menu item at a given index in the menu and disposes of it.</summary>
            /// <param name="index" type="number">Index of item.</param>
        }, 
        
        getItemAt: function(index) {
            /// <summary>Returns the menu item at a given index.</summary>
            /// <param name="index" type="number">Index of menu item.</param>
            /// <returns type="goog.ui.MenuItem?">Menu item (null if not found).</returns>
        }, 
        
        getItemCount: function() {
            /// <summary>Returns the number of items in the menu (including separators).</summary>
            /// <returns type="number">The number of items in the menu.</returns>
        }, 
        
        setVisible: function(visible, opt_force) {
            /// <summary>Shows/hides the menu button based on the value of the argument.  Also hides
            /// the popup menu if the button is being hidden.</summary>
            /// <param name="visible" type="boolean">Whether to show or hide the button.</param>
            /// <param name="opt_force" type="boolean=">If true, doesn&apos;t check whether the component
            ///     already has the requested visibility, and doesn&apos;t dispatch any events.</param>
            /// <returns type="boolean">Whether the visibility was changed.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Enables/disables the menu button based on the value of the argument, and
            /// updates its CSS styling.  Also hides the popup menu if the button is being
            /// disabled.</summary>
            /// <param name="enable" type="boolean">Whether to enable or disable the button.</param>
        }, 
        
        isAlignMenuToStart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the menu is aligned to the start of the button
            ///     (left if the render direction is left-to-right, right if the render
            ///     direction is right-to-left).</returns>
        }, 
        
        setAlignMenuToStart: function(alignToStart) {
            /// <summary>Sets whether the menu is aligned to the start or the end of the button.</summary>
            /// <param name="alignToStart" type="boolean">Whether the menu is to be aligned to the start
            ///     of the button (left if the render direction is left-to-right, right if
            ///     the render direction is right-to-left).</param>
        }, 
        
        setScrollOnOverflow: function(scrollOnOverflow) {
            /// <summary>Sets whether the menu should scroll when it&apos;s too big to fix vertically on
            /// the screen.  The css of the menu element should have overflow set to auto.
            /// Note: Adding or removing items while the menu is open will not work correctly
            /// if scrollOnOverflow is on.</summary>
            /// <param name="scrollOnOverflow" type="boolean">Whether the menu should scroll when too big
            ///     to fit on the screen.  If false, adjust logic will be used to try and
            ///     reposition the menu to fit.</param>
        }, 
        
        isScrollOnOverflow: function() {
            /// <summary></summary>
            /// <returns type="boolean">Wether the menu will scroll when it&apos;s to big to fit
            ///     vertically on the screen.</returns>
        }, 
        
        isFocusablePopupMenu: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the attached menu is focusable.</returns>
        }, 
        
        setFocusablePopupMenu: function(focusable) {
            /// <summary>Sets whether the attached popup menu is focusable.  If the popup menu is
            /// focusable, it may steal keyboard focus from the menu button, so the button
            /// will not hide the menu on blur.</summary>
            /// <param name="focusable" type="boolean">Whether the attached menu is focusable.</param>
        }, 
        
        setRenderMenuAsSibling: function(renderMenuAsSibling) {
            /// <summary>Sets whether to render the menu as a sibling element of the button.
            /// Normally, the menu is a child of document.body.  This option is useful if
            /// you need the menu to inherit styles from a common parent element, or if you
            /// otherwise need it to share a parent element for desired event handling.  One
            /// example of the latter is if the parent is in a goog.ui.Popup, to ensure that
            /// clicks on the menu are considered being within the popup.</summary>
            /// <param name="renderMenuAsSibling" type="boolean">Whether we render the menu at the end
            ///     of the dom or as a sibling to the button/label that renders the drop
            ///     down.</param>
        }, 
        
        showMenu: function() {
            /// <summary>Reveals the menu and hooks up menu-specific event handling.</summary>
        }, 
        
        hideMenu: function() {
            /// <summary>Hides the menu and cleans up menu-specific event handling.</summary>
        }, 
        
        setOpen: function(open, opt_e) {
            /// <summary>Opens or closes the attached popup menu.</summary>
            /// <param name="open" type="boolean">Whether to open or close the menu.</param>
            /// <param name="opt_e" type="goog.events.Event=">Mousedown event that caused the menu to
            ///     be opened.</param>
        }, 
        
        invalidateMenuSize: function() {
            /// <summary>Resets the MenuButton&apos;s size.  This is useful for cases where items are added
            /// or removed from the menu and scrollOnOverflow is on.  In those cases the
            /// menu will not behave correctly and resize itself unless this is called
            /// (usually followed by positionMenu()).</summary>
        }, 
        
        positionMenu: function() {
            /// <summary>Positions the menu under the button.  May be called directly in cases when
            /// the menu size is known to change.</summary>
        }, 
        
        handleHighlightItem: function(e) {
            /// <summary>Handles {@code HIGHLIGHT} events dispatched by the attached menu.</summary>
            /// <param name="e" type="goog.events.Event">Highlight event to handle.</param>
        }, 
        
        handleUnHighlightItem: function(e) {
            /// <summary>Handles UNHIGHLIGHT events dispatched by the associated menu.</summary>
            /// <param name="e" type="goog.events.Event">Unhighlight event to handle.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.MenuButton";
})(this);
