
/* vsdoc for goog.ui.MenuButtonRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.MenuButtonRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.MenuButtonRenderer"/>
    };

    var $x = window.goog.ui.MenuButtonRenderer;
    $x.prototype = {
                
        setContent: function(element, content) {
            /// <summary>Takes the menubutton&apos;s root element, and sets its content to the given
            /// text caption or DOM structure. Because the DOM structure of this button is
            /// conditional based on whether we need to work around FF2/RTL bugs, we
            /// override the default implementation to take this into account.</summary>
            /// <param name="element" type="Element">The control&apos;s root element.</param>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM
            ///     structure to be set as the control&apos;s content.</param>
        }, 
        
        getContentElement: function(element) {
            /// <summary>Takes the button&apos;s root element and returns the parent element of the
            /// button&apos;s contents.  Overrides the superclass implementation by taking
            /// the nested DIV structure of menu buttons into account.</summary>
            /// <param name="element" type="Element">Root element of the button whose content element
            ///     is to be returned.</param>
            /// <returns type="Element">The button&apos;s content element.</returns>
        }, 
        
        decorate: function(control, element) {
            /// <summary>Takes an element, decorates it with the menu button control, and returns
            /// the element.  Overrides {@link goog.ui.CustomButtonRenderer#decorate} by
            /// looking for a child element that can be decorated by a menu, and if it
            /// finds one, decorates it and attaches it to the menu button.</summary>
            /// <param name="control" type="goog.ui.Control">goog.ui.MenuButton to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        createButton: function(content, dom) {
            /// <summary>Takes a text caption or existing DOM structure, and returns the content and
            /// a dropdown arrow element wrapped in a pseudo-rounded-corner box.  Creates
            /// the following DOM structure:
            ///    &lt;div class=&quot;goog-inline-block goog-menu-button-outer-box&quot;&gt;
            ///      &lt;div class=&quot;goog-inline-block goog-menu-button-inner-box&quot;&gt;
            ///        &lt;div class=&quot;goog-inline-block goog-menu-button-caption&quot;&gt;
            ///          Contents...
            ///        &lt;/div&gt;
            ///        &lt;div class=&quot;goog-inline-block goog-menu-button-dropdown&quot;&gt;
            ///          &amp;nbsp;
            ///        &lt;/div&gt;
            ///      &lt;/div&gt;
            ///    &lt;/div&gt;</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to wrap in a box.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Pseudo-rounded-corner box containing the content.</returns>
        }, 
        
        createCaption: function(content, dom) {
            /// <summary>Takes a text caption or existing DOM structure, and returns it wrapped in
            /// an appropriately-styled DIV.  Creates the following DOM structure:
            ///    &lt;div class=&quot;goog-inline-block goog-menu-button-caption&quot;&gt;
            ///      Contents...
            ///    &lt;/div&gt;</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to wrap in a box.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Caption element.</returns>
        }, 
        
        wrapCaption: function(content, cssClass, dom) {
            /// <summary>Takes a text caption or existing DOM structure, and returns it wrapped in
            /// an appropriately-styled DIV.  Creates the following DOM structure:
            ///    &lt;div class=&quot;goog-inline-block goog-menu-button-caption&quot;&gt;
            ///      Contents...
            ///    &lt;/div&gt;</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to wrap in a box.</param>
            /// <param name="cssClass" type="string">The CSS class for the renderer.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Caption element.</returns>
        }, 
        
        createDropdown: function(dom) {
            /// <summary>Returns an appropriately-styled DIV containing a dropdown arrow element.
            /// Creates the following DOM structure:
            ///    &lt;div class=&quot;goog-inline-block goog-menu-button-dropdown&quot;&gt;
            ///      &amp;nbsp;
            ///    &lt;/div&gt;</summary>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Dropdown element.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.MenuButtonRenderer";
})(this);
