
/* vsdoc for goog.ui.MenuItemRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.MenuItemRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">CSS class name the renderer applies to menu item elements.</field>
        /// <returns type="goog.ui.MenuItemRenderer"/>
    };

    var $x = window.goog.ui.MenuItemRenderer;
    $x.prototype = {
                
        getAriaRole: function() {
            /// <summary></summary>
        }, 
        
        createDom: function(item) {
            /// <summary>Overrides {@link goog.ui.ControlRenderer#createDom} by adding extra markup
            /// and stying to the menu item&apos;s element if it is selectable or checkable.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item to render.</param>
            /// <returns type="Element">Root element for the item.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
        }, 
        
        decorate: function(item, element) {
            /// <summary>Overrides {@link goog.ui.ControlRenderer#decorate} by initializing the
            /// menu item to checkable based on whether the element to be decorated has
            /// extra stying indicating that it should be.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item instance to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        setContent: function(element, content) {
            /// <summary>Takes a menu item&apos;s root element, and sets its content to the given text
            /// caption or DOM structure.  Overrides the superclass immplementation by
            /// making sure that the checkbox structure (for selectable/checkable menu
            /// items) is preserved.</summary>
            /// <param name="element" type="Element">The item&apos;s root element.</param>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure to be
            ///     set as the item&apos;s content.</param>
        }, 
        
        hasContentStructure: function(element) {
            /// <summary>Returns true if the element appears to have a proper menu item structure by
            /// checking whether its first child has the appropriate structural class name.</summary>
            /// <param name="element" type="Element">Element to check.</param>
            /// <returns type="boolean">Whether the element appears to have a proper menu item DOM.</returns>
        }, 
        
        createContent: function(content, dom) {
            /// <summary>Wraps the given text caption or existing DOM node(s) in a structural element
            /// containing the menu item&apos;s contents.</summary>
            /// <param name="content" type="goog.ui.ControlContent">Menu item contents.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper for document interaction.</param>
            /// <returns type="Element">Menu item content element.</returns>
        }, 
        
        setSelectable: function(item, element, selectable) {
            /// <summary>Enables/disables radio button semantics on the menu item.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item to update.</param>
            /// <param name="element" type="Element">Menu item element to update (may be null if the
            ///     item hasn&apos;t been rendered yet).</param>
            /// <param name="selectable" type="boolean">Whether the item should be selectable.</param>
        }, 
        
        setCheckable: function(item, element, checkable) {
            /// <summary>Enables/disables checkbox semantics on the menu item.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item to update.</param>
            /// <param name="element" type="Element">Menu item element to update (may be null if the
            ///     item hasn&apos;t been rendered yet).</param>
            /// <param name="checkable" type="boolean">Whether the item should be checkable.</param>
        }, 
        
        hasCheckBoxStructure: function(element) {
            /// <summary>Determines whether the item contains a checkbox element.</summary>
            /// <param name="element" type="Element">Menu item root element.</param>
            /// <returns type="boolean">Whether the element contains a checkbox element.</returns>
        }, 
        
        setEnableCheckBoxStructure: function(item, element, enable) {
            /// <summary>Adds or removes extra markup and CSS styling to the menu item to make it
            /// selectable or non-selectable, depending on the value of the
            /// {@code selectable} argument.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item to update.</param>
            /// <param name="element" type="Element">Menu item element to update.</param>
            /// <param name="enable" type="boolean">Whether to add or remove the checkbox structure.</param>
        }, 
        
        getClassForState: function(state) {
            /// <summary>Takes a single {@link goog.ui.Component.State}, and returns the
            /// corresponding CSS class name (null if none).  Overrides the superclass
            /// implementation by using &apos;highlight&apos; as opposed to &apos;hover&apos; as the CSS
            /// class name suffix for the HOVER state, for backwards compatibility.</summary>
            /// <param name="state" type="goog.ui.Component.State">Component state.</param>
            /// <returns type="string|undefined">CSS class representing the given state
            ///     (undefined if none).</returns>
        }, 
        
        getStateFromClass: function(className) {
            /// <summary>Takes a single CSS class name which may represent a component state, and
            /// returns the corresponding component state (0x00 if none).  Overrides the
            /// superclass implementation by treating &apos;goog-option-selected&apos; as special,
            /// for backwards compatibility.</summary>
            /// <param name="className" type="string">CSS class name, possibly representing a component
            ///     state.</param>
            /// <returns type="goog.ui.Component.State">state Component state corresponding
            ///     to the given CSS class (0x00 if none).</returns>
        }, 
        
        getCssClass: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.MenuItemRenderer";
})(this);
