
/* vsdoc for goog.ui.Palette */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Palette = function(items, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="items" type="Array.Node">Array of DOM nodes to be displayed as items
        ///     in the palette grid (limited to one per cell).</param>
        /// <param name="opt_renderer" type="goog.ui.PaletteRenderer=">Renderer used to render or
        ///     decorate the palette; defaults to {@link goog.ui.PaletteRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper, used for
        ///     document interaction.</param>
        /// <returns type="goog.ui.Palette"/>
    };

    var $x = window.goog.ui.Palette;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setContentInternal: function(content) {
            /// <summary>Overrides {@link goog.ui.Control#setContentInternal} by also updating the
            /// grid size and the selection model.  Considered protected.</summary>
            /// <param name="content" type="goog.ui.ControlContent">Array of DOM nodes to be displayed
            ///     as items in the palette grid (one item per cell).</param>
        }, 
        
        getCaption: function() {
            /// <summary>Overrides {@link goog.ui.Control#getCaption} to return the empty string,
            /// since palettes don&apos;t have text captions.</summary>
            /// <returns type="string">The empty string.</returns>
        }, 
        
        setCaption: function(caption) {
            /// <summary>Overrides {@link goog.ui.Control#setCaption} to be a no-op, since palettes
            /// don&apos;t have text captions.</summary>
            /// <param name="caption" type="string">Ignored.</param>
        }, 
        
        handleMouseOver: function(e) {
            /// <summary>Handles mouseover events.  Overrides {@link goog.ui.Control#handleMouseOver}
            /// by determining which palette item (if any) was moused over, highlighting it,
            /// and un-highlighting any previously-highlighted item.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        handleMouseOut: function(e) {
            /// <summary>Handles mouseout events.  Overrides {@link goog.ui.Control#handleMouseOut}
            /// by determining the palette item that the mouse just left (if any), and
            /// making sure it is un-highlighted.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        handleMouseDown: function(e) {
            /// <summary>Handles mousedown events.  Overrides {@link goog.ui.Control#handleMouseDown}
            /// by ensuring that the item on which the user moused down is highlighted.</summary>
            /// <param name="e" type="goog.events.Event">Mouse event to handle.</param>
        }, 
        
        performActionInternal: function(e) {
            /// <summary>Selects the currently highlighted palette item (triggered by mouseup or by
            /// keyboard action).  Overrides {@link goog.ui.Control#performActionInternal}
            /// by selecting the highlighted item and dispatching an ACTION event.</summary>
            /// <param name="e" type="goog.events.Event">Mouse or key event that triggered the action.</param>
            /// <returns type="boolean">True if the action was allowed to proceed, false otherwise.</returns>
        }, 
        
        handleKeyEvent: function(e) {
            /// <summary>Handles keyboard events dispatched while the palette has focus.  Moves the
            /// highlight on arrow keys, and selects the highlighted item on Enter or Space.
            /// Returns true if the event was handled, false otherwise.  In particular, if
            /// the user attempts to navigate out of the grid, the highlight isn&apos;t changed,
            /// and this method returns false; it is then up to the parent component to
            /// handle the event (e.g. by wrapping the highlight around).  Overrides {@link
            /// goog.ui.Control#handleKeyEvent}.</summary>
            /// <param name="e" type="goog.events.KeyEvent">Key event to handle.</param>
            /// <returns type="boolean">True iff the key event was handled by the component.</returns>
        }, 
        
        handleSelectionChange: function(e) {
            /// <summary>Handles selection change events dispatched by the selection model.</summary>
            /// <param name="e" type="goog.events.Event">Selection event to handle.</param>
        }, 
        
        getSize: function() {
            /// <summary>Returns the size of the palette grid.</summary>
            /// <returns type="goog.math.Size">Palette size (columns x rows).</returns>
        }, 
        
        setSize: function(size, opt_rows) {
            /// <summary>Sets the size of the palette grid to the given size.  Callers can either
            /// pass a single {@link goog.math.Size} or a pair of numbers (first the number
            /// of columns, then the number of rows) to this method.  In both cases, the
            /// number of rows is optional and will be calculated automatically if needed.
            /// It is an error to attempt to change the size of the palette after it has
            /// been rendered.</summary>
            /// <param name="size" type="goog.math.Size|number">Either a size object or the number of
            ///     columns.</param>
            /// <param name="opt_rows" type="number=">The number of rows (optional).</param>
        }, 
        
        getHighlightedIndex: function() {
            /// <summary>Returns the 0-based index of the currently highlighted palette item, or -1
            /// if no item is highlighted.</summary>
            /// <returns type="number">Index of the highlighted item (-1 if none).</returns>
        }, 
        
        getHighlightedItem: function() {
            /// <summary>Returns the currently highlighted palette item, or null if no item is
            /// highlighted.</summary>
            /// <returns type="Node">The highlighted item (null if none).</returns>
        }, 
        
        setHighlightedIndex: function(index) {
            /// <summary>Highlights the item at the given 0-based index, or removes the highlight
            /// if the argument is -1 or out of range.  Any previously-highlighted item
            /// will be un-highlighted.</summary>
            /// <param name="index" type="number">0-based index of the item to highlight.</param>
        }, 
        
        setHighlightedItem: function(item) {
            /// <summary>Highlights the given item, or removes the highlight if the argument is null
            /// or invalid.  Any previously-highlighted item will be un-highlighted.</summary>
            /// <param name="item" type="Node">Item to highlight.</param>
        }, 
        
        getSelectedIndex: function() {
            /// <summary>Returns the 0-based index of the currently selected palette item, or -1
            /// if no item is selected.</summary>
            /// <returns type="number">Index of the selected item (-1 if none).</returns>
        }, 
        
        getSelectedItem: function() {
            /// <summary>Returns the currently selected palette item, or null if no item is selected.</summary>
            /// <returns type="Node">The selected item (null if none).</returns>
        }, 
        
        setSelectedIndex: function(index) {
            /// <summary>Selects the item at the given 0-based index, or clears the selection
            /// if the argument is -1 or out of range.  Any previously-selected item
            /// will be deselected.</summary>
            /// <param name="index" type="number">0-based index of the item to select.</param>
        }, 
        
        setSelectedItem: function(item) {
            /// <summary>Selects the given item, or clears the selection if the argument is null or
            /// invalid.  Any previously-selected item will be deselected.</summary>
            /// <param name="item" type="Node">Item to select.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Palette";
})(this);
