
/* vsdoc for goog.ui.PaletteRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.PaletteRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.PaletteRenderer"/>
    };

    var $x = window.goog.ui.PaletteRenderer;
    $x.prototype = {
                
        createDom: function(palette) {
            /// <summary>Returns the palette items arranged in a table wrapped in a DIV, with the
            /// renderer&apos;s own CSS class and additional state-specific classes applied to
            /// it.</summary>
            /// <param name="palette" type="goog.ui.Control">goog.ui.Palette to render.</param>
            /// <returns type="Element">Root element for the palette.</returns>
        }, 
        
        createGrid: function(items, size, dom) {
            /// <summary>Returns the given items in a table with {@code size.width} columns and
            /// {@code size.height} rows.  If the table is too big, empty cells will be
            /// created as needed.  If the table is too small, the items that don&apos;t fit
            /// will not be rendered.</summary>
            /// <param name="items" type="Array.Node">Palette items.</param>
            /// <param name="size" type="goog.math.Size">Palette size (columns x rows); both dimensions
            ///     must be specified as numbers.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper for document interaction.</param>
            /// <returns type="Element">Palette table element.</returns>
        }, 
        
        createTable: function(rows, dom) {
            /// <summary>Returns a table element (or equivalent) that wraps the given rows.</summary>
            /// <param name="rows" type="Array.Element">Array of row elements.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper for document interaction.</param>
            /// <returns type="Element">Palette table element.</returns>
        }, 
        
        createRow: function(cells, dom) {
            /// <summary>Returns a table row element (or equivalent) that wraps the given cells.</summary>
            /// <param name="cells" type="Array.Element">Array of cell elements.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper for document interaction.</param>
            /// <returns type="Element">Row element.</returns>
        }, 
        
        createCell: function(node, dom) {
            /// <summary>Returns a table cell element (or equivalent) that wraps the given palette
            /// item (which must be a DOM node).</summary>
            /// <param name="node" type="Node|string">Palette item.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper for document interaction.</param>
            /// <returns type="Element">Cell element.</returns>
        }, 
        
        canDecorate: function(element) {
            /// <summary>Overrides {@link goog.ui.ControlRenderer#canDecorate} to always return false.</summary>
            /// <param name="element" type="Element">Ignored.</param>
            /// <returns type="boolean">False, since palettes don&apos;t support the decorate flow (for
            ///     now).</returns>
        }, 
        
        decorate: function(palette, element) {
            /// <summary>Overrides {@link goog.ui.ControlRenderer#decorate} to be a no-op, since
            /// palettes don&apos;t support the decorate flow (for now).</summary>
            /// <param name="palette" type="goog.ui.Control">Ignored.</param>
            /// <param name="element" type="Element">Ignored.</param>
            /// <returns type="null">Always null.</returns>
        }, 
        
        setContent: function(element, content) {
            /// <summary>Overrides {@link goog.ui.ControlRenderer#setContent} for palettes.  Locates
            /// the HTML table representing the palette grid, and replaces the contents of
            /// each cell with a new element from the array of nodes passed as the second
            /// argument.  If the new content has too many items the table will have more
            /// rows added to fit, if there are less items than the table has cells, then the
            /// left over cells will be empty.</summary>
            /// <param name="element" type="Element">Root element of the palette control.</param>
            /// <param name="content" type="goog.ui.ControlContent">Array of items to replace existing
            ///     palette items.</param>
        }, 
        
        getContainingItem: function(palette, node) {
            /// <summary>Returns the item corresponding to the given node, or null if the node is
            /// neither a palette cell nor part of a palette item.</summary>
            /// <param name="palette" type="goog.ui.Palette">Palette in which to look for the item.</param>
            /// <param name="node" type="Node">Node to look for.</param>
            /// <returns type="Node">The corresponding palette item (null if not found).</returns>
        }, 
        
        highlightCell: function(palette, node, highlight) {
            /// <summary>Updates the highlight styling of the palette cell containing the given node
            /// based on the value of the Boolean argument.</summary>
            /// <param name="palette" type="goog.ui.Palette">Palette containing the item.</param>
            /// <param name="node" type="Node">Item whose cell is to be highlighted or un-highlighted.</param>
            /// <param name="highlight" type="boolean">If true, the cell is highlighted; otherwise it is
            ///     un-highlighted.</param>
        }, 
        
        selectCell: function(palette, node, select) {
            /// <summary>Updates the selection styling of the palette cell containing the given node
            /// based on the value of the Boolean argument.</summary>
            /// <param name="palette" type="goog.ui.Palette">Palette containing the item.</param>
            /// <param name="node" type="Node">Item whose cell is to be selected or deselected.</param>
            /// <param name="select" type="boolean">If true, the cell is selected; otherwise it is
            ///     deselected.</param>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.PaletteRenderer";
})(this);
