
/* vsdoc for goog.ui.PopupBase */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.PopupBase = function(opt_element, opt_type){
        /// <summary></summary>
        /// <param name="opt_element" type="Element=">A DOM element for the popup.</param>
        /// <param name="opt_type" type="goog.ui.PopupBase.Type=">Type of popup.</param>
        /// <field name="Type" type="">Constants for type of Popup</field>
        /// <field name="EventType" type="">Constants for event type fired by Popup</field>
        /// <field name="DEBOUNCE_DELAY_MS" type="number">A time in ms used to debounce events that happen right after each other.
        /// 
        /// A note about why this is necessary. There are two cases to consider.
        /// First case, a popup will usually see a focus event right after it&apos;s launched
        /// because it&apos;s typical for it to be launched in a mouse-down event which will
        /// then move focus to the launching button. We don&apos;t want to think this is a
        /// separate user action moving focus. Second case, a user clicks on the
        /// launcher button to close the menu. In that case, we&apos;ll close the menu in the
        /// focus event and then show it again because of the mouse down event, even
        /// though the intention is to just close the menu. This workaround appears to
        /// be the least intrusive fix.</field>
        /// <field name="reposition" type="">Repositions the popup according to the current state.
        /// Should be overriden by subclases.</field>
        /// <returns type="goog.ui.PopupBase"/>
    };

    var $x = window.goog.ui.PopupBase;
    $x.prototype = {
                
        getType: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.PopupBase.Type">The type of popup this is.</returns>
        }, 
        
        setType: function(type) {
            /// <summary>Specifies the type of popup to use.</summary>
            /// <param name="type" type="goog.ui.PopupBase.Type">Type of popup.</param>
        }, 
        
        shouldHideAsync: function() {
            /// <summary>Returns whether the popup should hide itself asynchronously using a timeout
            /// instead of synchronously.</summary>
            /// <returns type="boolean">Whether to hide async.</returns>
        }, 
        
        setShouldHideAsync: function(b) {
            /// <summary>Sets whether the popup should hide itself asynchronously using a timeout
            /// instead of synchronously.</summary>
            /// <param name="b" type="boolean">Whether to hide async.</param>
        }, 
        
        getElement: function() {
            /// <summary>Returns the dom element that should be used for the popup.</summary>
            /// <returns type="Element">The popup element.</returns>
        }, 
        
        setElement: function(elt) {
            /// <summary>Specifies the dom element that should be used for the popup.</summary>
            /// <param name="elt" type="Element">A DOM element for the popup.</param>
        }, 
        
        getAutoHide: function() {
            /// <summary>Returns whether the Popup dismisses itself when the user clicks outside of
            /// it.</summary>
            /// <returns type="boolean">Whether the Popup autohides on an external click.</returns>
        }, 
        
        setAutoHide: function(autoHide) {
            /// <summary>Sets whether the Popup dismisses itself when the user clicks outside of it.</summary>
            /// <param name="autoHide" type="boolean">Whether to autohide on an external click.</param>
        }, 
        
        getHideOnEscape: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the Popup autohides on the escape key.</returns>
        }, 
        
        setHideOnEscape: function(hideOnEscape) {
            /// <summary>Sets whether the Popup dismisses itself on the escape key.</summary>
            /// <param name="hideOnEscape" type="boolean">Whether to autohide on the escape key.</param>
        }, 
        
        getEnableCrossIframeDismissal: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether cross iframe dismissal is enabled.</returns>
        }, 
        
        setEnableCrossIframeDismissal: function(enable) {
            /// <summary>Sets whether clicks in other iframes should dismiss this popup.  In some
            /// cases it should be disabled, because it can cause spurious</summary>
            /// <param name="enable" type="boolean">Whether to enable cross iframe dismissal.</param>
        }, 
        
        getAutoHideRegion: function() {
            /// <summary>Returns the region inside which the Popup dismisses itself when the user
            /// clicks, or null if it&apos;s the entire document.</summary>
            /// <returns type="Element">The DOM element for autohide, or null if it hasn&apos;t been
            ///     set.</returns>
        }, 
        
        setAutoHideRegion: function(element) {
            /// <summary>Sets the region inside which the Popup dismisses itself when the user
            /// clicks.</summary>
            /// <param name="element" type="Element">The DOM element for autohide.</param>
        }, 
        
        setTransition: function(opt_showTransition, opt_hideTransition) {
            /// <summary>Sets transition animation on showing and hiding the popup.</summary>
            /// <param name="opt_showTransition" type="goog.fx.Transition=">Transition to play on
            ///     showing the popup.</param>
            /// <param name="opt_hideTransition" type="goog.fx.Transition=">Transition to play on
            ///     hiding the popup.</param>
        }, 
        
        getLastShowTime: function() {
            /// <summary>Returns the time when the popup was last shown.</summary>
            /// <returns type="number">time in ms since epoch when the popup was last shown, or
            /// -1 if the popup was never shown.</returns>
        }, 
        
        getLastHideTime: function() {
            /// <summary>Returns the time when the popup was last hidden.</summary>
            /// <returns type="number">time in ms since epoch when the popup was last hidden, or
            /// -1 if the popup was never hidden or is currently showing.</returns>
        }, 
        
        isVisible: function() {
            /// <summary>Returns whether the popup is currently visible.</summary>
            /// <returns type="boolean">whether the popup is currently visible.</returns>
        }, 
        
        isOrWasRecentlyVisible: function() {
            /// <summary>Returns whether the popup is currently visible or was visible within about
            /// 150 ms ago. This is used by clients to handle a very specific, but common,
            /// popup scenario. The button that launches the popup should close the popup
            /// on mouse down if the popup is alrady open. The problem is that the popup
            /// closes itself during the capture phase of the mouse down and thus the button
            /// thinks it&apos;s hidden and this should show it again. This method provides a
            /// good heuristic for clients. Typically in their event handler they will have
            /// code that is:
            /// 
            /// if (menu.isOrWasRecentlyVisible()) {
            ///   menu.setVisible(false);
            /// } else {
            ///   ... // code to position menu and initialize other state
            ///   menu.setVisible(true);
            /// }</summary>
            /// <returns type="boolean">Whether the popup is currently visible or was visible
            ///     within about 150 ms ago.</returns>
        }, 
        
        setVisible: function(visible) {
            /// <summary>Sets whether the popup should be visible. After this method
            /// returns, isVisible() will always return the new state, even if
            /// there is a transition.</summary>
            /// <param name="visible" type="boolean">Desired visibility state.</param>
        }, 
        
        showPopupElement: function() {
            /// <summary>Shows the popup element.</summary>
        }, 
        
        onBeforeShow: function() {
            /// <summary>Called before the popup is shown. Derived classes can override to hook this
            /// event but should make sure to call the parent class method.</summary>
            /// <returns type="boolean">If anyone called preventDefault on the event object (or
            ///     if any of the handlers returns false this will also return false.</returns>
        }, 
        
        onShow_: function() {
            /// <summary>Called after the popup is shown. Derived classes can override to hook this
            /// event but should make sure to call the parent class method.</summary>
        }, 
        
        onBeforeHide_: function(opt_target) {
            /// <summary>Called before the popup is hidden. Derived classes can override to hook this
            /// event but should make sure to call the parent class method.</summary>
            /// <param name="opt_target" type="Object=">Target of the event causing the hide.</param>
            /// <returns type="boolean">If anyone called preventDefault on the event object (or
            ///     if any of the handlers returns false this will also return false.</returns>
        }, 
        
        onHide_: function(opt_target) {
            /// <summary>Called after the popup is hidden. Derived classes can override to hook this
            /// event but should make sure to call the parent class method.</summary>
            /// <param name="opt_target" type="Object=">Target of the event causing the hide.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.PopupBase";
})(this);
