
/* vsdoc for goog.ui.PopupMenu */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.PopupMenu = function(opt_domHelper, opt_renderer){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <param name="opt_renderer" type="goog.ui.MenuRenderer=">Renderer used to render or
        ///     decorate the container; defaults to {@link goog.ui.MenuRenderer}.</param>
        /// <returns type="goog.ui.PopupMenu"/>
    };

    var $x = window.goog.ui.PopupMenu;
    $x.prototype = {
                
        decorateInternal: function(element) {
            /// <summary>Decorate an existing HTML structure with the menu. Menu items will be
            /// constructed from elements with classname &apos;goog-menuitem&apos;, separators will be
            /// made from HR elements.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        attach: function(element, opt_targetCorner, opt_menuCorner, opt_contextMenu, opt_margin) {
            /// <summary>Attaches the menu to a new popup position and anchor element.  A menu can
            /// only be attached to an element once, since attaching the same menu for
            /// multiple positions doesn&apos;t make sense.</summary>
            /// <param name="element" type="Element">Element whose click event should trigger the menu.</param>
            /// <param name="opt_targetCorner" type="goog.positioning.Corner=">Corner of the target that
            ///     the menu should be anchored to.</param>
            /// <param name="opt_menuCorner" type="goog.positioning.Corner=">Corner of the menu that
            ///     should be anchored.</param>
            /// <param name="opt_contextMenu" type="boolean=">Whether the menu should show on
            ///     {@link goog.events.EventType.CONTEXTMENU} events, false if it should
            ///     show on {@link goog.events.EventType.MOUSEDOWN} events. Default is
            ///     MOUSEDOWN.</param>
            /// <param name="opt_margin" type="goog.math.Box=">Margin for the popup used in positioning
            ///     algorithms.</param>
        }, 
        
        createAttachTarget: function(element, opt_targetCorner, opt_menuCorner, opt_contextMenu, opt_margin) {
            /// <summary>Creates an object describing how the popup menu should be attached to the
            /// anchoring element based on the given parameters. The created object is
            /// stored, keyed by {@code element} and is retrievable later by invoking
            /// {@link #getAttachTarget(element)} at a later point.
            /// 
            /// Subclass may add more properties to the returned object, as needed.</summary>
            /// <param name="element" type="Element">Element whose click event should trigger the menu.</param>
            /// <param name="opt_targetCorner" type="goog.positioning.Corner=">Corner of the target that
            ///     the menu should be anchored to.</param>
            /// <param name="opt_menuCorner" type="goog.positioning.Corner=">Corner of the menu that
            ///     should be anchored.</param>
            /// <param name="opt_contextMenu" type="boolean=">Whether the menu should show on
            ///     {@link goog.events.EventType.CONTEXTMENU} events, false if it should
            ///     show on {@link goog.events.EventType.MOUSEDOWN} events. Default is
            ///     MOUSEDOWN.</param>
            /// <param name="opt_margin" type="goog.math.Box=">Margin for the popup used in positioning
            ///     algorithms.</param>
            /// <returns type="Object">An object that describes how the popup menu should be
            ///     attached to the anchoring element.</returns>
        }, 
        
        getAttachTarget: function(element) {
            /// <summary>Returns the object describing how the popup menu should be attach to given
            /// element or {@code null}. The object is created and the association is formed
            /// when {@link #attach} is invoked.</summary>
            /// <param name="element" type="Element">DOM element.</param>
            /// <returns type="Object">The object created when {@link attach} is invoked on
            ///     {@code element}. Returns {@code null} if the element does not trigger
            ///     the menu (i.e. {@link attach} has never been invoked on
            ///     {@code element}).</returns>
        }, 
        
        isAttachTarget: function(element) {
            /// <summary></summary>
            /// <param name="element" type="Element">Any DOM element.</param>
            /// <returns type="boolean">Whether clicking on the given element will trigger the
            ///     menu.</returns>
        }, 
        
        getAttachedElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The current element where the popup is anchored, if it&apos;s
            ///     visible.</returns>
        }, 
        
        detachAll: function() {
            /// <summary>Detaches all listeners</summary>
        }, 
        
        detach: function(element) {
            /// <summary>Detaches a menu from a given element.</summary>
            /// <param name="element" type="Element">Element whose click event should trigger the menu.</param>
        }, 
        
        setToggleMode: function(toggle) {
            /// <summary>Sets whether the menu should toggle if it is already open.  For context
            /// menus this should be false, for toolbar menus it makes more sense to be true.</summary>
            /// <param name="toggle" type="boolean">The new toggle mode.</param>
        }, 
        
        getToggleMode: function() {
            /// <summary>Gets whether the menu is in toggle mode</summary>
            /// <returns type="boolean">toggle.</returns>
        }, 
        
        showWithPosition: function(position, opt_menuCorner, opt_margin, opt_anchor) {
            /// <summary>Show the menu using given positioning object.</summary>
            /// <param name="position" type="goog.positioning.AbstractPosition">The positioning instance.</param>
            /// <param name="opt_menuCorner" type="goog.positioning.Corner=">The corner of the menu to be
            ///     positioned.</param>
            /// <param name="opt_margin" type="goog.math.Box=">A margin specified in pixels.</param>
            /// <param name="opt_anchor" type="Element=">The element which acts as visual anchor for this
            ///     menu.</param>
        }, 
        
        showMenu: function(target, x, y) {
            /// <summary>Show the menu at a given attached target.</summary>
            /// <param name="target" type="Object">Popup target.</param>
            /// <param name="x" type="number">The client-X associated with the show event.</param>
            /// <param name="y" type="number">The client-Y associated with the show event.</param>
        }, 
        
        showAt: function(x, y, opt_menuCorner) {
            /// <summary>Shows the menu immediately at the given client coordinates.</summary>
            /// <param name="x" type="number">The client-X associated with the show event.</param>
            /// <param name="y" type="number">The client-Y associated with the show event.</param>
            /// <param name="opt_menuCorner" type="goog.positioning.Corner=">Corner of the menu that
            ///     should be anchored.</param>
        }, 
        
        showAtElement: function(element, targetCorner, opt_menuCorner) {
            /// <summary>Shows the menu immediately attached to the given element</summary>
            /// <param name="element" type="Element">The element to show at.</param>
            /// <param name="targetCorner" type="goog.positioning.Corner">The corner of the target to
            ///     anchor to.</param>
            /// <param name="opt_menuCorner" type="goog.positioning.Corner=">Corner of the menu that
            ///     should be anchored.</param>
        }, 
        
        hide: function() {
            /// <summary>Hides the menu.</summary>
        }, 
        
        isOrWasRecentlyVisible: function() {
            /// <summary>Returns whether the menu is currently visible or was visible within about
            /// 150 ms ago.  This stops the menu toggling back on if the toggleMode == false.</summary>
            /// <returns type="boolean">Whether the popup is currently visible or was visible
            ///     within about 150 ms ago.</returns>
        }, 
        
        wasRecentlyHidden: function() {
            /// <summary>Used to stop the menu toggling back on if the toggleMode == false.</summary>
            /// <returns type="boolean">Whether the menu was recently hidden.</returns>
        }, 
        
        onDocClick: function(e) {
            /// <summary>Handles click events that propagate to the document.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">The browser event.</param>
        }, 
        
        handleBlur: function(e) {
            /// <summary>Handles the key event target loosing focus.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">The browser event.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.PopupMenu";
})(this);
