
/* vsdoc for goog.ui.Ratings */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Ratings = function(opt_ratings, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_ratings" type="Array.string=">Ratings. Default: [1,2,3,4,5].</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <field name="EventType" type="">Enums for Ratings event type.</field>
        /// <returns type="goog.ui.Ratings"/>
    };

    var $x = window.goog.ui.Ratings;
    $x.prototype = {
                
        decorateInternal: function(el) {
            /// <summary>Decorate a HTML structure already in the document.  Expects the structure:
            /// &lt;pre&gt;
            /// - div
            ///   - select
            ///       - option 1 #text = 1 star
            ///       - option 2 #text = 2 stars
            ///       - option 3 #text = 3 stars
            ///       - option N (where N is max number of ratings)
            /// &lt;/pre&gt;
            /// 
            /// The div can contain other elements for graceful degredation, but they will be
            /// hidden when the decoration occurs.</summary>
            /// <param name="el" type="Element">Div element to decorate.</param>
        }, 
        
        enterDocument: function() {
            /// <summary>Render the rating widget inside the provided element. This will override the
            /// current content of the element.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary>Should be called when the widget is removed from the document but may be
            /// reused.  This removes all the listeners the widget has attached and destroys
            /// the DOM nodes it uses.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the base CSS class used by subcomponents of this component.</summary>
            /// <returns type="string">Component-specific CSS class.</returns>
        }, 
        
        setSelectedIndex: function(index) {
            /// <summary>Sets the selected index. If the provided index is greater than the number of
            /// ratings then the max is set.  0 is the first item, -1 is no selection.</summary>
            /// <param name="index" type="number">The index of the rating to select.</param>
        }, 
        
        getSelectedIndex: function() {
            /// <summary></summary>
            /// <returns type="number">The index of the currently selected rating.</returns>
        }, 
        
        getValue: function() {
            /// <summary>Returns the rating value of the currently selected rating</summary>
            /// <returns type="?string">The value of the currently selected rating (or null).</returns>
        }, 
        
        getHighlightedIndex: function() {
            /// <summary>Returns the index of the currently highlighted rating, -1 if the mouse isn&apos;t
            /// currently over the widget</summary>
            /// <returns type="number">The index of the currently highlighted rating.</returns>
        }, 
        
        getHighlightedValue: function() {
            /// <summary>Returns the value of the currently highlighted rating, null if the mouse
            /// isn&apos;t currently over the widget</summary>
            /// <returns type="?string">The value of the currently highlighted rating, or null.</returns>
        }, 
        
        setRatings: function(ratings) {
            /// <summary>Sets the array of ratings that the comonent</summary>
            /// <param name="ratings" type="Array.string">Array of value to use as ratings.</param>
        }, 
        
        getRatings: function() {
            /// <summary>Gets the array of ratings that the component</summary>
            /// <returns type="Array.string">Array of ratings.</returns>
        }, 
        
        setAttachedFormField: function(field) {
            /// <summary>Attaches an input or select element to the ratings widget. The value or
            /// index of the field will be updated along with the ratings widget.</summary>
            /// <param name="field" type="HTMLSelectElement|HTMLInputElement">The field to attach to.</param>
        }, 
        
        getAttachedFormField: function() {
            /// <summary>Returns the attached input or select element to the ratings widget.</summary>
            /// <returns type="HTMLSelectElement|HTMLInputElement|null">The attached form field.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Ratings";
})(this);
