
/* vsdoc for goog.ui.RoundedTabRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.RoundedTabRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.RoundedTabRenderer"/>
    };

    var $x = window.goog.ui.RoundedTabRenderer;
    $x.prototype = {
                
        getCssClass: function() {
            /// <summary>Returns the CSS class name to be applied to the root element of all tabs
            /// rendered or decorated using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class name.</returns>
        }, 
        
        createDom: function(tab) {
            /// <summary>Creates the tab&apos;s DOM structure, based on the containing tab bar&apos;s location
            /// relative to tab contents.  For example, the DOM for a tab in a tab bar
            /// located above tab contents would look like this:
            /// &lt;pre&gt;
            ///   &lt;div class=&quot;goog-rounded-tab&quot; title=&quot;...&quot;&gt;
            ///     &lt;table class=&quot;goog-rounded-tab-table&quot;&gt;
            ///       &lt;tbody&gt;
            ///         &lt;tr&gt;
            ///           &lt;td nowrap&gt;
            ///             &lt;div class=&quot;goog-rounded-tab-outer-edge&quot;&gt;&lt;/div&gt;
            ///             &lt;div class=&quot;goog-rounded-tab-inner-edge&quot;&gt;&lt;/div&gt;
            ///           &lt;/td&gt;
            ///         &lt;/tr&gt;
            ///         &lt;tr&gt;
            ///           &lt;td nowrap&gt;
            ///             &lt;div class=&quot;goog-rounded-tab-caption&quot;&gt;Hello, world&lt;/div&gt;
            ///           &lt;/td&gt;
            ///         &lt;/tr&gt;
            ///       &lt;/tbody&gt;
            ///     &lt;/table&gt;
            ///   &lt;/div&gt;
            /// &lt;/pre&gt;</summary>
            /// <param name="tab" type="goog.ui.Control">Tab to render.</param>
            /// <returns type="Element">Root element for the tab.</returns>
        }, 
        
        decorate: function(tab, element) {
            /// <summary>Decorates the element with the tab.  Overrides the superclass implementation
            /// by wrapping the tab&apos;s content in a table that implements rounded corners.</summary>
            /// <param name="tab" type="goog.ui.Control">Tab to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        createTab: function(dom, caption, location) {
            /// <summary>Creates a table implementing a rounded corner tab.</summary>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper to use for element construction.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to display as the tab&apos;s caption.</param>
            /// <param name="location" type="goog.ui.TabBar.Location">Tab bar location relative to the
            ///     tab contents.</param>
            /// <returns type="Element">Table implementing a rounded corner tab.</returns>
        }, 
        
        createCaption: function(dom, caption) {
            /// <summary>Creates a table row implementing the tab caption.</summary>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper to use for element construction.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Text caption or DOM structure
            ///     to display as the tab&apos;s caption.</param>
            /// <returns type="Element">Tab caption table row.</returns>
        }, 
        
        createEdge: function(dom, isTopEdge) {
            /// <summary>Creates a table row implementing a rounded tab edge.</summary>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper to use for element construction.</param>
            /// <param name="isTopEdge" type="boolean">Whether to create a top or bottom edge.</param>
            /// <returns type="Element">Rounded tab edge table row.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.RoundedTabRenderer";
})(this);
