
/* vsdoc for goog.ui.Select */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Select = function(caption, opt_menu, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="caption" type="goog.ui.ControlContent">Default caption or existing DOM
        ///     structure to display as the button&apos;s caption when nothing is selected.</param>
        /// <param name="opt_menu" type="goog.ui.Menu=">Menu containing selection options.</param>
        /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Renderer used to render or
        ///     decorate the control; defaults to {@link goog.ui.MenuButtonRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM hepler, used for
        ///     document interaction.</param>
        /// <returns type="goog.ui.Select"/>
    };

    var $x = window.goog.ui.Select;
    $x.prototype = {
                
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        decorateInternal: function(element) {
            /// <summary>Decorates the given element with this control.  Overrides the superclass
            /// implementation by initializing the default caption on the select button.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        handleMenuAction: function(e) {
            /// <summary>Handles {@link goog.ui.Component.EventType.ACTION} events dispatched by
            /// the menu item clicked by the user.  Updates the selection model, calls
            /// the superclass implementation to hide the menu, stops the propagation of
            /// the event, and dispatches an ACTION event on behalf of the select control
            /// itself.  Overrides {@link goog.ui.MenuButton#handleMenuAction}.</summary>
            /// <param name="e" type="goog.events.Event">Action event to handle.</param>
        }, 
        
        handleSelectionChange: function(e) {
            /// <summary>Handles {@link goog.events.EventType.SELECT} events raised by the
            /// selection model when the selection changes.  Updates the contents of the
            /// select button.</summary>
            /// <param name="e" type="goog.events.Event">Selection event to handle.</param>
        }, 
        
        setMenu: function(menu) {
            /// <summary>Replaces the menu currently attached to the control (if any) with the given
            /// argument, and updates the selection model.  Does nothing if the new menu is
            /// the same as the old one.  Overrides {@link goog.ui.MenuButton#setMenu}.</summary>
            /// <param name="menu" type="goog.ui.Menu">New menu to be attached to the menu button.</param>
            /// <returns type="goog.ui.Menu|undefined">Previous menu (undefined if none).</returns>
        }, 
        
        getDefaultCaption: function() {
            /// <summary>Returns the default caption to be shown when no option is selected.</summary>
            /// <returns type="goog.ui.ControlContent">Default caption.</returns>
        }, 
        
        setDefaultCaption: function(caption) {
            /// <summary>Sets the default caption to the given string or DOM structure.</summary>
            /// <param name="caption" type="goog.ui.ControlContent">Default caption to be shown
            ///    when no option is selected.</param>
        }, 
        
        addItem: function(item) {
            /// <summary>Adds a new menu item at the end of the menu.</summary>
            /// <param name="item" type="goog.ui.Control">Menu item to add to the menu.</param>
        }, 
        
        addItemAt: function(item, index) {
            /// <summary>Adds a new menu item at a specific index in the menu.</summary>
            /// <param name="item" type="goog.ui.MenuItem|goog.ui.MenuSeparator">Menu item to add to the
            ///     menu.</param>
            /// <param name="index" type="number">Index at which to insert the menu item.</param>
        }, 
        
        removeItem: function(item) {
            /// <summary>Removes an item from the menu and disposes it.</summary>
            /// <param name="item" type="goog.ui.MenuItem|goog.ui.MenuSeparator">The menu item to remove.</param>
        }, 
        
        removeItemAt: function(index) {
            /// <summary>Removes a menu item at a given index in the menu and disposes it.</summary>
            /// <param name="index" type="number">Index of item.</param>
        }, 
        
        setSelectedItem: function(item) {
            /// <summary>Selects the specified option (assumed to be in the select menu), and
            /// deselects the previously selected option, if any.  A null argument clears
            /// the selection.</summary>
            /// <param name="item" type="goog.ui.MenuItem">Option to be selected (null to clear
            ///     the selection).</param>
        }, 
        
        setSelectedIndex: function(index) {
            /// <summary>Selects the option at the specified index, or clears the selection if the
            /// index is out of bounds.</summary>
            /// <param name="index" type="number">Index of the option to be selected.</param>
        }, 
        
        setValue: function(value) {
            /// <summary>Selects the first option found with an associated value equal to the
            /// argument, or clears the selection if no such option is found.  A null
            /// argument also clears the selection.  Overrides {@link
            /// goog.ui.Button#setValue}.</summary>
            /// <param name="value" type="*">Value of the option to be selected (null to clear
            ///     the selection).</param>
        }, 
        
        getSelectedItem: function() {
            /// <summary>Returns the currently selected option.</summary>
            /// <returns type="goog.ui.MenuItem">The currently selected option (null if none).</returns>
        }, 
        
        getSelectedIndex: function() {
            /// <summary>Returns the index of the currently selected option.</summary>
            /// <returns type="number">0-based index of the currently selected option (-1 if none).</returns>
        }, 
        
        getSelectionModel: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.SelectionModel">The selection model.</returns>
        }, 
        
        updateCaption: function() {
            /// <summary>Updates the caption to be shown in the select button.  If no option is
            /// selected and a default caption is set, sets the caption to the default
            /// caption; otherwise to the empty string.</summary>
        }, 
        
        setOpen: function(open, opt_e) {
            /// <summary>Opens or closes the menu.  Overrides {@link goog.ui.MenuButton#setOpen} by
            /// highlighting the currently selected option on open.</summary>
            /// <param name="open" type="boolean">Whether to open or close the menu.</param>
            /// <param name="opt_e" type="goog.events.Event=">Mousedown event that caused the menu to
            ///     be opened.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Select";
})(this);
