
/* vsdoc for goog.ui.SelectionModel */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.SelectionModel = function(opt_items){
        /// <summary></summary>
        /// <param name="opt_items" type="Array.Object=">Array of items; defaults to empty.</param>
        /// <returns type="goog.ui.SelectionModel"/>
    };

    var $x = window.goog.ui.SelectionModel;
    $x.prototype = {
                
        getSelectionHandler: function() {
            /// <summary>Returns the selection handler function used by the selection model to change
            /// the internal selection state of items under its control.</summary>
            /// <returns type="Function">Selection handler function (null if none).</returns>
        }, 
        
        setSelectionHandler: function(handler) {
            /// <summary>Sets the selection handler function to be used by the selection model to
            /// change the internal selection state of items under its control.  The
            /// function must take two arguments:  an item and a Boolean to indicate whether
            /// the item is to be selected or deselected.  Selection handler functions are
            /// only needed if the items in the selection model don&apos;t natively support the
            /// {@code setSelected(Boolean)} interface.</summary>
            /// <param name="handler" type="Function">Selection handler function.</param>
        }, 
        
        getItemCount: function() {
            /// <summary>Returns the number of items controlled by the selection model.</summary>
            /// <returns type="number">Number of items.</returns>
        }, 
        
        indexOfItem: function(item) {
            /// <summary>Returns the 0-based index of the given item within the selection model, or
            /// -1 if no such item is found.</summary>
            /// <param name="item" type="Object|undefined">Item to look for.</param>
            /// <returns type="number">Index of the given item (-1 if none).</returns>
        }, 
        
        getFirst: function() {
            /// <summary></summary>
            /// <returns type="Object|undefined">The first item, or undefined if there are no items
            ///     in the model.</returns>
        }, 
        
        getLast: function() {
            /// <summary></summary>
            /// <returns type="Object|undefined">The last item, or undefined if there are no items
            ///     in the model.</returns>
        }, 
        
        getItemAt: function(index) {
            /// <summary>Returns the item at the given 0-based index.</summary>
            /// <param name="index" type="number">Index of the item to return.</param>
            /// <returns type="Object">Item at the given index (null if none).</returns>
        }, 
        
        addItems: function(items) {
            /// <summary>Bulk-adds items to the selection model.  This is more efficient than calling
            /// {@link #addItem} for each new item.</summary>
            /// <param name="items" type="Array.Object|undefined">New items to add.</param>
        }, 
        
        addItem: function(item) {
            /// <summary>Adds an item at the end of the list.</summary>
            /// <param name="item" type="Object">Item to add.</param>
        }, 
        
        addItemAt: function(item, index) {
            /// <summary>Adds an item at the given index.</summary>
            /// <param name="item" type="Object">Item to add.</param>
            /// <param name="index" type="number">Index at which to add the new item.</param>
        }, 
        
        removeItem: function(item) {
            /// <summary>Removes the given item (if it exists).  Dispatches a {@code SELECT} event if
            /// the removed item was the currently selected item.</summary>
            /// <param name="item" type="Object">Item to remove.</param>
        }, 
        
        removeItemAt: function(index) {
            /// <summary>Removes the item at the given index.</summary>
            /// <param name="index" type="number">Index of the item to remove.</param>
        }, 
        
        getSelectedItem: function() {
            /// <summary></summary>
            /// <returns type="Object">The currently selected item, or null if none.</returns>
        }, 
        
        getItems: function() {
            /// <summary></summary>
            /// <returns type="!Array.Object">All items in the selection model.</returns>
        }, 
        
        setSelectedItem: function(item) {
            /// <summary>Selects the given item, deselecting any previously selected item, and
            /// dispatches a {@code SELECT} event.</summary>
            /// <param name="item" type="Object">Item to select (null to clear the selection).</param>
        }, 
        
        getSelectedIndex: function() {
            /// <summary></summary>
            /// <returns type="number">The 0-based index of the currently selected item, or -1
            ///     if none.</returns>
        }, 
        
        setSelectedIndex: function(index) {
            /// <summary>Selects the item at the given index, deselecting any previously selected
            /// item, and dispatches a {@code SELECT} event.</summary>
            /// <param name="index" type="number">Index to select (-1 to clear the selection).</param>
        }, 
        
        clear: function() {
            /// <summary>Clears the selection model by removing all items from the selection.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.SelectionModel";
})(this);
