
/* vsdoc for goog.ui.ServerChart */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.ServerChart = function(type, opt_width, opt_height, opt_domHelper, opt_uri){
        /// <summary></summary>
        /// <param name="type" type="goog.ui.ServerChart.ChartType">The chart type.</param>
        /// <param name="opt_width" type="number=">The width of the chart.</param>
        /// <param name="opt_height" type="number=">The height of the chart.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM Helper.</param>
        /// <param name="opt_uri" type="string=">Optional uri used to connect to the chart server, if
        ///     different than goog.ui.ServerChart.CHART_SERVER_SCHEME_INDEPENDENT_URI.</param>
        /// <field name="CHART_SERVER_SCHEME_INDEPENDENT_URI" type="string">Base scheme-independent URI for the chart renderer.</field>
        /// <field name="CHART_SERVER_HTTP_URI" type="string">Base HTTP URI for the chart renderer.</field>
        /// <field name="CHART_SERVER_HTTPS_URI" type="string">Base HTTPS URI for the chart renderer.</field>
        /// <field name="CHART_SERVER_URI" type="string">Base URI for the chart renderer.</field>
        /// <field name="DEFAULT_NORMALIZATION" type="number">The 0 - 1.0 (&quot;fraction of the range&quot;) value to use when getMinValue() ==
        /// getMaxValue(). This determines, for example, the vertical position
        /// of the line in a flat line-chart.</field>
        /// <field name="EncodingType" type="">Enum of chart data encoding types</field>
        /// <field name="ChartType" type="">Enum of chart types with their short names used by the chartserver.</field>
        /// <field name="MultiAxisType" type="">Enum of multi-axis types.</field>
        /// <field name="MultiAxisAlignment" type="">Enum of multi-axis alignments.</field>
        /// <field name="LegendPosition" type="">Enum of legend positions.</field>
        /// <field name="AxisDisplayType" type="">Enum of line and tick options for an axis.</field>
        /// <field name="MaximumValue" type="">Enum of chart maximum values in pixels, as listed at:
        /// http://code.google.com/apis/chart/basics.html</field>
        /// <field name="UriParam" type="">Enum of ChartServer URI parameters.</field>
        /// <field name="CHART_VALUES" type="string">Array of possible ChartServer data values</field>
        /// <field name="CHART_VALUES_EXTENDED" type="string">Array of extended ChartServer data values</field>
        /// <field name="EXTENDED_UPPER_BOUND" type="">Upper bound for extended values</field>
        /// <field name="Event" type="">Event types dispatched by the ServerChart object</field>
        /// <returns type="goog.ui.ServerChart"/>
    };

    var $x = window.goog.ui.ServerChart;
    $x.prototype = {
                
        createDom: function() {
            /// <summary>Creates the DOM node (image) needed for the Chart</summary>
        }, 
        
        decorateInternal: function(img) {
            /// <summary>Decorate an image already in the DOM.
            /// Expects the following structure:
            /// &lt;pre&gt;
            ///   - img
            /// &lt;/pre&gt;</summary>
            /// <param name="img" type="Element">Image to decorate.</param>
        }, 
        
        updateChart: function() {
            /// <summary>Updates the image if any of the data or settings have changed.</summary>
        }, 
        
        setUri: function(uri) {
            /// <summary>Sets the URI of the chart.</summary>
            /// <param name="uri" type="goog.Uri">The chart URI.</param>
        }, 
        
        getUri: function() {
            /// <summary>Returns the URI of the chart.</summary>
            /// <returns type="goog.Uri">The chart URI.</returns>
        }, 
        
        getUriLengthLimit: function() {
            /// <summary>Returns the upper limit on the length of the chart image URI, after encoding.
            /// If the URI&apos;s length equals or exceeds it, goog.ui.ServerChart.UriTooLongEvent
            /// is dispatched on the goog.ui.ServerChart object.</summary>
            /// <returns type="number">The chart URI length limit.</returns>
        }, 
        
        setUriLengthLimit: function(uriLengthLimit) {
            /// <summary>Sets the upper limit on the length of the chart image URI, after encoding.
            /// If the URI&apos;s length equals or exceeds it, goog.ui.ServerChart.UriTooLongEvent
            /// is dispatched on the goog.ui.ServerChart object.</summary>
            /// <param name="uriLengthLimit" type="number">The chart URI length limit.</param>
        }, 
        
        setGridParameter: function(value) {
            /// <summary>Sets the &apos;chg&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify Grids.</summary>
            /// <param name="value" type="string">Value for the &apos;chg&apos; parameter in the chart Uri.</param>
        }, 
        
        getGridParameter: function() {
            /// <summary>Returns the &apos;chg&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify Grids.</summary>
            /// <returns type="string|undefined">The &apos;chg&apos; parameter of the chart Uri.</returns>
        }, 
        
        setMarkerParameter: function(value) {
            /// <summary>Sets the &apos;chm&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify Markers.</summary>
            /// <param name="value" type="string">Value for the &apos;chm&apos; parameter in the chart Uri.</param>
        }, 
        
        getMarkerParameter: function() {
            /// <summary>Returns the &apos;chm&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify Markers.</summary>
            /// <returns type="string|undefined">The &apos;chm&apos; parameter of the chart Uri.</returns>
        }, 
        
        setMiscParameter: function(value) {
            /// <summary>Sets the &apos;chp&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify certain options.
            /// e.g., finance charts use this to designate which line is the 0 axis.</summary>
            /// <param name="value" type="string|number">Value for the &apos;chp&apos; parameter in the chart Uri.</param>
        }, 
        
        getMiscParameter: function() {
            /// <summary>Returns the &apos;chp&apos; parameter of the chart Uri.
            /// This is used by various types of charts to specify certain options.
            /// e.g., finance charts use this to designate which line is the 0 axis.</summary>
            /// <returns type="string|undefined">The &apos;chp&apos; parameter of the chart Uri.</returns>
        }, 
        
        setBackgroundFill: function(fill) {
            /// <summary>Sets the background fill.</summary>
            /// <param name="fill" type="Array.Object">An array of background fill specification
            ///     objects. Each object may have the following properties:
            ///     {string} area The area to fill, either &apos;bg&apos; for background or &apos;c&apos; for
            ///         chart area.  The default is &apos;bg&apos;.
            ///     {string} color (required) The color of the background fill.
            ///     // TODO(user): Add support for gradient/stripes, which requires
            ///     // a different object structure.</param>
        }, 
        
        getBackgroundFill: function() {
            /// <summary>Returns the background fill.</summary>
            /// <returns type="Array.Object">An array of background fill specifications.
            ///     If the fill specification string is in an unsupported format, the method
            ///    returns an empty array.</returns>
        }, 
        
        setEncodingType: function(type) {
            /// <summary>Sets the encoding type.</summary>
            /// <param name="type" type="goog.ui.ServerChart.EncodingType">Desired data encoding type.</param>
        }, 
        
        getEncodingType: function() {
            /// <summary>Gets the encoding type.</summary>
            /// <returns type="goog.ui.ServerChart.EncodingType">The encoding type.</returns>
        }, 
        
        setType: function(type) {
            /// <summary>Sets the chart type.</summary>
            /// <param name="type" type="goog.ui.ServerChart.ChartType">The desired chart type.</param>
        }, 
        
        getType: function() {
            /// <summary>Returns the chart type.</summary>
            /// <returns type="goog.ui.ServerChart.ChartType">The chart type.</returns>
        }, 
        
        setSize: function(opt_width, opt_height) {
            /// <summary>Sets the chart size.</summary>
            /// <param name="opt_width" type="number=">Optional chart width, defaults to 300.</param>
            /// <param name="opt_height" type="number=">Optional chart height, defaults to 150.</param>
        }, 
        
        getSize: function() {
            /// <summary>Returns the chart size.</summary>
            /// <returns type="Array.string">[Width, Height].</returns>
        }, 
        
        setMinValue: function(minValue) {
            /// <summary>Sets the minimum value of the chart.</summary>
            /// <param name="minValue" type="number">The minimum value of the chart.</param>
        }, 
        
        getMinValue: function() {
            /// <summary></summary>
            /// <returns type="number">The minimum value of the chart.</returns>
        }, 
        
        setMaxValue: function(maxValue) {
            /// <summary>Sets the maximum value of the chart.</summary>
            /// <param name="maxValue" type="number">The maximum value of the chart.</param>
        }, 
        
        getMaxValue: function() {
            /// <summary></summary>
            /// <returns type="number">The maximum value of the chart.</returns>
        }, 
        
        setMargins: function(leftMargin, rightMargin, topMargin, bottomMargin) {
            /// <summary>Sets the chart margins.</summary>
            /// <param name="leftMargin" type="number">The size in pixels of the left margin.</param>
            /// <param name="rightMargin" type="number">The size in pixels of the right margin.</param>
            /// <param name="topMargin" type="number">The size in pixels of the top margin.</param>
            /// <param name="bottomMargin" type="number">The size in pixels of the bottom margin.</param>
        }, 
        
        setGridX: function(gridlines) {
            /// <summary>Sets the number of grid lines along the X-axis.</summary>
            /// <param name="gridlines" type="number">The number of X-axis grid lines.</param>
        }, 
        
        getGridX: function() {
            /// <summary></summary>
            /// <returns type="number">The number of gridlines along the X-axis.</returns>
        }, 
        
        setGridY: function(gridlines) {
            /// <summary>Sets the number of grid lines along the Y-axis.</summary>
            /// <param name="gridlines" type="number">The number of Y-axis grid lines.</param>
        }, 
        
        getGridY: function() {
            /// <summary></summary>
            /// <returns type="number">The number of gridlines along the Y-axis.</returns>
        }, 
        
        setXLabels: function(labels) {
            /// <summary>Sets the X Labels for the chart.</summary>
            /// <param name="labels" type="Array.string">The X Labels for the chart.</param>
        }, 
        
        getXLabels: function() {
            /// <summary></summary>
            /// <returns type="Array.string">The X Labels for the chart.</returns>
        }, 
        
        isBarChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a bar chart.</returns>
        }, 
        
        isPieChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a pie chart.</returns>
        }, 
        
        isGroupedBarChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a grouped bar chart.</returns>
        }, 
        
        isHorizontalBarChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a horizontal bar chart.</returns>
        }, 
        
        isLineChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a line chart.</returns>
        }, 
        
        isMap: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a map.</returns>
        }, 
        
        isStackedBarChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a stacked bar chart.</returns>
        }, 
        
        isVerticalBarChart: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the chart is a vertical bar chart.</returns>
        }, 
        
        setLeftLabels: function(labels) {
            /// <summary>Sets the Left Labels for the chart.
            /// NOTE: The array should start with the lowest value, and then
            ///       move progessively up the axis. So if you want labels
            ///       from 0 to 100 with 0 at bottom of the graph, then you would
            ///       want to pass something like [0,25,50,75,100].</summary>
            /// <param name="labels" type="Array.string">The Left Labels for the chart.</param>
        }, 
        
        getLeftLabels: function() {
            /// <summary></summary>
            /// <returns type="Array.string">The Left Labels for the chart.</returns>
        }, 
        
        setParameterValue: function(key, value) {
            /// <summary>Sets the given ChartServer parameter.</summary>
            /// <param name="key" type="goog.ui.ServerChart.UriParam">The ChartServer parameter to set.</param>
            /// <param name="value" type="string">The value to set for the ChartServer parameter.</param>
        }, 
        
        removeParameter: function(key) {
            /// <summary>Removes the given ChartServer parameter.</summary>
            /// <param name="key" type="goog.ui.ServerChart.UriParam">The ChartServer parameter to
            ///     remove.</param>
        }, 
        
        setRightLabels: function(labels) {
            /// <summary>Sets the Right Labels for the chart.
            /// NOTE: The array should start with the lowest value, and then
            ///       move progessively up the axis. So if you want labels
            ///       from 0 to 100 with 0 at bottom of the graph, then you would
            ///       want to pass something like [0,25,50,75,100].</summary>
            /// <param name="labels" type="Array.string">The Right Labels for the chart.</param>
        }, 
        
        getRightLabels: function() {
            /// <summary></summary>
            /// <returns type="Array.string">The Right Labels for the chart.</returns>
        }, 
        
        setLegendPosition: function(value) {
            /// <summary>Sets the position relative to the chart where the legend is to be displayed.</summary>
            /// <param name="value" type="goog.ui.ServerChart.LegendPosition">Legend position.</param>
        }, 
        
        getLegendPosition: function() {
            /// <summary>Returns the position relative to the chart where the legend is to be
            /// displayed.</summary>
            /// <returns type="goog.ui.ServerChart.LegendPosition">Legend position.</returns>
        }, 
        
        setNumVisibleDataSets: function(n) {
            /// <summary>Sets the number of &quot;visible&quot; data sets. All data sets that come after
            /// the visible data set are not drawn as part of the chart. Instead, they
            /// are available for positioning markers.</summary>
            /// <param name="n" type="?number">The number of visible data sets, or null if all data
            /// sets are to be visible.</param>
        }, 
        
        getNumVisibleDataSets: function() {
            /// <summary>Returns the number of &quot;visible&quot; data sets. All data sets that come after
            /// the visible data set are not drawn as part of the chart. Instead, they
            /// are available for positioning markers.</summary>
            /// <returns type="?number">The number of visible data sets, or null if all data
            /// sets are visible.</returns>
        }, 
        
        setVennSeries: function(weights, opt_legendText, opt_colors) {
            /// <summary>Sets the weight function for a Venn Diagram along with the associated
            ///     colors and legend text. Weights are assigned as follows:
            ///     weights[0] is relative area of circle A.
            ///     weights[1] is relative area of circle B.
            ///     weights[2] is relative area of circle C.
            ///     weights[3] is relative area of overlap of circles A and B.
            ///     weights[4] is relative area of overlap of circles A and C.
            ///     weights[5] is relative area of overlap of circles B and C.
            ///     weights[6] is relative area of overlap of circles A, B and C.
            /// For a two circle Venn Diagram the weights are assigned as follows:
            ///     weights[0] is relative area of circle A.
            ///     weights[1] is relative area of circle B.
            ///     weights[2] is relative area of overlap of circles A and B.</summary>
            /// <param name="weights" type="Array.number">The relative weights of the circles.</param>
            /// <param name="opt_legendText" type="Array.string=">The legend labels for the circles.</param>
            /// <param name="opt_colors" type="Array.string=">The colors for the circles.</param>
        }, 
        
        setTitle: function(title) {
            /// <summary>Sets the title of the chart.</summary>
            /// <param name="title" type="string">The chart title.</param>
        }, 
        
        setTitleSize: function(size) {
            /// <summary>Sets the size of the chart title.</summary>
            /// <param name="size" type="number">The title size, in points.</param>
        }, 
        
        getTitleSize: function() {
            /// <summary></summary>
            /// <returns type="number">size The title size, in points.</returns>
        }, 
        
        setTitleColor: function(color) {
            /// <summary>Sets the color of the chart title.
            /// 
            /// NOTE: The color string should NOT have a &apos;#&apos; at the beginning of it.</summary>
            /// <param name="color" type="string">The hex value for the title color.</param>
        }, 
        
        getTitleColor: function() {
            /// <summary></summary>
            /// <returns type="string">color The hex value for the title color.</returns>
        }, 
        
        setLegend: function(legend) {
            /// <summary>Adds a legend to the chart.</summary>
            /// <param name="legend" type="Array.string">The legend to add.</param>
        }, 
        
        setDataScaling: function(minimum, maximum) {
            /// <summary>Sets the data scaling.
            /// NOTE: This also changes the encoding type because data scaling will
            ///     only work with {@code goog.ui.ServerChart.EncodingType.TEXT}
            ///     encoding.</summary>
            /// <param name="minimum" type="number">The lowest number to apply to the data.</param>
            /// <param name="maximum" type="number">The highest number to apply to the data.</param>
        }, 
        
        setBarSpaceWidths: function(barWidth, opt_spaceBars, opt_spaceGroups) {
            /// <summary>Sets the widths of the bars and the spaces between the bars in a bar
            /// chart.
            /// NOTE: If the space between groups is specified but the space between
            ///     bars is left undefined, the space between groups will be interpreted
            ///     as the space between bars because this is the behavior exposed
            ///     in the external developers guide.</summary>
            /// <param name="barWidth" type="number">The width of a bar in pixels.</param>
            /// <param name="opt_spaceBars" type="number=">The width of the space between
            ///     bars in a group in pixels.</param>
            /// <param name="opt_spaceGroups" type="number=">The width of the space between
            ///     groups.</param>
        }, 
        
        setAutomaticBarWidth: function(opt_spaceBars, opt_spaceGroups) {
            /// <summary>Specifies that the bar width in a bar chart should be calculated
            /// automatically given the space available in the chart, while optionally
            /// setting the spaces between the bars.
            /// NOTE: If the space between groups is specified but the space between
            ///     bars is left undefined, the space between groups will be interpreted
            ///     as the space between bars because this is the behavior exposed
            ///     in the external developers guide.</summary>
            /// <param name="opt_spaceBars" type="number=">The width of the space between
            ///     bars in a group in pixels.</param>
            /// <param name="opt_spaceGroups" type="number=">The width of the space between
            ///     groups.</param>
        }, 
        
        addMultiAxis: function(axisType) {
            /// <summary>Adds a multi-axis to the chart, and sets its type. Multiple axes of the same
            /// type can be added.</summary>
            /// <param name="axisType" type="goog.ui.ServerChart.MultiAxisType">The desired axis type.</param>
            /// <returns type="number">The index of the newly inserted axis, suitable for feeding
            ///     to the setMultiAxis*() functions.</returns>
        }, 
        
        getMultiAxisType: function(opt_axisNumber) {
            /// <summary>Returns the axis type for the given axis, or all of them in an array if the
            /// axis number is not given.</summary>
            /// <param name="opt_axisNumber" type="number=">The axis index, as returned by addMultiAxis.</param>
            /// <returns type="goog.ui.ServerChart.MultiAxisType|
    Array.goog.ui.ServerChart.MultiAxisType">The axis type for the given axis, or all of them in an array if the
            ///     axis number is not given.</returns>
        }, 
        
        setMultiAxisLabelText: function(axisNumber, labelText) {
            /// <summary>Sets the label text (usually multiple values) for a given axis, overwriting
            /// any existing values.</summary>
            /// <param name="axisNumber" type="number">The axis index, as returned by addMultiAxis.</param>
            /// <param name="labelText" type="Array.string">The actual label text to be added.</param>
        }, 
        
        getMultiAxisLabelText: function(opt_axisNumber) {
            /// <summary>Returns the label text, or all of them in a two-dimensional array if the
            /// axis number is not given.</summary>
            /// <param name="opt_axisNumber" type="number=">The axis index, as returned by addMultiAxis.</param>
            /// <returns type="Object|Array.string">The label text, or all of them in a
            ///     two-dimensional array if the axis number is not given.</returns>
        }, 
        
        setMultiAxisLabelPosition: function(axisNumber, labelPosition) {
            /// <summary>Sets the label positions for a given axis, overwriting any existing values.
            /// The label positions are assumed to be floating-point numbers within the
            /// range of the axis.</summary>
            /// <param name="axisNumber" type="number">The axis index, as returned by addMultiAxis.</param>
            /// <param name="labelPosition" type="Array.number">The actual label positions to be added.</param>
        }, 
        
        getMultiAxisLabelPosition: function(opt_axisNumber) {
            /// <summary>Returns the label positions for a given axis number, or all of them in a
            /// two-dimensional array if the axis number is not given.</summary>
            /// <param name="opt_axisNumber" type="number=">The axis index, as returned by addMultiAxis.</param>
            /// <returns type="Object|Array.number">The label positions for a given axis number,
            ///     or all of them in a two-dimensional array if the axis number is not
            ///     given.</returns>
        }, 
        
        setMultiAxisRange: function(axisNumber, rangeStart, rangeEnd, opt_interval) {
            /// <summary>Sets the label range for a given axis, overwriting any existing range.
            /// The default range is from 0 to 100. If the start value is larger than the
            /// end value, the axis direction is reversed.  rangeStart and rangeEnd must
            /// be two different finite numbers.</summary>
            /// <param name="axisNumber" type="number">The axis index, as returned by addMultiAxis.</param>
            /// <param name="rangeStart" type="number">The new start of the range.</param>
            /// <param name="rangeEnd" type="number">The new end of the range.</param>
            /// <param name="opt_interval" type="number=">The interval between axis labels.</param>
        }, 
        
        getMultiAxisRange: function(opt_axisNumber) {
            /// <summary>Returns the label range for a given axis number as a two-element array of
            /// (range start, range end), or all of them in a two-dimensional array if the
            /// axis number is not given.</summary>
            /// <param name="opt_axisNumber" type="number=">The axis index, as returned by addMultiAxis.</param>
            /// <returns type="Object|Array.number">The label range for a given axis number as a
            ///     two-element array of (range start, range end), or all of them in a
            ///     two-dimensional array if the axis number is not given.</returns>
        }, 
        
        setMultiAxisLabelStyle: function(axisNumber, color, opt_fontSize, opt_alignment, opt_axisDisplay) {
            /// <summary>Sets the label style for a given axis, overwriting any existing style.
            /// The default style is as follows: Default is x-axis labels are centered, left
            /// hand y-axis labels are right aligned, right hand y-axis labels are left
            /// aligned. The font size and alignment are optional parameters.
            /// 
            /// NOTE: The color string should NOT have a &apos;#&apos; at the beginning of it.</summary>
            /// <param name="axisNumber" type="number">The axis index, as returned by addMultiAxis.</param>
            /// <param name="color" type="string">The hex value for this label&apos;s color.</param>
            /// <param name="opt_fontSize" type="number=">The label font size, in pixels.</param>
            /// <param name="opt_alignment" type="goog.ui.ServerChart.MultiAxisAlignment=">The label
            ///     alignment.</param>
            /// <param name="opt_axisDisplay" type="goog.ui.ServerChart.AxisDisplayType=">The axis
            ///     line and ticks.</param>
        }, 
        
        getMultiAxisLabelStyle: function(opt_axisNumber) {
            /// <summary>Returns the label style for a given axis number as a one- to three-element
            /// array, or all of them in a two-dimensional array if the axis number is not
            /// given.</summary>
            /// <param name="opt_axisNumber" type="number=">The axis index, as returned by addMultiAxis.</param>
            /// <returns type="Object|Array.number">The label style for a given axis number as a
            ///     one- to three-element array, or all of them in a two-dimensional array if
            ///     the axis number is not given.</returns>
        }, 
        
        addDataSet: function(data, color, opt_legendText) {
            /// <summary>Adds a data set.
            /// NOTE: The color string should NOT have a &apos;#&apos; at the beginning of it.</summary>
            /// <param name="data" type="Array.number|null">An array of numbers (values can be
            ///     NaN or null).</param>
            /// <param name="color" type="string">The hex value for this data set&apos;s color.</param>
            /// <param name="opt_legendText" type="string=">The legend text, if any, for this data
            ///     series. NOTE: If specified, all previously added data sets must also
            ///     have a legend text.</param>
        }, 
        
        clearDataSets: function() {
            /// <summary>Clears the data sets from the graph. All data, including the colors and
            /// legend text, is cleared.</summary>
        }, 
        
        getData: function(opt_setNumber) {
            /// <summary>Returns the given data set or all of them in a two-dimensional array if
            /// the set number is not given.</summary>
            /// <param name="opt_setNumber" type="number=">Optional data set number to get.</param>
            /// <returns type="Array">The given data set or all of them in a two-dimensional array
            ///     if the set number is not given.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ServerChart";
})(this);
