
/* vsdoc for goog.ui.SliderBase */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.SliderBase = function(opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="Orientation" type="">Enum for representing the orientation of the slider.</field>
        /// <field name="getCssClass" type="string">Returns the CSS class applied to the slider element for the given
        /// orientation. Subclasses must override this method.</field>
        /// <field name="createThumbs" type="function() : void">Subclasses must implement this method and set the valueThumb and
        /// extentThumb to non-null values. They can also set the rangeHighlight
        /// element if a range highlight is desired.</field>
        /// <returns type="goog.ui.SliderBase"/>
    };

    var $x = window.goog.ui.SliderBase;
    $x.prototype = {
                
        enableFlipForRtl: function(flipForRtl) {
            /// <summary>Enables/disables true RTL behavior.  This should be called immediately after
            /// construction.  This is a temporary flag to allow clients to transition
            /// to the new behavior at their convenience.  At some point it will be the
            /// default.</summary>
            /// <param name="flipForRtl" type="boolean">True if the slider should be flipped for RTL,
            ///     false otherwise.</param>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        decorateInternal: function(element) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
        }, 
        
        enterDocument: function() {
            /// <summary>Called when the DOM for the component is for sure in the document.
            /// Subclasses should override this method to set this element&apos;s role.</summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        getValueFromMousePosition: function(e) {
            /// <summary>Returns the value to use for the current mouse position</summary>
            /// <param name="e" type="goog.events.Event">The mouse event object.</param>
            /// <returns type="number">The value that this mouse position represents.</returns>
        }, 
        
        moveThumbs: function(delta) {
            /// <summary>Moves the thumbs by the specified delta as follows
            /// - as long as both thumbs stay within [min,max], both thumbs are moved
            /// - once a thumb reaches or exceeds min (or max, respectively), it stays
            /// - at min (or max, respectively).
            /// In case both thumbs have reached min (or max), no change event will fire.</summary>
            /// <param name="delta" type="number">The delta by which to move the selected range.</param>
        }, 
        
        setValueAndExtent: function(value, extent) {
            /// <summary>Sets the value and extent of the underlying range model. We enforce that
            /// getMinimum() <= value <= getMaximum() - extent and
            /// getMinExtent <= extent <= getMaximum() - getValue()
            /// If this is not satisifed for the given extent, the call is ignored and no
            /// CHANGE event fires. This is a utility method to allow setting the thumbs
            /// simultaneously and ensuring that only one event fires.</summary>
            /// <param name="value" type="number">The value to which to set the value.</param>
            /// <param name="extent" type="number">The value to which to set the extent.</param>
        }, 
        
        getMinimum: function() {
            /// <summary></summary>
            /// <returns type="number">The minimum value.</returns>
        }, 
        
        setMinimum: function(min) {
            /// <summary>Sets the minimum number.</summary>
            /// <param name="min" type="number">The minimum value.</param>
        }, 
        
        getMaximum: function() {
            /// <summary></summary>
            /// <returns type="number">The maximum value.</returns>
        }, 
        
        setMaximum: function(max) {
            /// <summary>Sets the maximum number.</summary>
            /// <param name="max" type="number">The maximum value.</param>
        }, 
        
        getValueThumb: function() {
            /// <summary></summary>
            /// <returns type="HTMLDivElement">The value thumb element.</returns>
        }, 
        
        getExtentThumb: function() {
            /// <summary></summary>
            /// <returns type="HTMLDivElement">The extent thumb element.</returns>
        }, 
        
        handleRangeModelChange: function(e) {
            /// <summary>Call back when the internal range model changes. Sub-classes may override
            /// and re-enter this method to update a11y state. Consider protected.</summary>
            /// <param name="e" type="goog.events.Event">The event object.</param>
        }, 
        
        getThumbCoordinateForValue: function(val) {
            /// <summary>Returns the position to move the handle to for a given value</summary>
            /// <param name="val" type="number">The value to get the coordinate for.</param>
            /// <returns type="goog.math.Coordinate">Coordinate with either x or y set.</returns>
        }, 
        
        animatedSetValue: function(v) {
            /// <summary>Sets the value and starts animating the handle towards that position.</summary>
            /// <param name="v" type="number">Value to set and animate to.</param>
        }, 
        
        setOrientation: function(orient) {
            /// <summary>Changes the orientation.</summary>
            /// <param name="orient" type="goog.ui.SliderBase.Orientation">The orientation.</param>
        }, 
        
        getOrientation: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.SliderBase.Orientation">the orientation of the slider.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getBlockIncrement: function() {
            /// <summary></summary>
            /// <returns type="number">The amount to increment/decrement for page up/down as well
            ///     as when holding down the mouse button on the background.</returns>
        }, 
        
        setBlockIncrement: function(value) {
            /// <summary>Sets the amount to increment/decrement for page up/down as well as when
            /// holding down the mouse button on the background.</summary>
            /// <param name="value" type="number">The value to set the block increment to.</param>
        }, 
        
        setMinExtent: function(value) {
            /// <summary>Sets the minimal value that the extent may have.</summary>
            /// <param name="value" type="number">The minimal value for the extent.</param>
        }, 
        
        getUnitIncrement: function() {
            /// <summary></summary>
            /// <returns type="number">The amount to increment/decrement for up, down, left and
            ///     right arrow keys.</returns>
        }, 
        
        setUnitIncrement: function(value) {
            /// <summary>Sets the amount to increment/decrement for up, down, left and right arrow
            /// keys.</summary>
            /// <param name="value" type="number">The value to set the unit increment to.</param>
        }, 
        
        getStep: function() {
            /// <summary></summary>
            /// <returns type="?number">The step value used to determine how to round the value.</returns>
        }, 
        
        setStep: function(step) {
            /// <summary>Sets the step value. The step value is used to determine how to round the
            /// value.</summary>
            /// <param name="step" type="?number">The step size.</param>
        }, 
        
        getMoveToPointEnabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether clicking on the backgtround should move directly to
            ///     that point.</returns>
        }, 
        
        setMoveToPointEnabled: function(val) {
            /// <summary>Sets whether clicking on the background should move directly to that point.</summary>
            /// <param name="val" type="boolean">Whether clicking on the background should move directly
            ///     to that point.</param>
        }, 
        
        getValue: function() {
            /// <summary></summary>
            /// <returns type="number">The value of the underlying range model.</returns>
        }, 
        
        setValue: function(value) {
            /// <summary>Sets the value of the underlying range model. We enforce that
            /// getMinimum() <= value <= getMaximum() - getExtent()
            /// If this is not satisifed for the given value, the call is ignored and no
            /// CHANGE event fires.</summary>
            /// <param name="value" type="number">The value.</param>
        }, 
        
        getExtent: function() {
            /// <summary></summary>
            /// <returns type="number">The value of the extent of the underlying range model.</returns>
        }, 
        
        setExtent: function(extent) {
            /// <summary>Sets the extent of the underlying range model. We enforce that
            /// getMinExtent() <= extent <= getMaximum() - getValue()
            /// If this is not satisifed for the given extent, the call is ignored and no
            /// CHANGE event fires.</summary>
            /// <param name="extent" type="number">The value to which to set the extent.</param>
        }, 
        
        setVisible: function(visible) {
            /// <summary>Change the visibility of the slider.
            /// You must call this if you had set the slider&apos;s value when it was invisible.</summary>
            /// <param name="visible" type="boolean">Whether to show the slider.</param>
        }, 
        
        setAriaRoles: function() {
            /// <summary>Set a11y roles and state.</summary>
        }, 
        
        updateAriaStates: function() {
            /// <summary>Set a11y roles and state when values change.</summary>
        }, 
        
        setHandleMouseWheel: function(enable) {
            /// <summary>Enables or disables mouse wheel handling for the slider. The mouse wheel
            /// handler enables the user to change the value of slider using a mouse wheel.</summary>
            /// <param name="enable" type="boolean">Whether to enable mouse wheel handling.</param>
        }, 
        
        isHandleMouseWheel: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the slider handles mousewheel.</returns>
        }, 
        
        setEnabled: function(enable) {
            /// <summary>Enables or disables the slider. A disabled slider will ignore all
            /// user-initiated events. Also fires goog.ui.Component.EventType.ENABLE/DISABLE
            /// event as appropriate.</summary>
            /// <param name="enable" type="boolean">Whether to enable the slider or not.</param>
        }, 
        
        isEnabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the slider is enabled or not.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.SliderBase";
})(this);
