
/* vsdoc for goog.ui.SubMenu */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.SubMenu = function(content, opt_model, opt_domHelper, opt_renderer){
        /// <summary></summary>
        /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure to
        ///     display as the content of the submenu (use to add icons or styling to
        ///     menus).</param>
        /// <param name="opt_model" type="*=">Data/model associated with the menu item.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional dom helper used for dom
        ///     interactions.</param>
        /// <param name="opt_renderer" type="goog.ui.MenuItemRenderer=">Renderer used to render or
        ///     decorate the component; defaults to {@link goog.ui.SubMenuRenderer}.</param>
        /// <field name="MENU_DELAY_MS" type="number">The delay before opening the sub menu in milliseconds.  (This number is
        /// arbitrary, it would be good to get some user studies or a designer to play
        /// with some numbers).</field>
        /// <returns type="goog.ui.SubMenu"/>
    };

    var $x = window.goog.ui.SubMenu;
    $x.prototype = {
                
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setHighlighted: function(highlight, opt_btnPressed) {
            /// <summary></summary>
            /// <param name="highlight" type="boolean">Whether item should be highlighted.</param>
            /// <param name="opt_btnPressed" type="boolean=">Whether the mouse button is held down.</param>
        }, 
        
        showSubMenu: function() {
            /// <summary>Show the submenu and ensure that all siblings are hidden.</summary>
        }, 
        
        dismissSubMenu: function() {
            /// <summary>Dismisses the menu and all further submenus.</summary>
        }, 
        
        clearTimers: function() {
            /// <summary>Clears the show and hide timers for the sub menu.</summary>
        }, 
        
        setVisible: function(visible, opt_force) {
            /// <summary>Sets the menu item to be visible or invisible.</summary>
            /// <param name="visible" type="boolean">Whether to show or hide the component.</param>
            /// <param name="opt_force" type="boolean=">If true, doesn&apos;t check whether the component
            ///     already has the requested visibility, and doesn&apos;t dispatch any events.</param>
            /// <returns type="boolean">Whether the visibility was changed.</returns>
        }, 
        
        handleKeyEvent: function(e) {
            /// <summary>Handles a key event that is passed to the menu item from its parent because
            /// it is highlighted.  If the right key is pressed the sub menu takes control
            /// and delegates further key events to its menu until it is dismissed OR the
            /// left key is pressed.</summary>
            /// <param name="e" type="goog.events.KeyEvent">A key event.</param>
            /// <returns type="boolean">Whether the event was handled.</returns>
        }, 
        
        handleMouseOver: function(e) {
            /// <summary></summary>
            /// <param name="e" type="goog.events.BrowserEvent">Mouse event to handle.</param>
        }, 
        
        performActionInternal: function(e) {
            /// <summary>Overrides the default mouseup event handler, so that the ACTION isn&apos;t
            /// dispatched for the submenu itself, instead the submenu is shown instantly.</summary>
            /// <param name="e" type="goog.events.Event">The browser event.</param>
            /// <returns type="boolean">True if the action was allowed to proceed, false otherwise.</returns>
        }, 
        
        setAlignToEnd: function(alignToEnd) {
            /// <summary>Sets whether the submenu is aligned at the end of the parent menu.</summary>
            /// <param name="alignToEnd" type="boolean">True to align to end, false to align to start.</param>
        }, 
        
        isAlignedToEnd: function() {
            /// <summary>Determines whether the submenu is aligned at the end of the parent menu.</summary>
            /// <returns type="boolean">True if aligned to the end (the default), false if
            ///     aligned to the start.</returns>
        }, 
        
        addItem: function(item) {
            /// <summary>Adds a new menu item at the end of the menu.</summary>
            /// <param name="item" type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator">Menu
            ///     item to add to the menu.</param>
        }, 
        
        addItemAt: function(item, n) {
            /// <summary>Adds a new menu item at a specific index in the menu.</summary>
            /// <param name="item" type="goog.ui.MenuHeader|goog.ui.MenuItem|goog.ui.MenuSeparator">Menu
            ///     item to add to the menu.</param>
            /// <param name="n" type="number">Index at which to insert the menu item.</param>
        }, 
        
        removeItem: function(item) {
            /// <summary>Removes an item from the menu and disposes it.</summary>
            /// <param name="item" type="goog.ui.MenuItem">The menu item to remove.</param>
        }, 
        
        removeItemAt: function(n) {
            /// <summary>Removes a menu item at a given index in the menu and disposes it.</summary>
            /// <param name="n" type="number">Index of item.</param>
        }, 
        
        getItemAt: function(n) {
            /// <summary>Returns a reference to the menu item at a given index.</summary>
            /// <param name="n" type="number">Index of menu item.</param>
            /// <returns type="goog.ui.Component">Reference to the menu item.</returns>
        }, 
        
        getItemCount: function() {
            /// <summary>Returns the number of items in the sub menu (including separators).</summary>
            /// <returns type="number">The number of items in the menu.</returns>
        }, 
        
        getItems: function() {
            /// <summary>Returns the menu items contained in the sub menu.</summary>
            /// <returns type="Array.goog.ui.MenuItem">An array of menu items.</returns>
        }, 
        
        getMenu: function() {
            /// <summary>Gets a reference to the submenu&apos;s actual menu.</summary>
            /// <returns type="goog.ui.Menu">Reference to the object representing the sub menu.</returns>
        }, 
        
        setMenu: function(menu, opt_internal) {
            /// <summary>Sets the submenu to a specific menu.</summary>
            /// <param name="menu" type="goog.ui.Menu">The menu to show when this item is selected.</param>
            /// <param name="opt_internal" type="boolean=">Whether this menu is an &quot;internal&quot; menu, and
            ///     should be disposed of when this object is disposed of.</param>
        }, 
        
        containsElement: function(element) {
            /// <summary>Returns true if the provided element is to be considered inside the menu for
            /// purposes such as dismissing the menu on an event.  This is so submenus can
            /// make use of elements outside their own DOM.</summary>
            /// <param name="element" type="Element">The element to test for.</param>
            /// <returns type="boolean">Whether or not the provided element is contained.</returns>
        }, 
        
        setPositionAdjustable: function(isAdjustable) {
            /// <summary></summary>
            /// <param name="isAdjustable" type="boolean">Whether this submenu is adjustable.</param>
        }, 
        
        isPositionAdjustable: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this submenu is adjustable.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.SubMenu";
})(this);
