
/* vsdoc for goog.ui.TabBar */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.TabBar = function(opt_location, opt_renderer, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_location" type="goog.ui.TabBar.Location=">Tab bar location; defaults to
        ///     {@link goog.ui.TabBar.Location.TOP}.</param>
        /// <param name="opt_renderer" type="goog.ui.TabBarRenderer=">Renderer used to render or
        ///     decorate the container; defaults to {@link goog.ui.TabBarRenderer}.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for document
        ///     interaction.</param>
        /// <field name="Location" type="">Tab bar location relative to tab contents.</field>
        /// <returns type="goog.ui.TabBar"/>
    };

    var $x = window.goog.ui.TabBar;
    $x.prototype = {
                
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        removeChild: function(tab, opt_unrender) {
            /// <summary>Removes the tab from the tab bar.  Overrides the superclass implementation
            /// by deselecting the tab being removed.  Since {@link #removeChildAt} uses
            /// {@link #removeChild} internally, we only need to override this method.</summary>
            /// <param name="tab" type="string|goog.ui.Component">Tab to remove.</param>
            /// <param name="opt_unrender" type="boolean=">Whether to call {@code exitDocument} on the
            ///     removed tab, and detach its DOM from the document (defaults to false).</param>
            /// <returns type="goog.ui.Control">The removed tab, if any.</returns>
        }, 
        
        getLocation: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.TabBar.Location">Tab bar location relative to tab contents.</returns>
        }, 
        
        setLocation: function(location) {
            /// <summary>Sets the location of the tab bar relative to tab contents.</summary>
            /// <param name="location" type="goog.ui.TabBar.Location">Tab bar location relative to tab
            ///     contents.</param>
        }, 
        
        isAutoSelectTabs: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether keyboard navigation should change the selected tab,
            ///     or just move the highlight.</returns>
        }, 
        
        setAutoSelectTabs: function(enable) {
            /// <summary>Enables or disables auto-selecting tabs using the keyboard.  If auto-select
            /// is enabled, keyboard navigation switches tabs immediately, otherwise it just
            /// moves the highlight.</summary>
            /// <param name="enable" type="boolean">Whether keyboard navigation should change the
            ///     selected tab, or just move the highlight.</param>
        }, 
        
        setHighlightedIndexFromKeyEvent: function(index) {
            /// <summary>Highlights the tab at the given index in response to a keyboard event.
            /// Overrides the superclass implementation by also selecting the tab if
            /// {@link #isAutoSelectTabs} returns true.</summary>
            /// <param name="index" type="number">Index of tab to highlight.</param>
        }, 
        
        getSelectedTab: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.Control?">The currently selected tab (null if none).</returns>
        }, 
        
        setSelectedTab: function(tab) {
            /// <summary>Selects the given tab.</summary>
            /// <param name="tab" type="goog.ui.Control?">Tab to select (null to select none).</param>
        }, 
        
        getSelectedTabIndex: function() {
            /// <summary></summary>
            /// <returns type="number">Index of the currently selected tab (-1 if none).</returns>
        }, 
        
        setSelectedTabIndex: function(index) {
            /// <summary>Selects the tab at the given index.</summary>
            /// <param name="index" type="number">Index of the tab to select (-1 to select none).</param>
        }, 
        
        deselectIfSelected: function(tab) {
            /// <summary>If the specified tab is the currently selected tab, deselects it, and
            /// selects the closest selectable tab in the tab bar (first looking before,
            /// then after the deselected tab).  Does nothing if the argument is not the
            /// currently selected tab.  Called internally when a tab is removed, hidden,
            /// or disabled, to ensure that another tab is selected instead.</summary>
            /// <param name="tab" type="goog.ui.Control?">Tab to deselect (if any).</param>
        }, 
        
        isSelectableTab: function(tab) {
            /// <summary>Returns true if the tab is selectable, false otherwise.  Only visible and
            /// enabled tabs are selectable.</summary>
            /// <param name="tab" type="goog.ui.Control">Tab to check.</param>
            /// <returns type="boolean">Whether the tab is selectable.</returns>
        }, 
        
        handleTabSelect: function(e) {
            /// <summary>Handles {@code SELECT} events dispatched by tabs as they become selected.</summary>
            /// <param name="e" type="goog.events.Event">Select event to handle.</param>
        }, 
        
        handleTabUnselect: function(e) {
            /// <summary>Handles {@code UNSELECT} events dispatched by tabs as they become deselected.</summary>
            /// <param name="e" type="goog.events.Event">Unselect event to handle.</param>
        }, 
        
        handleTabDisable: function(e) {
            /// <summary>Handles {@code DISABLE} events displayed by tabs.</summary>
            /// <param name="e" type="goog.events.Event">Disable event to handle.</param>
        }, 
        
        handleTabHide: function(e) {
            /// <summary>Handles {@code HIDE} events displayed by tabs.</summary>
            /// <param name="e" type="goog.events.Event">Hide event to handle.</param>
        }, 
        
        handleFocus: function(e) {
            /// <summary>Handles focus events dispatched by the tab bar&apos;s key event target.  If no tab
            /// is currently highlighted, highlights the selected tab or the first tab if no
            /// tab is selected either.</summary>
            /// <param name="e" type="goog.events.Event">Focus event to handle.</param>
        }, 
        
        getOrientationFromLocation: function(location) {
            /// <summary>Returns the {@link goog.ui.Container.Orientation} that is implied by the
            /// given {@link goog.ui.TabBar.Location}.</summary>
            /// <param name="location" type="goog.ui.TabBar.Location">Tab bar location.</param>
            /// <returns type="goog.ui.Container.Orientation">Corresponding orientation.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.TabBar";
})(this);
