
/* vsdoc for goog.ui.TabRenderer */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.TabRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <returns type="goog.ui.TabRenderer"/>
    };

    var $x = window.goog.ui.TabRenderer;
    $x.prototype = {
                
        getCssClass: function() {
            /// <summary>Returns the CSS class name to be applied to the root element of all tabs
            /// rendered or decorated using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class name.</returns>
        }, 
        
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to the tab element.
            /// See http://wiki/Main/ARIA for more info.</summary>
            /// <returns type="goog.dom.a11y.Role">ARIA role.</returns>
        }, 
        
        createDom: function(tab) {
            /// <summary>Returns the tab&apos;s contents wrapped in a DIV, with the renderer&apos;s own CSS
            /// class and additional state-specific classes applied to it.  Creates the
            /// following DOM structure:
            /// &lt;pre&gt;
            ///   &lt;div class=&quot;goog-tab&quot; title=&quot;Title&quot;&gt;Content&lt;/div&gt;
            /// &lt;/pre&gt;</summary>
            /// <param name="tab" type="goog.ui.Control">Tab to render.</param>
            /// <returns type="Element">Root element for the tab.</returns>
        }, 
        
        decorate: function(tab, element) {
            /// <summary>Decorates the element with the tab.  Initializes the tab&apos;s ID, content,
            /// tooltip, and state based on the ID of the element, its title, child nodes,
            /// and CSS classes, respectively.  Returns the element.</summary>
            /// <param name="tab" type="goog.ui.Control">Tab to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        getTooltip: function(element) {
            /// <summary>Takes a tab&apos;s root element, and returns its tooltip text, or the empty
            /// string if the element has no tooltip.</summary>
            /// <param name="element" type="Element">The tab&apos;s root element.</param>
            /// <returns type="string">The tooltip text (empty string if none).</returns>
        }, 
        
        setTooltip: function(element, tooltip) {
            /// <summary>Takes a tab&apos;s root element and a tooltip string, and updates the element
            /// with the new tooltip.  If the new tooltip is null or undefined, sets the
            /// element&apos;s title to the empty string.</summary>
            /// <param name="element" type="Element">The tab&apos;s root element.</param>
            /// <param name="tooltip" type="string|null|undefined">New tooltip text (if any).</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.TabRenderer";
})(this);
