
/* vsdoc for goog.ui.Tooltip */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.Tooltip = function(opt_el, opt_str, opt_domHelper){
        /// <summary></summary>
        /// <param name="opt_el" type="Element|string=">Element to display tooltip for, either
        ///     element reference or string id.</param>
        /// <param name="opt_str" type="?string=">Text message to display in tooltip.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="cursorPosition" type="!goog.math.Coordinate">Cursor position relative to the page.</field>
        /// <field name="className" type="string">CSS class name for tooltip.</field>
        /// <field name="State" type="">Possible states for the tooltip to be in.</field>
        /// <field name="Activation" type="">Popup activation types. Used to select a positioning strategy.</field>
        /// <returns type="goog.ui.Tooltip"/>
    };

    var $x = window.goog.ui.Tooltip;
    $x.prototype = {
                
        getDomHelper: function() {
            /// <summary>Returns the dom helper that is being used on this component.</summary>
            /// <returns type="goog.dom.DomHelper">The dom helper used on this component.</returns>
        }, 
        
        getChildTooltip: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.Tooltip">Active tooltip in a child element, or null if none.</returns>
        }, 
        
        attach: function(el) {
            /// <summary>Attach to element. Tooltip will be displayed when the cursor is over the
            /// element or when the element has been active for a few milliseconds.</summary>
            /// <param name="el" type="Element|string">Element to display tooltip for, either element
            ///                            reference or string id.</param>
        }, 
        
        detach: function(opt_el) {
            /// <summary>Detach from element(s).</summary>
            /// <param name="opt_el" type="Element|string=">Element to detach from, either element
            ///                                reference or string id. If no element is
            ///                                specified all are detached.</param>
        }, 
        
        setShowDelayMs: function(delay) {
            /// <summary>Sets delay in milliseconds before tooltip is displayed for an element.</summary>
            /// <param name="delay" type="number">The delay in milliseconds.</param>
        }, 
        
        getShowDelayMs: function() {
            /// <summary></summary>
            /// <returns type="number">The delay in milliseconds before tooltip is displayed for an
            ///     element.</returns>
        }, 
        
        setHideDelayMs: function(delay) {
            /// <summary>Sets delay in milliseconds before tooltip is hidden once the cursor leavs
            /// the element.</summary>
            /// <param name="delay" type="number">The delay in milliseconds.</param>
        }, 
        
        getHideDelayMs: function() {
            /// <summary></summary>
            /// <returns type="number">The delay in milliseconds before tooltip is hidden once the
            ///     cursor leaves the element.</returns>
        }, 
        
        setText: function(str) {
            /// <summary>Sets tooltip message as plain text.</summary>
            /// <param name="str" type="string">Text message to display in tooltip.</param>
        }, 
        
        setHtml: function(str) {
            /// <summary>Sets tooltip message as HTML markup.</summary>
            /// <param name="str" type="string">HTML message to display in tooltip.</param>
        }, 
        
        setElement: function(el) {
            /// <summary>Sets tooltip element.</summary>
            /// <param name="el" type="Element">HTML element to use as the tooltip.</param>
        }, 
        
        getText: function() {
            /// <summary></summary>
            /// <returns type="string">The tooltip message as plain text.</returns>
        }, 
        
        getHtml: function() {
            /// <summary></summary>
            /// <returns type="string">The tooltip message as HTML.</returns>
        }, 
        
        getState: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.Tooltip.State">Current state of tooltip.</returns>
        }, 
        
        setRequireInteraction: function(requireInteraction) {
            /// <summary>Sets whether tooltip requires the mouse to have moved or the anchor receive
            /// focus before the tooltip will be shown.</summary>
            /// <param name="requireInteraction" type="boolean">Whether tooltip should require some user
            ///     interaction before showing tooltip.</param>
        }, 
        
        isCoordinateInTooltip: function(coord) {
            /// <summary>Returns true if the coord is in the tooltip.</summary>
            /// <param name="coord" type="goog.math.Coordinate">Coordinate being tested.</param>
            /// <returns type="boolean">Whether the coord is in the tooltip.</returns>
        }, 
        
        onBeforeShow: function() {
            /// <summary>Called before the popup is shown.</summary>
            /// <returns type="boolean">Whether tooltip should be shown.</returns>
        }, 
        
        onHide_: function() {
            /// <summary>Called after the popup is hidden.</summary>
        }, 
        
        maybeShow: function(el, opt_pos) {
            /// <summary>Called by timer from mouse over handler. Shows tooltip if cursor is still
            /// over the same element.</summary>
            /// <param name="el" type="Element">Element to show tooltip for.</param>
            /// <param name="opt_pos" type="goog.positioning.AbstractPosition=">Position to display popup
            ///     at.</param>
        }, 
        
        getElements: function() {
            /// <summary></summary>
            /// <returns type="goog.structs.Set">Elements this widget is attached to.</returns>
        }, 
        
        getActiveElement: function() {
            /// <summary></summary>
            /// <returns type="Element">Active element reference.</returns>
        }, 
        
        setActiveElement: function(activeEl) {
            /// <summary></summary>
            /// <param name="activeEl" type="Element">Active element reference.</param>
        }, 
        
        showForElement: function(el, opt_pos) {
            /// <summary>Shows tooltip for a specific element.</summary>
            /// <param name="el" type="Element">Element to show tooltip for.</param>
            /// <param name="opt_pos" type="goog.positioning.AbstractPosition=">Position to display popup
            ///     at.</param>
        }, 
        
        maybeHide: function(el) {
            /// <summary>Called by timer from mouse out handler. Hides tooltip if cursor is still
            /// outside element and tooltip, or if a child of tooltip has the focus.</summary>
            /// <param name="el" type="Element">Tooltip&apos;s anchor when hide timer was started.</param>
        }, 
        
        hasActiveChild: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether tooltip element contains an active child tooltip,
            ///     and should thus not be hidden.  When the child tooltip is hidden, it
            ///     will check if the parent should be hidden, too.</returns>
        }, 
        
        handleMouseOver: function(event) {
            /// <summary>Handler for mouse over events.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        getAnchorFromElement: function(el) {
            /// <summary>Find anchor containing the given element, if any.</summary>
            /// <param name="el" type="Element">Element that triggered event.</param>
            /// <returns type="Element">Element in elements_ array that contains given element,
            ///     or null if not found.</returns>
        }, 
        
        handleMouseMove: function(event) {
            /// <summary>Handler for mouse move events.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">MOUSEMOVE event.</param>
        }, 
        
        handleFocus: function(event) {
            /// <summary>Handler for focus events.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        getPositioningStrategy: function(activationType) {
            /// <summary>Return a Position instance for repositioning the tooltip. Override in
            /// subclasses to customize the way repositioning is done.</summary>
            /// <param name="activationType" type="goog.ui.Tooltip.Activation">Information about what
            ///    kind of event caused the popup to be shown.</param>
            /// <returns type="!goog.positioning.AbstractPosition">The position object used
            ///    to position the tooltip.</returns>
        }, 
        
        handleMouseOutAndBlur: function(event) {
            /// <summary>Handler for mouse out and blur events.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        handleTooltipMouseOver: function(event) {
            /// <summary>Handler for mouse over events for the tooltip element.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        handleTooltipMouseOut: function(event) {
            /// <summary>Handler for mouse out events for the tooltip element.</summary>
            /// <param name="event" type="goog.events.BrowserEvent">Event object.</param>
        }, 
        
        startShowTimer: function(el, opt_pos) {
            /// <summary>Helper method, starts timer that calls maybeShow.  are passed to
            /// the maybeShow method.</summary>
            /// <param name="el" type="Element">Element to show tooltip for.</param>
            /// <param name="opt_pos" type="goog.positioning.AbstractPosition=">Position to display popup
            ///     at.</param>
        }, 
        
        clearShowTimer: function() {
            /// <summary>Helper method called to clear the show timer.</summary>
        }, 
        
        startHideTimer: function() {
            /// <summary>Helper method called to start the close timer.</summary>
        }, 
        
        clearHideTimer: function() {
            /// <summary>Helper method called to clear the close timer.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.Tooltip";
})(this);
