
/* vsdoc for goog.ui.ac.AutoComplete */

(function (window) {
    window.goog.ui.ac = window.goog.ui.ac || {};

    window.goog.ui.ac.AutoComplete = function(matcher, renderer, selectionHandler){
        /// <summary></summary>
        /// <param name="matcher" type="Object">A data source and row matcher, implements
        ///        &lt;code&gt;requestMatchingRows(token, maxMatches, matchCallback)&lt;/code&gt;.</param>
        /// <param name="renderer" type="goog.events.EventTarget">An object that implements
        ///        &lt;code&gt;
        ///          isVisible():boolean<br>
        ///          renderRows(rows:Array, token:string, target:Element);<br>
        ///          hiliteId(row-id:number);<br>
        ///          dismiss();<br>
        ///          dispose():
        ///        &lt;/code&gt;.</param>
        /// <param name="selectionHandler" type="Object">An object that implements
        ///        &lt;code&gt;
        ///          selectRow(row);<br>
        ///          update(opt_force);
        ///        &lt;/code&gt;.</param>
        /// <field name="matcher_" type="Object">A data-source which provides autocomplete suggestions.</field>
        /// <field name="selectionHandler_" type="Object">A handler which interacts with the input DOM element (textfield, textarea,
        /// or richedit).</field>
        /// <field name="renderer_" type="goog.events.EventTarget">A renderer to render/show/highlight/hide the autocomplete menu.</field>
        /// <field name="token_" type="?string">Currently typed token which will be used for completion.</field>
        /// <field name="rows_" type="Array">Autcomplete suggestion items.</field>
        /// <field name="hiliteId_" type="number">Id of the currently highlighted row.</field>
        /// <field name="firstRowId_" type="number">Id of the first row in autocomplete menu. Note that new ids are assigned
        /// everytime new suggestions are fetched.</field>
        /// <field name="target_" type="Element">The target HTML node for displaying.</field>
        /// <field name="EventType" type="">Events associated with the autocomplete</field>
        /// <returns type="goog.ui.ac.AutoComplete"/>
    };

    var $x = window.goog.ui.ac.AutoComplete;
    $x.prototype = {
                
        getRenderer: function() {
            /// <summary>Returns the renderer that renders/shows/highlights/hides the autocomplete
            /// menu.</summary>
            /// <returns type="goog.events.EventTarget">Renderer used by the this widget.</returns>
        }, 
        
        handleEvent: function(e) {
            /// <summary>Generic event handler that handles any events this object is listening to.</summary>
            /// <param name="e" type="goog.events.Event">Event Object.</param>
        }, 
        
        setMaxMatches: function(max) {
            /// <summary>Sets the max number of matches to fetch from the Matcher.</summary>
            /// <param name="max" type="number">Max number of matches.</param>
        }, 
        
        setAutoHilite: function(autoHilite) {
            /// <summary>Sets whether or not the first row should be highlighted by default.</summary>
            /// <param name="autoHilite" type="boolean">true iff the first row should be
            ///      highlighted by default.</param>
        }, 
        
        setAllowFreeSelect: function(allowFreeSelect) {
            /// <summary>Sets whether or not the up/down arrow can unhilite all rows.</summary>
            /// <param name="allowFreeSelect" type="boolean">true iff the up arrow can unhilite all rows.</param>
        }, 
        
        setWrap: function(wrap) {
            /// <summary>Sets whether or not selections can wrap around the edges.</summary>
            /// <param name="wrap" type="boolean">true iff sections should wrap around the edges.</param>
        }, 
        
        setTriggerSuggestionsOnUpdate: function(triggerSuggestionsOnUpdate) {
            /// <summary>Sets whether or not to request new suggestions immediately after completion
            /// of a suggestion.</summary>
            /// <param name="triggerSuggestionsOnUpdate" type="boolean">true iff completion should fetch
            ///     new suggestions.</param>
        }, 
        
        setToken: function(token, opt_fullString) {
            /// <summary>Sets the token to match against.  This triggers calls to the Matcher to
            /// fetch the matches (up to maxMatches), and then it triggers a call to
            /// &lt;code&gt;renderer.renderRows()&lt;/code&gt;.</summary>
            /// <param name="token" type="string">The string for which to search in the Matcher.</param>
            /// <param name="opt_fullString" type="string=">Optionally, the full string in the input
            ///     field.</param>
        }, 
        
        getTarget: function() {
            /// <summary>Gets the current target HTML node for displaying autocomplete UI.</summary>
            /// <returns type="Element">The current target HTML node for displaying autocomplete
            ///     UI.</returns>
        }, 
        
        setTarget: function(target) {
            /// <summary>Sets the current target HTML node for displaying autocomplete UI.
            /// Can be an implementation specific definition of how to display UI in relation
            /// to the target node.
            /// This target will be passed into  &lt;code&gt;renderer.renderRows()&lt;/code&gt;</summary>
            /// <param name="target" type="Element">The current target HTML node for displaying
            ///     autocomplete UI.</param>
        }, 
        
        isOpen: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the autocomplete&apos;s renderer is open.</returns>
        }, 
        
        getRowCount: function() {
            /// <summary></summary>
            /// <returns type="number">Number of rows in the autocomplete.</returns>
        }, 
        
        hiliteNext: function() {
            /// <summary>Moves the hilite to the next row, or does nothing if we&apos;re already at the
            /// end of the current set of matches.  Calls renderer.hiliteId() when there&apos;s
            /// something to do.</summary>
            /// <returns type="boolean">Returns true on a successful hilite.</returns>
        }, 
        
        hilitePrev: function() {
            /// <summary>Moves the hilite to the previous row, or does nothing if we&apos;re already at
            /// the beginning of the current set of matches.  Calls renderer.hiliteId()
            /// when there&apos;s something to do.</summary>
            /// <returns type="boolean">Returns true on a successful hilite.</returns>
        }, 
        
        hiliteId: function(id) {
            /// <summary>Hilites the id if it&apos;s valid, otherwise does nothing.</summary>
            /// <param name="id" type="number">A row id (not index).</param>
            /// <returns type="boolean">Whether the id was hilited.</returns>
        }, 
        
        hiliteIndex: function(index) {
            /// <summary>Hilites the index, if it&apos;s valid, otherwise does nothing.</summary>
            /// <param name="index" type="number">The row&apos;s index.</param>
            /// <returns type="boolean">Whether the index was hilited.</returns>
        }, 
        
        selectHilited: function() {
            /// <summary>If there are any current matches, this passes the hilited row data to
            /// &lt;code&gt;selectionHandler.selectRow()&lt;/code&gt;</summary>
            /// <returns type="boolean">Whether there are any current matches.</returns>
        }, 
        
        hasHighlight: function() {
            /// <summary>Returns whether or not the autocomplete is open and has a highlighted row.</summary>
            /// <returns type="boolean">Whether an autocomplete row is highlighted.</returns>
        }, 
        
        dismiss: function() {
            /// <summary>Clears out the token, rows, and hilite, and calls
            /// &lt;code&gt;renderer.dismiss()&lt;/code&gt;</summary>
        }, 
        
        dismissOnDelay: function() {
            /// <summary>Call a dismiss after a delay, if there&apos;s already a dismiss active, ignore.</summary>
        }, 
        
        cancelDelayedDismiss: function() {
            /// <summary>Cancel the active delayed dismiss if there is one.</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        renderRows: function(rows, opt_options) {
            /// <summary>Renders the rows and adds highlighting.</summary>
            /// <param name="rows" type="!Array">Set of data that match the given token.</param>
            /// <param name="opt_options" type="(boolean|goog.ui.ac.RenderOptions)=">If true,
            ///     keeps the currently hilited (by index) element hilited. If false not.
            ///     Otherwise a RenderOptions object.</param>
        }, 
        
        getIndexOfId: function(id) {
            /// <summary>Gets the index corresponding to a particular id.</summary>
            /// <param name="id" type="number">A unique id for the row.</param>
            /// <returns type="number">A valid index into rows_, or -1 if the id is invalid.</returns>
        }, 
        
        attachInputs: function(var_args) {
            /// <summary>Attach text areas or input boxes to the autocomplete by DOM reference.  After
            /// elements are attached to the autocomplete, when a user types they will see
            /// the autocomplete drop down.</summary>
            /// <param name="var_args" type="...Element">Variable args: Input or text area elements to
            ///     attach the autocomplete too.</param>
        }, 
        
        detachInputs: function(var_args) {
            /// <summary>Detach text areas or input boxes to the autocomplete by DOM reference.</summary>
            /// <param name="var_args" type="...Element">Variable args: Input or text area elements to
            ///     detach from the autocomplete.</param>
        }, 
        
        attachInputWithAnchor: function(inputElement, anchorElement) {
            /// <summary>Attaches the autocompleter to a text area or text input element
            /// with an anchor element. The anchor element is the element the
            /// autocomplete box will be positioned against.</summary>
            /// <param name="inputElement" type="Element">The input element. May be &apos;textarea&apos;,
            ///     text &apos;input&apos; element, or any other element that exposes similar
            ///     interface.</param>
            /// <param name="anchorElement" type="Element">The anchor element.</param>
        }, 
        
        update: function(opt_force) {
            /// <summary>Forces an update of the display.</summary>
            /// <param name="opt_force" type="boolean=">Whether to force an update.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ac.AutoComplete";
})(this);
