
/* vsdoc for goog.ui.ac.InputHandler */

(function (window) {
    window.goog.ui.ac = window.goog.ui.ac || {};

    window.goog.ui.ac.InputHandler = function(opt_separators, opt_literals, opt_multi, opt_throttleTime){
        /// <summary></summary>
        /// <param name="opt_separators" type="?string=">Separators to split multiple entries.</param>
        /// <param name="opt_literals" type="?string=">Characters used to delimit text literals.</param>
        /// <param name="opt_multi" type="?boolean=">Whether to allow multiple entries
        ///     (Default: true).</param>
        /// <param name="opt_throttleTime" type="?number=">Number of milliseconds to throttle
        ///     keyevents with (Default: 150). Use -1 to disable updates on typing. Note
        ///     that typing the separator will update autocomplete suggestions.</param>
        /// <field name="STANDARD_LIST_SEPARATORS" type="string">Standard list separators.</field>
        /// <field name="QUOTE_LITERALS" type="string">Literals for quotes.</field>
        /// <returns type="goog.ui.ac.InputHandler"/>
    };

    var $x = window.goog.ui.ac.InputHandler;
    $x.prototype = {
                
        attachAutoComplete: function(ac) {
            /// <summary>Attach an instance of an AutoComplete</summary>
            /// <param name="ac" type="goog.ui.ac.AutoComplete">Autocomplete object.</param>
        }, 
        
        getAutoComplete: function() {
            /// <summary>Returns the associated autocomplete instance.</summary>
            /// <returns type="goog.ui.ac.AutoComplete">The associated autocomplete instance.</returns>
        }, 
        
        getActiveElement: function() {
            /// <summary>Returns the current active element.</summary>
            /// <returns type="Element">The currently active element.</returns>
        }, 
        
        getValue: function() {
            /// <summary>Returns the value of the current active element.</summary>
            /// <returns type="string">The value of the current active element.</returns>
        }, 
        
        setValue: function(value) {
            /// <summary>Sets the value of the current active element.</summary>
            /// <param name="value" type="string">The new value.</param>
        }, 
        
        getCursorPosition: function() {
            /// <summary>Returns the current cursor position.</summary>
            /// <returns type="number">The index of the cursor position.</returns>
        }, 
        
        setCursorPosition: function(pos) {
            /// <summary>Sets the cursor at the given position.</summary>
            /// <param name="pos" type="number">The index of the cursor position.</param>
        }, 
        
        attachInput: function(target) {
            /// <summary>Attaches the input handler to a target element. The target element
            /// should be a textarea, input box, or other focusable element with the
            /// same interface.</summary>
            /// <param name="target" type="Element|goog.events.EventTarget">An element to attach the
            ///     input handler too.</param>
        }, 
        
        detachInput: function(target) {
            /// <summary>Detaches the input handler from the provided element.</summary>
            /// <param name="target" type="Element|goog.events.EventTarget">An element to detach the
            ///     input handler from.</param>
        }, 
        
        attachInputs: function(var_args) {
            /// <summary>Attaches the input handler to multiple elements.</summary>
            /// <param name="var_args" type="...Element">Elements to attach the input handler too.</param>
        }, 
        
        detachInputs: function(var_args) {
            /// <summary>Detaches the input handler from multuple elements.</summary>
            /// <param name="var_args" type="...Element">Variable arguments for elements to unbind from.</param>
        }, 
        
        selectRow: function(row, opt_multi) {
            /// <summary>Selects the given row.  Implements the SelectionHandler interface.</summary>
            /// <param name="row" type="Object">The row to select.</param>
            /// <param name="opt_multi" type="boolean=">Should this be treated as a single or multi-token
            ///     auto-complete?  Overrides previous setting of opt_multi on constructor.</param>
            /// <returns type="boolean">Whether to suppress the update event.</returns>
        }, 
        
        setTokenText: function(tokenText, opt_multi) {
            /// <summary>Sets the text of the current token without updating the autocomplete
            /// choices.</summary>
            /// <param name="tokenText" type="string">The text for the current token.</param>
            /// <param name="opt_multi" type="boolean=">Should this be treated as a single or multi-token
            ///     auto-complete?  Overrides previous setting of opt_multi on constructor.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        setSeparators: function(separators) {
            /// <summary>Sets the entry separator characters.</summary>
            /// <param name="separators" type="string">The separator characters to set.</param>
        }, 
        
        setUpsideDown: function(upsideDown) {
            /// <summary>Sets whether to flip the orientation of up &amp; down for hiliting next
            /// and previous autocomplete entries.</summary>
            /// <param name="upsideDown" type="boolean">Whether the orientation is upside down.</param>
        }, 
        
        setWhitespaceWrapEntries: function(newValue) {
            /// <summary>Sets whether auto-completed tokens should be wrapped with whitespace.</summary>
            /// <param name="newValue" type="boolean">boolean value indicating whether or not
            ///     auto-completed tokens should be wrapped with whitespace.</param>
        }, 
        
        setGenerateNewTokenOnLiteral: function(newValue) {
            /// <summary>Sets whether new tokens should be generated from literals.  That is, should
            /// hello&apos;world be two tokens, assuming &apos; is a literal?</summary>
            /// <param name="newValue" type="boolean">boolean value indicating whether or not
            /// new tokens should be generated from literals.</param>
        }, 
        
        setTrimmingRegExp: function(trimmer) {
            /// <summary>Sets the regular expression used to trim the tokens before passing them to
            /// the matcher:  every substring that matches the given regular expression will
            /// be removed.  This can also be set to null to disable trimming.</summary>
            /// <param name="trimmer" type="RegExp">Regexp to use for trimming or null to disable it.</param>
        }, 
        
        setPreventDefaultOnTab: function(newValue) {
            /// <summary>Sets whether we will prevent the default input behavior (moving focus to the
            /// next focusable  element) on TAB.</summary>
            /// <param name="newValue" type="boolean">Whether to preventDefault on TAB.</param>
        }, 
        
        setSeparatorCompletes: function(newValue) {
            /// <summary>Sets whether separators perform autocomplete.</summary>
            /// <param name="newValue" type="boolean">Whether to autocomplete on separators.</param>
        }, 
        
        setSeparatorSelects: function(newValue) {
            /// <summary>Sets whether separators perform autocomplete.</summary>
            /// <param name="newValue" type="boolean">Whether to autocomplete on separators.</param>
        }, 
        
        getThrottleTime: function() {
            /// <summary>Gets the time to wait before updating the results. If the update during
            /// typing flag is switched on, this delay counts from the last update,
            /// otherwise from the last keypress.</summary>
            /// <returns type="number">Throttle time in milliseconds.</returns>
        }, 
        
        setRowJustSelected: function(justSelected) {
            /// <summary>Sets whether a row has just been selected.</summary>
            /// <param name="justSelected" type="boolean">Whether or not the row has just been selected.</param>
        }, 
        
        setThrottleTime: function(time) {
            /// <summary>Sets the time to wait before updating the results.</summary>
            /// <param name="time" type="number">New throttle time in milliseconds.</param>
        }, 
        
        getUpdateDuringTyping: function() {
            /// <summary>Gets whether the result list is updated during typing.</summary>
            /// <returns type="boolean">Value of the flag.</returns>
        }, 
        
        setUpdateDuringTyping: function(value) {
            /// <summary>Sets whether the result list should be updated during typing.</summary>
            /// <param name="value" type="boolean">New value of the flag.</param>
        }, 
        
        handleKeyEvent: function(e) {
            /// <summary>Handles a key event.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Browser event object.</param>
            /// <returns type="boolean">True if the key event was handled.</returns>
        }, 
        
        needKeyUpListener: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether this inputhandler need to listen on key-up.</returns>
        }, 
        
        handleKeyUp: function(e) {
            /// <summary>Handles the key up event. Registered only if needKeyUpListener returns true.</summary>
            /// <param name="e" type="goog.events.Event">The keyup event.</param>
            /// <returns type="boolean">Whether an action was taken or not.</returns>
        }, 
        
        handleFocus: function(e) {
            /// <summary>Handles an element getting focus.</summary>
            /// <param name="e" type="goog.events.Event">Browser event object.</param>
        }, 
        
        processFocus: function(target) {
            /// <summary>Registers handlers for the active element when it receives focus.</summary>
            /// <param name="target" type="Element">The element to focus.</param>
        }, 
        
        handleBlur: function(opt_e) {
            /// <summary>Handles an element blurring.</summary>
            /// <param name="opt_e" type="goog.events.Event=">Browser event object.</param>
        }, 
        
        handleMouseDown: function(e) {
            /// <summary>For subclasses to override to handle the mouse-down event.</summary>
            /// <param name="e" type="goog.events.BrowserEvent">Browser event object.</param>
        }, 
        
        update: function(opt_force) {
            /// <summary>Checks if an update has occurred and notified the autocomplete of the new
            /// token.</summary>
            /// <param name="opt_force" type="boolean=">If true the menu will be forced to update.</param>
        }, 
        
        parseToken: function() {
            /// <summary>Parses a text area or input box for the currently highlighted token.</summary>
            /// <returns type="string">Token to complete.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ac.InputHandler";
})(this);
