
/* vsdoc for goog.ui.ac.RemoteArrayMatcher */

(function (window) {
    window.goog.ui.ac = window.goog.ui.ac || {};

    window.goog.ui.ac.RemoteArrayMatcher = function(url, opt_noSimilar){
        /// <summary></summary>
        /// <param name="url" type="string">The Uri which generates the auto complete matches.  The
        ///     search term is passed to the server as the &apos;token&apos; query param.</param>
        /// <param name="opt_noSimilar" type="boolean=">If true, request that the server does not do
        ///     similarity matches for the input token against the dictionary.
        ///     The value is sent to the server as the &apos;use_similar&apos; query param which is
        ///     either &quot;1&quot; (opt_noSimilar==false) or &quot;0&quot; (opt_noSimilar==true).</param>
        /// <returns type="goog.ui.ac.RemoteArrayMatcher"/>
    };

    var $x = window.goog.ui.ac.RemoteArrayMatcher;
    $x.prototype = {
                
        setMethod: function(method) {
            /// <summary>Set the send method (&quot;GET&quot;, &quot;POST&quot;).</summary>
            /// <param name="method" type="string">The send method; default: GET.</param>
        }, 
        
        setContent: function(content) {
            /// <summary>Set the post data.</summary>
            /// <param name="content" type="string">Post data.</param>
        }, 
        
        setHeaders: function(headers) {
            /// <summary>Set the HTTP headers.</summary>
            /// <param name="headers" type="Object|goog.structs.Map">Map of headers to add to the
            ///     request.</param>
        }, 
        
        setTimeoutInterval: function(interval) {
            /// <summary>Set the timeout interval.</summary>
            /// <param name="interval" type="number">Number of milliseconds after which an
            ///     incomplete request will be aborted; 0 means no timeout is set.</param>
        }, 
        
        buildUrl: function(uri, token, maxMatches, useSimilar, opt_fullString) {
            /// <summary>Builds a complete GET-style URL, given the base URI and autocomplete related
            /// parameter values.
            /// <b>Override this to build any customized lookup URLs.</b>
            /// <b>Can be used to change request method and any post content as well.</b></summary>
            /// <param name="uri" type="string">The base URI of the request target.</param>
            /// <param name="token" type="string">Current token in autocomplete.</param>
            /// <param name="maxMatches" type="number">Maximum number of matches required.</param>
            /// <param name="useSimilar" type="boolean">A hint to the server.</param>
            /// <param name="opt_fullString" type="string=">Complete text in the input element.</param>
            /// <returns type="?string">The complete url. Return null if no request should be sent.</returns>
        }, 
        
        shouldRequestMatches: function(uri, token, maxMatches, useSimilar, opt_fullString) {
            /// <summary>Returns whether the suggestions should be updated?
            /// <b>Override this to prevent updates eg - when token is empty.</b></summary>
            /// <param name="uri" type="string">The base URI of the request target.</param>
            /// <param name="token" type="string">Current token in autocomplete.</param>
            /// <param name="maxMatches" type="number">Maximum number of matches required.</param>
            /// <param name="useSimilar" type="boolean">A hint to the server.</param>
            /// <param name="opt_fullString" type="string=">Complete text in the input element.</param>
            /// <returns type="boolean">Whether new matches be requested.</returns>
        }, 
        
        parseResponseText: function(responseText) {
            /// <summary>Parses and retrieves the array of suggestions from XHR response.
            /// <b>Override this if the response is not a simple JSON array.</b></summary>
            /// <param name="responseText" type="string">The XHR response text.</param>
            /// <returns type="Array.string">The array of suggestions.</returns>
        }, 
        
        xhrCallback: function(token, matchHandler, event) {
            /// <summary>Handles the XHR response.</summary>
            /// <param name="token" type="string">The XHR autocomplete token.</param>
            /// <param name="matchHandler" type="Function">The AutoComplete match handler.</param>
            /// <param name="event" type="goog.events.Event">The XHR success event.</param>
        }, 
        
        requestMatchingRows: function(token, maxMatches, matchHandler, opt_fullString) {
            /// <summary>Retrieve a set of matching rows from the server via ajax.</summary>
            /// <param name="token" type="string">The text that should be matched; passed to the server
            ///     as the &apos;token&apos; query param.</param>
            /// <param name="maxMatches" type="number">The maximum number of matches requested from the
            ///     server; passed as the &apos;max_matches&apos; query param.  The server is
            ///     responsible for limiting the number of matches that are returned.</param>
            /// <param name="matchHandler" type="Function">Callback to execute on the result after
            ///     matching.</param>
            /// <param name="opt_fullString" type="string=">The full string from the input box.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ac.RemoteArrayMatcher";
})(this);
