
/* vsdoc for goog.ui.ac.Renderer */

(function (window) {
    window.goog.ui.ac = window.goog.ui.ac || {};

    window.goog.ui.ac.Renderer = function(opt_parentNode, opt_customRenderer, opt_rightAlign, opt_useStandardHighlighting){
        /// <summary></summary>
        /// <param name="opt_parentNode" type="Element=">optional reference to the parent element
        ///     that will hold the autocomplete elements. goog.dom.getDocument().body
        ///     will be used if this is null.</param>
        /// <param name="opt_customRenderer" type="?({renderRow}|{render})=">Custom full renderer to
        ///     render each row. Should be something with a renderRow or render method.</param>
        /// <param name="opt_rightAlign" type="boolean=">Determines if the autocomplete will always
        ///     be right aligned. False by default.</param>
        /// <param name="opt_useStandardHighlighting" type="boolean=">Determines if standard
        ///     highlighting should be applied to each row of data. Standard highlighting
        ///     bolds every matching substring for a given token in each row.</param>
        /// <field name="rowDivs_" type="Array.<Element>">Array of the node divs that hold each result that is being displayed.</field>
        /// <field name="hilitedRow_" type="number">The index of the currently highlighted row</field>
        /// <field name="startRenderingRows_" type="number">The time that the rendering of the menu rows started</field>
        /// <field name="className" type="string">Classname for the main element</field>
        /// <field name="rowClassName" type="string">Classname for row divs</field>
        /// <field name="activeClassName" type="string">Class name for active row div.
        /// Active row will have rowClassName &amp; activeClassName &amp;
        /// legacyActiveClassName.</field>
        /// <field name="highlightedClassName" type="string">Class name for the bold tag highlighting the matched part of the text.</field>
        /// <field name="DELAY_BEFORE_MOUSEOVER" type="number">The delay before mouseover events are registered, in milliseconds</field>
        /// <returns type="goog.ui.ac.Renderer"/>
    };

    var $x = window.goog.ui.ac.Renderer;
    $x.prototype = {
                
        getElement: function() {
            /// <summary>Gets the renderer&apos;s element.</summary>
            /// <returns type="Element">The  main element that controls the rendered autocomplete.</returns>
        }, 
        
        setWidthProvider: function(widthProvider) {
            /// <summary>Sets the width provider element. The provider is only used on redraw and as
            /// such will not automatically update on resize.</summary>
            /// <param name="widthProvider" type="Node">The element whose width should be mirrored.</param>
        }, 
        
        setTopAlign: function(align) {
            /// <summary>Set whether to align autocomplete to top of target element</summary>
            /// <param name="align" type="boolean">If true, align to top.</param>
        }, 
        
        getTopAlign: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether we should be aligning to the top of
            ///     the target element.</returns>
        }, 
        
        setRightAlign: function(align) {
            /// <summary>Set whether to align autocomplete to the right of the target element.</summary>
            /// <param name="align" type="boolean">If true, align to right.</param>
        }, 
        
        getRightAlign: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the autocomplete menu should be right aligned.</returns>
        }, 
        
        setUseStandardHighlighting: function(useStandardHighlighting) {
            /// <summary>Set whether or not standard highlighting should be used when rendering rows.</summary>
            /// <param name="useStandardHighlighting" type="boolean">true if standard highlighting used.</param>
        }, 
        
        setHighlightAllTokens: function(highlightAllTokens) {
            /// <summary>Set whether or not to highlight all matching tokens rather than just the
            /// first.</summary>
            /// <param name="highlightAllTokens" type="boolean">Whether to highlight all matching tokens
            ///     rather than just the first.</param>
        }, 
        
        setMenuFadeDuration: function(duration) {
            /// <summary>Sets the duration (in msec) of the fade animation when menu is shown/hidden.
            /// Setting to 0 (default) disables animation entirely.</summary>
            /// <param name="duration" type="number">Duration (in msec) of the fade animation (or 0 for
            ///     no animation).</param>
        }, 
        
        setAnchorElement: function(anchor) {
            /// <summary>Sets the anchor element for the subsequent call to renderRows.</summary>
            /// <param name="anchor" type="Element">The anchor element.</param>
        }, 
        
        renderRows: function(rows, token, opt_target) {
            /// <summary>Render the autocomplete UI</summary>
            /// <param name="rows" type="Array">Matching UI rows.</param>
            /// <param name="token" type="string">Token we are currently matching against.</param>
            /// <param name="opt_target" type="Element=">Current HTML node, will position popup beneath
            ///     this node.</param>
        }, 
        
        dismiss: function() {
            /// <summary>Hide the object.</summary>
        }, 
        
        show: function() {
            /// <summary>Show the object.</summary>
        }, 
        
        isVisible: function() {
            /// <summary></summary>
            /// <returns type="boolean">True if the object is visible.</returns>
        }, 
        
        hiliteRow: function(index) {
            /// <summary>Sets the &apos;active&apos; class of the nth item.</summary>
            /// <param name="index" type="number">Index of the item to highlight.</param>
        }, 
        
        hiliteNone: function() {
            /// <summary>Removes the &apos;active&apos; class from the currently selected row.</summary>
        }, 
        
        hiliteId: function(id) {
            /// <summary>Sets the &apos;active&apos; class of the item with a given id.</summary>
            /// <param name="id" type="number">Id of the row to hilight. If id is -1 then no rows get
            ///     hilited.</param>
        }, 
        
        redraw: function() {
            /// <summary>Redraw (or draw if this is the first call) the rendered auto-complete drop
            /// down.</summary>
        }, 
        
        getAnchorCorner: function() {
            /// <summary></summary>
            /// <returns type="goog.positioning.Corner">The anchor corner to position the popup at.</returns>
        }, 
        
        reposition: function() {
            /// <summary>Repositions the auto complete popup relative to the location node, if it
            /// exists and the auto position has been set.</summary>
        }, 
        
        setAutoPosition: function(auto) {
            /// <summary>Sets whether the renderer should try to determine where to position the
            /// drop down.</summary>
            /// <param name="auto" type="boolean">Whether to autoposition the drop down.</param>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the renderer and its associated HTML.</summary>
        }, 
        
        renderRowHtml: function(row, token) {
            /// <summary>Render a row by creating a div and then calling row rendering callback or
            /// default row handler</summary>
            /// <param name="row" type="Object">Object representing row.</param>
            /// <param name="token" type="string">Token to highlight.</param>
            /// <returns type="Element">An element with the rendered HTML.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.ac.Renderer";
})(this);
