
/* vsdoc for goog.ui.editor.AbstractDialog */

(function (window) {
    window.goog.ui.editor = window.goog.ui.editor || {};

    window.goog.ui.editor.AbstractDialog = function(domHelper){
        /// <summary></summary>
        /// <param name="domHelper" type="goog.dom.DomHelper">DomHelper to be used to create the
        /// dialog&apos;s dom structure.</param>
        /// <field name="EventType" type="">Event type constants for events the dialog fires.</field>
        /// <field name="createDialogControl" type="goog.ui.Dialog">Creates and returns the goog.ui.Dialog control that is being wrapped
        /// by this object.</field>
        /// <field name="createOkEvent" type="goog.events.Event">Creates and returns the event object to be used when dispatching the OK
        /// event to listeners, or returns null to prevent the dialog from closing.
        /// Subclasses should override this to return their own subclass of
        /// goog.events.Event that includes all data a plugin would need from the dialog.</field>
        /// <returns type="goog.ui.editor.AbstractDialog"/>
    };

    var $x = window.goog.ui.editor.AbstractDialog;
    $x.prototype = {
                
        show: function() {
            /// <summary>Causes the dialog box to appear, centered on the screen. Lazily creates the
            /// dialog if needed.</summary>
        }, 
        
        hide: function() {
            /// <summary>Hides the dialog, causing AFTER_HIDE to fire.</summary>
        }, 
        
        isOpen: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the dialog is open.</returns>
        }, 
        
        processOkAndClose: function() {
            /// <summary>Runs the handler registered on the OK button event and closes the dialog if
            /// that handler succeeds.
            /// This is useful in cases such as double-clicking an item in the dialog is
            /// equivalent to selecting it and clicking the default button.</summary>
        }, 
        
        getOkButtonElement: function() {
            /// <summary>Returns the HTML Button element for the OK button in this dialog.</summary>
            /// <returns type="Element">The button element if found, else null.</returns>
        }, 
        
        getCancelButtonElement: function() {
            /// <summary>Returns the HTML Button element for the Cancel button in this dialog.</summary>
            /// <returns type="Element">The button element if found, else null.</returns>
        }, 
        
        getButtonElement: function(buttonId) {
            /// <summary>Returns the HTML Button element for the button added to this dialog with
            /// the given button id.</summary>
            /// <param name="buttonId" type="string">The id of the button to get.</param>
            /// <returns type="Element">The button element if found, else null.</returns>
        }, 
        
        handleOk: function(e) {
            /// <summary>Handles the event dispatched by the wrapped dialog control when the user
            /// clicks the OK button. Attempts to create the OK event object and dispatches
            /// it if successful.</summary>
            /// <param name="e" type="goog.ui.Dialog.Event">wrapped dialog OK event object.</param>
            /// <returns type="boolean">Whether the default action (closing the dialog) should
            ///     still be executed. This will be false if the OK event could not be
            ///     created to be dispatched, or if any listener to that event returs false
            ///     or calls preventDefault.</returns>
        }, 
        
        handleCancel: function() {
            /// <summary>Handles the event dispatched by the wrapped dialog control when the user
            /// clicks the Cancel button. Simply dispatches a CANCEL event.</summary>
            /// <returns type="boolean">Returns false if any of the handlers called prefentDefault
            ///     on the event or returned false themselves.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary>Disposes of the dialog. If the dialog is open, it will be hidden and
            /// AFTER_HIDE will be dispatched.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.editor.AbstractDialog";
})(this);
