
/* vsdoc for goog.ui.editor.AbstractDialog.Builder */

(function (window) {
    window.goog.ui.editor.AbstractDialog = window.goog.ui.editor.AbstractDialog || {};

    window.goog.ui.editor.AbstractDialog.Builder = function(editorDialog){
        /// <summary></summary>
        /// <param name="editorDialog" type="goog.ui.editor.AbstractDialog">Editor dialog object
        ///     that will wrap the wrapped dialog object this builder will create.</param>
        /// <returns type="goog.ui.editor.AbstractDialog.Builder"/>
    };

    var $x = window.goog.ui.editor.AbstractDialog.Builder;
    $x.prototype = {
                
        setTitle: function(title) {
            /// <summary>Sets the title of the dialog.</summary>
            /// <param name="title" type="string">Title HTML (escaped).</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        addOkButton: function(opt_label) {
            /// <summary>Adds an OK button to the dialog. Clicking this button will cause {@link
            /// handleOk} to run, subsequently dispatching an OK event.</summary>
            /// <param name="opt_label" type="string=">The caption for the button, if not &quot;OK&quot;.</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        addCancelButton: function(opt_label) {
            /// <summary>Adds a Cancel button to the dialog. Clicking this button will cause {@link
            /// handleCancel} to run, subsequently dispatching a CANCEL event.</summary>
            /// <param name="opt_label" type="string=">The caption for the button, if not &quot;Cancel&quot;.</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        addButton: function(label, handler, opt_buttonId) {
            /// <summary>Adds a custom button to the dialog.</summary>
            /// <param name="label" type="string">The caption for the button.</param>
            /// <param name="handler" type="function(goog.ui.Dialog.EventType):*">Function called when
            ///     the button is clicked. It is recommended that this function be a method
            ///     in the concrete subclass of AbstractDialog using this Builder, and that
            ///     it dispatch an event (see {@link handleOk}).</param>
            /// <param name="opt_buttonId" type="string=">Identifier to be used to access the button when
            ///     calling AbstractDialog.getButtonElement().</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        addClassName: function(className) {
            /// <summary>Puts a CSS class on the dialog&apos;s main element.</summary>
            /// <param name="className" type="string">The class to add.</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        setContent: function(contentElem) {
            /// <summary>Sets the content element of the dialog.</summary>
            /// <param name="contentElem" type="Element">An element for the main body.</param>
            /// <returns type="goog.ui.editor.AbstractDialog.Builder">This.</returns>
        }, 
        
        build: function() {
            /// <summary>Builds the wrapped dialog control. May only be called once, after which
            /// no more methods may be called on this builder.</summary>
            /// <returns type="goog.ui.Dialog">The wrapped dialog control.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.editor.AbstractDialog.Builder";
})(this);
