
/* vsdoc for goog.ui.editor.Bubble */

(function (window) {
    window.goog.ui.editor = window.goog.ui.editor || {};

    window.goog.ui.editor.Bubble = function(parent, zIndex){
        /// <summary></summary>
        /// <param name="parent" type="Element">The parent element for this bubble.</param>
        /// <param name="zIndex" type="number">The z index to draw the bubble at.</param>
        /// <field name="BUBBLE_CLASSNAME" type="string">The css class name of the bubble container element.</field>
        /// <field name="logger" type="goog.debug.Logger">A logger for goog.ui.editor.Bubble.</field>
        /// <returns type="goog.ui.editor.Bubble"/>
    };

    var $x = window.goog.ui.editor.Bubble;
    $x.prototype = {
                
        createBubbleDom: function(dom, container) {
            /// <summary>Creates and adds DOM for the bubble UI to the given container.  This default
            /// implementation just returns the container itself.</summary>
            /// <param name="dom" type="!goog.dom.DomHelper">DOM helper to use.</param>
            /// <param name="container" type="!Element">Element to add the new elements to.</param>
            /// <returns type="!Element">The element where bubble content should be added.</returns>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        getContentElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The element that where the bubble&apos;s contents go.</returns>
        }, 
        
        getContainerElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The element that contains the bubble.</returns>
        }, 
        
        getEventHandler: function() {
            /// <summary></summary>
            /// <returns type="goog.events.EventHandler">The event handler.</returns>
        }, 
        
        hasPanelOfType: function(type) {
            /// <summary>Returns whether there is already a panel of the given type.</summary>
            /// <param name="type" type="string">Type of panel to check.</param>
            /// <returns type="boolean">Whether there is already a panel of the given type.</returns>
        }, 
        
        addPanel: function(type, title, targetElement, contentFn, opt_preferTopPosition) {
            /// <summary>Adds a panel to the bubble.</summary>
            /// <param name="type" type="string">The type of bubble panel this is.  Should usually be
            ///     the same as the tagName of the targetElement.  This ensures multiple
            ///     bubble panels don&apos;t appear for the same element.</param>
            /// <param name="title" type="string">The title of the panel.</param>
            /// <param name="targetElement" type="Element">The target element of the bubble.</param>
            /// <param name="contentFn" type="function(Element): void">Function that when called with
            ///     a container element, will add relevant panel content to it.</param>
            /// <param name="opt_preferTopPosition" type="boolean=">Whether to prefer placing the bubble
            ///     above the element instead of below it.  Defaults to preferring below.
            ///     If any panel prefers the top position, the top position is used.</param>
            /// <returns type="string">The id of the panel.</returns>
        }, 
        
        removePanel: function(id) {
            /// <summary>Removes the panel with the given id.</summary>
            /// <param name="id" type="string">The id of the panel.</param>
        }, 
        
        handlePopupHide: function() {
            /// <summary>Handles the popup&apos;s hide event by removing all panels and dispatching a
            /// HIDE event.</summary>
        }, 
        
        isVisible: function() {
            /// <summary>Returns the visibility of the bubble.</summary>
            /// <returns type="boolean">True if visible false if not.</returns>
        }, 
        
        reposition: function() {
            /// <summary>Positions and displays this bubble below its targetElement. Assumes that
            /// the bubbleContainer is already contained in the document object it applies
            /// to.</summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.editor.Bubble";
})(this);
