
/* vsdoc for goog.ui.editor.ToolbarController */

(function (window) {
    window.goog.ui.editor = window.goog.ui.editor || {};

    window.goog.ui.editor.ToolbarController = function(field, toolbar){
        /// <summary></summary>
        /// <param name="field" type="!goog.editor.Field">Editable field to be controlled by the
        ///     toolbar.</param>
        /// <param name="toolbar" type="!goog.ui.Toolbar">Toolbar to control the editable field.</param>
        /// <returns type="goog.ui.editor.ToolbarController"/>
    };

    var $x = window.goog.ui.editor.ToolbarController;
    $x.prototype = {
                
        getComponentId: function(command) {
            /// <summary>Returns the Closure component ID of the control that corresponds to the
            /// given {@link goog.editor.Command} constant.
            /// Subclasses may override this method if they want to use a custom mapping
            /// scheme from commands to controls.</summary>
            /// <param name="command" type="string">Editor command.</param>
            /// <returns type="string">Closure component ID of the corresponding toolbar
            ///     control, if any.</returns>
        }, 
        
        getCommand: function(id) {
            /// <summary>Returns the {@link goog.editor.Command} constant
            /// that corresponds to the given Closure component ID.  Subclasses may override
            /// this method if they want to use a custom mapping scheme from controls to
            /// commands.</summary>
            /// <param name="id" type="string">Closure component ID of a toolbar control.</param>
            /// <returns type="string">Editor command or dialog constant corresponding to the
            ///     toolbar control, if any.</returns>
        }, 
        
        getHandler: function() {
            /// <summary>Returns the event handler object for the editor toolbar.  Useful for classes
            /// that extend {@code goog.ui.editor.ToolbarController}.</summary>
            /// <returns type="!goog.events.EventHandler">The event handler object.</returns>
        }, 
        
        getField: function() {
            /// <summary>Returns the field instance managed by the toolbar.  Useful for
            /// classes that extend {@code goog.ui.editor.ToolbarController}.</summary>
            /// <returns type="!goog.editor.Field">The field managed by the toolbar.</returns>
        }, 
        
        getToolbar: function() {
            /// <summary>Returns the toolbar UI component that manages the editor.  Useful for
            /// classes that extend {@code goog.ui.editor.ToolbarController}.</summary>
            /// <returns type="!goog.ui.Toolbar">The toolbar UI component.</returns>
        }, 
        
        isVisible: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the toolbar is visible.</returns>
        }, 
        
        setVisible: function(visible) {
            /// <summary>Shows or hides the toolbar.</summary>
            /// <param name="visible" type="boolean">Whether to show or hide the toolbar.</param>
        }, 
        
        isEnabled: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the toolbar is enabled.</returns>
        }, 
        
        setEnabled: function(enabled) {
            /// <summary>Enables or disables the toolbar.</summary>
            /// <param name="enabled" type="boolean">Whether to enable or disable the toolbar.</param>
        }, 
        
        blur: function() {
            /// <summary>Programmatically blurs the editor toolbar, un-highlighting the currently
            /// highlighted item, and closing the currently open menu (if any).</summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        updateToolbar: function(e) {
            /// <summary>Updates the toolbar in response to editor events.  Specifically, updates
            /// button states based on {@code COMMAND_VALUE_CHANGE} events, reflecting the
            /// effective formatting of the selection.</summary>
            /// <param name="e" type="goog.events.Event">Editor event to handle.</param>
        }, 
        
        updateToolbarFromState: function(state) {
            /// <summary>Updates the toolbar to reflect a given state.</summary>
            /// <param name="state" type="Object">Object mapping editor commands to values.</param>
        }, 
        
        handleAction: function(e) {
            /// <summary>Handles {@code ACTION} events dispatched by toolbar buttons in response to
            /// user actions by executing the corresponding field command.</summary>
            /// <param name="e" type="goog.events.Event">Action event to handle.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.editor.ToolbarController";
})(this);
