
/* vsdoc for goog.ui.editor.ToolbarFactory */

(function (window) {
    window.goog.ui.editor = window.goog.ui.editor || {};

    window.goog.ui.editor.ToolbarFactory = {
        /// <summary></summary>
        /// <returns type="goog.ui.editor.ToolbarFactory"/>
                
        getPrimaryFont: function(fontSpec) {
            /// <summary>Takes a font spec (e.g. &quot;Arial, Helvetica, sans-serif&quot;) and returns the
            /// primary font name, normalized to lowercase (e.g. &quot;arial&quot;).</summary>
            /// <param name="fontSpec" type="string">Font specification.</param>
            /// <returns type="string">The primary font name, in lowercase.</returns>
        }, 
        
        addFonts: function(button, fonts) {
            /// <summary>Bulk-adds fonts to the given font menu button.  The argument must be an
            /// array of font descriptor objects, each of which must have the following
            /// attributes:
            /// &lt;ul&gt;
            ///   &lt;li&gt;{@code caption} - Caption to show in the font menu (e.g. &apos;Tahoma&apos;)
            ///   &lt;li&gt;{@code value} - Value for the corresponding &apos;font-family&apos; CSS style
            ///       (e.g. &apos;Tahoma, Arial, sans-serif&apos;)
            /// &lt;/ul&gt;</summary>
            /// <param name="button" type="!goog.ui.Select">Font menu button.</param>
            /// <param name="fonts" type="!Array.{caption: string|value: string}">Array of
            ///     font descriptors.</param>
        }, 
        
        addFont: function(button, caption, value) {
            /// <summary>Adds a menu item to the given font menu button.  The first font listed in
            /// the {@code value} argument is considered the font ID, so adding two items
            /// whose CSS style starts with the same font may lead to unpredictable results.</summary>
            /// <param name="button" type="!goog.ui.Select">Font menu button.</param>
            /// <param name="caption" type="string">Caption to show for the font menu.</param>
            /// <param name="value" type="string">Value for the corresponding &apos;font-family&apos; CSS style.</param>
        }, 
        
        addFontSizes: function(button, sizes) {
            /// <summary>Bulk-adds font sizes to the given font size menu button.  The argument must
            /// be an array of font size descriptor objects, each of which must have the
            /// following attributes:
            /// &lt;ul&gt;
            ///   &lt;li&gt;{@code caption} - Caption to show in the font size menu (e.g. &apos;Huge&apos;)
            ///   &lt;li&gt;{@code value} - Value for the corresponding HTML font size (e.g. 6)
            /// &lt;/ul&gt;</summary>
            /// <param name="button" type="!goog.ui.Select">Font size menu button.</param>
            /// <param name="sizes" type="!Array.{caption: string|value:number}">Array of font
            ///     size descriptors.</param>
        }, 
        
        addFontSize: function(button, caption, value) {
            /// <summary>Adds a menu item to the given font size menu button.  The {@code value}
            /// argument must be a legacy HTML font size in the 0-7 range.</summary>
            /// <param name="button" type="!goog.ui.Select">Font size menu button.</param>
            /// <param name="caption" type="string">Caption to show in the font size menu.</param>
            /// <param name="value" type="number">Value for the corresponding HTML font size.</param>
        }, 
        
        getPxFromLegacySize: function(fontSize) {
            /// <summary>Converts a legacy font size specification into an equivalent pixel size.
            /// For example, {@code &amp;lt;font size=&quot;6&quot;&amp;gt;} is {@code font-size: 32px;}, etc.</summary>
            /// <param name="fontSize" type="number">Legacy font size spec in the 0-7 range.</param>
            /// <returns type="number">Equivalent pixel size.</returns>
        }, 
        
        getLegacySizeFromPx: function(px) {
            /// <summary>Converts a pixel font size specification into an equivalent legacy size.
            /// For example, {@code font-size: 32px;} is {@code &amp;lt;font size=&quot;6&quot;&amp;gt;}, etc.
            /// If the given pixel size doesn&apos;t exactly match one of the legacy sizes, -1 is
            /// returned.</summary>
            /// <param name="px" type="number">Pixel font size.</param>
            /// <returns type="number">Equivalent legacy size spec in the 0-7 range, or -1 if none
            ///     exists.</returns>
        }, 
        
        addFormatOptions: function(button, formats) {
            /// <summary>Bulk-adds format options to the given &quot;Format block&quot; menu button.  The
            /// argument must be an array of format option descriptor objects, each of
            /// which must have the following attributes:
            /// &lt;ul&gt;
            ///   &lt;li&gt;{@code caption} - Caption to show in the menu (e.g. &apos;Minor heading&apos;)
            ///   &lt;li&gt;{@code command} - Corresponding {@link goog.dom.TagName} (e.g.
            ///       &apos;H4&apos;)
            /// &lt;/ul&gt;</summary>
            /// <param name="button" type="!goog.ui.Select">&quot;Format block&quot; menu button.</param>
            /// <param name="formats" type="!Array.{caption: string|command: goog.dom.TagName}">Array
            ///     of format option descriptors.</param>
        }, 
        
        addFormatOption: function(button, caption, tag) {
            /// <summary>Adds a menu item to the given &quot;Format block&quot; menu button.</summary>
            /// <param name="button" type="!goog.ui.Select">&quot;Format block&quot; menu button.</param>
            /// <param name="caption" type="string">Caption to show in the menu.</param>
            /// <param name="tag" type="goog.dom.TagName">Corresponding block format tag.</param>
        }, 
        
        makeToolbar: function(items, elem, opt_isRightToLeft) {
            /// <summary>Creates a {@link goog.ui.Toolbar} containing the specified set of
            /// toolbar buttons, and renders it into the given parent element.  Each
            /// item in the {@code items} array must a {@link goog.ui.Control}.</summary>
            /// <param name="items" type="!Array.goog.ui.Control">Toolbar items; each must
            ///     be a {@link goog.ui.Control}.</param>
            /// <param name="elem" type="!Element">Toolbar parent element.</param>
            /// <param name="opt_isRightToLeft" type="boolean=">Whether the editor chrome is
            ///     right-to-left; defaults to the directionality of the toolbar parent
            ///     element.</param>
            /// <returns type="!goog.ui.Toolbar">Editor toolbar, rendered into the given parent
            ///     element.</returns>
        }, 
        
        makeButton: function(id, tooltip, caption, opt_classNames, opt_renderer, opt_domHelper) {
            /// <summary>Creates a toolbar button with the given ID, tooltip, and caption.  Applies
            /// any custom CSS class names to the button&apos;s caption element.</summary>
            /// <param name="id" type="string">Button ID; must equal a {@link goog.editor.Command} for
            ///     built-in buttons, anything else for custom buttons.</param>
            /// <param name="tooltip" type="string">Tooltip to be shown on hover.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Button caption.</param>
            /// <param name="opt_classNames" type="string=">CSS class name(s) to apply to the caption
            ///     element.</param>
            /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Button renderer; defaults to
            ///     {@link goog.ui.ToolbarButtonRenderer} if unspecified.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for DOM
            ///     creation; defaults to the current document if unspecified.</param>
            /// <returns type="!goog.ui.Button">A toolbar button.</returns>
        }, 
        
        makeToggleButton: function(id, tooltip, caption, opt_classNames, opt_renderer, opt_domHelper) {
            /// <summary>Creates a toggle button with the given ID, tooltip, and caption. Applies
            /// any custom CSS class names to the button&apos;s caption element. The button
            /// returned has checkbox-like toggle semantics.</summary>
            /// <param name="id" type="string">Button ID; must equal a {@link goog.editor.Command} for
            ///     built-in buttons, anything else for custom buttons.</param>
            /// <param name="tooltip" type="string">Tooltip to be shown on hover.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Button caption.</param>
            /// <param name="opt_classNames" type="string=">CSS class name(s) to apply to the caption
            ///     element.</param>
            /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Button renderer; defaults to
            ///     {@link goog.ui.ToolbarButtonRenderer} if unspecified.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for DOM
            ///     creation; defaults to the current document if unspecified.</param>
            /// <returns type="!goog.ui.Button">A toggle button.</returns>
        }, 
        
        makeMenuButton: function(id, tooltip, caption, opt_classNames, opt_renderer, opt_domHelper) {
            /// <summary>Creates a menu button with the given ID, tooltip, and caption. Applies
            /// any custom CSS class names to the button&apos;s caption element.  The button
            /// returned doesn&apos;t have an actual menu attached; use {@link
            /// goog.ui.MenuButton#setMenu} to attach a {@link goog.ui.Menu} to the
            /// button.</summary>
            /// <param name="id" type="string">Button ID; must equal a {@link goog.editor.Command} for
            ///     built-in buttons, anything else for custom buttons.</param>
            /// <param name="tooltip" type="string">Tooltip to be shown on hover.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Button caption.</param>
            /// <param name="opt_classNames" type="string=">CSS class name(s) to apply to the caption
            ///     element.</param>
            /// <param name="opt_renderer" type="goog.ui.ButtonRenderer=">Button renderer; defaults to
            ///     {@link goog.ui.ToolbarMenuButtonRenderer} if unspecified.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for DOM
            ///     creation; defaults to the current document if unspecified.</param>
            /// <returns type="!goog.ui.MenuButton">A menu button.</returns>
        }, 
        
        makeSelectButton: function(id, tooltip, caption, opt_classNames, opt_renderer, opt_domHelper) {
            /// <summary>Creates a select button with the given ID, tooltip, and caption. Applies
            /// any custom CSS class names to the button&apos;s root element.  The button
            /// returned doesn&apos;t have an actual menu attached; use {@link
            /// goog.ui.Select#setMenu} to attach a {@link goog.ui.Menu} containing
            /// {@link goog.ui.Option}s to the select button.</summary>
            /// <param name="id" type="string">Button ID; must equal a {@link goog.editor.Command} for
            ///     built-in buttons, anything else for custom buttons.</param>
            /// <param name="tooltip" type="string">Tooltip to be shown on hover.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Button caption; used as the
            ///     default caption when nothing is selected.</param>
            /// <param name="opt_classNames" type="string=">CSS class name(s) to apply to the button&apos;s
            ///     root element.</param>
            /// <param name="opt_renderer" type="goog.ui.MenuButtonRenderer=">Button renderer;
            ///     defaults to {@link goog.ui.ToolbarMenuButtonRenderer} if unspecified.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for DOM
            ///     creation; defaults to the current document if unspecified.</param>
            /// <returns type="!goog.ui.Select">A select button.</returns>
        }, 
        
        makeColorMenuButton: function(id, tooltip, caption, opt_classNames, opt_renderer, opt_domHelper) {
            /// <summary>Creates a color menu button with the given ID, tooltip, and caption.
            /// Applies any custom CSS class names to the button&apos;s caption element.  The
            /// button is created with a default color menu containing standard color
            /// palettes.</summary>
            /// <param name="id" type="string">Button ID; must equal a {@link goog.editor.Command} for
            ///     built-in toolbar buttons, but can be anything else for custom buttons.</param>
            /// <param name="tooltip" type="string">Tooltip to be shown on hover.</param>
            /// <param name="caption" type="goog.ui.ControlContent">Button caption.</param>
            /// <param name="opt_classNames" type="string=">CSS class name(s) to apply to the caption
            ///     element.</param>
            /// <param name="opt_renderer" type="goog.ui.ColorMenuButtonRenderer=">Button renderer;
            ///     defaults to {@link goog.ui.ToolbarColorMenuButtonRenderer}
            ///     if unspecified.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">DOM helper, used for DOM
            ///     creation; defaults to the current document if unspecified.</param>
            /// <returns type="!goog.ui.ColorMenuButton">A color menu button.</returns>
        }
        
    };

    var $x = window.goog.ui.editor.ToolbarFactory;
    $x.__namespace = "true";
    $x.__typeName = "goog.ui.editor.ToolbarFactory";
})(this);
