
/* vsdoc for goog.ui.emoji.PopupEmojiPicker */

(function (window) {
    window.goog.ui.emoji = window.goog.ui.emoji || {};

    window.goog.ui.emoji.PopupEmojiPicker = function(defaultImgUrl, opt_domHelper){
        /// <summary></summary>
        /// <param name="defaultImgUrl" type="string">Url of the img that should be used to fill up
        ///     the cells in the emoji table, to prevent jittering. Should be the same
        ///     size as the emoji.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <returns type="goog.ui.emoji.PopupEmojiPicker"/>
    };

    var $x = window.goog.ui.emoji.PopupEmojiPicker;
    $x.prototype = {
                
        addEmojiGroup: function(title, emojiGroup) {
            /// <summary>Adds a group of emoji to the picker.</summary>
            /// <param name="title" type="string|Element">Title for the group.</param>
            /// <param name="emojiGroup" type="Array.Array">A new group of emoji to be added. Each
            ///    internal array contains [emojiUrl, emojiId].</param>
        }, 
        
        setToggleMode: function(toggle) {
            /// <summary>Sets whether the emoji picker should toggle if it is already open.</summary>
            /// <param name="toggle" type="boolean">The toggle mode to use.</param>
        }, 
        
        getToggleMode: function() {
            /// <summary>Gets whether the emojipicker is in toggle mode</summary>
            /// <returns type="boolean">toggle.</returns>
        }, 
        
        setDelayedLoad: function(shouldDelay) {
            /// <summary>Sets whether loading of images should be delayed until after dom creation.
            /// Thus, this function must be called before {@link #createDom}. If set to true,
            /// the client must call {@link #loadImages} when they wish the images to be
            /// loaded.</summary>
            /// <param name="shouldDelay" type="boolean">Whether to delay loading the images.</param>
        }, 
        
        setFocusable: function(focusable) {
            /// <summary>Sets whether the emoji picker can accept focus.</summary>
            /// <param name="focusable" type="boolean">Whether the emoji picker should accept focus.</param>
        }, 
        
        setUrlPrefix: function(urlPrefix) {
            /// <summary>Sets the URL prefix for the emoji URLs.</summary>
            /// <param name="urlPrefix" type="string">Prefix that should be prepended to all URLs.</param>
        }, 
        
        setTabLocation: function(tabLocation) {
            /// <summary>Sets the location of the tabs in relation to the emoji grids. This should
            /// only be called before the picker has been rendered.</summary>
            /// <param name="tabLocation" type="goog.ui.TabPane.TabLocation">The location of the tabs.</param>
        }, 
        
        setNumRows: function(numRows) {
            /// <summary>Sets the number of rows per grid in the emoji picker. This should only be
            /// called before the picker has been rendered.</summary>
            /// <param name="numRows" type="number">Number of rows per grid.</param>
        }, 
        
        setNumColumns: function(numCols) {
            /// <summary>Sets the number of columns per grid in the emoji picker. This should only be
            /// called before the picker has been rendered.</summary>
            /// <param name="numCols" type="number">Number of columns per grid.</param>
        }, 
        
        setProgressiveRender: function(progressive) {
            /// <summary>Sets the progressive rendering aspect of this emojipicker. Must be called
            /// before createDom to have an effect.</summary>
            /// <param name="progressive" type="boolean">Whether the picker should render progressively.</param>
        }, 
        
        getNumEmojiGroups: function() {
            /// <summary>Returns the number of emoji groups in this picker.</summary>
            /// <returns type="number">The number of emoji groups in this picker.</returns>
        }, 
        
        loadImages: function() {
            /// <summary>Causes the emoji imgs to be loaded into the picker. Used for delayed loading.</summary>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        attach: function(element) {
            /// <summary>Attaches the popup emoji picker to an element.</summary>
            /// <param name="element" type="Element">The element to attach to.</param>
        }, 
        
        detach: function(element) {
            /// <summary>Detatches the popup emoji picker from an element.</summary>
            /// <param name="element" type="Element">The element to detach from.</param>
        }, 
        
        getEmojiPicker: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.emoji.EmojiPicker">The emoji picker instance.</returns>
        }, 
        
        getAutoHide: function() {
            /// <summary>Returns whether the Popup dismisses itself when the user clicks outside of
            /// it.</summary>
            /// <returns type="boolean">Whether the Popup autohides on an external click.</returns>
        }, 
        
        setAutoHide: function(autoHide) {
            /// <summary>Sets whether the Popup dismisses itself when the user clicks outside of it -
            /// must be called after the Popup has been created (in createDom()),
            /// otherwise it does nothing.</summary>
            /// <param name="autoHide" type="boolean">Whether to autohide on an external click.</param>
        }, 
        
        getAutoHideRegion: function() {
            /// <summary>Returns the region inside which the Popup dismisses itself when the user
            /// clicks, or null if it was not set. Null indicates the entire document is
            /// the autohide region.</summary>
            /// <returns type="Element">The DOM element for autohide, or null if it hasn&apos;t been
            ///     set.</returns>
        }, 
        
        setAutoHideRegion: function(element) {
            /// <summary>Sets the region inside which the Popup dismisses itself when the user
            /// clicks - must be called after the Popup has been created (in createDom()),
            /// otherwise it does nothing.</summary>
            /// <param name="element" type="Element">The DOM element for autohide.</param>
        }, 
        
        getPopup: function() {
            /// <summary>Returns the {@link goog.ui.PopupBase} from this picker. Returns null if the
            /// popup has not yet been created.
            /// 
            /// NOTE: This should *ONLY* be called from tests. If called before createDom(),
            /// this should return null.</summary>
            /// <returns type="goog.ui.PopupBase?">The popup, or null if it hasn&apos;t been created.</returns>
        }, 
        
        getLastTarget: function() {
            /// <summary></summary>
            /// <returns type="Element">The last element that triggered the popup.</returns>
        }, 
        
        getSelectedEmoji: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.emoji.Emoji">The currently selected emoji.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.emoji.PopupEmojiPicker";
})(this);
