
/* vsdoc for goog.ui.equation.ImageRenderer */

(function (window) {
    window.goog.ui.equation = window.goog.ui.equation || {};

    window.goog.ui.equation.ImageRenderer = {
        /// <summary></summary>
        /// <field name="MAX_EQUATION_LENGTH" type="number">The longest equation which may be displayed, in characters.</field>
        /// <field name="EE_IMG_CLASS" type="string">Class to put on our equations IMG elements.</field>
        /// <field name="EE_IMG_ATTR" type="string">Non-standard to put on our equations IMG elements. Useful when classes need
        /// to be scrubbed from the user-generated HTML, but non-standard attributes
        /// can be white-listed.</field>
        /// <field name="EE_IMG_VERTICAL_ALIGN" type="string">Vertical alignment for the equations IMG elements.</field>
        /// <field name="BACKGROUND_COLOR" type="string">The default background color as used in the img url, which is fully
        /// transparent white.</field>
        /// <field name="FOREGROUND_COLOR" type="string">The default foreground color as used in the img url, which is black.</field>
        /// <field name="NO_RESIZE_IMG_CLASS" type="string">Class to put on IMG elements to keep the resize property bubble from
        /// appearing. This is different from PLACEHOLDER_IMG_CLASS because it&apos;s
        /// reasonable in some cases to be able to resize a placeholder (which should
        /// be reflected when the placeholder is replaced with the other content).</field>
        /// <returns type="goog.ui.equation.ImageRenderer"/>
                
        getImageUrl: function(equation) {
            /// <summary>Returns the equation image src url given the equation.</summary>
            /// <param name="equation" type="string">The equation.</param>
            /// <returns type="string">The equation image src url (empty string in case the
            ///   equation was empty).</returns>
        }, 
        
        getEquationFromImageUrl: function(imageUrl) {
            /// <summary>Returns the equation string src for given image url.</summary>
            /// <param name="imageUrl" type="string">The image url.</param>
            /// <returns type="string?">The equation string, null if imageUrl cannot be parsed.</returns>
        }, 
        
        getEquationFromImage: function(equationNode) {
            /// <summary>Gets the equation string from the given equation IMG node. Returns empty
            /// string if the src attribute of the is not a valid equation url.</summary>
            /// <param name="equationNode" type="Element">The equation IMG element.</param>
            /// <returns type="string">The equation string.</returns>
        }, 
        
        isEquationElement: function(node) {
            /// <summary>Checks whether given node is an equation element.</summary>
            /// <param name="node" type="Node">The node to check.</param>
            /// <returns type="boolean">Whether given node is an equation element.</returns>
        }, 
        
        getHtml: function(equation) {
            /// <summary>Returns the html for the html image tag for the given equation.</summary>
            /// <param name="equation" type="string">The equation.</param>
            /// <returns type="string">The html code to embed in the document.</returns>
        }, 
        
        isEquationTooLong: function(equation) {
            /// <summary>Checks whether equation is too long to be displayed.</summary>
            /// <param name="equation" type="string">The equation to test.</param>
            /// <returns type="boolean">Whether the equation is too long.</returns>
        }
        
    };

    var $x = window.goog.ui.equation.ImageRenderer;
    $x.__namespace = "true";
    $x.__typeName = "goog.ui.equation.ImageRenderer";
})(this);
