
/* vsdoc for goog.ui.media.MediaModel */

(function (window) {
    window.goog.ui.media = window.goog.ui.media || {};

    window.goog.ui.media.MediaModel = function(opt_url, opt_caption, opt_description, opt_type, opt_medium, opt_duration, opt_width, opt_height){
        /// <summary></summary>
        /// <param name="opt_url" type="string=">An optional URL of the media.</param>
        /// <param name="opt_caption" type="string=">An optional caption of the media.</param>
        /// <param name="opt_description" type="string=">An optional description of the media.</param>
        /// <param name="opt_type" type="goog.ui.media.MediaModel.MimeType=">The type of the media.</param>
        /// <param name="opt_medium" type="goog.ui.media.MediaModel.Medium=">The medium of the media.</param>
        /// <param name="opt_duration" type="number=">The duration of the media in seconds.</param>
        /// <param name="opt_width" type="number=">The width of the media in pixels.</param>
        /// <param name="opt_height" type="number=">The height of the media in pixels.</param>
        /// <field name="MimeType" type="">The supported media mime types, a subset of the media types found here:
        /// {@link http://www.iana.org/assignments/media-types/} and here
        /// {@link http://en.wikipedia.org/wiki/Internet_media_type}</field>
        /// <field name="Medium" type="">Supported mediums, found here:
        /// {@link http://video.search.yahoo.com/mrss}</field>
        /// <returns type="goog.ui.media.MediaModel"/>
    };

    var $x = window.goog.ui.media.MediaModel;
    $x.prototype = {
                
        getUrl: function() {
            /// <summary>Gets the URL of this media.</summary>
            /// <returns type="string|undefined">The URL of the media.</returns>
        }, 
        
        setUrl: function(url) {
            /// <summary>Sets the URL of this media.</summary>
            /// <param name="url" type="string">The URL of the media.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getCaption: function() {
            /// <summary>Gets the caption of this media.</summary>
            /// <returns type="string|undefined">The caption of the media.</returns>
        }, 
        
        setCaption: function(caption) {
            /// <summary>Sets the caption of this media.</summary>
            /// <param name="caption" type="string">The caption of the media.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getType: function() {
            /// <summary>Gets the media mime type.</summary>
            /// <returns type="goog.ui.media.MediaModel.MimeType|undefined">The media mime type.</returns>
        }, 
        
        setType: function(type) {
            /// <summary>Sets the media mime type.</summary>
            /// <param name="type" type="goog.ui.media.MediaModel.MimeType">The media mime type.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getMedium: function() {
            /// <summary>Gets the media medium.</summary>
            /// <returns type="goog.ui.media.MediaModel.Medium|undefined">The media medium.</returns>
        }, 
        
        setMedium: function(medium) {
            /// <summary>Sets the media medium.</summary>
            /// <param name="medium" type="goog.ui.media.MediaModel.Medium">The media medium.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getDescription: function() {
            /// <summary>Gets the description of this media.</summary>
            /// <returns type="string|undefined">The description of the media.</returns>
        }, 
        
        setDescription: function(description) {
            /// <summary>Sets the description of this media.</summary>
            /// <param name="description" type="string">The description of the media.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getThumbnails: function() {
            /// <summary>Gets the thumbnail urls.</summary>
            /// <returns type="Array.goog.ui.media.MediaModel.Thumbnail">The list of thumbnails.</returns>
        }, 
        
        setThumbnails: function(thumbnails) {
            /// <summary>Sets the thumbnail list.</summary>
            /// <param name="thumbnails" type="Array.goog.ui.media.MediaModel.Thumbnail">The list of
            ///     thumbnail.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getDuration: function() {
            /// <summary>Gets the duration of the media.</summary>
            /// <returns type="number|undefined">The duration in seconds.</returns>
        }, 
        
        setDuration: function(duration) {
            /// <summary>Sets duration of the media.</summary>
            /// <param name="duration" type="number">The duration of the media, in seconds.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getWidth: function() {
            /// <summary>Gets the width of the media in pixels.</summary>
            /// <returns type="number|undefined">The width in pixels.</returns>
        }, 
        
        setWidth: function(width) {
            /// <summary>Sets the width of the media.</summary>
            /// <param name="width" type="number">The width of the media, in pixels.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getHeight: function() {
            /// <summary>Gets the height of the media in pixels.</summary>
            /// <returns type="number|undefined">The height in pixels.</returns>
        }, 
        
        setHeight: function(height) {
            /// <summary>Sets the height of the media.</summary>
            /// <param name="height" type="number">The height of the media, in pixels.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getPlayer: function() {
            /// <summary>Gets the player data.</summary>
            /// <returns type="goog.ui.media.MediaModel.Player|undefined">The media player data.</returns>
        }, 
        
        setPlayer: function(player) {
            /// <summary>Sets the player data.</summary>
            /// <param name="player" type="goog.ui.media.MediaModel.Player">The media player data.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        getCategories: function() {
            /// <summary>Gets the categories of the media.</summary>
            /// <returns type="Array.goog.ui.media.MediaModel.Category">The categories of the
            ///     media.</returns>
        }, 
        
        setCategories: function(categories) {
            /// <summary>Sets the categories of the media</summary>
            /// <param name="categories" type="Array.goog.ui.media.MediaModel.Category">The categories
            ///     of the media.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        findCategoryWithScheme: function(scheme) {
            /// <summary>Finds the first category with the given scheme.</summary>
            /// <param name="scheme" type="string">The scheme to search for.</param>
            /// <returns type="goog.ui.media.MediaModel.Category">The category that has the
            ///     given scheme. May be null.</returns>
        }, 
        
        getCredits: function() {
            /// <summary>Gets the credits of the media.</summary>
            /// <returns type="!Array.goog.ui.media.MediaModel.Credit">The credits of the media.</returns>
        }, 
        
        setCredits: function(credits) {
            /// <summary>Sets the credits of the media</summary>
            /// <param name="credits" type="!Array.goog.ui.media.MediaModel.Credit">The credits of the
            ///     media.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself, used for chaining.</returns>
        }, 
        
        findCreditsWithRole: function(role) {
            /// <summary>Finds all credits with the given role.</summary>
            /// <param name="role" type="string">The role to search for.</param>
            /// <returns type="!Array.!goog.ui.media.MediaModel.Credit">An array of credits
            ///     with the given role. May be empty.</returns>
        }, 
        
        getSubTitles: function() {
            /// <summary>Gets the subtitles for the media.</summary>
            /// <returns type="Array.goog.ui.media.MediaModel.SubTitle">The subtitles.</returns>
        }, 
        
        setSubTitles: function(subtitles) {
            /// <summary>Sets the subtitles for the media</summary>
            /// <param name="subtitles" type="Array.goog.ui.media.MediaModel.SubTitle">The subtitles.</param>
            /// <returns type="!goog.ui.media.MediaModel">The object itself.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.media.MediaModel";
})(this);
