
/* vsdoc for goog.ui.media.Mp3 */

(function (window) {
    window.goog.ui.media = window.goog.ui.media || {};

    window.goog.ui.media.Mp3 = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <field name="MATCHER" type="RegExp">Regular expression to check if a given URL is a valid mp3 URL.
        /// 
        /// Copied from http://go/markdownlite.js.
        /// 
        /// NOTE(user): although it would be easier to use goog.string.endsWith(&apos;.mp3&apos;),
        /// in the future, we want to provide media inlining, which is basically getting
        /// a text and replacing all mp3 references with an mp3 player, so it makes sense
        /// to share the same regular expression to match everything.</field>
        /// <returns type="goog.ui.media.Mp3"/>
    };

    var $x = window.goog.ui.media.Mp3;
    $x.prototype = {
                
        newControl: function(dataModel, opt_domHelper) {
            /// <summary>A static convenient method to construct a goog.ui.media.Media control out of
            /// a mp3 URL. It checks the mp3 URL, sets it as the data model
            /// goog.ui.media.Mp3 renderer uses, sets the states supported by the renderer,
            /// and returns a Control that binds everything together. This is what you
            /// should be using for constructing Mp3 videos, except if you need more fine
            /// control over the configuration.</summary>
            /// <param name="dataModel" type="goog.ui.media.MediaModel">A media model that must contain
            ///     an mp3 url on {@code dataModel.getUrl}.</param>
            /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper, used for
            ///     document interaction.</param>
            /// <returns type="goog.ui.media.Media">A goog.ui.Control subclass with the mp3
            ///     renderer.</returns>
        }, 
        
        setFlashUrl: function(flashUrl) {
            /// <summary>A static method that sets which flash URL this class should use. Use this if
            /// you want to host your own flash mp3 player.</summary>
            /// <param name="flashUrl" type="string">The URL of the flash mp3 player.</param>
        }, 
        
        buildFlashUrl: function(mp3Url) {
            /// <summary>A static method that builds a URL that will contain the flash player that
            /// will play the {@code mp3Url}.</summary>
            /// <param name="mp3Url" type="string">The URL of the mp3 music.</param>
            /// <returns type="string">An URL of a flash player that will know how to play the
            ///     given {@code mp3Url}.</returns>
        }, 
        
        createDom: function(c) {
            /// <summary>Creates the initial DOM structure of a mp3 video, which is basically a
            /// the flash object pointing to a flash mp3 player.</summary>
            /// <param name="c" type="goog.ui.Control">The media control.</param>
            /// <returns type="Element">A DOM structure that represents the control.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.media.Mp3";
})(this);
