
/* vsdoc for goog.ui.media.YoutubeModel */

(function (window) {
    window.goog.ui.media = window.goog.ui.media || {};

    window.goog.ui.media.YoutubeModel = function(videoId, opt_caption, opt_description){
        /// <summary></summary>
        /// <param name="videoId" type="string">The youtube video id.</param>
        /// <param name="opt_caption" type="string=">An optional caption of the youtube video.</param>
        /// <param name="opt_description" type="string=">An optional description of the youtube
        ///     video.</param>
        /// <returns type="goog.ui.media.YoutubeModel"/>
    };

    var $x = window.goog.ui.media.YoutubeModel;
    $x.prototype = {
                
        newInstance: function(youtubeUrl, opt_caption, opt_description) {
            /// <summary>A auxiliary static method that parses a youtube URL, extracting the ID of the
            /// video, and builds a YoutubeModel.</summary>
            /// <param name="youtubeUrl" type="string">A youtube URL.</param>
            /// <param name="opt_caption" type="string=">An optional caption of the youtube video.</param>
            /// <param name="opt_description" type="string=">An optional description of the youtube
            ///     video.</param>
            /// <returns type="goog.ui.media.YoutubeModel">The data model that represents the
            ///     youtube URL.</returns>
        }, 
        
        buildUrl: function(videoId) {
            /// <summary>The opposite of {@code goog.ui.media.Youtube.newInstance}: it takes a videoId
            /// and returns a youtube URL.</summary>
            /// <param name="videoId" type="string">The youtube video ID.</param>
            /// <returns type="string">The youtube URL.</returns>
        }, 
        
        getThumbnailUrl: function(youtubeId) {
            /// <summary>A static auxiliary method that builds a static image URL with a preview of
            /// the youtube video.
            /// 
            /// NOTE(user): patterned after Gmail&apos;s gadgets/youtube,
            /// 
            /// TODO(user): how do I specify the width/height of the resulting image on the
            /// url ? is there an official API for http://ytimg.com ?</summary>
            /// <param name="youtubeId" type="string">The youtube video ID.</param>
            /// <returns type="string">An URL that contains an image with a preview of the youtube
            ///     movie.</returns>
        }, 
        
        getFlashUrl: function(videoId, opt_autoplay) {
            /// <summary>An auxiliary method that builds URL of the flash movie to be embedded,
            /// out of the youtube video id.</summary>
            /// <param name="videoId" type="string">The youtube video ID.</param>
            /// <param name="opt_autoplay" type="boolean=">Whether the flash movie should start playing
            ///     as soon as it is shown, or if it should show a &apos;play&apos; button.</param>
            /// <returns type="string">The flash URL to be embedded on the page.</returns>
        }, 
        
        getVideoId: function() {
            /// <summary>Gets the Youtube video id.</summary>
            /// <returns type="string">The Youtube video id.</returns>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.media.YoutubeModel";
})(this);
