
/* vsdoc for goog.ui.registry */

(function (window) {
    window.goog.ui = window.goog.ui || {};

    window.goog.ui.registry = {
        /// <summary></summary>
        /// <returns type="goog.ui.registry"/>
                
        getDefaultRenderer: function(componentCtor) {
            /// <summary>Given a {@link goog.ui.Component} constructor, returns an instance of its
            /// default renderer.  If the default renderer is a singleton, returns the
            /// singleton instance; otherwise returns a new instance of the renderer class.</summary>
            /// <param name="componentCtor" type="Function">Component constructor function (for example
            ///     {@code goog.ui.Button}).</param>
            /// <returns type="goog.ui.ControlRenderer?">Renderer instance (for example the
            ///     singleton instance of {@code goog.ui.ButtonRenderer}), or null if
            ///     no default renderer was found.</returns>
        }, 
        
        setDefaultRenderer: function(componentCtor, rendererCtor) {
            /// <summary>Sets the default renderer for the given {@link goog.ui.Component}
            /// constructor.</summary>
            /// <param name="componentCtor" type="Function">Component constructor function (for example
            ///     {@code goog.ui.Button}).</param>
            /// <param name="rendererCtor" type="Function">Renderer constructor function (for example
            ///     {@code goog.ui.ButtonRenderer}).</param>
        }, 
        
        getDecoratorByClassName: function(className) {
            /// <summary>Returns the {@link goog.ui.Component} instance created by the decorator
            /// factory function registered for the given CSS class name, or null if no
            /// decorator factory function was found.</summary>
            /// <param name="className" type="string">CSS class name.</param>
            /// <returns type="goog.ui.Component?">Component instance.</returns>
        }, 
        
        setDecoratorByClassName: function(className, decoratorFn) {
            /// <summary>Maps a CSS class name to a function that returns a new instance of
            /// {@link goog.ui.Component} or a subclass, suitable to decorate an element
            /// that has the specified CSS class.</summary>
            /// <param name="className" type="string">CSS class name.</param>
            /// <param name="decoratorFn" type="Function">No-argument function that returns a new
            ///     instance of a {@link goog.ui.Component} to decorate an element.</param>
        }, 
        
        getDecorator: function(element) {
            /// <summary>Returns an instance of {@link goog.ui.Component} or a subclass suitable to
            /// decorate the given element, based on its CSS class.</summary>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="goog.ui.Component?">Component to decorate the element (null if
            ///     none).</returns>
        }, 
        
        reset: function() {
            /// <summary>Resets the global renderer and decorator registry.</summary>
        }
        
    };

    var $x = window.goog.ui.registry;
    $x.__namespace = "true";
    $x.__typeName = "goog.ui.registry";
})(this);
