
/* vsdoc for goog.ui.style.app.MenuButtonRenderer */

(function (window) {
    window.goog.ui.style.app = window.goog.ui.style.app || {};

    window.goog.ui.style.app.MenuButtonRenderer = function(){
        /// <summary></summary>
        /// <field name="CSS_CLASS" type="string">Default CSS class to be applied to the root element of components rendered
        /// by this renderer.</field>
        /// <field name="IE6_CLASS_COMBINATIONS" type="Array.<Array.<string>>">Array of arrays of CSS classes that we want composite classes added and
        /// removed for in IE6 and lower as a workaround for lack of multi-class CSS
        /// selector support.</field>
        /// <returns type="goog.ui.style.app.MenuButtonRenderer"/>
    };

    var $x = window.goog.ui.style.app.MenuButtonRenderer;
    $x.prototype = {
                
        getAriaRole: function() {
            /// <summary>Returns the ARIA role to be applied to menu buttons, which
            /// have a menu attached to them.</summary>
            /// <returns type="goog.dom.a11y.Role">ARIA role.</returns>
        }, 
        
        getContentElement: function(element) {
            /// <summary>Takes the button&apos;s root element and returns the parent element of the
            /// button&apos;s contents.  Overrides the superclass implementation by taking
            /// the nested DIV structure of menu buttons into account.</summary>
            /// <param name="element" type="Element">Root element of the button whose content element
            ///     is to be returned.</param>
            /// <returns type="Element">The button&apos;s content element.</returns>
        }, 
        
        decorate: function(control, element) {
            /// <summary>Takes an element, decorates it with the menu button control, and returns
            /// the element.  Overrides {@link goog.ui.style.app.ButtonRenderer#decorate} by
            /// looking for a child element that can be decorated by a menu, and if it
            /// finds one, decorates it and attaches it to the menu button.</summary>
            /// <param name="control" type="goog.ui.Control">goog.ui.MenuButton to decorate the element.</param>
            /// <param name="element" type="Element">Element to decorate.</param>
            /// <returns type="Element">Decorated element.</returns>
        }, 
        
        createButton: function(content, dom) {
            /// <summary>Takes a text caption or existing DOM structure, and returns the content and
            /// a dropdown arrow element wrapped in a pseudo-rounded-corner box.  Creates
            /// the following DOM structure:
            ///  &lt;div class=&quot;goog-inline-block goog-button-outer-box&quot;&gt;
            ///    &lt;div class=&quot;goog-inline-block goog-button-inner-box&quot;&gt;
            ///      &lt;div class=&quot;goog-button-pos&quot;&gt;
            ///        &lt;div class=&quot;goog-button-top-shadow&quot;&gt;&amp;nbsp;&lt;/div&gt;
            ///        &lt;div class=&quot;goog-button-content&quot;&gt;
            ///          Contents...
            ///          &lt;div class=&quot;goog-menu-button-dropdown&quot;&gt; &lt;/div&gt;
            ///        &lt;/div&gt;
            ///      &lt;/div&gt;
            ///    &lt;/div&gt;
            ///  &lt;/div&gt;</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure to wrap
            ///     in a box.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Pseudo-rounded-corner box containing the content.</returns>
        }, 
        
        setContent: function(element, content) {
            /// <summary></summary>
            /// <param name="element" type=""></param>
            /// <param name="content" type=""></param>
        }, 
        
        createContentWithDropdown: function(content, dom) {
            /// <summary>Inserts dropdown element as last child of existing content.</summary>
            /// <param name="content" type="goog.ui.ControlContent">Text caption or DOM structure.</param>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document ineraction.</param>
            /// <returns type="Array.Node">DOM structure to be set as the button&apos;s content.</returns>
        }, 
        
        createDropdown: function(dom) {
            /// <summary>Returns an appropriately-styled DIV containing a dropdown arrow.
            /// Creates the following DOM structure:
            ///    &lt;div class=&quot;goog-menu-button-dropdown&quot;&gt; &lt;/div&gt;</summary>
            /// <param name="dom" type="goog.dom.DomHelper">DOM helper, used for document interaction.</param>
            /// <returns type="Element">Dropdown element.</returns>
        }, 
        
        getCssClass: function() {
            /// <summary>Returns the CSS class to be applied to the root element of components
            /// rendered using this renderer.</summary>
            /// <returns type="string">Renderer-specific CSS class.</returns>
        }, 
        
        getIe6ClassCombinations: function() {
            /// <summary></summary>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.style.app.MenuButtonRenderer";
})(this);
