
/* vsdoc for goog.ui.tree.BaseNode */

(function (window) {
    window.goog.ui.tree = window.goog.ui.tree || {};

    window.goog.ui.tree.BaseNode = function(html, opt_config, opt_domHelper){
        /// <summary></summary>
        /// <param name="html" type="string">The html content of the node label.</param>
        /// <param name="opt_config" type="Object=">The configuration for the tree. See
        ///    {@link goog.ui.tree.TreeControl.defaultConfig}. If not specified the
        ///    default config will be used.</param>
        /// <param name="opt_domHelper" type="goog.dom.DomHelper=">Optional DOM helper.</param>
        /// <field name="EventType" type="">The event types dispatched by this class.</field>
        /// <field name="allNodes" type="Object">Map of nodes in existence. Needed to route events to the appropriate nodes.
        /// Nodes are added to the map at {@link #enterDocument} time and removed at
        /// {@link #exitDocument} time.</field>
        /// <field name="remove" type=""></field>
        /// <field name="getTree" type="">Returns the tree.</field>
        /// <field name="deselect" type="">Originally it was intended to deselect the node but never worked.</field>
        /// <field name="getCalculatedIconClass" type="">Gets the calculated icon class.</field>
        /// <field name="onClick_" type="">Handles a click event.</field>
        /// <field name="getClientData" type="*"></field>
        /// <field name="setClientData" type="">Sets client data to associate with the node.</field>
        /// <returns type="goog.ui.tree.BaseNode"/>
    };

    var $x = window.goog.ui.tree.BaseNode;
    $x.prototype = {
                
        disposeInternal: function() {
            /// <summary></summary>
        }, 
        
        initAccessibility: function() {
            /// <summary>Adds roles and states.</summary>
        }, 
        
        createDom: function() {
            /// <summary></summary>
        }, 
        
        enterDocument: function() {
            /// <summary></summary>
        }, 
        
        exitDocument: function() {
            /// <summary></summary>
        }, 
        
        addChildAt: function(child, index, opt_render) {
            /// <summary>The method assumes that the child doesn&apos;t have parent node yet.
            /// The {@code opt_render} argument is not used. If the parent node is expanded,
            /// the child node&apos;s state will be the same as the parent&apos;s. Otherwise the
            /// child&apos;s DOM tree won&apos;t be created.</summary>
            /// <param name="child" type=""></param>
            /// <param name="index" type=""></param>
            /// <param name="opt_render" type=""></param>
        }, 
        
        add: function(child, opt_before) {
            /// <summary>Adds a node as a child to the current node.</summary>
            /// <param name="child" type="goog.ui.tree.BaseNode">The child to add.</param>
            /// <param name="opt_before" type="goog.ui.tree.BaseNode=">If specified, the new child is
            ///    added as a child before this one. If not specified, it&apos;s appended to the
            ///    end.</param>
            /// <returns type="goog.ui.tree.BaseNode">The added child.</returns>
        }, 
        
        removeChild: function(childNode, opt_unrender) {
            /// <summary>Removes a child. The caller is responsible for disposing the node.</summary>
            /// <param name="childNode" type="goog.ui.Component|string">The child to remove. Must be a
            ///     {@link goog.ui.tree.BaseNode}.</param>
            /// <param name="opt_unrender" type="boolean=">Unused. The child will always be unrendered.</param>
            /// <returns type="goog.ui.tree.BaseNode">The child that was removed.</returns>
        }, 
        
        getDepth: function() {
            /// <summary>Returns the depth of the node in the tree. Should not be overridden.</summary>
            /// <returns type="number">The non-negative depth of this node (the root is zero).</returns>
        }, 
        
        contains: function(node) {
            /// <summary>Returns true if the node is a descendant of this node</summary>
            /// <param name="node" type="goog.ui.tree.BaseNode">The node to check.</param>
            /// <returns type="boolean">True if the node is a descendant of this node, false
            ///    otherwise.</returns>
        }, 
        
        getChildren: function() {
            /// <summary>Returns the children of this node.</summary>
            /// <returns type="!Array.!goog.ui.tree.BaseNode">The children.</returns>
        }, 
        
        getFirstChild: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The first child of this node.</returns>
        }, 
        
        getLastChild: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The last child of this node.</returns>
        }, 
        
        getPreviousSibling: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The previous sibling of this node.</returns>
        }, 
        
        getNextSibling: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The next sibling of this node.</returns>
        }, 
        
        isLastSibling: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the node is the last sibling.</returns>
        }, 
        
        isSelected: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the node is selected.</returns>
        }, 
        
        select: function() {
            /// <summary>Selects the node.</summary>
        }, 
        
        setSelectedInternal: function(selected) {
            /// <summary>Called from the tree to instruct the node change its selection state.</summary>
            /// <param name="selected" type="boolean">The new selection state.</param>
        }, 
        
        getExpanded: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the node is expanded.</returns>
        }, 
        
        setExpandedInternal: function(expanded) {
            /// <summary>Sets the node to be expanded internally, without state change events.</summary>
            /// <param name="expanded" type="boolean">Whether to expand or close the node.</param>
        }, 
        
        setExpanded: function(expanded) {
            /// <summary>Sets the node to be expanded.</summary>
            /// <param name="expanded" type="boolean">Whether to expand or close the node.</param>
        }, 
        
        toggle: function() {
            /// <summary>Toggles the expanded state of the node.</summary>
        }, 
        
        expand: function() {
            /// <summary>Expands the node.</summary>
        }, 
        
        collapse: function() {
            /// <summary>Collapses the node.</summary>
        }, 
        
        collapseChildren: function() {
            /// <summary>Collapses the children of the node.</summary>
        }, 
        
        collapseAll: function() {
            /// <summary>Collapses the children and the node.</summary>
        }, 
        
        expandChildren: function() {
            /// <summary>Expands the children of the node.</summary>
        }, 
        
        expandAll: function() {
            /// <summary>Expands the children and the node.</summary>
        }, 
        
        reveal: function() {
            /// <summary>Expands the parent chain of this node so that it is visible.</summary>
        }, 
        
        setIsUserCollapsible: function(isCollapsible) {
            /// <summary>Sets whether the node will allow the user to collapse it.</summary>
            /// <param name="isCollapsible" type="boolean">Whether to allow node collapse.</param>
        }, 
        
        isUserCollapsible: function() {
            /// <summary></summary>
            /// <returns type="boolean">Whether the node is collapsible by user actions.</returns>
        }, 
        
        toHtml: function(sb) {
            /// <summary>Returns the html for the node.</summary>
            /// <param name="sb" type="goog.string.StringBuffer">A string buffer to append the HTML to.</param>
        }, 
        
        getRowHtml: function() {
            /// <summary></summary>
            /// <returns type="string">The html for the row.</returns>
        }, 
        
        getRowClassName: function() {
            /// <summary></summary>
            /// <returns type="string">The class name for the row.</returns>
        }, 
        
        getLabelHtml: function() {
            /// <summary></summary>
            /// <returns type="string">The html for the label.</returns>
        }, 
        
        getAfterLabelHtml: function() {
            /// <summary>Returns the html that appears after the label. This is useful if you want to
            /// put extra UI on the row of the label but not inside the anchor tag.</summary>
            /// <returns type="string">The html.</returns>
        }, 
        
        setAfterLabelHtml: function(html) {
            /// <summary>Sets the html that appears after the label. This is useful if you want to
            /// put extra UI on the row of the label but not inside the anchor tag.</summary>
            /// <param name="html" type="string">The html.</param>
        }, 
        
        getIconHtml: function() {
            /// <summary></summary>
            /// <returns type="string">The html for the icon.</returns>
        }, 
        
        getExpandIconHtml: function() {
            /// <summary></summary>
            /// <returns type="string">The source for the icon.</returns>
        }, 
        
        getExpandIconClass: function() {
            /// <summary></summary>
            /// <returns type="string">The class names of the icon used for expanding the node.</returns>
        }, 
        
        getLineStyle: function() {
            /// <summary></summary>
            /// <returns type="string">The line style.</returns>
        }, 
        
        getLineStyle2: function() {
            /// <summary></summary>
            /// <returns type="string">The line style.</returns>
        }, 
        
        getElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The element for the tree node.</returns>
        }, 
        
        getRowElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The row is the div that is used to draw the node without
            ///     the children.</returns>
        }, 
        
        getExpandIconElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The expanded icon element.</returns>
        }, 
        
        getIconElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The icon element.</returns>
        }, 
        
        getLabelElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The label element.</returns>
        }, 
        
        getAfterLabelElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The element after the label.</returns>
        }, 
        
        getChildrenElement: function() {
            /// <summary></summary>
            /// <returns type="Element">The div containing the children.</returns>
        }, 
        
        setIconClass: function(s) {
            /// <summary>Sets the icon class for the node.</summary>
            /// <param name="s" type="string">The icon class.</param>
        }, 
        
        getIconClass: function() {
            /// <summary>Gets the icon class for the node.</summary>
            /// <returns type="string">s The icon source.</returns>
        }, 
        
        setExpandedIconClass: function(s) {
            /// <summary>Sets the icon class for when the node is expanded.</summary>
            /// <param name="s" type="string">The expanded icon class.</param>
        }, 
        
        getExpandedIconClass: function() {
            /// <summary>Gets the icon class for when the node is expanded.</summary>
            /// <returns type="string">The class.</returns>
        }, 
        
        setText: function(s) {
            /// <summary>Sets the text of the label.</summary>
            /// <param name="s" type="string">The plain text of the label.</param>
        }, 
        
        getText: function() {
            /// <summary>Returns the text of the label. If the text was originally set as HTML, the
            /// return value is unspecified.</summary>
            /// <returns type="string">The plain text of the label.</returns>
        }, 
        
        setHtml: function(s) {
            /// <summary>Sets the html of the label.</summary>
            /// <param name="s" type="string">The html string for the label.</param>
        }, 
        
        getHtml: function() {
            /// <summary>Returns the html of the label.</summary>
            /// <returns type="string">The html string of the label.</returns>
        }, 
        
        setToolTip: function(s) {
            /// <summary>Sets the text of the tooltip.</summary>
            /// <param name="s" type="string">The tooltip text to set.</param>
        }, 
        
        getToolTip: function() {
            /// <summary>Returns the text of the tooltip.</summary>
            /// <returns type="?string">The tooltip text.</returns>
        }, 
        
        updateRow: function() {
            /// <summary>Updates the row styles.</summary>
        }, 
        
        updateExpandIcon: function() {
            /// <summary>Updates the expand icon of the node.</summary>
        }, 
        
        onMouseDown: function(e) {
            /// <summary>Handles mouse down event.</summary>
            /// <param name="e" type="!goog.events.BrowserEvent">The browser event.</param>
        }, 
        
        onDoubleClick_: function(e) {
            /// <summary>Handles a double click event.</summary>
            /// <param name="e" type="!goog.events.BrowserEvent">The browser event.</param>
        }, 
        
        onKeyDown: function(e) {
            /// <summary>Handles a key down event.</summary>
            /// <param name="e" type="!goog.events.BrowserEvent">The browser event.</param>
            /// <returns type="boolean">The handled value.</returns>
        }, 
        
        getLastShownDescendant: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The last shown descendant.</returns>
        }, 
        
        getNextShownNode: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The next node to show or null if there isn&apos;t
            ///     a next node to show.</returns>
        }, 
        
        getPreviousShownNode: function() {
            /// <summary></summary>
            /// <returns type="goog.ui.tree.BaseNode">The previous node to show.</returns>
        }, 
        
        getConfig: function() {
            /// <summary></summary>
            /// <returns type="Object">The configuration for the tree.</returns>
        }, 
        
        setTreeInternal: function(tree) {
            /// <summary>Internal method that is used to set the tree control on the node.</summary>
            /// <param name="tree" type="goog.ui.tree.TreeControl">The tree control.</param>
        }
        
    };

    $x.__class = "true";
    $x.__typeName = "goog.ui.tree.BaseNode";
})(this);
