
/* vsdoc for goog.uri.utils */

(function (window) {
    window.goog.uri = window.goog.uri || {};

    window.goog.uri.utils = {
        /// <summary></summary>
        /// <field name="QueryArray" type=""></field>
        /// <field name="QueryValue" type=""></field>
        /// <field name="ComponentIndex" type="">The index of each URI component in the return value of goog.uri.utils.split.</field>
        /// <field name="StandardQueryParam" type="">Standard supported query parameters.</field>
        /// <returns type="goog.uri.utils"/>
                
        buildFromEncodedParts: function(opt_scheme, opt_userInfo, opt_domain, opt_port, opt_path, opt_queryData, opt_fragment) {
            /// <summary>Builds a URI string from already-encoded parts.
            /// 
            /// No encoding is performed.  Any component may be omitted as either null or
            /// undefined.</summary>
            /// <param name="opt_scheme" type="?string=">The scheme such as &apos;http&apos;.</param>
            /// <param name="opt_userInfo" type="?string=">The user name before the &apos;@&apos;.</param>
            /// <param name="opt_domain" type="?string=">The domain such as &apos;www.google.com&apos;, already
            ///     URI-encoded.</param>
            /// <param name="opt_port" type="(string|number|null)=">The port number.</param>
            /// <param name="opt_path" type="?string=">The path, already URI-encoded.  If it is not
            ///     empty, it must begin with a slash.</param>
            /// <param name="opt_queryData" type="?string=">The URI-encoded query data.</param>
            /// <param name="opt_fragment" type="?string=">The URI-encoded fragment identifier.</param>
            /// <returns type="string">The fully combined URI.</returns>
        }, 
        
        split: function(uri) {
            /// <summary>Splits a URI into its component parts.
            /// 
            /// Each component can be accessed via the component indices; for example:
            /// &lt;pre&gt;
            /// goog.uri.utils.split(someStr)[goog.uri.utils.CompontentIndex.QUERY_DATA];
            /// &lt;/pre&gt;</summary>
            /// <param name="uri" type="string">The URI string to examine.</param>
            /// <returns type="!Array.string|undefined">Each component still URI-encoded.
            ///     Each component that is present will contain the encoded value, whereas
            ///     components that are not present will be undefined or empty, depending
            ///     on the browser&apos;s regular expression implementation.  Never null, since
            ///     arbitrary strings may still look like path names.</returns>
        }, 
        
        getScheme: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The protocol or scheme, or null if none.  Does not
            ///     include trailing colons or slashes.</returns>
        }, 
        
        getEffectiveScheme: function(uri) {
            /// <summary>Gets the effective scheme for the URL.  If the URL is relative then the
            /// scheme is derived from the page&apos;s location.</summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="string">The protocol or scheme, always lower case.</returns>
        }, 
        
        getUserInfoEncoded: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The user name still encoded, or null if none.</returns>
        }, 
        
        getUserInfo: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The decoded user info, or null if none.</returns>
        }, 
        
        getDomainEncoded: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The domain name still encoded, or null if none.</returns>
        }, 
        
        getDomain: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The decoded domain, or null if none.</returns>
        }, 
        
        getPort: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?number">The port number, or null if none.</returns>
        }, 
        
        getPathEncoded: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The path still encoded, or null if none. Includes the
            ///     leading slash, if any.</returns>
        }, 
        
        getPath: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The decoded path, or null if none.  Includes the leading
            ///     slash, if any.</returns>
        }, 
        
        getQueryData: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The query data still encoded, or null if none.  Does not
            ///     include the question mark itself.</returns>
        }, 
        
        getFragmentEncoded: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The fragment identifier, or null if none.  Does not
            ///     include the hash mark itself.</returns>
        }, 
        
        setFragmentEncoded: function(uri, fragment) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <param name="fragment" type="?string">The encoded fragment identifier, or null if none.
            ///     Does not include the hash mark itself.</param>
            /// <returns type="string">The URI with the fragment set.</returns>
        }, 
        
        getFragment: function(uri) {
            /// <summary></summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="?string">The decoded fragment identifier, or null if none.  Does
            ///     not include the hash mark.</returns>
        }, 
        
        getHost: function(uri) {
            /// <summary>Extracts everything up to the port of the URI.</summary>
            /// <param name="uri" type="string">The URI string.</param>
            /// <returns type="string">Everything up to and including the port.</returns>
        }, 
        
        getPathAndAfter: function(uri) {
            /// <summary>Extracts the path of the URL and everything after.</summary>
            /// <param name="uri" type="string">The URI string.</param>
            /// <returns type="string">The URI, starting at the path and including the query
            ///     parameters and fragment identifier.</returns>
        }, 
        
        removeFragment: function(uri) {
            /// <summary>Gets the URI with the fragment identifier removed.</summary>
            /// <param name="uri" type="string">The URI to examine.</param>
            /// <returns type="string">Everything preceding the hash mark.</returns>
        }, 
        
        haveSameDomain: function(uri1, uri2) {
            /// <summary>Ensures that two URI&apos;s have the exact same domain, scheme, and port.
            /// 
            /// Unlike the version in goog.Uri, this checks protocol, and therefore is
            /// suitable for checking against the browser&apos;s same-origin policy.</summary>
            /// <param name="uri1" type="string">The first URI.</param>
            /// <param name="uri2" type="string">The second URI.</param>
            /// <returns type="boolean">Whether they have the same domain and port.</returns>
        }, 
        
        buildQueryData: function(keysAndValues, opt_startIndex) {
            /// <summary>Builds a query data string from a sequence of alternating keys and values.
            /// Currently generates &quot;&amp;key&amp;&quot; for empty args.</summary>
            /// <param name="keysAndValues" type="goog.uri.utils.QueryArray">Alternating keys and
            ///     values.  See the typedef.</param>
            /// <param name="opt_startIndex" type="number=">A start offset into the arary, defaults to 0.</param>
            /// <returns type="string">The encoded query string, in the for &apos;a=1&amp;b=2&apos;.</returns>
        }, 
        
        buildQueryDataFromMap: function(map) {
            /// <summary>Builds a query data string from a map.
            /// Currently generates &quot;&amp;key&amp;&quot; for empty args.</summary>
            /// <param name="map" type="Object">An object where keys are URI-encoded parameter keys,
            ///     and the values are arbitrary types or arrays.  Keys with a null value
            ///     are dropped.</param>
            /// <returns type="string">The encoded query string, in the for &apos;a=1&amp;b=2&apos;.</returns>
        }, 
        
        appendParams: function(uri, var_args) {
            /// <summary>Appends URI parameters to an existing URI.
            /// 
            /// The variable arguments may contain alternating keys and values.  Keys are
            /// assumed to be already URI encoded.  The values should not be URI-encoded,
            /// and will instead be encoded by this function.
            /// &lt;pre&gt;
            /// appendParams(&apos;http://www.foo.com?existing=true&apos;,
            ///     &apos;key1&apos;, &apos;value1&apos;,
            ///     &apos;key2&apos;, &apos;value?willBeEncoded&apos;,
            ///     &apos;key3&apos;, [&apos;valueA&apos;, &apos;valueB&apos;, &apos;valueC&apos;],
            ///     &apos;key4&apos;, null);
            /// result: &apos;http://www.foo.com?existing=true&amp;&apos; +
            ///     &apos;key1=value1&amp;&apos; +
            ///     &apos;key2=value%3FwillBeEncoded&amp;&apos; +
            ///     &apos;key3=valueA&amp;key3=valueB&amp;key3=valueC&apos;
            /// &lt;/pre&gt;
            /// 
            /// A single call to this function will not exhibit quadratic behavior in IE,
            /// whereas multiple repeated calls may, although the effect is limited by
            /// fact that URL&apos;s generally can&apos;t exceed 2kb.</summary>
            /// <param name="uri" type="string">The original URI, which may already have query data.</param>
            /// <param name="var_args" type="...(goog.uri.utils.QueryArray|string|goog.uri.utils.QueryValue)">An array or argument list conforming to goog.uri.utils.QueryArray.</param>
            /// <returns type="string">The URI with all query parameters added.</returns>
        }, 
        
        appendParamsFromMap: function(uri, map) {
            /// <summary>Appends query parameters from a map.</summary>
            /// <param name="uri" type="string">The original URI, which may already have query data.</param>
            /// <param name="map" type="Object">An object where keys are URI-encoded parameter keys,
            ///     and the values are arbitrary types or arrays.  Keys with a null value
            ///     are dropped.</param>
            /// <returns type="string">The new parameters.</returns>
        }, 
        
        appendParam: function(uri, key, value) {
            /// <summary>Appends a single URI parameter.
            /// 
            /// Repeated calls to this can exhibit quadratic behavior in IE6 due to the
            /// way string append works, though it should be limited given the 2kb limit.</summary>
            /// <param name="uri" type="string">The original URI, which may already have query data.</param>
            /// <param name="key" type="string">The key, which must already be URI encoded.</param>
            /// <param name="value" type="*">The value, which will be stringized and encoded (assumed
            ///     not already to be encoded).</param>
            /// <returns type="string">The URI with the query parameter added.</returns>
        }, 
        
        hasParam: function(uri, keyEncoded) {
            /// <summary>Determines if the URI contains a specific key.
            /// 
            /// Performs no object instantiations.</summary>
            /// <param name="uri" type="string">The URI to process.  May contain a fragment
            ///     identifier.</param>
            /// <param name="keyEncoded" type="string">The URI-encoded key.  Case-sensitive.</param>
            /// <returns type="boolean">Whether the key is present.</returns>
        }, 
        
        getParamValue: function(uri, keyEncoded) {
            /// <summary>Gets the first value of a query parameter.</summary>
            /// <param name="uri" type="string">The URI to process.  May contain a fragment.</param>
            /// <param name="keyEncoded" type="string">The URI-encoded key.  Case-sensitive.</param>
            /// <returns type="?string">The first value of the parameter (URI-decoded), or null
            ///     if the parameter is not found.</returns>
        }, 
        
        getParamValues: function(uri, keyEncoded) {
            /// <summary>Gets all values of a query parameter.</summary>
            /// <param name="uri" type="string">The URI to process.  May contain a framgnet.</param>
            /// <param name="keyEncoded" type="string">The URI-encoded key.  Case-snsitive.</param>
            /// <returns type="!Array.string">All URI-decoded values with the given key.
            ///     If the key is not found, this will have length 0, but never be null.</returns>
        }, 
        
        removeParam: function(uri, keyEncoded) {
            /// <summary>Removes all instances of a query parameter.</summary>
            /// <param name="uri" type="string">The URI to process.  Must not contain a fragment.</param>
            /// <param name="keyEncoded" type="string">The URI-encoded key.</param>
            /// <returns type="string">The URI with all instances of the parameter removed.</returns>
        }, 
        
        setParam: function(uri, keyEncoded, value) {
            /// <summary>Replaces all existing definitions of a parameter with a single definition.
            /// 
            /// Repeated calls to this can exhibit quadratic behavior due to the need to
            /// find existing instances and reconstruct the string, though it should be
            /// limited given the 2kb limit.  Consider using appendParams to append multiple
            /// parameters in bulk.</summary>
            /// <param name="uri" type="string">The original URI, which may already have query data.</param>
            /// <param name="keyEncoded" type="string">The key, which must already be URI encoded.</param>
            /// <param name="value" type="*">The value, which will be stringized and encoded (assumed
            ///     not already to be encoded).</param>
            /// <returns type="string">The URI with the query parameter added.</returns>
        }, 
        
        appendPath: function(baseUri, path) {
            /// <summary>Generates a URI path using a given URI and a path with checks to
            /// prevent consecutive &quot;//&quot;. The baseUri passed in must not contain
            /// query or fragment identifiers. The path to append may not contain query or
            /// fragment identifiers.</summary>
            /// <param name="baseUri" type="string">URI to use as the base.</param>
            /// <param name="path" type="string">Path to append.</param>
            /// <returns type="string">Updated URI.</returns>
        }, 
        
        makeUnique: function(uri) {
            /// <summary>Sets the zx parameter of a URI to a random value.</summary>
            /// <param name="uri" type="string">Any URI.</param>
            /// <returns type="string">That URI with the &quot;zx&quot; parameter added or replaced to
            ///     contain a random string.</returns>
        }
        
    };

    var $x = window.goog.uri.utils;
    $x.__namespace = "true";
    $x.__typeName = "goog.uri.utils";
})(this);
