
/* vsdoc for goog.vec.Mat3 */

(function (window) {
    window.goog.vec = window.goog.vec || {};

    window.goog.vec.Mat3 = {
        /// <summary></summary>
        /// <field name="cloneFloat32" type="!goog.vec.Mat3.Float32">Creates a clone of a 3x3 matrix of Float32.</field>
        /// <field name="cloneFloat64" type="!goog.vec.Mat3.Float64">Creates a clone of a 3x3 matrix of Float64.</field>
        /// <field name="clone" type="!goog.vec.Mat3.Type">Creates a clone of a 3x3 matrix of Float32.</field>
        /// <returns type="goog.vec.Mat3"/>
                
        createFloat32: function() {
            /// <summary>Creates the array representation of a 3x3 matrix of Float32.
            /// The use of the array directly instead of a class reduces overhead.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Float32">The new matrix.</returns>
        }, 
        
        createFloat64: function() {
            /// <summary>Creates the array representation of a 3x3 matrix of Float64.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Float64">The new matrix.</returns>
        }, 
        
        createNumber: function() {
            /// <summary>Creates the array representation of a 3x3 matrix of Number.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Number">The new matrix.</returns>
        }, 
        
        create: function() {
            /// <summary>Creates the array representation of a 3x3 matrix of Float32.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Type">The new matrix.</returns>
        }, 
        
        createFloat32Identity: function() {
            /// <summary>Creates a 3x3 identity matrix of Float32.</summary>
            /// <returns type="!goog.vec.Mat3.Float32">The new 9 element array.</returns>
        }, 
        
        createFloat64Identity: function() {
            /// <summary>Creates a 3x3 identity matrix of Float64.</summary>
            /// <returns type="!goog.vec.Mat3.Float64">The new 9 element array.</returns>
        }, 
        
        createNumberIdentity: function() {
            /// <summary>Creates a 3x3 identity matrix of Number.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Number">The new 9 element array.</returns>
        }, 
        
        createIdentity: function() {
            /// <summary>Creates the array representation of a 3x3 matrix of Float32.
            /// The returned matrix is cleared to all zeros.</summary>
            /// <returns type="!goog.vec.Mat3.Type">The new 9 element array.</returns>
        }, 
        
        createFloat32FromArray: function(matrix) {
            /// <summary>Creates a 3x3 matrix of Float32 initialized from the given array.</summary>
            /// <param name="matrix" type="goog.vec.Mat3.AnyType">The array containing the
            ///     matrix values in column major order.</param>
            /// <returns type="!goog.vec.Mat3.Float32">The new, nine element array.</returns>
        }, 
        
        createFloat32FromValues: function(v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Creates a 3x3 matrix of Float32 initialized from the given values.</summary>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <returns type="!goog.vec.Mat3.Float32">The new, nine element array.</returns>
        }, 
        
        createFloat64FromArray: function(matrix) {
            /// <summary>Creates a 3x3 matrix of Float64 initialized from the given array.</summary>
            /// <param name="matrix" type="goog.vec.Mat3.AnyType">The array containing the
            ///     matrix values in column major order.</param>
            /// <returns type="!goog.vec.Mat3.Float64">The new, nine element array.</returns>
        }, 
        
        createFloat64FromValues: function(v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Creates a 3x3 matrix of Float64 initialized from the given values.</summary>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <returns type="!goog.vec.Mat3.Float64">The new, nine element array.</returns>
        }, 
        
        createFromArray: function(matrix) {
            /// <summary>Creates a 3x3 matrix of Float32 initialized from the given array.</summary>
            /// <param name="matrix" type="goog.vec.Mat3.Mat3Like">The array containing the
            ///     matrix values in column major order.</param>
            /// <returns type="!goog.vec.Mat3.Type">The new, nine element array.</returns>
        }, 
        
        createFromValues: function(v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Creates a 3x3 matrix of Float32 initialized from the given values.</summary>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <returns type="!goog.vec.Mat3.Type">The new, nine element array.</returns>
        }, 
        
        getElement: function(mat, row, column) {
            /// <summary>Retrieves the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix containing the value to
            ///     retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <returns type="number">The element value at the requested row, column indices.</returns>
        }, 
        
        setElement: function(mat, row, column, value) {
            /// <summary>Sets the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix containing the value to
            ///     retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <param name="value" type="number">The value to set at the requested row, column.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setFromValues: function(mat, v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Initializes the matrix from the set of values. Note the values supplied are
            /// in column major order.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the
            ///     values.</param>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setFromArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in column major order.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="values" type="goog.vec.Mat3.AnyType">The column major ordered
            ///     array of values to store in the matrix.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setFromRowMajorArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in row major order.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="values" type="goog.vec.Mat3.AnyType">The row major ordered array
            ///     of values to store in the matrix.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setDiagonalValues: function(mat, v00, v11, v22) {
            /// <summary>Sets the diagonal values of the matrix from the given values.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="v00" type="number">The values for (0, 0).</param>
            /// <param name="v11" type="number">The values for (1, 1).</param>
            /// <param name="v22" type="number">The values for (2, 2).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setDiagonal: function(mat, vec) {
            /// <summary>Sets the diagonal values of the matrix from the given vector.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector containing the values.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setColumnValues: function(mat, column, v0, v1, v2) {
            /// <summary>Sets the specified column with the supplied values.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to recieve the values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="v0" type="number">The value for row 0.</param>
            /// <param name="v1" type="number">The value for row 1.</param>
            /// <param name="v2" type="number">The value for row 2.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setColumn: function(mat, column, vec) {
            /// <summary>Sets the specified column with the value from the supplied array.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector elements for the column.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        getColumn: function(mat, column, vec) {
            /// <summary>Retrieves the specified column from the matrix into the given vector
            /// array.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix supplying the values.</param>
            /// <param name="column" type="number">The column to get the values from.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector elements to receive the
            ///     column.</param>
            /// <returns type="goog.vec.Vec3.AnyType">return vec so that operations can be
            ///     chained together.</returns>
        }, 
        
        setColumns: function(mat, vec0, vec1, vec2) {
            /// <summary>Sets the columns of the matrix from the set of vector elements.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The values for column 0.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The values for column 1.</param>
            /// <param name="vec2" type="goog.vec.Vec3.AnyType">The values for column 2.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        getColumns: function(mat, vec0, vec1, vec2) {
            /// <summary>Retrieves the column values from the given matrix into the given vector
            /// elements.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix supplying the columns.</param>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector to receive column 0.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The vector to receive column 1.</param>
            /// <param name="vec2" type="goog.vec.Vec3.AnyType">The vector to receive column 2.</param>
        }, 
        
        setRowValues: function(mat, row, v0, v1, v2) {
            /// <summary>Sets the row values from the supplied values.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="row" type="number">The index of the row to receive the values.</param>
            /// <param name="v0" type="number">The value for column 0.</param>
            /// <param name="v1" type="number">The value for column 1.</param>
            /// <param name="v2" type="number">The value for column 2.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        setRow: function(mat, row, vec) {
            /// <summary>Sets the row values from the supplied vector.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the row values.</param>
            /// <param name="row" type="number">The index of the row.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector containing the values.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        getRow: function(mat, row, vec) {
            /// <summary>Retrieves the row values into the given vector.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix supplying the values.</param>
            /// <param name="row" type="number">The index of the row supplying the values.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector to receive the row.</param>
            /// <returns type="goog.vec.Vec3.AnyType">return vec so that operations can be
            ///     chained together.</returns>
        }, 
        
        setRows: function(mat, vec0, vec1, vec2) {
            /// <summary>Sets the rows of the matrix from the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to receive the values.</param>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The values for row 0.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The values for row 1.</param>
            /// <param name="vec2" type="goog.vec.Vec3.AnyType">The values for row 2.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained together.</returns>
        }, 
        
        getRows: function(mat, vec0, vec1, vec2) {
            /// <summary>Retrieves the rows of the matrix into the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to supplying the values.</param>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector to receive row 0.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The vector to receive row 1.</param>
            /// <param name="vec2" type="goog.vec.Vec3.AnyType">The vector to receive row 2.</param>
        }, 
        
        makeZero: function(mat) {
            /// <summary>Makes the given 3x3 matrix the zero matrix.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so operations can be chained.</returns>
        }, 
        
        makeIdentity: function(mat) {
            /// <summary>Makes the given 3x3 matrix the identity matrix.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so operations can be chained.</returns>
        }, 
        
        addMat: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component addition of the matrices mat0 and mat1, storing
            /// the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.Mat3.AnyType">The first addend.</param>
            /// <param name="mat1" type="goog.vec.Mat3.AnyType">The second addend.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to
            ///     receive the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        subMat: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component subtraction of the matrices mat0 and mat1,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.Mat3.AnyType">The minuend.</param>
            /// <param name="mat1" type="goog.vec.Mat3.AnyType">The subtrahend.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        multScalar: function(mat, scalar, resultMat) {
            /// <summary>Multiplies matrix mat0 with the given scalar, storing the result
            /// into resultMat.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="scalar" type="number">The scalar value to multiple to each element of mat.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to receive
            ///     the results (may be mat).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        multMat: function(mat0, mat1, resultMat) {
            /// <summary>Multiplies the two matrices mat0 and mat1 using matrix multiplication,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.Mat3.AnyType">The first (left hand) matrix.</param>
            /// <param name="mat1" type="goog.vec.Mat3.AnyType">The second (right hand) matrix.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        transpose: function(mat, resultMat) {
            /// <summary>Transposes the given matrix mat storing the result into resultMat.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix to transpose.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to receive
            ///     the results (may be mat).</param>
            /// <returns type="goog.vec.Mat3.AnyType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        invert: function(mat0, resultMat) {
            /// <summary>Computes the inverse of mat0 storing the result into resultMat. If the
            /// inverse is defined, this function returns true, false otherwise.</summary>
            /// <param name="mat0" type="goog.vec.Mat3.AnyType">The matrix to invert.</param>
            /// <param name="resultMat" type="goog.vec.Mat3.AnyType">The matrix to receive
            ///     the result (may be mat0).</param>
            /// <returns type="boolean">True if the inverse is defined. If false is returned,
            ///     resultMat is not modified.</returns>
        }, 
        
        equals: function(mat0, mat1) {
            /// <summary>Returns true if the components of mat0 are equal to the components of mat1.</summary>
            /// <param name="mat0" type="goog.vec.Mat3.AnyType">The first matrix.</param>
            /// <param name="mat1" type="goog.vec.Mat3.AnyType">The second matrix.</param>
            /// <returns type="boolean">True if the the two matrices are equivalent.</returns>
        }, 
        
        multVec3: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed matrix into resultVec.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix supplying the transformation.</param>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector to transform.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        makeTranslate: function(mat, x, y) {
            /// <summary>Makes the given 3x3 matrix a translation matrix with x and y
            /// translation values.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="x" type="number">The translation along the x axis.</param>
            /// <param name="y" type="number">The translation along the y axis.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeScale: function(mat, x, y, z) {
            /// <summary>Makes the given 3x3 matrix a scale matrix with x, y, and z scale factors.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The 3x3 (9-element) matrix
            ///     array to receive the new scale matrix.</param>
            /// <param name="x" type="number">The scale along the x axis.</param>
            /// <param name="y" type="number">The scale along the y axis.</param>
            /// <param name="z" type="number">The scale along the z axis.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeRotate: function(mat, angle, ax, ay, az) {
            /// <summary>Makes the given 3x3 matrix a rotation matrix with the given rotation
            /// angle about the axis defined by the vector (ax, ay, az).</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <param name="ax" type="number">The x component of the rotation axis.</param>
            /// <param name="ay" type="number">The y component of the rotation axis.</param>
            /// <param name="az" type="number">The z component of the rotation axis.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeRotateX: function(mat, angle) {
            /// <summary>Makes the given 3x3 matrix a rotation matrix with the given rotation
            /// angle about the X axis.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeRotateY: function(mat, angle) {
            /// <summary>Makes the given 3x3 matrix a rotation matrix with the given rotation
            /// angle about the Y axis.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeRotateZ: function(mat, angle) {
            /// <summary>Makes the given 3x3 matrix a rotation matrix with the given rotation
            /// angle about the Z axis.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        rotate: function(mat, angle, x, y, z) {
            /// <summary>Rotate the given matrix by angle about the x,y,z axis.  Equivalent to:
            /// goog.vec.Mat3.multMat(
            ///     mat,
            ///     goog.vec.Mat3.makeRotate(goog.vec.Mat3.create(), angle, x, y, z),
            ///     mat);</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The angle in radians.</param>
            /// <param name="x" type="number">The x component of the rotation axis.</param>
            /// <param name="y" type="number">The y component of the rotation axis.</param>
            /// <param name="z" type="number">The z component of the rotation axis.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        rotateX: function(mat, angle) {
            /// <summary>Rotate the given matrix by angle about the x axis.  Equivalent to:
            /// goog.vec.Mat3.multMat(
            ///     mat,
            ///     goog.vec.Mat3.makeRotateX(goog.vec.Mat3.create(), angle),
            ///     mat);</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        rotateY: function(mat, angle) {
            /// <summary>Rotate the given matrix by angle about the y axis.  Equivalent to:
            /// goog.vec.Mat3.multMat(
            ///     mat,
            ///     goog.vec.Mat3.makeRotateY(goog.vec.Mat3.create(), angle),
            ///     mat);</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        rotateZ: function(mat, angle) {
            /// <summary>Rotate the given matrix by angle about the z axis.  Equivalent to:
            /// goog.vec.Mat3.multMat(
            ///     mat,
            ///     goog.vec.Mat3.makeRotateZ(goog.vec.Mat3.create(), angle),
            ///     mat);</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="angle" type="number">The angle in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        makeEulerZXZ: function(mat, theta1, theta2, theta3) {
            /// <summary>Makes the given 3x3 matrix a rotation matrix given Euler angles using
            /// the ZXZ convention.
            /// Given the euler angles [theta1, theta2, theta3], the rotation is defined as
            /// rotation = rotation_z(theta1) * rotation_x(theta2) * rotation_z(theta3),
            /// with theta1 in [0, 2 * pi], theta2 in [0, pi] and theta3 in [0, 2 * pi].
            /// rotation_x(theta) means rotation around the X axis of theta radians.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="theta1" type="number">The angle of rotation around the Z axis in radians.</param>
            /// <param name="theta2" type="number">The angle of rotation around the X axis in radians.</param>
            /// <param name="theta3" type="number">The angle of rotation around the Z axis in radians.</param>
            /// <returns type="goog.vec.Mat3.AnyType">return mat so that operations can be
            ///     chained.</returns>
        }, 
        
        toEulerZXZ: function(mat, euler, opt_theta2IsNegative) {
            /// <summary>Decomposes a rotation matrix into Euler angles using the ZXZ convention so
            /// that rotation = rotation_z(theta1) * rotation_x(theta2) * rotation_z(theta3),
            /// with theta1 in [0, 2 * pi], theta2 in [0, pi] and theta3 in [0, 2 * pi].
            /// rotation_x(theta) means rotation around the X axis of theta radians.</summary>
            /// <param name="mat" type="goog.vec.Mat3.AnyType">The matrix.</param>
            /// <param name="euler" type="goog.vec.Vec3.AnyType">The ZXZ Euler angles in
            ///     radians as [theta1, theta2, theta3].</param>
            /// <param name="opt_theta2IsNegative" type="boolean=">Whether theta2 is in [-pi, 0] instead
            ///     of the default [0, pi].</param>
            /// <returns type="goog.vec.Vec3.AnyType">return euler so that operations can be
            ///     chained together.</returns>
        }
        
    };

    var $x = window.goog.vec.Mat3;
    $x.__namespace = "true";
    $x.__typeName = "goog.vec.Mat3";
})(this);
