
/* vsdoc for goog.vec.Matrix3 */

(function (window) {
    window.goog.vec = window.goog.vec || {};

    window.goog.vec.Matrix3 = {
        /// <summary></summary>
        /// <field name="clone" type="goog.vec.Matrix3.Type">Creates a clone of a 3x3 matrix.</field>
        /// <returns type="goog.vec.Matrix3"/>
                
        create: function() {
            /// <summary>Creates the array representation of a 3x3 matrix. The use of the array
            /// directly eliminates any overhead associated with the class representation
            /// defined above. The returned matrix is cleared to all zeros.</summary>
            /// <returns type="goog.vec.Matrix3.Type">The new, nine element array.</returns>
        }, 
        
        createIdentity: function() {
            /// <summary>Creates the array representation of a 3x3 matrix. The use of the array
            /// directly eliminates any overhead associated with the class representation
            /// defined above. The returned matrix is initialized with the identity.</summary>
            /// <returns type="goog.vec.Matrix3.Type">The new, nine element array.</returns>
        }, 
        
        createFromArray: function(matrix) {
            /// <summary>Creates a 3x3 matrix initialized from the given array.</summary>
            /// <param name="matrix" type="goog.vec.ArrayType">The array containing the
            ///     matrix values in column major order.</param>
            /// <returns type="goog.vec.Matrix3.Type">The new, nine element array.</returns>
        }, 
        
        createFromValues: function(v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Creates a 3x3 matrix initialized from the given values.</summary>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <returns type="goog.vec.Matrix3.Type">The new, nine element array.</returns>
        }, 
        
        getElement: function(mat, row, column) {
            /// <summary>Retrieves the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     value to retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <returns type="number">The element value at the requested row, column indices.</returns>
        }, 
        
        setElement: function(mat, row, column, value) {
            /// <summary>Sets the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     value to retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <param name="value" type="number">The value to set at the requested row, column.</param>
        }, 
        
        setFromValues: function(mat, v00, v10, v20, v01, v11, v21, v02, v12, v22) {
            /// <summary>Initializes the matrix from the set of values. Note the values supplied are
            /// in column major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
        }, 
        
        setFromArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in column major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="values" type="goog.vec.ArrayType">The column major ordered
            ///     array of values to store in the matrix.</param>
        }, 
        
        setFromRowMajorArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in row major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="values" type="goog.vec.ArrayType">The row major ordered array
            ///     of values to store in the matrix.</param>
        }, 
        
        setDiagonalValues: function(mat, v00, v11, v22) {
            /// <summary>Sets the diagonal values of the matrix from the given values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="v00" type="number">The values for (0, 0).</param>
            /// <param name="v11" type="number">The values for (1, 1).</param>
            /// <param name="v22" type="number">The values for (2, 2).</param>
        }, 
        
        setDiagonal: function(mat, vec) {
            /// <summary>Sets the diagonal values of the matrix from the given vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector containing the
            ///     values.</param>
        }, 
        
        setColumnValues: function(mat, column, v0, v1, v2) {
            /// <summary>Sets the specified column with the supplied values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to recieve the
            ///     values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="v0" type="number">The value for row 0.</param>
            /// <param name="v1" type="number">The value for row 1.</param>
            /// <param name="v2" type="number">The value for row 2.</param>
        }, 
        
        setColumn: function(mat, column, vec) {
            /// <summary>Sets the specified column with the value from the supplied array.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector elements for the
            ///     column.</param>
        }, 
        
        getColumn: function(mat, column, vec) {
            /// <summary>Retrieves the specified column from the matrix into the given vector
            /// array.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     values.</param>
            /// <param name="column" type="number">The column to get the values from.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector elements to receive
            ///     the column.</param>
        }, 
        
        setColumns: function(mat, vec0, vec1, vec2) {
            /// <summary>Sets the columns of the matrix from the set of vector elements.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The values for column 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The values for column 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The values for column 2.</param>
        }, 
        
        getColumns: function(mat, vec0, vec1, vec2) {
            /// <summary>Retrieves the column values from the given matrix into the given vector
            /// elements.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     columns to retrieve.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 2.</param>
        }, 
        
        setRowValues: function(mat, row, v0, v1, v2) {
            /// <summary>Sets the row values from the supplied values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="row" type="number">The index of the row to receive the values.</param>
            /// <param name="v0" type="number">The value for column 0.</param>
            /// <param name="v1" type="number">The value for column 1.</param>
            /// <param name="v2" type="number">The value for column 2.</param>
        }, 
        
        setRow: function(mat, row, vec) {
            /// <summary>Sets the row values from the supplied vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     row values.</param>
            /// <param name="row" type="number">The index of the row.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector containing the values.</param>
        }, 
        
        getRow: function(mat, row, vec) {
            /// <summary>Retrieves the row values into the given vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     values.</param>
            /// <param name="row" type="number">The index of the row supplying the values.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector to receive the row.</param>
        }, 
        
        setRows: function(mat, vec0, vec1, vec2) {
            /// <summary>Sets the rows of the matrix from the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The values for row 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The values for row 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The values for row 2.</param>
        }, 
        
        getRows: function(mat, vec0, vec1, vec2) {
            /// <summary>Retrieves the rows of the matrix into the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to supplying
            ///     the values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The vector to receive row 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The vector to receive row 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The vector to receive row 2.</param>
        }, 
        
        setZero: function(mat) {
            /// <summary>Clears the given matrix to zero.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to clear.</param>
        }, 
        
        setIdentity: function(mat) {
            /// <summary>Sets the given matrix to the identity matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to set.</param>
        }, 
        
        add: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component addition of the matrices mat0 and mat1, storing
            /// the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first addend.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second addend.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to
            ///     receive the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        subtract: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component subtraction of the matrices mat0 and mat1,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The minuend.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The subtrahend.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        scale: function(mat0, scalar, resultMat) {
            /// <summary>Performs a component-wise multiplication of mat0 with the given scalar
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The matrix to scale.</param>
            /// <param name="scalar" type="number">The scalar value to multiple to each element of mat0.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be mat0).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        multMat: function(mat0, mat1, resultMat) {
            /// <summary>Multiplies the two matrices mat0 and mat1 using matrix multiplication,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first (left hand) matrix.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second (right hand)
            ///     matrix.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        transpose: function(mat, resultMat) {
            /// <summary>Transposes the given matrix mat storing the result into resultMat.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to transpose.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be mat).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        invert: function(mat0, resultMat) {
            /// <summary>Computes the inverse of mat0 storing the result into resultMat. If the
            /// inverse is defined, this function returns true, false otherwise.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The matrix to invert.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the result (may be mat0).</param>
            /// <returns type="boolean">True if the inverse is defined. If false is returned,
            ///     resultMat is not modified.</returns>
        }, 
        
        equals: function(mat0, mat1) {
            /// <summary>Returns true if the components of mat0 are equal to the components of mat1.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first matrix.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second matrix.</param>
            /// <returns type="boolean">True if the the two matrices are equivalent.</returns>
        }, 
        
        multVec3: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed matrix into resultVec.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector to transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        makeTranslate: function(mat, x, y) {
            /// <summary>Initializes the given 3x3 matrix as a translation matrix with x and y
            /// translation values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 3x3 (9-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="x" type="number">The translation along the x axis.</param>
            /// <param name="y" type="number">The translation along the y axis.</param>
        }, 
        
        makeScale: function(mat, x, y, z) {
            /// <summary>Initializes the given 3x3 matrix as a scale matrix with x, y and z scale
            /// factors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 3x3 (9-element) matrix
            ///     array to receive the new scale matrix.</param>
            /// <param name="x" type="number">The scale along the x axis.</param>
            /// <param name="y" type="number">The scale along the y axis.</param>
            /// <param name="z" type="number">The scale along the z axis.</param>
        }, 
        
        makeAxisAngleRotate: function(mat, angle, ax, ay, az) {
            /// <summary>Initializes the given 3x3 matrix as a rotation matrix with the given rotation
            /// angle about the axis defined by the vector (ax, ay, az).</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 3x3 (9-element) matrix
            ///     array to receive the new scale matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <param name="ax" type="number">The x component of the rotation axis.</param>
            /// <param name="ay" type="number">The y component of the rotation axis.</param>
            /// <param name="az" type="number">The z component of the rotation axis.</param>
        }
        
    };

    var $x = window.goog.vec.Matrix3;
    $x.__namespace = "true";
    $x.__typeName = "goog.vec.Matrix3";
})(this);
