
/* vsdoc for goog.vec.Matrix4 */

(function (window) {
    window.goog.vec = window.goog.vec || {};

    window.goog.vec.Matrix4 = {
        /// <summary></summary>
        /// <field name="clone" type="goog.vec.Matrix4.Type">Creates a clone of a 4x4 matrix.</field>
        /// <returns type="goog.vec.Matrix4"/>
                
        create: function() {
            /// <summary>Creates the array representation of a 4x4 matrix. The use of the array
            /// directly eliminates any overhead associated with the class representation
            /// defined above. The returned matrix is cleared to all zeros.</summary>
            /// <returns type="goog.vec.Matrix4.Type">The new, sixteen element array.</returns>
        }, 
        
        createIdentity: function() {
            /// <summary>Creates the array representation of a 4x4 matrix. The use of the array
            /// directly eliminates any overhead associated with the class representation
            /// defined above. The returned matrix is initialized with the identity</summary>
            /// <returns type="goog.vec.Matrix4.Type">The new, sixteen element array.</returns>
        }, 
        
        createFromArray: function(matrix) {
            /// <summary>Creates a 4x4 matrix initialized from the given array.</summary>
            /// <param name="matrix" type="goog.vec.ArrayType">The array containing the
            ///     matrix values in column major order.</param>
            /// <returns type="goog.vec.Matrix4.Type">The new, 16 element array.</returns>
        }, 
        
        createFromValues: function(v00, v10, v20, v30, v01, v11, v21, v31, v02, v12, v22, v32, v03, v13, v23, v33) {
            /// <summary>Creates a 4x4 matrix initialized from the given values.</summary>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v30" type="number">The values at (3, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v31" type="number">The values at (3, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <param name="v32" type="number">The values at (3, 2).</param>
            /// <param name="v03" type="number">The values at (0, 3).</param>
            /// <param name="v13" type="number">The values at (1, 3).</param>
            /// <param name="v23" type="number">The values at (2, 3).</param>
            /// <param name="v33" type="number">The values at (3, 3).</param>
            /// <returns type="goog.vec.Matrix4.Type">The new, 16 element array.</returns>
        }, 
        
        getElement: function(mat, row, column) {
            /// <summary>Retrieves the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     value to retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <returns type="number">The element value at the requested row, column indices.</returns>
        }, 
        
        setElement: function(mat, row, column, value) {
            /// <summary>Sets the element at the requested row and column.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     value to retrieve.</param>
            /// <param name="row" type="number">The row index.</param>
            /// <param name="column" type="number">The column index.</param>
            /// <param name="value" type="number">The value to set at the requested row, column.</param>
        }, 
        
        setFromValues: function(mat, v00, v10, v20, v30, v01, v11, v21, v31, v02, v12, v22, v32, v03, v13, v23, v33) {
            /// <summary>Initializes the matrix from the set of values. Note the values supplied are
            /// in column major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="v00" type="number">The values at (0, 0).</param>
            /// <param name="v10" type="number">The values at (1, 0).</param>
            /// <param name="v20" type="number">The values at (2, 0).</param>
            /// <param name="v30" type="number">The values at (3, 0).</param>
            /// <param name="v01" type="number">The values at (0, 1).</param>
            /// <param name="v11" type="number">The values at (1, 1).</param>
            /// <param name="v21" type="number">The values at (2, 1).</param>
            /// <param name="v31" type="number">The values at (3, 1).</param>
            /// <param name="v02" type="number">The values at (0, 2).</param>
            /// <param name="v12" type="number">The values at (1, 2).</param>
            /// <param name="v22" type="number">The values at (2, 2).</param>
            /// <param name="v32" type="number">The values at (3, 2).</param>
            /// <param name="v03" type="number">The values at (0, 3).</param>
            /// <param name="v13" type="number">The values at (1, 3).</param>
            /// <param name="v23" type="number">The values at (2, 3).</param>
            /// <param name="v33" type="number">The values at (3, 3).</param>
        }, 
        
        setFromArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in column major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="values" type="goog.vec.ArrayType">The column major ordered
            ///     array of values to store in the matrix.</param>
        }, 
        
        setFromRowMajorArray: function(mat, values) {
            /// <summary>Sets the matrix from the array of values stored in row major order.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="values" type="goog.vec.ArrayType">The row major ordered array of
            ///     values to store in the matrix.</param>
        }, 
        
        setDiagonalValues: function(mat, v00, v11, v22, v33) {
            /// <summary>Sets the diagonal values of the matrix from the given values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="v00" type="number">The values for (0, 0).</param>
            /// <param name="v11" type="number">The values for (1, 1).</param>
            /// <param name="v22" type="number">The values for (2, 2).</param>
            /// <param name="v33" type="number">The values for (3, 3).</param>
        }, 
        
        setDiagonal: function(mat, vec) {
            /// <summary>Sets the diagonal values of the matrix from the given vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector containing the
            ///     values.</param>
        }, 
        
        setColumnValues: function(mat, column, v0, v1, v2, v3) {
            /// <summary>Sets the specified column with the supplied values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to recieve the
            ///     values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="v0" type="number">The value for row 0.</param>
            /// <param name="v1" type="number">The value for row 1.</param>
            /// <param name="v2" type="number">The value for row 2.</param>
            /// <param name="v3" type="number">The value for row 3.</param>
        }, 
        
        setColumn: function(mat, column, vec) {
            /// <summary>Sets the specified column with the value from the supplied array.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="column" type="number">The column index to set the values on.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector of elements for the
            ///     column.</param>
        }, 
        
        getColumn: function(mat, column, vec) {
            /// <summary>Retrieves the specified column from the matrix into the given vector
            /// array.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     values.</param>
            /// <param name="column" type="number">The column to get the values from.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector of elements to
            ///     receive the column.</param>
        }, 
        
        setColumns: function(mat, vec0, vec1, vec2, vec3) {
            /// <summary>Sets the columns of the matrix from the set of vector elements.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The values for column 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The values for column 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The values for column 2.</param>
            /// <param name="vec3" type="goog.vec.ArrayType">The values for column 3.</param>
        }, 
        
        getColumns: function(mat, vec0, vec1, vec2, vec3) {
            /// <summary>Retrieves the column values from the given matrix into the given vector
            /// elements.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix containing the
            ///     columns to retrieve.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 2.</param>
            /// <param name="vec3" type="goog.vec.ArrayType">The vector elements to receive
            ///     column 3.</param>
        }, 
        
        setRowValues: function(mat, row, v0, v1, v2, v3) {
            /// <summary>Sets the row values from the supplied values.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="row" type="number">The index of the row to receive the values.</param>
            /// <param name="v0" type="number">The value for column 0.</param>
            /// <param name="v1" type="number">The value for column 1.</param>
            /// <param name="v2" type="number">The value for column 2.</param>
            /// <param name="v3" type="number">The value for column 3.</param>
        }, 
        
        setRow: function(mat, row, vec) {
            /// <summary>Sets the row values from the supplied vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     row values.</param>
            /// <param name="row" type="number">The index of the row.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector containing the
            ///     values.</param>
        }, 
        
        getRow: function(mat, row, vec) {
            /// <summary>Retrieves the row values into the given vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     values.</param>
            /// <param name="row" type="number">The index of the row supplying the values.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector to receive the
            ///     row.</param>
        }, 
        
        setRows: function(mat, vec0, vec1, vec2, vec3) {
            /// <summary>Sets the rows of the matrix from the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to receive the
            ///     values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The values for row 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The values for row 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The values for row 2.</param>
            /// <param name="vec3" type="goog.vec.ArrayType">The values for row 3.</param>
        }, 
        
        getRows: function(mat, vec0, vec1, vec2, vec3) {
            /// <summary>Retrieves the rows of the matrix into the supplied vectors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to supply the
            ///     values.</param>
            /// <param name="vec0" type="goog.vec.ArrayType">The vector to receive row 0.</param>
            /// <param name="vec1" type="goog.vec.ArrayType">The vector to receive row 1.</param>
            /// <param name="vec2" type="goog.vec.ArrayType">The vector to receive row 2.</param>
            /// <param name="vec3" type="goog.vec.ArrayType">The vector to receive row 3.</param>
        }, 
        
        setZero: function(mat) {
            /// <summary>Clears the given matrix to zero.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to clear.</param>
        }, 
        
        setIdentity: function(mat) {
            /// <summary>Sets the given matrix to the identity matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to set.</param>
        }, 
        
        add: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component addition of the matrix mat0 and mat1, storing
            /// the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first addend.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second addend.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to
            ///     receive the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        subtract: function(mat0, mat1, resultMat) {
            /// <summary>Performs a per-component subtraction of the matrix mat0 and mat1,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The minuend.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The subtrahend.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        scale: function(mat0, scalar, resultMat) {
            /// <summary>Performs a component-wise multiplication of mat0 with the given scalar
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The matrix to scale.</param>
            /// <param name="scalar" type="number">The scalar value to multiple to each element of mat0.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be mat0).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        multMat: function(mat0, mat1, resultMat) {
            /// <summary>Multiplies the two matrices mat0 and mat1 using matrix multiplication,
            /// storing the result into resultMat.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first (left hand) matrix.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second (right hand)
            ///     matrix.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be either mat0 or mat1).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        transpose: function(mat, resultMat) {
            /// <summary>Transposes the given matrix mat storing the result into resultMat.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to transpose.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the results (may be mat).</param>
            /// <returns type="goog.vec.ArrayType">return resultMat so that operations can be
            ///     chained together.</returns>
        }, 
        
        determinant: function(mat) {
            /// <summary>Computes the determinant of the matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to compute the
            ///     matrix for.</param>
            /// <returns type="number">The determinant of the matrix.</returns>
        }, 
        
        invert: function(mat, resultMat) {
            /// <summary>Computes the inverse of mat storing the result into resultMat. If the
            /// inverse is defined, this function returns true, false otherwise.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix to invert.</param>
            /// <param name="resultMat" type="goog.vec.ArrayType">The matrix to receive
            ///     the result (may be mat).</param>
            /// <returns type="boolean">True if the inverse is defined. If false is returned,
            ///     resultMat is not modified.</returns>
        }, 
        
        equals: function(mat0, mat1) {
            /// <summary>Returns true if the components of mat0 are equal to the components of mat1.</summary>
            /// <param name="mat0" type="goog.vec.ArrayType">The first matrix.</param>
            /// <param name="mat1" type="goog.vec.ArrayType">The second matrix.</param>
            /// <returns type="boolean">True if the the two matrices are equivalent.</returns>
        }, 
        
        multVec3: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec. The input vector is multiplied against the
            /// upper 3x4 matrix omitting the projective component.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The 3 element vector to
            ///     transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The 3 element vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        multVec3NoTranslate: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec. The input vector is multiplied against the
            /// upper 3x3 matrix omitting the projective component and translation
            /// components.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The 3 element vector to
            ///     transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The 3 element vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        multVec3Projective: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec. The input vector is multiplied against the
            /// full 4x4 matrix with the homogeneous divide applied to reduce the 4 element
            /// vector to a 3 element vector.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The 3 element vector to
            ///     transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The 3 element vector
            ///     to receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        multVec4: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector to transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        multVec3ToArray: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec. The input matrix is multiplied against the
            /// upper 3x4 matrix omitting the projective component.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The 3 element vector to
            ///     transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The 3 element vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        multVec4ToArray: function(mat, vec, resultVec) {
            /// <summary>Transforms the given vector with the given matrix storing the resulting,
            /// transformed vector into resultVec.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix supplying the
            ///     transformation.</param>
            /// <param name="vec" type="goog.vec.ArrayType">The vector to transform.</param>
            /// <param name="resultVec" type="goog.vec.ArrayType">The vector to
            ///     receive the results (may be vec).</param>
            /// <returns type="goog.vec.ArrayType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        makeTranslate: function(mat, x, y, z) {
            /// <summary>Initializes the given 4x4 matrix as a translation matrix with x, y and z
            /// translation factors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="x" type="number">The translation along the x axis.</param>
            /// <param name="y" type="number">The translation along the y axis.</param>
            /// <param name="z" type="number">The translation along the z axis.</param>
        }, 
        
        makeScale: function(mat, x, y, z) {
            /// <summary>Initializes the given 4x4 matrix as a scale matrix with x, y and z scale
            /// factors.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="x" type="number">The scale along the x axis.</param>
            /// <param name="y" type="number">The scale along the y axis.</param>
            /// <param name="z" type="number">The scale along the z axis.</param>
        }, 
        
        makeAxisAngleRotate: function(mat, angle, ax, ay, az) {
            /// <summary>Initializes the given 4x4 matrix as a rotation matrix with the given rotation
            /// angle about the axis defined by the vector (ax, ay, az).</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="angle" type="number">The rotation angle in radians.</param>
            /// <param name="ax" type="number">The x component of the rotation axis.</param>
            /// <param name="ay" type="number">The y component of the rotation axis.</param>
            /// <param name="az" type="number">The z component of the rotation axis.</param>
        }, 
        
        makeFrustum: function(mat, left, right, bottom, top, near, far) {
            /// <summary>Initializes the given 4x4 matrix as a perspective projection matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="left" type="number">The coordinate of the left clipping plane.</param>
            /// <param name="right" type="number">The coordinate of the right clipping plane.</param>
            /// <param name="bottom" type="number">The coordinate of the bottom clipping plane.</param>
            /// <param name="top" type="number">The coordinate of the top clipping plane.</param>
            /// <param name="near" type="number">The distance to the near clipping plane.</param>
            /// <param name="far" type="number">The distance to the far clipping plane.</param>
        }, 
        
        makePerspective: function(mat, fovy, aspect, near, far) {
            /// <summary>Initializes the given 4x4 matrix as a perspective projection matrix given a
            /// field of view and aspect ratio.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="fovy" type="number">The field of view along the y (vertical) axis in
            ///     radians.</param>
            /// <param name="aspect" type="number">The x (width) to y (height) aspect ratio.</param>
            /// <param name="near" type="number">The distance to the near clipping plane.</param>
            /// <param name="far" type="number">The distance to the far clipping plane.</param>
        }, 
        
        makeOrtho: function(mat, left, right, bottom, top, near, far) {
            /// <summary>Initializes the given 4x4 matrix as an orthographic projection matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The 4x4 (16-element) matrix
            ///     array to receive the new translation matrix.</param>
            /// <param name="left" type="number">The coordinate of the left clipping plane.</param>
            /// <param name="right" type="number">The coordinate of the right clipping plane.</param>
            /// <param name="bottom" type="number">The coordinate of the bottom clipping plane.</param>
            /// <param name="top" type="number">The coordinate of the top clipping plane.</param>
            /// <param name="near" type="number">The distance to the near clipping plane.</param>
            /// <param name="far" type="number">The distance to the far clipping plane.</param>
        }, 
        
        lookAt: function(viewMatrix, eyePt, centerPt, worldUpVec) {
            /// <summary>Updates a matrix representing the modelview matrix of a camera so that
            /// the camera is &apos;looking at&apos; the given center point.</summary>
            /// <param name="viewMatrix" type="goog.vec.ArrayType">The matrix.</param>
            /// <param name="eyePt" type="goog.vec.ArrayType">The position of the eye point
            ///     (camera origin).</param>
            /// <param name="centerPt" type="goog.vec.ArrayType">The point to aim the camera
            ///     at.</param>
            /// <param name="worldUpVec" type="goog.vec.ArrayType">The vector that
            ///     identifies the up direction for the camera.</param>
        }, 
        
        toLookAt: function(viewMatrix, eyePt, fwdVec, worldUpVec) {
            /// <summary>Decomposes a matrix into the lookAt vectors eyePt, fwdVec and worldUpVec.
            /// The matrix represents the modelview matrix of a camera. It is the inverse
            /// of lookAt except for the output of the fwdVec instead of centerPt.
            /// The centerPt itself cannot be recovered from a modelview matrix.</summary>
            /// <param name="viewMatrix" type="goog.vec.ArrayType">The matrix.</param>
            /// <param name="eyePt" type="goog.vec.ArrayType">The position of the eye point
            ///     (camera origin).</param>
            /// <param name="fwdVec" type="goog.vec.ArrayType">The vector describing where
            ///     the camera points to.</param>
            /// <param name="worldUpVec" type="goog.vec.ArrayType">The vector that
            ///     identifies the up direction for the camera.</param>
            /// <returns type="boolean">True if the method succeeds, false otherwise.
            ///     The method can only fail if the inverse of viewMatrix is not defined.</returns>
        }, 
        
        fromEulerZXZ: function(matrix, theta1, theta2, theta3) {
            /// <summary>Constructs a rotation matrix from its Euler angles using the ZXZ convention.
            /// Given the euler angles [theta1, theta2, theta3], the rotation is defined as
            /// rotation = rotation_z(theta1) * rotation_x(theta2) * rotation_z(theta3),
            /// where rotation_x(theta) means rotation around the X axis of theta radians.</summary>
            /// <param name="matrix" type="goog.vec.ArrayType">The rotation matrix.</param>
            /// <param name="theta1" type="number">The angle of rotation around the Z axis in radians.</param>
            /// <param name="theta2" type="number">The angle of rotation around the X axis in radians.</param>
            /// <param name="theta3" type="number">The angle of rotation around the Z axis in radians.</param>
        }, 
        
        toEulerZXZ: function(matrix, euler) {
            /// <summary>Decomposes a rotation matrix into Euler angles using the ZXZ convention.</summary>
            /// <param name="matrix" type="goog.vec.ArrayType">The rotation matrix.</param>
            /// <param name="euler" type="goog.vec.ArrayType">The ZXZ Euler angles in
            ///     radians. euler = [roll, tilt, pan].</param>
        }, 
        
        applyTranslate: function(mat, x, y, z) {
            /// <summary>Applies a translation by x,y,z to the given matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix.</param>
            /// <param name="x" type="number">The translation along the x axis.</param>
            /// <param name="y" type="number">The translation along the y axis.</param>
            /// <param name="z" type="number">The translation along the z axis.</param>
        }, 
        
        applyScale: function(mat, x, y, z) {
            /// <summary>Applies an x,y,z scale to the given matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix.</param>
            /// <param name="x" type="number">The x scale factor.</param>
            /// <param name="y" type="number">The y scale factor.</param>
            /// <param name="z" type="number">The z scale factor.</param>
        }, 
        
        applyRotate: function(mat, angle, x, y, z) {
            /// <summary>Applies a rotation by angle about the x,y,z axis to the given matrix.</summary>
            /// <param name="mat" type="goog.vec.ArrayType">The matrix.</param>
            /// <param name="angle" type="number">The angle in radians.</param>
            /// <param name="x" type="number">The x component of the rotation axis.</param>
            /// <param name="y" type="number">The y component of the rotation axis.</param>
            /// <param name="z" type="number">The z component of the rotation axis.</param>
        }
        
    };

    var $x = window.goog.vec.Matrix4;
    $x.__namespace = "true";
    $x.__typeName = "goog.vec.Matrix4";
})(this);
