
/* vsdoc for goog.vec.Quaternion */

(function (window) {
    window.goog.vec = window.goog.vec || {};

    window.goog.vec.Quaternion = {
        /// <summary></summary>
        /// <field name="createFloat32" type="!goog.vec.Quaternion.Float32">Creates a Float32 quaternion, initialized to zero.</field>
        /// <field name="createFloat64" type="goog.vec.Quaternion.Float64">Creates a Float64 quaternion, initialized to zero.</field>
        /// <field name="createNumber" type="goog.vec.Quaternion.Number">Creates a Number quaternion, initialized to zero.</field>
        /// <field name="createFloat32FromArray" type="!goog.vec.Quaternion.Float32">Creates a new Float32 quaternion initialized with the values from the
        /// supplied array.</field>
        /// <field name="createFloat64FromArray" type="!goog.vec.Quaternion.Float64">Creates a new Float64 quaternion initialized with the values from the
        /// supplied array.</field>
        /// <field name="createFloat32FromValues" type="!goog.vec.Quaternion.Float32">Creates a new Float32 quaternion initialized with the supplied values.</field>
        /// <field name="createFloat64FromValues" type="!goog.vec.Quaternion.Float64">Creates a new Float64 quaternion initialized with the supplied values.</field>
        /// <field name="cloneFloat32" type="goog.vec.Quaternion.Float32">Creates a clone of the given Float32 quaternion.</field>
        /// <field name="cloneFloat64" type="goog.vec.Quaternion.Float64">Creates a clone of the given Float64 quaternion.</field>
        /// <field name="setFromValues" type="!goog.vec.Vec4.AnyType">Initializes the quaternion with the given values.</field>
        /// <field name="setFromArray" type="!goog.vec.Quaternion.AnyType">Initializes the quaternion with the given array of values.</field>
        /// <field name="add" type="">Adds the two quaternions.</field>
        /// <field name="negate" type="">Negates a quaternion, storing the result into resultQuat.</field>
        /// <field name="scale" type="">Multiplies each component of quat0 with scalar storing the product into
        /// resultVec.</field>
        /// <field name="magnitudeSquared" type="number">Returns the square magnitude of the given quaternion.</field>
        /// <field name="magnitude" type="number">Returns the magnitude of the given quaternion.</field>
        /// <field name="normalize" type="">Normalizes the given quaternion storing the result into resultVec.</field>
        /// <field name="dot" type="number">Computes the dot (scalar) product of two quaternions.</field>
        /// <field name="nlerp" type="">Compute the simple linear interpolation of the two quaternions q0 and q1
        /// according to the coefficient t. The resulting quaternion is stored in
        /// resultVec.</field>
        /// <returns type="goog.vec.Quaternion"/>
                
        conjugate: function(quat, resultQuat) {
            /// <summary>Computes the conjugate of the quaternion in quat storing the result into
            /// resultQuat.</summary>
            /// <param name="quat" type="goog.vec.Quaternion.AnyType">The source quaternion.</param>
            /// <param name="resultQuat" type="goog.vec.Quaternion.AnyType">The quaternion to
            ///     receive the result.</param>
            /// <returns type="!goog.vec.Quaternion.AnyType">Return q so that
            ///     operations can be chained together.</returns>
        }, 
        
        concat: function(quat0, quat1, resultQuat) {
            /// <summary>Concatenates the two quaternions storing the result into resultQuat.</summary>
            /// <param name="quat0" type="goog.vec.Quaternion.AnyType">The first quaternion.</param>
            /// <param name="quat1" type="goog.vec.Quaternion.AnyType">The second quaternion.</param>
            /// <param name="resultQuat" type="goog.vec.Quaternion.AnyType">The quaternion to
            ///     receive the result.</param>
            /// <returns type="!goog.vec.Quaternion.AnyType">Return q so that
            ///     operations can be chained together.</returns>
        }, 
        
        fromAngleAxis: function(angle, axis, quat) {
            /// <summary>Generates a unit quaternion from the given angle-axis rotation pair.
            /// The rotation axis is not required to be a unit vector, but should
            /// have non-zero length.  The angle should be specified in radians.</summary>
            /// <param name="angle" type="number">The angle (in radians) to rotate about the axis.</param>
            /// <param name="axis" type="goog.vec.Quaternion.AnyType">Unit vector specifying the
            ///     axis of rotation.</param>
            /// <param name="quat" type="goog.vec.Quaternion.AnyType">Unit quaternion to store the
            ///     result.</param>
            /// <returns type="goog.vec.Quaternion.AnyType">Return q so that
            ///     operations can be chained together.</returns>
        }, 
        
        toAngleAxis: function(quat, axis) {
            /// <summary>Generates an angle-axis rotation pair from a unit quaternion.
            /// The quaternion is assumed to be of unit length.  The calculated
            /// values are returned via the passed &apos;axis&apos; object and the &apos;angle&apos;
            /// number returned by the function itself. The returned rotation axis
            /// is a non-zero length unit vector, and the returned angle is in
            /// radians in the range of [-PI, +PI].</summary>
            /// <param name="quat" type="goog.vec.Quaternion.AnyType">Unit quaternion to convert.</param>
            /// <param name="axis" type="goog.vec.Quaternion.AnyType">Vector to store the returned
            ///     rotation axis.</param>
            /// <returns type="number">angle Angle (in radians) to rotate about &apos;axis&apos;.
            ///     The range of the returned angle is [-PI, +PI].</returns>
        }, 
        
        fromRotationMatrix4: function(matrix, quat) {
            /// <summary>Generates the quaternion from the given rotation matrix.</summary>
            /// <param name="matrix" type="goog.vec.Quaternion.AnyType">The source matrix.</param>
            /// <param name="quat" type="goog.vec.Quaternion.AnyType">The resulting quaternion.</param>
            /// <returns type="!goog.vec.Quaternion.AnyType">Return q so that
            ///     operations can be chained together.</returns>
        }, 
        
        toRotationMatrix4: function(quat, matrix) {
            /// <summary>Generates the rotation matrix from the given quaternion.</summary>
            /// <param name="quat" type="goog.vec.Quaternion.AnyType">The source quaternion.</param>
            /// <param name="matrix" type="goog.vec.AnyType">The resulting matrix.</param>
            /// <returns type="!goog.vec.AnyType">Return resulting matrix so that
            ///     operations can be chained together.</returns>
        }, 
        
        slerp: function(q0, q1, t, resultQuat) {
            /// <summary>Computes the spherical linear interpolated value from the given quaternions
            /// q0 and q1 according to the coefficient t. The resulting quaternion is stored
            /// in resultQuat.</summary>
            /// <param name="q0" type="goog.vec.Quaternion.AnyType">The first quaternion.</param>
            /// <param name="q1" type="goog.vec.Quaternion.AnyType">The second quaternion.</param>
            /// <param name="t" type="number">The interpolating coefficient.</param>
            /// <param name="resultQuat" type="goog.vec.Quaternion.AnyType">The quaternion to
            ///     receive the result.</param>
            /// <returns type="goog.vec.Quaternion.AnyType">Return q so that
            ///     operations can be chained together.</returns>
        }
        
    };

    var $x = window.goog.vec.Quaternion;
    $x.__namespace = "true";
    $x.__typeName = "goog.vec.Quaternion";
})(this);
