
/* vsdoc for goog.vec.Vec3 */

(function (window) {
    window.goog.vec = window.goog.vec || {};

    window.goog.vec.Vec3 = {
        /// <summary></summary>
        /// <field name="cloneFloat32" type="!goog.vec.Vec3.Float32">Creates a clone of the given 3 element Float32 vector.</field>
        /// <field name="cloneFloat64" type="!goog.vec.Vec3.Float64">Creates a clone of the given 3 element vector.</field>
        /// <returns type="goog.vec.Vec3"/>
                
        createFloat32: function() {
            /// <summary>Creates a 3 element vector of Float32. The array is initialized to zero.</summary>
            /// <returns type="!goog.vec.Vec3.Float32">The new 3 element array.</returns>
        }, 
        
        createFloat64: function() {
            /// <summary>Creates a 3 element vector of Float64. The array is initialized to zero.</summary>
            /// <returns type="!goog.vec.Vec3.Float64">The new 3 element array.</returns>
        }, 
        
        createNumber: function() {
            /// <summary>Creates a 3 element vector of Number. The array is initialized to zero.</summary>
            /// <returns type="!goog.vec.Vec3.Number">The new 3 element array.</returns>
        }, 
        
        create: function() {
            /// <summary>Creates a 3 element vector of Float32Array. The array is initialized to zero.</summary>
            /// <returns type="!goog.vec.Vec3.Type">The new 3 element array.</returns>
        }, 
        
        createFloat32FromArray: function(vec) {
            /// <summary>Creates a new 3 element FLoat32 vector initialized with the value from the
            /// given array.</summary>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The source 3 element array.</param>
            /// <returns type="!goog.vec.Vec3.Float32">The new 3 element array.</returns>
        }, 
        
        createFloat32FromValues: function(v0, v1, v2) {
            /// <summary>Creates a new 3 element Float32 vector initialized with the supplied values.</summary>
            /// <param name="v0" type="number">The value for element at index 0.</param>
            /// <param name="v1" type="number">The value for element at index 1.</param>
            /// <param name="v2" type="number">The value for element at index 2.</param>
            /// <returns type="!goog.vec.Vec3.Float32">The new vector.</returns>
        }, 
        
        createFloat64FromArray: function(vec) {
            /// <summary>Creates a new 3 element Float64 vector initialized with the value from the
            /// given array.</summary>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The source 3 element array.</param>
            /// <returns type="!goog.vec.Vec3.Float64">The new 3 element array.</returns>
        }, 
        
        createFloat64FromValues: function(v0, v1, v2) {
            /// <summary>Creates a new 3 element Float64 vector initialized with the supplied values.</summary>
            /// <param name="v0" type="number">The value for element at index 0.</param>
            /// <param name="v1" type="number">The value for element at index 1.</param>
            /// <param name="v2" type="number">The value for element at index 2.</param>
            /// <returns type="!goog.vec.Vec3.Float64">The new vector.</returns>
        }, 
        
        createFromArray: function(vec) {
            /// <summary>Creates a new 3 element vector initialized with the value from the given
            /// array.</summary>
            /// <param name="vec" type="goog.vec.Vec3.Vec3Like">The source 3 element array.</param>
            /// <returns type="!goog.vec.Vec3.Type">The new 3 element array.</returns>
        }, 
        
        createFromValues: function(v0, v1, v2) {
            /// <summary>Creates a new 3 element vector initialized with the supplied values.</summary>
            /// <param name="v0" type="number">The value for element at index 0.</param>
            /// <param name="v1" type="number">The value for element at index 1.</param>
            /// <param name="v2" type="number">The value for element at index 2.</param>
            /// <returns type="!goog.vec.Vec3.Type">The new vector.</returns>
        }, 
        
        clone: function(vec) {
            /// <summary>Creates a clone of the given 3 element vector.</summary>
            /// <param name="vec" type="goog.vec.Vec3.Vec3Like">The source 3 element vector.</param>
            /// <returns type="!goog.vec.Vec3.Type">The new cloned vector.</returns>
        }, 
        
        setFromValues: function(vec, v0, v1, v2) {
            /// <summary>Initializes the vector with the given values.</summary>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector to receive the values.</param>
            /// <param name="v0" type="number">The value for element at index 0.</param>
            /// <param name="v1" type="number">The value for element at index 1.</param>
            /// <param name="v2" type="number">The value for element at index 2.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return vec so that operations can be
            ///     chained together.</returns>
        }, 
        
        setFromArray: function(vec, values) {
            /// <summary>Initializes the vector with the given array of values.</summary>
            /// <param name="vec" type="goog.vec.Vec3.AnyType">The vector to receive the
            ///     values.</param>
            /// <param name="values" type="goog.vec.Vec3.AnyType">The array of values.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return vec so that operations can be
            ///     chained together.</returns>
        }, 
        
        add: function(vec0, vec1, resultVec) {
            /// <summary>Performs a component-wise addition of vec0 and vec1 together storing the
            /// result into resultVec.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The first addend.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The second addend.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the result. May be vec0 or vec1.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        subtract: function(vec0, vec1, resultVec) {
            /// <summary>Performs a component-wise subtraction of vec1 from vec0 storing the
            /// result into resultVec.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The minuend.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">The subtrahend.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the result. May be vec0 or vec1.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        negate: function(vec0, resultVec) {
            /// <summary>Negates vec0, storing the result into resultVec.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector to negate.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the result. May be vec0.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        scale: function(vec0, scalar, resultVec) {
            /// <summary>Multiplies each component of vec0 with scalar storing the product into
            /// resultVec.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The source vector.</param>
            /// <param name="scalar" type="number">The value to multiply with each component of vec0.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the result. May be vec0.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        magnitudeSquared: function(vec0) {
            /// <summary>Returns the magnitudeSquared of the given vector.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector.</param>
            /// <returns type="number">The magnitude of the vector.</returns>
        }, 
        
        magnitude: function(vec0) {
            /// <summary>Returns the magnitude of the given vector.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector.</param>
            /// <returns type="number">The magnitude of the vector.</returns>
        }, 
        
        normalize: function(vec0, resultVec) {
            /// <summary>Normalizes the given vector storing the result into resultVec.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">The vector to normalize.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to
            ///     receive the result. May be vec0.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        dot: function(v0, v1) {
            /// <summary>Returns the scalar product of vectors v0 and v1.</summary>
            /// <param name="v0" type="goog.vec.Vec3.AnyType">The first vector.</param>
            /// <param name="v1" type="goog.vec.Vec3.AnyType">The second vector.</param>
            /// <returns type="number">The scalar product.</returns>
        }, 
        
        cross: function(v0, v1, resultVec) {
            /// <summary>Computes the vector (cross) product of v0 and v1 storing the result into
            /// resultVec.</summary>
            /// <param name="v0" type="goog.vec.Vec3.AnyType">The first vector.</param>
            /// <param name="v1" type="goog.vec.Vec3.AnyType">The second vector.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to receive the
            ///     results. May be either v0 or v1.</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        distanceSquared: function(vec0, vec1) {
            /// <summary>Returns the squared distance between two points.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">First point.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">Second point.</param>
            /// <returns type="number">The squared distance between the points.</returns>
        }, 
        
        distance: function(vec0, vec1) {
            /// <summary>Returns the distance between two points.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">First point.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">Second point.</param>
            /// <returns type="number">The distance between the points.</returns>
        }, 
        
        direction: function(vec0, vec1, resultVec) {
            /// <summary>Returns a unit vector pointing from one point to another.
            /// If the input points are equal then the result will be all zeros.</summary>
            /// <param name="vec0" type="goog.vec.Vec3.AnyType">Origin point.</param>
            /// <param name="vec1" type="goog.vec.Vec3.AnyType">Target point.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to receive the
            ///     results (may be vec0 or vec1).</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        lerp: function(v0, v1, f, resultVec) {
            /// <summary>Linearly interpolate from vec0 to v1 according to f. The value of f should be
            /// in the range [0..1] otherwise the results are undefined.</summary>
            /// <param name="v0" type="goog.vec.Vec3.AnyType">The first vector.</param>
            /// <param name="v1" type="goog.vec.Vec3.AnyType">The second vector.</param>
            /// <param name="f" type="number">The interpolation factor.</param>
            /// <param name="resultVec" type="goog.vec.Vec3.AnyType">The vector to receive the
            ///     results (may be v0 or v1).</param>
            /// <returns type="!goog.vec.Vec3.AnyType">return resultVec so that operations can be
            ///     chained together.</returns>
        }, 
        
        equals: function(v0, v1) {
            /// <summary>Returns true if the components of v0 are equal to the components of v1.</summary>
            /// <param name="v0" type="goog.vec.Vec3.AnyType">The first vector.</param>
            /// <param name="v1" type="goog.vec.Vec3.AnyType">The second vector.</param>
            /// <returns type="boolean">True if the vectors are equal, false otherwise.</returns>
        }
        
    };

    var $x = window.goog.vec.Vec3;
    $x.__namespace = "true";
    $x.__typeName = "goog.vec.Vec3";
})(this);
