
/* vsdoc for goog.window */

(function (window) {
    window.goog = window.goog || {};

    window.goog.window = {
        /// <summary></summary>
        /// <field name="DEFAULT_POPUP_HEIGHT" type="number">Default height for popup windows</field>
        /// <field name="DEFAULT_POPUP_WIDTH" type="number">Default width for popup windows</field>
        /// <field name="DEFAULT_POPUP_TARGET" type="string">Default target for popup windows</field>
        /// <returns type="goog.window"/>
                
        open: function(linkRef, opt_options, opt_parentWin) {
            /// <summary>Opens a new window.</summary>
            /// <param name="linkRef" type="string|Object">A string or an object that supports toString,
            ///     for example goog.Uri.  If this is an object with a &apos;href&apos; attribute, such
            ///     as HTMLAnchorElement, it will be used instead.</param>
            /// <param name="opt_options" type="Object=">supports the following options:
            ///  &apos;target&apos;: (string) target (window name). If null, linkRef.target will
            ///          be used.
            ///  &apos;width&apos;: (number) window width.
            ///  &apos;height&apos;: (number) window height.
            ///  &apos;top&apos;: (number) distance from top of screen
            ///  &apos;left&apos;: (number) distance from left of screen
            ///  &apos;toolbar&apos;: (boolean) show toolbar
            ///  &apos;scrollbars&apos;: (boolean) show scrollbars
            ///  &apos;location&apos;: (boolean) show location
            ///  &apos;statusbar&apos;: (boolean) show statusbar
            ///  &apos;menubar&apos;: (boolean) show menubar
            ///  &apos;resizable&apos;: (boolean) resizable
            ///  &apos;noreferrer&apos;: (boolean) whether to attempt to remove the referrer header
            ///      from the request headers. Does this by opening a blank window that
            ///      then redirects to the target url, so users may see some flickering.</param>
            /// <param name="opt_parentWin" type="Window=">Parent window that should be used to open the
            ///                 new window.</param>
            /// <returns type="Window">Returns the window object that was opened. This returns
            ///                  null if a popup blocker prevented the window from being
            ///                  opened.</returns>
        }, 
        
        openBlank: function(opt_message, opt_options, opt_parentWin) {
            /// <summary>Opens a new window without any real content in it.
            /// 
            /// This can be used to get around popup blockers if you need to open a window
            /// in response to a user event, but need to do asynchronous work to determine
            /// the URL to open, and then set the URL later.
            /// 
            /// Example usage:
            /// 
            /// var newWin = goog.window.openBlank(&apos;Loading...&apos;);
            /// setTimeout(
            ///     function() {
            ///       newWin.location.href = &apos;http://www.google.com&apos;;
            ///     }, 100);</summary>
            /// <param name="opt_message" type="string=">String to show in the new window. This string
            ///     will be HTML-escaped to avoid XSS issues.</param>
            /// <param name="opt_options" type="Object=">Options to open window with.
            ///     {@see goog.window.open for exact option semantics}.</param>
            /// <param name="opt_parentWin" type="Window=">Parent window that should be used to open the
            ///                 new window.</param>
            /// <returns type="Window">Returns the window object that was opened. This returns
            ///                  null if a popup blocker prevented the window from being
            ///                  opened.</returns>
        }, 
        
        popup: function(linkRef, opt_options) {
            /// <summary>Raise a help popup window, defaulting to &quot;Google standard&quot; size and name.
            /// 
            /// (If your project is using GXPs, consider using {@link PopUpLink.gxp}.)</summary>
            /// <param name="linkRef" type="string|Object">if this is a string, it will be used as the
            /// URL of the popped window; otherwise it&apos;s assumed to be an HTMLAnchorElement
            /// (or some other object with &quot;target&quot; and &quot;href&quot; properties).</param>
            /// <param name="opt_options" type="Object=">Options to open window with.
            ///     {@see goog.window.open for exact option semantics}
            ///     Additional wrinkles to the options:
            ///     - if &apos;target&apos; field is null, linkRef.target will be used. If *that&apos;s*
            ///     null, the default is &quot;google_popup&quot;.
            ///     - if &apos;width&apos; field is not specified, the default is 690.
            ///     - if &apos;height&apos; field is not specified, the default is 500.</param>
            /// <returns type="boolean">true if the window was not popped up, false if it was.</returns>
        }
        
    };

    var $x = window.goog.window;
    $x.__namespace = "true";
    $x.__typeName = "goog.window";
})(this);
